// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3danimation_python.h"

// main header
#include "qt3danimation_qadditiveclipblend_wrapper.h"

// Argument includes
#include <Qt3DAnimation/qabstractclipblendnode.h>
#include <Qt3DCore/qnode.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DAnimation;

// Native ---------------------------------------------------------

void QAdditiveClipBlendWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAdditiveClipBlendWrapper::QAdditiveClipBlendWrapper(::Qt3DCore::QNode * parent) : Qt3DAnimation::QAdditiveClipBlend(parent)
{
}

void QAdditiveClipBlendWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAdditiveClipBlend", funcName);
        return;
    }
}

void QAdditiveClipBlendWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAdditiveClipBlend", funcName);
        return;
    }
}

void QAdditiveClipBlendWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAdditiveClipBlend", funcName);
        return;
    }
}

void QAdditiveClipBlendWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAdditiveClipBlend", funcName);
        return;
    }
}

bool QAdditiveClipBlendWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAdditiveClipBlend", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAdditiveClipBlend", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAdditiveClipBlendWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAdditiveClipBlend", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAdditiveClipBlend", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAdditiveClipBlendWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAdditiveClipBlend", funcName);
        return;
    }
}

const QMetaObject *QAdditiveClipBlendWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DAnimation::QAdditiveClipBlend::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAdditiveClipBlendWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DAnimation::QAdditiveClipBlend::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAdditiveClipBlendWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAdditiveClipBlendWrapper *>(this));
    return Qt3DAnimation::QAdditiveClipBlend::qt_metacast(_clname);
}

QAdditiveClipBlendWrapper::~QAdditiveClipBlendWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DAnimation_QAdditiveClipBlend_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DAnimation::QAdditiveClipBlend >()))
        return -1;

    QAdditiveClipBlendWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QAdditiveClipBlend", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAdditiveClipBlend::QAdditiveClipBlend(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QAdditiveClipBlend(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QAdditiveClipBlend(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAdditiveClipBlend(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QAdditiveClipBlendWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QAdditiveClipBlendWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DAnimation::QAdditiveClipBlend >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DAnimation_QAdditiveClipBlendFunc_additiveClip(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QAdditiveClipBlend *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // additiveClip()const
        Qt3DAnimation::QAbstractClipBlendNode * cppResult = const_cast<const ::Qt3DAnimation::QAdditiveClipBlend *>(cppSelf)->additiveClip();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAbstractClipBlendNode_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QAdditiveClipBlendFunc_additiveFactor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QAdditiveClipBlend *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // additiveFactor()const
        float cppResult = const_cast<const ::Qt3DAnimation::QAdditiveClipBlend *>(cppSelf)->additiveFactor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QAdditiveClipBlendFunc_baseClip(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QAdditiveClipBlend *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // baseClip()const
        Qt3DAnimation::QAbstractClipBlendNode * cppResult = const_cast<const ::Qt3DAnimation::QAdditiveClipBlend *>(cppSelf)->baseClip();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAbstractClipBlendNode_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QAdditiveClipBlendFunc_setAdditiveClip(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QAdditiveClipBlend *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAdditiveClipBlend::setAdditiveClip(Qt3DAnimation::QAbstractClipBlendNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAbstractClipBlendNode_IDX]), (pyArg)))) {
        overloadId = 0; // setAdditiveClip(Qt3DAnimation::QAbstractClipBlendNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAdditiveClip", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DAnimation::QAbstractClipBlendNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAdditiveClip(Qt3DAnimation::QAbstractClipBlendNode*)
            cppSelf->setAdditiveClip(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DAnimation_QAdditiveClipBlendFunc_setAdditiveFactor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QAdditiveClipBlend *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAdditiveClipBlend::setAdditiveFactor(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setAdditiveFactor(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAdditiveFactor", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAdditiveFactor(float)
            cppSelf->setAdditiveFactor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DAnimation_QAdditiveClipBlendFunc_setBaseClip(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QAdditiveClipBlend *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAdditiveClipBlend::setBaseClip(Qt3DAnimation::QAbstractClipBlendNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAbstractClipBlendNode_IDX]), (pyArg)))) {
        overloadId = 0; // setBaseClip(Qt3DAnimation::QAbstractClipBlendNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBaseClip", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DAnimation::QAbstractClipBlendNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBaseClip(Qt3DAnimation::QAbstractClipBlendNode*)
            cppSelf->setBaseClip(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_Qt3DAnimation_QAdditiveClipBlend_PropertyStrings[] = {
    "additiveClip::",
    "additiveFactor::",
    "baseClip::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DAnimation_QAdditiveClipBlend_methods[] = {
    {"additiveClip", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAdditiveClipBlendFunc_additiveClip), METH_NOARGS, nullptr},
    {"additiveFactor", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAdditiveClipBlendFunc_additiveFactor), METH_NOARGS, nullptr},
    {"baseClip", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAdditiveClipBlendFunc_baseClip), METH_NOARGS, nullptr},
    {"setAdditiveClip", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAdditiveClipBlendFunc_setAdditiveClip), METH_O, nullptr},
    {"setAdditiveFactor", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAdditiveClipBlendFunc_setAdditiveFactor), METH_O, nullptr},
    {"setBaseClip", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAdditiveClipBlendFunc_setBaseClip), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DAnimation_QAdditiveClipBlend_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DAnimation::QAdditiveClipBlend *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAdditiveClipBlendWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DAnimation_QAdditiveClipBlend_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DAnimation_QAdditiveClipBlend_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DAnimation_QAdditiveClipBlend_Type = nullptr;
static PyTypeObject *Sbk_Qt3DAnimation_QAdditiveClipBlend_TypeF(void)
{
    return _Sbk_Qt3DAnimation_QAdditiveClipBlend_Type;
}

static PyType_Slot Sbk_Qt3DAnimation_QAdditiveClipBlend_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAdditiveClipBlend_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAdditiveClipBlend_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAdditiveClipBlend_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAdditiveClipBlend_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAdditiveClipBlend_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DAnimation_QAdditiveClipBlend_spec = {
    "2:PySide6.Qt3DAnimation.Qt3DAnimation.QAdditiveClipBlend",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DAnimation_QAdditiveClipBlend_slots
};

} //extern "C"

static void *Sbk_Qt3DAnimation_QAdditiveClipBlend_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DAnimation::QAdditiveClipBlend *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAdditiveClipBlend_PythonToCpp_QAdditiveClipBlend_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DAnimation_QAdditiveClipBlend_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAdditiveClipBlend_PythonToCpp_QAdditiveClipBlend_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DAnimation_QAdditiveClipBlend_TypeF()))
        return QAdditiveClipBlend_PythonToCpp_QAdditiveClipBlend_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAdditiveClipBlend_PTR_CppToPython_QAdditiveClipBlend(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DAnimation::QAdditiveClipBlend *>(const_cast<void *>(cppIn)), Sbk_Qt3DAnimation_QAdditiveClipBlend_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DAnimation_QAdditiveClipBlend_SignatureStrings[] = {
    "PySide6.Qt3DAnimation.Qt3DAnimation.QAdditiveClipBlend(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,baseClip:Qt3DAnimation.QAbstractClipBlendNode=None,additiveClip:Qt3DAnimation.QAbstractClipBlendNode=None,additiveFactor:float=None)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QAdditiveClipBlend.additiveClip(self)->PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QAdditiveClipBlend.additiveFactor(self)->float",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QAdditiveClipBlend.baseClip(self)->PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QAdditiveClipBlend.setAdditiveClip(self,additiveClip:PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QAdditiveClipBlend.setAdditiveFactor(self,additiveFactor:float)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QAdditiveClipBlend.setBaseClip(self,baseClip:PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode)",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DAnimation_QAdditiveClipBlend_SignatureByteSize = 205;
static constexpr uint8_t Qt3DAnimation_QAdditiveClipBlend_SignatureBytes[205] = {
    0x78, 0xda, 0xc5, 0x93, 0x41, 0x0a, 0xc2, 0x30, 0x10, 0x45, 0xf7, 0x9e, 0xc4, 0x4a, 0xed, 0x46,
    0x70, 0x11, 0xa8, 0xd0, 0x2a, 0x6e, 0x84, 0x5a, 0xf1, 0x04, 0xa9, 0x99, 0x42, 0x20, 0x66, 0x4a,
    0x32, 0x2a, 0xbd, 0xbd, 0x12, 0xa9, 0xc6, 0xd2, 0x85, 0xa4, 0x82, 0xbb, 0x84, 0x61, 0xfe, 0xbc,
    0xff, 0x27, 0x29, 0xdb, 0xa3, 0x14, 0xb0, 0x4c, 0x0e, 0xb4, 0xd8, 0x64, 0x5a, 0x9e, 0x39, 0x49,
    0xd4, 0xfd, 0x5b, 0x26, 0x84, 0x24, 0x79, 0x85, 0xb5, 0x92, 0x4d, 0xae, 0x40, 0x8b, 0xa9, 0x05,
    0x55, 0xc7, 0x0d, 0x37, 0xa0, 0x89, 0x95, 0x9e, 0xc4, 0x1a, 0x0d, 0x78, 0x87, 0x02, 0x05, 0xa4,
    0xfa, 0xa2, 0x54, 0x43, 0x26, 0x9e, 0xb1, 0x1d, 0xb4, 0x37, 0x34, 0x62, 0xaf, 0x55, 0x9b, 0x16,
    0xa8, 0x21, 0xae, 0xb8, 0x75, 0xa2, 0xac, 0x3f, 0xb0, 0xb2, 0x64, 0xf8, 0x89, 0x5e, 0x03, 0x9d,
    0x90, 0x6b, 0xe1, 0x1e, 0x4b, 0x40, 0xdb, 0xf6, 0x51, 0x46, 0xc3, 0x6a, 0x85, 0x9c, 0x5c, 0x25,
    0x9a, 0x94, 0x41, 0x11, 0x24, 0x3e, 0x88, 0xcb, 0x23, 0x9a, 0xaf, 0xbe, 0x93, 0x1a, 0xa2, 0x1c,
    0x4b, 0xf1, 0xf4, 0xd5, 0x71, 0x38, 0x7b, 0xa1, 0x92, 0xdd, 0x52, 0xfe, 0x67, 0xca, 0x02, 0x65,
    0xfd, 0x74, 0x3f, 0x17, 0x1f, 0xce, 0x14, 0xfd, 0x00, 0xca, 0x0b, 0x7b, 0xf0, 0x61, 0x8d, 0x99,
    0x91, 0xfb, 0xe9, 0xbf, 0x3f, 0xc8, 0x18, 0xc3, 0x77, 0x6d, 0xbb, 0x69, 0xe0
};
#endif

PyTypeObject *init_Qt3DAnimation_QAdditiveClipBlend(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX].type != nullptr)
        return SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DAnimation_QAdditiveClipBlend_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAbstractClipBlendNode_IDX]))));

    _Sbk_Qt3DAnimation_QAdditiveClipBlend_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QAdditiveClipBlend",
        "Qt3DAnimation::QAdditiveClipBlend*",
        &Sbk_Qt3DAnimation_QAdditiveClipBlend_spec,
        &Shiboken::callCppDestructor< Qt3DAnimation::QAdditiveClipBlend >,
        Sbk_Qt3DAnimation_QAdditiveClipBlend_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DAnimation_QAdditiveClipBlend_TypeF(); // references _Sbk_Qt3DAnimation_QAdditiveClipBlend_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DAnimation_QAdditiveClipBlend_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DAnimation_QAdditiveClipBlend_SignatureBytes, Qt3DAnimation_QAdditiveClipBlend_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DAnimation_QAdditiveClipBlend_PropertyStrings);
    SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAdditiveClipBlend_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAdditiveClipBlend_PythonToCpp_QAdditiveClipBlend_PTR,
        is_QAdditiveClipBlend_PythonToCpp_QAdditiveClipBlend_PTR_Convertible,
        QAdditiveClipBlend_PTR_CppToPython_QAdditiveClipBlend);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QAdditiveClipBlend");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QAdditiveClipBlend*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QAdditiveClipBlend&");
    Shiboken::Conversions::registerConverterAlias(converter, "QAdditiveClipBlend");
    Shiboken::Conversions::registerConverterAlias(converter, "QAdditiveClipBlend*");
    Shiboken::Conversions::registerConverterAlias(converter, "QAdditiveClipBlend&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DAnimation::QAdditiveClipBlend).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAdditiveClipBlendWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DAnimation_QAdditiveClipBlend_TypeF(), &Sbk_Qt3DAnimation_QAdditiveClipBlend_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Qt3DAnimation::QAdditiveClipBlend::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DAnimation::QAdditiveClipBlend::staticMetaObject, sizeof(QAdditiveClipBlendWrapper));

    return pyType;
}
