// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3danimation_python.h"

// main header
#include "qt3danimation_qchannelcomponent_wrapper.h"

// Argument includes
#include <QString>
#include <Qt3DAnimation/qchannelcomponent.h>
#include <Qt3DAnimation/qkeyframe.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DAnimation;


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DAnimation_QChannelComponent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DAnimation::QChannelComponent >()))
        return -1;

    ::Qt3DAnimation::QChannelComponent *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QChannelComponent", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QChannelComponent::QChannelComponent()
    // 1: QChannelComponent::QChannelComponent(QString)
    // 2: QChannelComponent::QChannelComponent(Qt3DAnimation::QChannelComponent)
    if (numArgs == 0) {
        overloadId = 0; // QChannelComponent()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QChannelComponent(Qt3DAnimation::QChannelComponent)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // QChannelComponent(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QChannelComponent()
        {

            // QChannelComponent()
            cptr = new ::Qt3DAnimation::QChannelComponent();
            break;
        }
        case 1: // QChannelComponent(const QString &name)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QChannelComponent(QString)
                cptr = new ::Qt3DAnimation::QChannelComponent(cppArg0);
            }
            break;
        }
        case 2: // QChannelComponent(const Qt3DAnimation::QChannelComponent &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Qt3DAnimation::QChannelComponent cppArg0_local;
            ::Qt3DAnimation::QChannelComponent *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QChannelComponent(Qt3DAnimation::QChannelComponent)
                cptr = new ::Qt3DAnimation::QChannelComponent(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Qt3DAnimation::QChannelComponent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Qt3DAnimation_QChannelComponentFunc_appendKeyFrame(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QChannelComponent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChannelComponent::appendKeyFrame(Qt3DAnimation::QKeyFrame)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), (pyArg)))) {
        overloadId = 0; // appendKeyFrame(Qt3DAnimation::QKeyFrame)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "appendKeyFrame", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DAnimation::QKeyFrame *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // appendKeyFrame(Qt3DAnimation::QKeyFrame)
            cppSelf->appendKeyFrame(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DAnimation_QChannelComponentFunc_begin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QChannelComponent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // begin()const
        const Qt3DAnimation::QKeyFrame * cppResult = const_cast<const ::Qt3DAnimation::QChannelComponent *>(cppSelf)->begin();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QChannelComponentFunc_cbegin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QChannelComponent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cbegin()const
        const Qt3DAnimation::QKeyFrame * cppResult = const_cast<const ::Qt3DAnimation::QChannelComponent *>(cppSelf)->cbegin();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QChannelComponentFunc_cend(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QChannelComponent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cend()const
        const Qt3DAnimation::QKeyFrame * cppResult = const_cast<const ::Qt3DAnimation::QChannelComponent *>(cppSelf)->cend();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QChannelComponentFunc_clearKeyFrames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QChannelComponent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearKeyFrames()
        cppSelf->clearKeyFrames();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DAnimation_QChannelComponentFunc_end(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QChannelComponent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // end()const
        const Qt3DAnimation::QKeyFrame * cppResult = const_cast<const ::Qt3DAnimation::QChannelComponent *>(cppSelf)->end();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QChannelComponentFunc_insertKeyFrame(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QChannelComponent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertKeyFrame", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QChannelComponent::insertKeyFrame(int,Qt3DAnimation::QKeyFrame)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insertKeyFrame(int,Qt3DAnimation::QKeyFrame)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertKeyFrame", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::Qt3DAnimation::QKeyFrame *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertKeyFrame(int,Qt3DAnimation::QKeyFrame)
            cppSelf->insertKeyFrame(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DAnimation_QChannelComponentFunc_keyFrameCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QChannelComponent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // keyFrameCount()const
        int cppResult = const_cast<const ::Qt3DAnimation::QChannelComponent *>(cppSelf)->keyFrameCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QChannelComponentFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QChannelComponent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::Qt3DAnimation::QChannelComponent *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QChannelComponentFunc_removeKeyFrame(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QChannelComponent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChannelComponent::removeKeyFrame(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // removeKeyFrame(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeKeyFrame", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeKeyFrame(int)
            cppSelf->removeKeyFrame(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DAnimation_QChannelComponentFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QChannelComponent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChannelComponent::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", errInfo, SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QString)
            cppSelf->setName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DAnimation_QChannelComponent__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::Qt3DAnimation::QChannelComponent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DAnimation_QChannelComponent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DAnimation_QChannelComponent_methods[] = {
    {"appendKeyFrame", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QChannelComponentFunc_appendKeyFrame), METH_O, nullptr},
    {"begin", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QChannelComponentFunc_begin), METH_NOARGS, nullptr},
    {"cbegin", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QChannelComponentFunc_cbegin), METH_NOARGS, nullptr},
    {"cend", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QChannelComponentFunc_cend), METH_NOARGS, nullptr},
    {"clearKeyFrames", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QChannelComponentFunc_clearKeyFrames), METH_NOARGS, nullptr},
    {"end", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QChannelComponentFunc_end), METH_NOARGS, nullptr},
    {"insertKeyFrame", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QChannelComponentFunc_insertKeyFrame), METH_VARARGS, nullptr},
    {"keyFrameCount", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QChannelComponentFunc_keyFrameCount), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QChannelComponentFunc_name), METH_NOARGS, nullptr},
    {"removeKeyFrame", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QChannelComponentFunc_removeKeyFrame), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QChannelComponentFunc_setName), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QChannelComponent__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_Qt3DAnimation_QChannelComponent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DAnimation_QChannelComponent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DAnimation_QChannelComponent_Type = nullptr;
static PyTypeObject *Sbk_Qt3DAnimation_QChannelComponent_TypeF(void)
{
    return _Sbk_Qt3DAnimation_QChannelComponent_Type;
}

static PyType_Slot Sbk_Qt3DAnimation_QChannelComponent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DAnimation_QChannelComponent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DAnimation_QChannelComponent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DAnimation_QChannelComponent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DAnimation_QChannelComponent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DAnimation_QChannelComponent_spec = {
    "2:PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DAnimation_QChannelComponent_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QChannelComponent_PythonToCpp_QChannelComponent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DAnimation_QChannelComponent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QChannelComponent_PythonToCpp_QChannelComponent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DAnimation_QChannelComponent_TypeF()))
        return QChannelComponent_PythonToCpp_QChannelComponent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QChannelComponent_PTR_CppToPython_QChannelComponent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_Qt3DAnimation_QChannelComponent_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QChannelComponent_COPY_CppToPython_QChannelComponent(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::Qt3DAnimation::QChannelComponent *>(cppIn);
    return Shiboken::Object::newObject(Sbk_Qt3DAnimation_QChannelComponent_TypeF(), new ::Qt3DAnimation::QChannelComponent(*source), true, true);
}

// Python to C++ copy conversion.
static void QChannelComponent_PythonToCpp_QChannelComponent_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::Qt3DAnimation::QChannelComponent *>(cppOut) = *reinterpret_cast< ::Qt3DAnimation::QChannelComponent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QChannelComponent_PythonToCpp_QChannelComponent_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DAnimation_QChannelComponent_TypeF()))
        return QChannelComponent_PythonToCpp_QChannelComponent_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DAnimation_QChannelComponent_SignatureStrings[] = {
    "2:PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent(self)",
    "1:PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent(self,name:QString)",
    "0:PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent(self,arg__1:PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent.appendKeyFrame(self,kf:PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent.begin(self)->PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent.cbegin(self)->PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent.cend(self)->PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent.clearKeyFrames(self)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent.end(self)->PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent.insertKeyFrame(self,index:int,kf:PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent.keyFrameCount(self)->int",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent.name(self)->QString",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent.removeKeyFrame(self,index:int)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent.setName(self,name:QString)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DAnimation_QChannelComponent_SignatureByteSize = 229;
static constexpr uint8_t Qt3DAnimation_QChannelComponent_SignatureBytes[229] = {
    0x78, 0xda, 0xbd, 0x94, 0x4f, 0x0b, 0x82, 0x40, 0x10, 0xc5, 0xef, 0x7e, 0x92, 0x84, 0x94, 0xfe,
    0x40, 0x07, 0x0f, 0x41, 0x18, 0x5d, 0x82, 0x48, 0xfc, 0x00, 0xcb, 0x96, 0xa3, 0x2d, 0xea, 0xec,
    0xb2, 0x6e, 0x91, 0xdf, 0xbe, 0x05, 0xdd, 0xc0, 0x20, 0xa8, 0x11, 0x3c, 0xce, 0xe1, 0xfd, 0xde,
    0x7b, 0xbb, 0xc3, 0xac, 0xa2, 0x73, 0x9b, 0x8a, 0x0c, 0x36, 0x61, 0x62, 0xd6, 0xfb, 0x1d, 0x8a,
    0x9a, 0x1b, 0x21, 0xf1, 0x73, 0x8a, 0x6f, 0x1c, 0x11, 0xaa, 0x58, 0xd6, 0x4a, 0x22, 0xa0, 0x99,
    0x35, 0x50, 0xe5, 0xbe, 0xb7, 0x1c, 0xa1, 0x9e, 0x23, 0xaf, 0x21, 0x4a, 0x52, 0xa3, 0x05, 0x16,
    0xbe, 0xb7, 0x18, 0x83, 0xe2, 0xba, 0x60, 0x8c, 0x18, 0xc6, 0xf7, 0x48, 0xb2, 0x90, 0x2b, 0x05,
    0x98, 0x1d, 0xa1, 0x3d, 0x68, 0x5b, 0xa4, 0xcb, 0x51, 0xe6, 0xbf, 0x65, 0x70, 0x2a, 0xaa, 0xf7,
    0x05, 0x0a, 0x81, 0xdd, 0x1f, 0x04, 0xdb, 0xbf, 0x1c, 0x89, 0x86, 0xd7, 0xe9, 0x1d, 0xed, 0xe3,
    0x4e, 0xea, 0x57, 0x01, 0xd7, 0x8e, 0xd1, 0xf4, 0xfb, 0x4d, 0x43, 0x4d, 0x9c, 0x5c, 0x60, 0x03,
    0xda, 0x0c, 0x17, 0x51, 0x60, 0x06, 0xcf, 0x48, 0xa0, 0x99, 0x6c, 0x25, 0xcb, 0x5e, 0x1f, 0xcb,
    0xbb, 0x3b, 0x0f, 0xc1, 0xd6, 0x06, 0x20, 0xe2, 0xd0, 0x55, 0xb1, 0x94, 0xfe, 0x46, 0x10, 0x49,
    0x1a, 0x6a, 0xf9, 0x80, 0x2f, 0xcf, 0x43, 0x6d, 0xdb, 0x80, 0x39, 0xbd, 0x69, 0xc3, 0x43, 0x46,
    0x03, 0x32, 0x76, 0x95, 0xaa, 0x65, 0xcc, 0x75, 0x36, 0xad, 0xb2, 0xb4, 0x30, 0xb5, 0x93, 0xf7,
    0x02, 0x0b, 0xca, 0x07, 0x0a
};
#endif

PyTypeObject *init_Qt3DAnimation_QChannelComponent(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX].type != nullptr)
        return SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DAnimation_QChannelComponent_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_Qt3DAnimation_QChannelComponent_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QChannelComponent",
        "Qt3DAnimation::QChannelComponent",
        &Sbk_Qt3DAnimation_QChannelComponent_spec,
        &Shiboken::callCppDestructor< ::Qt3DAnimation::QChannelComponent >,
        Sbk_Qt3DAnimation_QChannelComponent_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_Qt3DAnimation_QChannelComponent_TypeF(); // references _Sbk_Qt3DAnimation_QChannelComponent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DAnimation_QChannelComponent_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DAnimation_QChannelComponent_SignatureBytes, Qt3DAnimation_QChannelComponent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DAnimation_QChannelComponent_PropertyStrings);
    SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QChannelComponent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QChannelComponent_PythonToCpp_QChannelComponent_PTR,
        is_QChannelComponent_PythonToCpp_QChannelComponent_PTR_Convertible,
        QChannelComponent_PTR_CppToPython_QChannelComponent,
        QChannelComponent_COPY_CppToPython_QChannelComponent);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QChannelComponent");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QChannelComponent*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QChannelComponent&");
    Shiboken::Conversions::registerConverterAlias(converter, "QChannelComponent");
    Shiboken::Conversions::registerConverterAlias(converter, "QChannelComponent*");
    Shiboken::Conversions::registerConverterAlias(converter, "QChannelComponent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DAnimation::QChannelComponent).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QChannelComponent_PythonToCpp_QChannelComponent_COPY,
        is_QChannelComponent_PythonToCpp_QChannelComponent_COPY_Convertible);

    qRegisterMetaType< ::Qt3DAnimation::QChannelComponent >("QChannelComponent");
    qRegisterMetaType< ::Qt3DAnimation::QChannelComponent >("Qt3DAnimation::QChannelComponent");

    return pyType;
}
