// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1


// module include
#include "pyside6_qt3dcore_python.h"

// main header
#include "qsharedpointer_qaspectjob_wrapper.h"

// Extra includes
#include <Qt3DCore/qaspectjob.h>
#include <sbksmartpointer.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DCore_QAspectJobPtr_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSharedPointer<Qt3DCore::QAspectJob> >()))
        return -1;

    ::QSharedPointer<Qt3DCore::QAspectJob> *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAspectJobPtr", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAspectJobPtr::QAspectJobPtr()
    // 1: QAspectJobPtr::QAspectJobPtr(Qt3DCore::QAspectJob*)
    if (numArgs == 0) {
        overloadId = 0; // QAspectJobPtr()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAspectJob_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QAspectJobPtr(Qt3DCore::QAspectJob*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAspectJobPtr()
        {

            // QAspectJobPtr()
            cptr = new ::QSharedPointer<Qt3DCore::QAspectJob>();
            break;
        }
        case 1: // QAspectJobPtr(Qt3DCore::QAspectJob *pointee)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Qt3DCore::QAspectJob *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAspectJobPtr(Qt3DCore::QAspectJob*)
                cptr = new ::QSharedPointer<Qt3DCore::QAspectJob>(cppArg0);

                // Ownership transferences.
                Shiboken::Object::releaseOwnership(pyArgs[0]);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSharedPointer<Qt3DCore::QAspectJob> >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Qt3DCore_QAspectJobPtrFunc_reset(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSharedPointer<Qt3DCore::QAspectJob> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "reset", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAspectJobPtr::reset()
    // 1: QAspectJobPtr::reset(Qt3DCore::QAspectJob*)
    if (numArgs == 0) {
        overloadId = 0; // reset()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAspectJob_IDX]), (pyArgs[0])))) {
        overloadId = 1; // reset(Qt3DCore::QAspectJob*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "reset", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // reset()
        {

            // reset()
            cppSelf->reset();
            break;
        }
        case 1: // reset(Qt3DCore::QAspectJob *t)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::Qt3DCore::QAspectJob *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // reset(Qt3DCore::QAspectJob*)
                cppSelf->reset(cppArg0);

                // Ownership transferences.
                Shiboken::Object::releaseOwnership(pyArgs[0]);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QAspectJobPtrFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSharedPointer<Qt3DCore::QAspectJob> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()const
        Qt3DCore::QAspectJob * cppResult = const_cast<const ::QSharedPointer<Qt3DCore::QAspectJob> *>(cppSelf)->data();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAspectJob_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAspectJobPtr__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSharedPointer<Qt3DCore::QAspectJob> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

extern "C"
{
static PyObject *Sbk_Qt3DCore_QAspectJobPtr__dir__(PyObject *self)
{
    Shiboken::AutoDecRef pointee(PyObject_CallMethod(self, "data", 0));
    return Shiboken::SmartPointer::dir(self, pointee);
}
} // extern C

static PyMethodDef Sbk_Qt3DCore_QAspectJobPtr_methods[] = {
    {"reset", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAspectJobPtrFunc_reset), METH_VARARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAspectJobPtrFunc_data), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAspectJobPtr__copy__), METH_NOARGS, nullptr},
    {"__dir__", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAspectJobPtr__dir__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_Qt3DCore_QAspectJobPtr_getattro(PyObject *self, PyObject *name)
{
    PyObject *tmp = PyObject_GenericGetAttr(self, name);
    if (tmp)
        return tmp;
    if (PyErr_ExceptionMatches(PyExc_AttributeError) == 0)
        return nullptr;
    PyErr_Clear();
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSharedPointer<Qt3DCore::QAspectJob> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    if (cppSelf->isNull()) {
        PyTypeObject *tp = Py_TYPE(self);
        PyErr_Format(PyExc_AttributeError, "Attempt to retrieve '%s' from null object '%s'.",
                     Shiboken::String::toCString(name), tp->tp_name);
        return nullptr;
    }
    // Try to find the 'name' attribute, by retrieving the PyObject for the corresponding C++ object held by the smart pointer.
    if (auto *rawObj = PyObject_CallMethod(self, "data", 0)) {
        if (auto *attribute = PyObject_GetAttr(rawObj, name))
            tmp = attribute;
        Py_DECREF(rawObj);
    }
    if (!tmp) {
        PyTypeObject *tp = Py_TYPE(self);
        PyErr_Format(PyExc_AttributeError,
                     "'%.50s' object has no attribute '%.400s'",
                     tp->tp_name, Shiboken::String::toCString(name));
    }
    return tmp;
}

static int Sbk_Qt3DCore_QAspectJobPtr_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    // Try to find the 'name' attribute, by retrieving the PyObject for the corresponding C++ object held by the smart pointer.
    if (auto *rawObj = PyObject_CallMethod(self, "data", 0)) {
        if (PyObject_HasAttr(rawObj, name) != 0)
            return PyObject_GenericSetAttr(rawObj, name, value);
        Py_DECREF(rawObj);
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static int Sbk_Qt3DCore_QAspectJobPtr___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QSharedPointer<Qt3DCore::QAspectJob> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    return !cppSelf->isNull() ? 1 : 0;
}

static PyObject * Sbk_Qt3DCore_QAspectJobPtr_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSharedPointer<Qt3DCore::QAspectJob> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]), (pyArg)))) {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSharedPointer<Qt3DCore::QAspectJob> cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        const auto *cppSelfPointee = cppSelf.data();
        const auto *cppArg0Pointee = cppArg0.data();
        bool cppResult= false;
        switch (op) {
        case Py_EQ:
            cppResult = cppSelfPointee == cppArg0Pointee;
            break;
        case Py_NE:
            cppResult = cppSelfPointee != cppArg0Pointee;
            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
        }
        pyResult = cppResult ? Py_True : Py_False;
        Py_INCREF(pyResult);
    }
    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_Qt3DCore_QAspectJobPtr_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DCore_QAspectJobPtr_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_Qt3DCore_QAspectJobPtr__repr__(PyObject *self)
{
    Shiboken::AutoDecRef pointee(PyObject_CallMethod(self, "data", 0));
    return Shiboken::SmartPointer::repr(self, pointee);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DCore_QAspectJobPtr_Type = nullptr;
static PyTypeObject *Sbk_Qt3DCore_QAspectJobPtr_TypeF(void)
{
    return _Sbk_Qt3DCore_QAspectJobPtr_Type;
}

static PyType_Slot Sbk_Qt3DCore_QAspectJobPtr_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_Qt3DCore_QAspectJobPtr__repr__)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_Qt3DCore_QAspectJobPtr_getattro)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DCore_QAspectJobPtr_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DCore_QAspectJobPtr_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DCore_QAspectJobPtr_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_Qt3DCore_QAspectJobPtr_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DCore_QAspectJobPtr_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DCore_QAspectJobPtr_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_Qt3DCore_QAspectJobPtr___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DCore_QAspectJobPtr_spec = {
    "2:PySide6.Qt3DCore.Qt3DCore.QAspectJobPtr",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DCore_QAspectJobPtr_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAspectJobPtr_PythonToCpp_QAspectJobPtr_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DCore_QAspectJobPtr_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAspectJobPtr_PythonToCpp_QAspectJobPtr_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DCore_QAspectJobPtr_TypeF()))
        return QAspectJobPtr_PythonToCpp_QAspectJobPtr_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAspectJobPtr_PTR_CppToPython_QAspectJobPtr(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_Qt3DCore_QAspectJobPtr_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QAspectJobPtr_COPY_CppToPython_QAspectJobPtr(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSharedPointer<Qt3DCore::QAspectJob> *>(cppIn);
    return Shiboken::Object::newObject(Sbk_Qt3DCore_QAspectJobPtr_TypeF(), new ::QSharedPointer<Qt3DCore::QAspectJob>(*source), true, true);
}

// Python to C++ copy conversion.
static void QAspectJobPtr_PythonToCpp_QAspectJobPtr_COPY(PyObject *pyIn, void *cppOut)
{
    auto *ptr = reinterpret_cast<::QSharedPointer<Qt3DCore::QAspectJob> *>(cppOut);
    if (pyIn == Py_None)
        ptr->reset();
    else
        *ptr = *reinterpret_cast< ::QSharedPointer<Qt3DCore::QAspectJob> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QAspectJobPtr_PythonToCpp_QAspectJobPtr_COPY_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None || PyObject_TypeCheck(pyIn, Sbk_Qt3DCore_QAspectJobPtr_TypeF()))
        return QAspectJobPtr_PythonToCpp_QAspectJobPtr_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DCore_QAspectJobPtr_SignatureStrings[] = {
    "1:PySide6.Qt3DCore.Qt3DCore.QAspectJobPtr(self)",
    "0:PySide6.Qt3DCore.Qt3DCore.QAspectJobPtr(self,pointee:PySide6.Qt3DCore.Qt3DCore.QAspectJob)",
    "1:PySide6.Qt3DCore.Qt3DCore.QAspectJobPtr.reset(self)",
    "0:PySide6.Qt3DCore.Qt3DCore.QAspectJobPtr.reset(self,t:PySide6.Qt3DCore.Qt3DCore.QAspectJob)",
    "PySide6.Qt3DCore.Qt3DCore.QAspectJobPtr.data(self)->PySide6.Qt3DCore.Qt3DCore.QAspectJob",
    "PySide6.Qt3DCore.Qt3DCore.QAspectJobPtr.__copy__(self)->typing.Self",
    "PySide6.Qt3DCore.Qt3DCore.QAspectJobPtr.__dir__()",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DCore_QAspectJobPtr_SignatureByteSize = 126;
static constexpr uint8_t Qt3DCore_QAspectJobPtr_SignatureBytes[126] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x31, 0x76,
    0x71, 0xce, 0x2f, 0x4a, 0x45, 0x62, 0x38, 0x16, 0x17, 0xa4, 0x26, 0x97, 0x78, 0xe5, 0x27, 0x05,
    0x94, 0x14, 0x69, 0x14, 0xa7, 0xe6, 0xa4, 0x69, 0x72, 0x19, 0x90, 0xa4, 0x5e, 0xa7, 0x20, 0x3f,
    0x33, 0xaf, 0x24, 0x35, 0x95, 0x28, 0x4d, 0x9a, 0x5c, 0x86, 0xc4, 0x1a, 0xae, 0x57, 0x94, 0x5a,
    0x9c, 0x5a, 0x42, 0xaa, 0x93, 0x90, 0x74, 0xe9, 0x94, 0x10, 0xe9, 0x24, 0x62, 0x8d, 0x4e, 0x49,
    0x2c, 0x49, 0x84, 0xb8, 0x47, 0xd7, 0x8e, 0x18, 0x3d, 0x44, 0x1b, 0x1c, 0x1f, 0x9f, 0x9c, 0x5f,
    0x50, 0x19, 0x1f, 0x0f, 0x33, 0xbc, 0xa4, 0xb2, 0x20, 0x33, 0x2f, 0x5d, 0x2f, 0x18, 0xc8, 0x23,
    0xc1, 0x8c, 0x94, 0xcc, 0x22, 0xa0, 0x11, 0x9a, 0x5c, 0x00, 0xe9, 0x7f, 0xa8, 0x9b
};
#endif

PyTypeObject *init_Qt3DCore_QAspectJobPtr(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX].type != nullptr)
        return SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DCore_QAspectJobPtr_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_Qt3DCore_QAspectJobPtr_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QAspectJobPtr",
        "QSharedPointer<Qt3DCore::QAspectJob>",
        &Sbk_Qt3DCore_QAspectJobPtr_spec,
        &Shiboken::callCppDestructor< ::QSharedPointer<Qt3DCore::QAspectJob> >,
        Sbk_Qt3DCore_QAspectJobPtr_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DCore_QAspectJobPtr_TypeF(); // references _Sbk_Qt3DCore_QAspectJobPtr_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DCore_QAspectJobPtr_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DCore_QAspectJobPtr_SignatureBytes, Qt3DCore_QAspectJobPtr_SignatureByteSize);
#endif
    SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAspectJobPtr_PythonToCpp_QAspectJobPtr_PTR,
        is_QAspectJobPtr_PythonToCpp_QAspectJobPtr_PTR_Convertible,
        QAspectJobPtr_PTR_CppToPython_QAspectJobPtr,
        QAspectJobPtr_COPY_CppToPython_QAspectJobPtr);

    Shiboken::Conversions::registerConverterName(converter, "QSharedPointer<Qt3DCore::QAspectJob>");
    Shiboken::Conversions::registerConverterName(converter, "QSharedPointer<Qt3DCore::QAspectJob>*");
    Shiboken::Conversions::registerConverterName(converter, "QSharedPointer<Qt3DCore::QAspectJob>&");
    Shiboken::Conversions::registerConverterAlias(converter, "QSharedPointer<QAspectJob>");
    Shiboken::Conversions::registerConverterAlias(converter, "QSharedPointer<QAspectJob>*");
    Shiboken::Conversions::registerConverterAlias(converter, "QSharedPointer<QAspectJob>&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSharedPointer<Qt3DCore::QAspectJob>).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QAspectJobPtr_PythonToCpp_QAspectJobPtr_COPY,
        is_QAspectJobPtr_PythonToCpp_QAspectJobPtr_COPY_Convertible);

    qRegisterMetaType< ::QSharedPointer<Qt3DCore::QAspectJob> >("QSharedPointer<Qt3DCore::QAspectJob>");
    qRegisterMetaType< ::QSharedPointer<Qt3DCore::QAspectJob> >("Qt3DCore::QSharedPointer<Qt3DCore::QAspectJob>");

    return pyType;
}
