// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dcore_python.h"

// main header
#include "qt3dcore_qattribute_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <Qt3DCore/qattribute.h>
#include <Qt3DCore/qbuffer.h>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAttributeWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAttributeWrapper::QAttributeWrapper(::Qt3DCore::QBuffer * buf, ::Qt3DCore::QAttribute::VertexBaseType vertexBaseType, uint vertexSize, uint count, uint offset, uint stride, ::Qt3DCore::QNode * parent) : Qt3DCore::QAttribute(buf, vertexBaseType, vertexSize, count, offset, stride, parent)
{
}

QAttributeWrapper::QAttributeWrapper(::Qt3DCore::QBuffer * buf, const ::QString & name, ::Qt3DCore::QAttribute::VertexBaseType vertexBaseType, uint vertexSize, uint count, uint offset, uint stride, ::Qt3DCore::QNode * parent) : Qt3DCore::QAttribute(buf, name, vertexBaseType, vertexSize, count, offset, stride, parent)
{
}

QAttributeWrapper::QAttributeWrapper(::Qt3DCore::QNode * parent) : Qt3DCore::QAttribute(parent)
{
}

void QAttributeWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAttribute", funcName);
        return;
    }
}

void QAttributeWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAttribute", funcName);
        return;
    }
}

void QAttributeWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAttribute", funcName);
        return;
    }
}

void QAttributeWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAttribute", funcName);
        return;
    }
}

bool QAttributeWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAttribute", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAttribute", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAttributeWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAttribute", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAttribute", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAttributeWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAttribute", funcName);
        return;
    }
}

const QMetaObject *QAttributeWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DCore::QAttribute::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAttributeWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DCore::QAttribute::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAttributeWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAttributeWrapper *>(this));
    return Qt3DCore::QAttribute::qt_metacast(_clname);
}

QAttributeWrapper::~QAttributeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DCore_QAttribute_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DCore::QAttribute >()))
        return -1;

    QAttributeWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOOO:QAttribute", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAttribute::QAttribute(Qt3DCore::QBuffer*,Qt3DCore::QAttribute::VertexBaseType,uint,uint,uint=,uint=,Qt3DCore::QNode*=)
    // 1: QAttribute::QAttribute(Qt3DCore::QBuffer*,QString,Qt3DCore::QAttribute::VertexBaseType,uint,uint,uint=,uint=,Qt3DCore::QNode*=)
    // 2: QAttribute::QAttribute(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 2; // QAttribute(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBuffer_IDX]), (pyArgs[0])))) {
        if (numArgs >= 5
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_VertexBaseType_IDX])))->converter, (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[4])))) {
            if (numArgs == 5) {
                overloadId = 1; // QAttribute(Qt3DCore::QBuffer*,QString,Qt3DCore::QAttribute::VertexBaseType,uint,uint,uint,uint,Qt3DCore::QNode*)
            } else if (numArgs >= 6
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[5])))) {
                if (numArgs == 6) {
                    overloadId = 1; // QAttribute(Qt3DCore::QBuffer*,QString,Qt3DCore::QAttribute::VertexBaseType,uint,uint,uint,uint,Qt3DCore::QNode*)
                } else if (numArgs >= 7
                    && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[6])))) {
                    if (numArgs == 7) {
                        overloadId = 1; // QAttribute(Qt3DCore::QBuffer*,QString,Qt3DCore::QAttribute::VertexBaseType,uint,uint,uint,uint,Qt3DCore::QNode*)
                    } else if (numArgs >= 8
                        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[7])))) {
                        overloadId = 1; // QAttribute(Qt3DCore::QBuffer*,QString,Qt3DCore::QAttribute::VertexBaseType,uint,uint,uint,uint,Qt3DCore::QNode*)
                    }
                }
            }
        } else if (numArgs >= 4
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_VertexBaseType_IDX])))->converter, (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 0; // QAttribute(Qt3DCore::QBuffer*,Qt3DCore::QAttribute::VertexBaseType,uint,uint,uint,uint,Qt3DCore::QNode*)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 0; // QAttribute(Qt3DCore::QBuffer*,Qt3DCore::QAttribute::VertexBaseType,uint,uint,uint,uint,Qt3DCore::QNode*)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[5])))) {
                    if (numArgs == 6) {
                        overloadId = 0; // QAttribute(Qt3DCore::QBuffer*,Qt3DCore::QAttribute::VertexBaseType,uint,uint,uint,uint,Qt3DCore::QNode*)
                    } else if (numArgs >= 7
                        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[6])))) {
                        overloadId = 0; // QAttribute(Qt3DCore::QBuffer*,Qt3DCore::QAttribute::VertexBaseType,uint,uint,uint,uint,Qt3DCore::QNode*)
                    }
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QAttribute(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAttribute(Qt3DCore::QBuffer *buf, Qt3DCore::QAttribute::VertexBaseType vertexBaseType, uint vertexSize, uint count, uint offset, uint stride, Qt3DCore::QNode *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_offset = Shiboken::String::createStaticString("offset");
                if (PyDict_Contains(kwds, key_offset) != 0) {
                    value = PyDict_GetItem(kwds, key_offset);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_offset);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_offset);
                }
                static PyObject *const key_stride = Shiboken::String::createStaticString("stride");
                if (PyDict_Contains(kwds, key_stride) != 0) {
                    value = PyDict_GetItem(kwds, key_stride);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_stride);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_stride);
                }
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Qt3DCore::QBuffer *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt3DCore::QAttribute::VertexBaseType cppArg1{Qt3DCore::QAttribute::Byte};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            uint cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            uint cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            uint cppArg4 = 0;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            uint cppArg5 = 0;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return -1;
            ::Qt3DCore::QNode *cppArg6 = nullptr;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAttribute(Qt3DCore::QBuffer*,Qt3DCore::QAttribute::VertexBaseType,uint,uint,uint,uint,Qt3DCore::QNode*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QAttributeWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QAttributeWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[6], self);
            }
            break;
        }
        case 1: // QAttribute(Qt3DCore::QBuffer *buf, const QString &name, Qt3DCore::QAttribute::VertexBaseType vertexBaseType, uint vertexSize, uint count, uint offset, uint stride, Qt3DCore::QNode *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_offset = Shiboken::String::createStaticString("offset");
                if (PyDict_Contains(kwds, key_offset) != 0) {
                    value = PyDict_GetItem(kwds, key_offset);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_offset);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_offset);
                }
                static PyObject *const key_stride = Shiboken::String::createStaticString("stride");
                if (PyDict_Contains(kwds, key_stride) != 0) {
                    value = PyDict_GetItem(kwds, key_stride);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_stride);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_stride);
                }
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Qt3DCore::QBuffer *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt3DCore::QAttribute::VertexBaseType cppArg2{Qt3DCore::QAttribute::Byte};
            pythonToCpp[2](pyArgs[2], &cppArg2);
            uint cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            uint cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            uint cppArg5 = 0;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            uint cppArg6 = 0;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return -1;
            ::Qt3DCore::QNode *cppArg7 = nullptr;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAttribute(Qt3DCore::QBuffer*,QString,Qt3DCore::QAttribute::VertexBaseType,uint,uint,uint,uint,Qt3DCore::QNode*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QAttributeWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QAttributeWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[7], self);
            }
            break;
        }
        case 2: // QAttribute(Qt3DCore::QNode *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Qt3DCore::QNode *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAttribute(Qt3DCore::QNode*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QAttributeWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QAttributeWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DCore::QAttribute >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_attributeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // attributeType()const
        Qt3DCore::QAttribute::AttributeType cppResult = const_cast<const ::Qt3DCore::QAttribute *>(cppSelf)->attributeType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_AttributeType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_buffer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // buffer()const
        Qt3DCore::QBuffer * cppResult = const_cast<const ::Qt3DCore::QAttribute *>(cppSelf)->buffer();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBuffer_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_byteOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // byteOffset()const
        uint cppResult = const_cast<const ::Qt3DCore::QAttribute *>(cppSelf)->byteOffset();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_byteStride(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // byteStride()const
        uint cppResult = const_cast<const ::Qt3DCore::QAttribute *>(cppSelf)->byteStride();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        uint cppResult = const_cast<const ::Qt3DCore::QAttribute *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_defaultColorAttributeName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultColorAttributeName()
        QString cppResult = ::Qt3DCore::QAttribute::defaultColorAttributeName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_defaultJointIndicesAttributeName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultJointIndicesAttributeName()
        QString cppResult = ::Qt3DCore::QAttribute::defaultJointIndicesAttributeName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_defaultJointWeightsAttributeName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultJointWeightsAttributeName()
        QString cppResult = ::Qt3DCore::QAttribute::defaultJointWeightsAttributeName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_defaultNormalAttributeName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultNormalAttributeName()
        QString cppResult = ::Qt3DCore::QAttribute::defaultNormalAttributeName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_defaultPositionAttributeName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultPositionAttributeName()
        QString cppResult = ::Qt3DCore::QAttribute::defaultPositionAttributeName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_defaultTangentAttributeName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultTangentAttributeName()
        QString cppResult = ::Qt3DCore::QAttribute::defaultTangentAttributeName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_defaultTextureCoordinate1AttributeName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultTextureCoordinate1AttributeName()
        QString cppResult = ::Qt3DCore::QAttribute::defaultTextureCoordinate1AttributeName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_defaultTextureCoordinate2AttributeName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultTextureCoordinate2AttributeName()
        QString cppResult = ::Qt3DCore::QAttribute::defaultTextureCoordinate2AttributeName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_defaultTextureCoordinateAttributeName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultTextureCoordinateAttributeName()
        QString cppResult = ::Qt3DCore::QAttribute::defaultTextureCoordinateAttributeName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_divisor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // divisor()const
        uint cppResult = const_cast<const ::Qt3DCore::QAttribute *>(cppSelf)->divisor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::Qt3DCore::QAttribute *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_setAttributeType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAttribute::setAttributeType(Qt3DCore::QAttribute::AttributeType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_AttributeType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAttributeType(Qt3DCore::QAttribute::AttributeType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAttributeType", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);

    // Call function/method
    {
        ::Qt3DCore::QAttribute::AttributeType cppArg0{Qt3DCore::QAttribute::VertexAttribute};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAttributeType(Qt3DCore::QAttribute::AttributeType)
            cppSelf->setAttributeType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_setBuffer(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAttribute::setBuffer(Qt3DCore::QBuffer*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBuffer_IDX]), (pyArg)))) {
        overloadId = 0; // setBuffer(Qt3DCore::QBuffer*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBuffer", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DCore::QBuffer *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBuffer(Qt3DCore::QBuffer*)
            cppSelf->setBuffer(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_setByteOffset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAttribute::setByteOffset(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // setByteOffset(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setByteOffset", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setByteOffset(uint)
            cppSelf->setByteOffset(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_setByteStride(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAttribute::setByteStride(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // setByteStride(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setByteStride", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setByteStride(uint)
            cppSelf->setByteStride(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_setCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAttribute::setCount(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // setCount(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCount", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCount(uint)
            cppSelf->setCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_setDivisor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAttribute::setDivisor(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // setDivisor(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDivisor", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDivisor(uint)
            cppSelf->setDivisor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAttribute::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QString)
            cppSelf->setName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_setVertexBaseType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAttribute::setVertexBaseType(Qt3DCore::QAttribute::VertexBaseType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_VertexBaseType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setVertexBaseType(Qt3DCore::QAttribute::VertexBaseType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVertexBaseType", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);

    // Call function/method
    {
        ::Qt3DCore::QAttribute::VertexBaseType cppArg0{Qt3DCore::QAttribute::Byte};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVertexBaseType(Qt3DCore::QAttribute::VertexBaseType)
            cppSelf->setVertexBaseType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_setVertexSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAttribute::setVertexSize(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // setVertexSize(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVertexSize", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVertexSize(uint)
            cppSelf->setVertexSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_vertexBaseType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vertexBaseType()const
        Qt3DCore::QAttribute::VertexBaseType cppResult = const_cast<const ::Qt3DCore::QAttribute *>(cppSelf)->vertexBaseType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_VertexBaseType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QAttributeFunc_vertexSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vertexSize()const
        uint cppResult = const_cast<const ::Qt3DCore::QAttribute *>(cppSelf)->vertexSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DCore_QAttribute_PropertyStrings[] = {
    "attributeType::",
    "buffer::",
    "byteOffset::",
    "byteStride::",
    "count::",
    "defaultColorAttributeName:",
    "defaultJointIndicesAttributeName:",
    "defaultJointWeightsAttributeName:",
    "defaultNormalAttributeName:",
    "defaultPositionAttributeName:",
    "defaultTangentAttributeName:",
    "defaultTextureCoordinate1AttributeName:",
    "defaultTextureCoordinate2AttributeName:",
    "defaultTextureCoordinateAttributeName:",
    "divisor::",
    "name::",
    "vertexBaseType::",
    "vertexSize::",
    nullptr // Sentinel
};

static const char *Sbk_Qt3DCore_QAttribute_EnumFlagInfo[] = {
    "AttributeType:Enum",
    "VertexBaseType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DCore_QAttribute_methods[] = {
    {"attributeType", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_attributeType), METH_NOARGS, nullptr},
    {"buffer", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_buffer), METH_NOARGS, nullptr},
    {"byteOffset", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_byteOffset), METH_NOARGS, nullptr},
    {"byteStride", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_byteStride), METH_NOARGS, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_count), METH_NOARGS, nullptr},
    {"defaultColorAttributeName", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_defaultColorAttributeName), METH_NOARGS|METH_STATIC, nullptr},
    {"defaultJointIndicesAttributeName", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_defaultJointIndicesAttributeName), METH_NOARGS|METH_STATIC, nullptr},
    {"defaultJointWeightsAttributeName", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_defaultJointWeightsAttributeName), METH_NOARGS|METH_STATIC, nullptr},
    {"defaultNormalAttributeName", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_defaultNormalAttributeName), METH_NOARGS|METH_STATIC, nullptr},
    {"defaultPositionAttributeName", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_defaultPositionAttributeName), METH_NOARGS|METH_STATIC, nullptr},
    {"defaultTangentAttributeName", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_defaultTangentAttributeName), METH_NOARGS|METH_STATIC, nullptr},
    {"defaultTextureCoordinate1AttributeName", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_defaultTextureCoordinate1AttributeName), METH_NOARGS|METH_STATIC, nullptr},
    {"defaultTextureCoordinate2AttributeName", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_defaultTextureCoordinate2AttributeName), METH_NOARGS|METH_STATIC, nullptr},
    {"defaultTextureCoordinateAttributeName", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_defaultTextureCoordinateAttributeName), METH_NOARGS|METH_STATIC, nullptr},
    {"divisor", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_divisor), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_name), METH_NOARGS, nullptr},
    {"setAttributeType", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_setAttributeType), METH_O, nullptr},
    {"setBuffer", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_setBuffer), METH_O, nullptr},
    {"setByteOffset", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_setByteOffset), METH_O, nullptr},
    {"setByteStride", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_setByteStride), METH_O, nullptr},
    {"setCount", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_setCount), METH_O, nullptr},
    {"setDivisor", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_setDivisor), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_setName), METH_O, nullptr},
    {"setVertexBaseType", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_setVertexBaseType), METH_O, nullptr},
    {"setVertexSize", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_setVertexSize), METH_O, nullptr},
    {"vertexBaseType", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_vertexBaseType), METH_NOARGS, nullptr},
    {"vertexSize", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAttributeFunc_vertexSize), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DCore_QAttribute_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DCore::QAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAttributeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DCore_QAttribute_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DCore_QAttribute_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DCore_QAttribute_Type = nullptr;
static PyTypeObject *Sbk_Qt3DCore_QAttribute_TypeF(void)
{
    return _Sbk_Qt3DCore_QAttribute_Type;
}

static PyType_Slot Sbk_Qt3DCore_QAttribute_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DCore_QAttribute_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DCore_QAttribute_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DCore_QAttribute_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DCore_QAttribute_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DCore_QAttribute_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DCore_QAttribute_spec = {
    "2:PySide6.Qt3DCore.Qt3DCore.QAttribute",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DCore_QAttribute_slots
};

} //extern "C"

static void *Sbk_Qt3DCore_QAttribute_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DCore::QAttribute *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Qt3DCore_QAttribute_AttributeType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DCore::QAttribute::AttributeType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DCore::QAttribute::AttributeType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DCore_QAttribute_AttributeType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_AttributeType_IDX])))
        return Enum_PythonToCpp_Qt3DCore_QAttribute_AttributeType;
    return {};
}

static PyObject *Qt3DCore_QAttribute_AttributeType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DCore::QAttribute::AttributeType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DCore::QAttribute::AttributeType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_AttributeType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DCore_QAttribute_VertexBaseType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DCore::QAttribute::VertexBaseType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DCore::QAttribute::VertexBaseType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DCore_QAttribute_VertexBaseType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_VertexBaseType_IDX])))
        return Enum_PythonToCpp_Qt3DCore_QAttribute_VertexBaseType;
    return {};
}

static PyObject *Qt3DCore_QAttribute_VertexBaseType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DCore::QAttribute::VertexBaseType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DCore::QAttribute::VertexBaseType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_VertexBaseType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAttribute_PythonToCpp_QAttribute_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DCore_QAttribute_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAttribute_PythonToCpp_QAttribute_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DCore_QAttribute_TypeF()))
        return QAttribute_PythonToCpp_QAttribute_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAttribute_PTR_CppToPython_QAttribute(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DCore::QAttribute *>(const_cast<void *>(cppIn)), Sbk_Qt3DCore_QAttribute_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DCore_QAttribute_SignatureStrings[] = {
    "2:PySide6.Qt3DCore.Qt3DCore.QAttribute(self,buf:PySide6.Qt3DCore.Qt3DCore.QBuffer,vertexBaseType:PySide6.Qt3DCore.Qt3DCore.QAttribute.VertexBaseType,vertexSize:uint,count:uint,offset:uint=0,stride:uint=0,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,buffer:Qt3DCore.QBuffer=None,name:QString=None,vertexBaseType:Qt3DCore.QAttribute.VertexBaseType=None,vertexSize:uint=None,count:uint=None,byteStride:uint=None,byteOffset:uint=None,divisor:uint=None,attributeType:Qt3DCore.QAttribute.AttributeType=None,defaultPositionAttributeName:QString=None,defaultNormalAttributeName:QString=None,defaultColorAttributeName:QString=None,defaultTextureCoordinateAttributeName:QString=None,defaultTextureCoordinate1AttributeName:QString=None,defaultTextureCoordinate2AttributeName:QString=None,defaultTangentAttributeName:QString=None,defaultJointIndicesAttributeName:QString=None,defaultJointWeightsAttributeName:QString=None)",
    "1:PySide6.Qt3DCore.Qt3DCore.QAttribute(self,buf:PySide6.Qt3DCore.Qt3DCore.QBuffer,name:QString,vertexBaseType:PySide6.Qt3DCore.Qt3DCore.QAttribute.VertexBaseType,vertexSize:uint,count:uint,offset:uint=0,stride:uint=0,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,buffer:Qt3DCore.QBuffer=None,name:QString=None,vertexBaseType:Qt3DCore.QAttribute.VertexBaseType=None,vertexSize:uint=None,count:uint=None,byteStride:uint=None,byteOffset:uint=None,divisor:uint=None,attributeType:Qt3DCore.QAttribute.AttributeType=None,defaultPositionAttributeName:QString=None,defaultNormalAttributeName:QString=None,defaultColorAttributeName:QString=None,defaultTextureCoordinateAttributeName:QString=None,defaultTextureCoordinate1AttributeName:QString=None,defaultTextureCoordinate2AttributeName:QString=None,defaultTangentAttributeName:QString=None,defaultJointIndicesAttributeName:QString=None,defaultJointWeightsAttributeName:QString=None)",
    "0:PySide6.Qt3DCore.Qt3DCore.QAttribute(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,buffer:Qt3DCore.QBuffer=None,name:QString=None,vertexBaseType:Qt3DCore.QAttribute.VertexBaseType=None,vertexSize:uint=None,count:uint=None,byteStride:uint=None,byteOffset:uint=None,divisor:uint=None,attributeType:Qt3DCore.QAttribute.AttributeType=None,defaultPositionAttributeName:QString=None,defaultNormalAttributeName:QString=None,defaultColorAttributeName:QString=None,defaultTextureCoordinateAttributeName:QString=None,defaultTextureCoordinate1AttributeName:QString=None,defaultTextureCoordinate2AttributeName:QString=None,defaultTangentAttributeName:QString=None,defaultJointIndicesAttributeName:QString=None,defaultJointWeightsAttributeName:QString=None)",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.attributeType(self)->PySide6.Qt3DCore.Qt3DCore.QAttribute.AttributeType",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.buffer(self)->PySide6.Qt3DCore.Qt3DCore.QBuffer",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.byteOffset(self)->uint",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.byteStride(self)->uint",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.count(self)->uint",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.defaultColorAttributeName()->QString",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.defaultJointIndicesAttributeName()->QString",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.defaultJointWeightsAttributeName()->QString",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.defaultNormalAttributeName()->QString",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.defaultPositionAttributeName()->QString",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.defaultTangentAttributeName()->QString",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.defaultTextureCoordinate1AttributeName()->QString",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.defaultTextureCoordinate2AttributeName()->QString",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.defaultTextureCoordinateAttributeName()->QString",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.divisor(self)->uint",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.name(self)->QString",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.setAttributeType(self,attributeType:PySide6.Qt3DCore.Qt3DCore.QAttribute.AttributeType)",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.setBuffer(self,buffer:PySide6.Qt3DCore.Qt3DCore.QBuffer)",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.setByteOffset(self,byteOffset:uint)",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.setByteStride(self,byteStride:uint)",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.setCount(self,count:uint)",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.setDivisor(self,divisor:uint)",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.setName(self,name:QString)",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.setVertexBaseType(self,type:PySide6.Qt3DCore.Qt3DCore.QAttribute.VertexBaseType)",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.setVertexSize(self,size:uint)",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.vertexBaseType(self)->PySide6.Qt3DCore.Qt3DCore.QAttribute.VertexBaseType",
    "PySide6.Qt3DCore.Qt3DCore.QAttribute.vertexSize(self)->uint",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DCore_QAttribute_SignatureByteSize = 516;
static constexpr uint8_t Qt3DCore_QAttribute_SignatureBytes[516] = {
    0x78, 0xda, 0xed, 0x57, 0x51, 0x6f, 0x82, 0x30, 0x10, 0x7e, 0xdf, 0x2f, 0xd1, 0x85, 0x19, 0x75,
    0xc9, 0x1e, 0x48, 0x5c, 0xa2, 0xf8, 0xb2, 0x2d, 0x41, 0x0d, 0x66, 0x7b, 0x46, 0x39, 0x5c, 0x13,
    0x6c, 0x4d, 0x29, 0x4e, 0xf6, 0xeb, 0x57, 0x2d, 0xb0, 0x82, 0x08, 0x2d, 0xba, 0x97, 0x85, 0xb7,
    0x5a, 0xef, 0xfb, 0xee, 0xce, 0xde, 0x77, 0x77, 0x0e, 0xcd, 0x79, 0xec, 0x20, 0x0f, 0x9e, 0x7a,
    0x0b, 0xf6, 0x38, 0xb5, 0x08, 0x05, 0xe9, 0x30, 0x66, 0x8c, 0xa2, 0x55, 0xc4, 0xa0, 0x13, 0x42,
    0xe0, 0x1b, 0xab, 0xc8, 0xaf, 0xb2, 0x9e, 0x44, 0xbe, 0x0f, 0xd4, 0xd8, 0x03, 0x65, 0x70, 0x98,
    0xb8, 0x21, 0x2c, 0xe3, 0x1d, 0x28, 0xd1, 0xf7, 0xde, 0x73, 0x98, 0x84, 0xc2, 0x41, 0xdf, 0x60,
    0x46, 0x08, 0x33, 0x63, 0x4d, 0x22, 0xcc, 0xc4, 0x91, 0xf8, 0x7e, 0x08, 0xe2, 0x3c, 0xea, 0x1b,
    0x21, 0x27, 0xf0, 0x20, 0xfd, 0xb4, 0x73, 0x29, 0x70, 0xbb, 0x0a, 0x8f, 0x36, 0xf1, 0x60, 0x84,
    0xa3, 0x20, 0xd8, 0x31, 0x6a, 0xdc, 0x9b, 0x6f, 0x10, 0x7f, 0x11, 0xea, 0xcd, 0x70, 0x10, 0x8f,
    0x6c, 0x82, 0xe1, 0x98, 0x21, 0x4f, 0xc1, 0x2c, 0xe6, 0x24, 0xbe, 0xc4, 0xee, 0x16, 0xcc, 0x85,
    0xc3, 0x5d, 0xe2, 0x8d, 0xb8, 0x29, 0xa4, 0x5a, 0x9f, 0x99, 0x0c, 0xcb, 0xd2, 0x13, 0x97, 0xbf,
    0x39, 0x26, 0xa1, 0xc4, 0x0c, 0x1c, 0x29, 0xbd, 0xec, 0x72, 0x26, 0xfd, 0x02, 0xa7, 0x4b, 0x0f,
    0xed, 0x51, 0x48, 0xa8, 0x74, 0xe3, 0xa6, 0xee, 0x2f, 0x86, 0x35, 0x96, 0x2d, 0x12, 0x1a, 0xf0,
    0xdd, 0x28, 0x60, 0x73, 0x12, 0x22, 0x86, 0x08, 0xce, 0x2c, 0xec, 0xb3, 0xb4, 0x13, 0x4b, 0x9b,
    0xd0, 0xad, 0x1b, 0xd4, 0xdb, 0x59, 0x24, 0x20, 0xb4, 0xde, 0x6c, 0x09, 0x07, 0x16, 0x51, 0xb0,
    0x08, 0x7f, 0x11, 0x84, 0x5d, 0x06, 0x0d, 0x20, 0x83, 0x06, 0x98, 0xa1, 0x02, 0xc6, 0xc5, 0x1b,
    0x5e, 0x59, 0xf5, 0x86, 0xaf, 0x84, 0xbf, 0xc1, 0x0b, 0xf6, 0xd0, 0x1a, 0x42, 0x45, 0xeb, 0x0f,
    0x40, 0x9b, 0x4f, 0x56, 0x61, 0xdd, 0xbd, 0x1b, 0xdc, 0x5c, 0xa3, 0x72, 0x29, 0xb7, 0x82, 0x6d,
    0x05, 0xdb, 0x0a, 0xf6, 0xa6, 0x82, 0xed, 0x6b, 0x08, 0xb6, 0xd5, 0x40, 0xab, 0x81, 0xff, 0xa8,
    0x01, 0xa5, 0x31, 0x92, 0x7b, 0xf3, 0x93, 0x1e, 0xba, 0x0f, 0xcf, 0x4a, 0xc8, 0x5c, 0x2d, 0xa8,
    0x39, 0x13, 0x3a, 0x51, 0xf0, 0x22, 0xf4, 0xa3, 0x48, 0x9a, 0x15, 0x77, 0x4a, 0x7c, 0xac, 0x68,
    0x75, 0xac, 0x50, 0x8b, 0x3e, 0xf6, 0xa4, 0x3c, 0x7d, 0xd8, 0xc5, 0xea, 0xee, 0x70, 0x9a, 0xe4,
    0x01, 0xb5, 0x98, 0x2e, 0x16, 0xcf, 0x55, 0x84, 0x65, 0xf5, 0xd5, 0x94, 0xb0, 0x44, 0xf1, 0x4d,
    0xa9, 0x4a, 0xdb, 0x4c, 0x53, 0xb2, 0x32, 0x7d, 0x36, 0xe6, 0xaa, 0xee, 0x29, 0x37, 0xa3, 0x1d,
    0xfe, 0x0d, 0xed, 0x95, 0xac, 0x62, 0x94, 0xe8, 0x8b, 0xe1, 0x38, 0x1b, 0x53, 0x94, 0x96, 0x47,
    0xae, 0xf6, 0xf1, 0x59, 0xe7, 0x2a, 0x0c, 0x30, 0xfd, 0x2e, 0xd6, 0x55, 0x76, 0x3e, 0xf9, 0xed,
    0x64, 0xe9, 0xf4, 0xaf, 0x6d, 0x67, 0x1a, 0xec, 0xf9, 0x96, 0x56, 0x9c, 0xdf, 0x7a, 0x44, 0x52,
    0x7f, 0x2b, 0x6e, 0x07, 0xea, 0x44, 0x56, 0xd6, 0xec, 0xa4, 0x8d, 0x43, 0x1d, 0x3e, 0x95, 0x0a,
    0x24, 0xb7, 0x78, 0xa8, 0x53, 0xd8, 0x69, 0xa9, 0xe4, 0x16, 0x2a, 0x75, 0x7c, 0x7e, 0xa3, 0x12,
    0x4c, 0xac, 0xe1, 0xbf, 0x2d, 0x5d, 0xaf, 0xc7, 0x9d, 0x4d, 0x78, 0x0c, 0xd3, 0xed, 0x4d, 0x91,
    0x62, 0x7f, 0x1e, 0xb5, 0xea, 0x7c, 0xce, 0x87, 0xac, 0xe3, 0x2e, 0x0b, 0x37, 0xd5, 0xf2, 0x0f,
    0xce, 0x0c, 0xdd, 0x90
};
#endif

PyTypeObject *init_Qt3DCore_QAttribute(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX].type != nullptr)
        return SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DCore_QAttribute_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]))));

    _Sbk_Qt3DCore_QAttribute_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QAttribute",
        "Qt3DCore::QAttribute*",
        &Sbk_Qt3DCore_QAttribute_spec,
        &Shiboken::callCppDestructor< Qt3DCore::QAttribute >,
        Sbk_Qt3DCore_QAttribute_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DCore_QAttribute_TypeF(); // references _Sbk_Qt3DCore_QAttribute_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DCore_QAttribute_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DCore_QAttribute_SignatureBytes, Qt3DCore_QAttribute_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DCore_QAttribute_PropertyStrings);
    SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAttribute_PythonToCpp_QAttribute_PTR,
        is_QAttribute_PythonToCpp_QAttribute_PTR_Convertible,
        QAttribute_PTR_CppToPython_QAttribute);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QAttribute");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QAttribute*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QAttribute&");
    Shiboken::Conversions::registerConverterAlias(converter, "QAttribute");
    Shiboken::Conversions::registerConverterAlias(converter, "QAttribute*");
    Shiboken::Conversions::registerConverterAlias(converter, "QAttribute&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DCore::QAttribute).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAttributeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DCore_QAttribute_TypeF(), &Sbk_Qt3DCore_QAttribute_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DCore_QAttribute_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'AttributeType'.
    const char *AttributeType_Initializer[] = {
        "VertexAttribute",
        "IndexAttribute",
        "DrawIndirectAttribute",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AttributeType_InitializerValues[] = {
        uint8_t(Qt3DCore::QAttribute::AttributeType::VertexAttribute),      //  0x00  0
        uint8_t(Qt3DCore::QAttribute::AttributeType::IndexAttribute),       //  0x01  1
        uint8_t(Qt3DCore::QAttribute::AttributeType::DrawIndirectAttribute) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DCore_QAttribute_TypeF(),
        "2:PySide6.Qt3DCore.Qt3DCore.QAttribute.AttributeType",
        AttributeType_Initializer, AttributeType_InitializerValues);
    SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_AttributeType_IDX].type = EType;
    // Register converter for enum 'Qt3DCore::QAttribute::AttributeType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DCore_QAttribute_AttributeType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DCore_QAttribute_AttributeType,
            is_Enum_PythonToCpp_Qt3DCore_QAttribute_AttributeType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QAttribute::AttributeType");
        Shiboken::Conversions::registerConverterAlias(converter, "QAttribute::AttributeType");
        Shiboken::Conversions::registerConverterAlias(converter, "AttributeType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AttributeType' enum.

    // Initialization of enum 'VertexBaseType'.
    const char *VertexBaseType_Initializer[] = {
        "Byte",
        "UnsignedByte",
        "Short",
        "UnsignedShort",
        "Int",
        "UnsignedInt",
        "HalfFloat",
        "Float",
        "Double",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t VertexBaseType_InitializerValues[] = {
        uint8_t(Qt3DCore::QAttribute::VertexBaseType::Byte),          //  0x00  0
        uint8_t(Qt3DCore::QAttribute::VertexBaseType::UnsignedByte),  //  0x01  1
        uint8_t(Qt3DCore::QAttribute::VertexBaseType::Short),         //  0x02  2
        uint8_t(Qt3DCore::QAttribute::VertexBaseType::UnsignedShort), //  0x03  3
        uint8_t(Qt3DCore::QAttribute::VertexBaseType::Int),           //  0x04  4
        uint8_t(Qt3DCore::QAttribute::VertexBaseType::UnsignedInt),   //  0x05  5
        uint8_t(Qt3DCore::QAttribute::VertexBaseType::HalfFloat),     //  0x06  6
        uint8_t(Qt3DCore::QAttribute::VertexBaseType::Float),         //  0x07  7
        uint8_t(Qt3DCore::QAttribute::VertexBaseType::Double)         //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DCore_QAttribute_TypeF(),
        "2:PySide6.Qt3DCore.Qt3DCore.QAttribute.VertexBaseType",
        VertexBaseType_Initializer, VertexBaseType_InitializerValues);
    SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAttribute_VertexBaseType_IDX].type = EType;
    // Register converter for enum 'Qt3DCore::QAttribute::VertexBaseType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DCore_QAttribute_VertexBaseType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DCore_QAttribute_VertexBaseType,
            is_Enum_PythonToCpp_Qt3DCore_QAttribute_VertexBaseType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QAttribute::VertexBaseType");
        Shiboken::Conversions::registerConverterAlias(converter, "QAttribute::VertexBaseType");
        Shiboken::Conversions::registerConverterAlias(converter, "VertexBaseType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'VertexBaseType' enum.

    PySide::Signal::registerSignals(pyType, &::Qt3DCore::QAttribute::staticMetaObject);
    qRegisterMetaType< ::Qt3DCore::QAttribute::AttributeType >("QAttribute::AttributeType");
    qRegisterMetaType< ::Qt3DCore::QAttribute::AttributeType >("Qt3DCore::QAttribute::AttributeType");
    qRegisterMetaType< ::Qt3DCore::QAttribute::VertexBaseType >("QAttribute::VertexBaseType");
    qRegisterMetaType< ::Qt3DCore::QAttribute::VertexBaseType >("Qt3DCore::QAttribute::VertexBaseType");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DCore::QAttribute::staticMetaObject, sizeof(QAttributeWrapper));

    return pyType;
}
