// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dcore_python.h"

// main header
#include "qt3dcore_qtransform_wrapper.h"

// Argument includes
#include <QList>
#include <Qt3DCore/qentity.h>
#include <Qt3DCore/qnode.h>
#include <QtGui/qmatrix4x4.h>
#include <QtGui/qquaternion.h>
#include <QtGui/qvectornd.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QTransformWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QTransformWrapper::QTransformWrapper(::Qt3DCore::QNode * parent) : Qt3DCore::QTransform(parent)
{
}

void QTransformWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTransform", funcName);
        return;
    }
}

void QTransformWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTransform", funcName);
        return;
    }
}

void QTransformWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTransform", funcName);
        return;
    }
}

void QTransformWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTransform", funcName);
        return;
    }
}

bool QTransformWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTransform", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QTransform", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QTransformWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTransform", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QTransform", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QTransformWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTransform", funcName);
        return;
    }
}

const QMetaObject *QTransformWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DCore::QTransform::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QTransformWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DCore::QTransform::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QTransformWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QTransformWrapper *>(this));
    return Qt3DCore::QTransform::qt_metacast(_clname);
}

QTransformWrapper::~QTransformWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DCore_QTransform_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DCore::QTransform >()))
        return -1;

    QTransformWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QTransform", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTransform::QTransform(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QTransform(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QTransform(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QTransform(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QTransformWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QTransformWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DCore::QTransform >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_fromAxes(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "fromAxes", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTransform::fromAxes(QVector3D,QVector3D,QVector3D)->QQuaternion
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[2])))) {
        overloadId = 0; // fromAxes(QVector3D,QVector3D,QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromAxes", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QVector3D cppArg1_local;
        ::QVector3D *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QVector3D cppArg2_local;
        ::QVector3D *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // fromAxes(QVector3D,QVector3D,QVector3D)
            QQuaternion cppResult = ::Qt3DCore::QTransform::fromAxes(*cppArg0, *cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_fromAxesAndAngles(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 5)
        return Shiboken::returnWrongArguments(args, "fromAxesAndAngles", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    if (PyArg_UnpackTuple(args, "fromAxesAndAngles", 4, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTransform::fromAxesAndAngles(QVector3D,float,QVector3D,float)->QQuaternion
    // 1: static QTransform::fromAxesAndAngles(QVector3D,float,QVector3D,float,QVector3D,float)->QQuaternion
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 0; // fromAxesAndAngles(QVector3D,float,QVector3D,float)
        } else if (numArgs == 6
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[5])))) {
            overloadId = 1; // fromAxesAndAngles(QVector3D,float,QVector3D,float,QVector3D,float)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromAxesAndAngles", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // fromAxesAndAngles(const QVector3D &axis1, float angle1, const QVector3D &axis2, float angle2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QVector3D cppArg0_local;
            ::QVector3D *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QVector3D cppArg2_local;
            ::QVector3D *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromAxesAndAngles(QVector3D,float,QVector3D,float)
                QQuaternion cppResult = ::Qt3DCore::QTransform::fromAxesAndAngles(*cppArg0, cppArg1, *cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
            }
            break;
        }
        case 1: // fromAxesAndAngles(const QVector3D &axis1, float angle1, const QVector3D &axis2, float angle2, const QVector3D &axis3, float angle3)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QVector3D cppArg0_local;
            ::QVector3D *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QVector3D cppArg2_local;
            ::QVector3D *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QVector3D cppArg4_local;
            ::QVector3D *cppArg4 = &cppArg4_local;
            if (pythonToCpp[4].isValue())
                pythonToCpp[4](pyArgs[4], &cppArg4_local);
            else
                pythonToCpp[4](pyArgs[4], &cppArg4);

            float cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromAxesAndAngles(QVector3D,float,QVector3D,float,QVector3D,float)
                QQuaternion cppResult = ::Qt3DCore::QTransform::fromAxesAndAngles(*cppArg0, cppArg1, *cppArg2, cppArg3, *cppArg4, cppArg5);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_fromAxisAndAngle(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 3)
        return Shiboken::returnWrongArguments(args, "fromAxisAndAngle", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    if (PyArg_UnpackTuple(args, "fromAxisAndAngle", 2, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTransform::fromAxisAndAngle(QVector3D,float)->QQuaternion
    // 1: static QTransform::fromAxisAndAngle(float,float,float,float)->QQuaternion
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 1; // fromAxisAndAngle(float,float,float,float)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // fromAxisAndAngle(QVector3D,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromAxisAndAngle", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // fromAxisAndAngle(const QVector3D &axis, float angle)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QVector3D cppArg0_local;
            ::QVector3D *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromAxisAndAngle(QVector3D,float)
                QQuaternion cppResult = ::Qt3DCore::QTransform::fromAxisAndAngle(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
            }
            break;
        }
        case 1: // fromAxisAndAngle(float x, float y, float z, float angle)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromAxisAndAngle(float,float,float,float)
                QQuaternion cppResult = ::Qt3DCore::QTransform::fromAxisAndAngle(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_fromEulerAngles(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments(args, "fromEulerAngles", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    if (PyArg_UnpackTuple(args, "fromEulerAngles", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTransform::fromEulerAngles(QVector3D)->QQuaternion
    // 1: static QTransform::fromEulerAngles(float,float,float)->QQuaternion
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 1; // fromEulerAngles(float,float,float)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))) {
        overloadId = 0; // fromEulerAngles(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromEulerAngles", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // fromEulerAngles(const QVector3D &eulerAngles)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QVector3D cppArg0_local;
            ::QVector3D *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // fromEulerAngles(QVector3D)
                QQuaternion cppResult = ::Qt3DCore::QTransform::fromEulerAngles(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
            }
            break;
        }
        case 1: // fromEulerAngles(float pitch, float yaw, float roll)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromEulerAngles(float,float,float)
                QQuaternion cppResult = ::Qt3DCore::QTransform::fromEulerAngles(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_matrix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // matrix()const
        QMatrix4x4 cppResult = const_cast<const ::Qt3DCore::QTransform *>(cppSelf)->matrix();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_rotateAround(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "rotateAround", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTransform::rotateAround(QVector3D,float,QVector3D)->QMatrix4x4
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[2])))) {
        overloadId = 0; // rotateAround(QVector3D,float,QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rotateAround", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QVector3D cppArg2_local;
        ::QVector3D *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // rotateAround(QVector3D,float,QVector3D)
            QMatrix4x4 cppResult = ::Qt3DCore::QTransform::rotateAround(*cppArg0, cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_rotateFromAxes(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "rotateFromAxes", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTransform::rotateFromAxes(QVector3D,QVector3D,QVector3D)->QMatrix4x4
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[2])))) {
        overloadId = 0; // rotateFromAxes(QVector3D,QVector3D,QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rotateFromAxes", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QVector3D cppArg1_local;
        ::QVector3D *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QVector3D cppArg2_local;
        ::QVector3D *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // rotateFromAxes(QVector3D,QVector3D,QVector3D)
            QMatrix4x4 cppResult = ::Qt3DCore::QTransform::rotateFromAxes(*cppArg0, *cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_rotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rotation()const
        QQuaternion cppResult = const_cast<const ::Qt3DCore::QTransform *>(cppSelf)->rotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_rotationX(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rotationX()const
        float cppResult = const_cast<const ::Qt3DCore::QTransform *>(cppSelf)->rotationX();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_rotationY(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rotationY()const
        float cppResult = const_cast<const ::Qt3DCore::QTransform *>(cppSelf)->rotationY();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_rotationZ(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rotationZ()const
        float cppResult = const_cast<const ::Qt3DCore::QTransform *>(cppSelf)->rotationZ();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_scale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scale()const
        float cppResult = const_cast<const ::Qt3DCore::QTransform *>(cppSelf)->scale();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_scale3D(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scale3D()const
        QVector3D cppResult = const_cast<const ::Qt3DCore::QTransform *>(cppSelf)->scale3D();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_setMatrix(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::setMatrix(QMatrix4x4)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArg)))) {
        overloadId = 0; // setMatrix(QMatrix4x4)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMatrix", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMatrix4x4 cppArg0_local;
        ::QMatrix4x4 *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setMatrix(QMatrix4x4)
            cppSelf->setMatrix(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_setRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::setRotation(QQuaternion)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArg)))) {
        overloadId = 0; // setRotation(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRotation", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuaternion cppArg0_local;
        ::QQuaternion *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotation(QQuaternion)
            cppSelf->setRotation(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_setRotationX(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::setRotationX(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setRotationX(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRotationX", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotationX(float)
            cppSelf->setRotationX(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_setRotationY(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::setRotationY(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setRotationY(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRotationY", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotationY(float)
            cppSelf->setRotationY(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_setRotationZ(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::setRotationZ(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setRotationZ(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRotationZ", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotationZ(float)
            cppSelf->setRotationZ(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_setScale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::setScale(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setScale(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setScale", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setScale(float)
            cppSelf->setScale(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_setScale3D(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::setScale3D(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setScale3D(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setScale3D", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setScale3D(QVector3D)
            cppSelf->setScale3D(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_setTranslation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTransform::setTranslation(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setTranslation(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTranslation", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTranslation(QVector3D)
            cppSelf->setTranslation(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_translation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // translation()const
        QVector3D cppResult = const_cast<const ::Qt3DCore::QTransform *>(cppSelf)->translation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QTransformFunc_worldMatrix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // worldMatrix()const
        QMatrix4x4 cppResult = const_cast<const ::Qt3DCore::QTransform *>(cppSelf)->worldMatrix();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DCore_QTransform_PropertyStrings[] = {
    "matrix::",
    "rotation::",
    "rotationX::",
    "rotationY::",
    "rotationZ::",
    "scale3D::",
    "scale::",
    "translation::",
    "worldMatrix:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DCore_QTransform_methods[] = {
    {"fromAxes", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_fromAxes), METH_VARARGS|METH_STATIC, nullptr},
    {"fromAxesAndAngles", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_fromAxesAndAngles), METH_VARARGS|METH_STATIC, nullptr},
    {"fromAxisAndAngle", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_fromAxisAndAngle), METH_VARARGS|METH_STATIC, nullptr},
    {"fromEulerAngles", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_fromEulerAngles), METH_VARARGS|METH_STATIC, nullptr},
    {"matrix", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_matrix), METH_NOARGS, nullptr},
    {"rotateAround", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_rotateAround), METH_VARARGS|METH_STATIC, nullptr},
    {"rotateFromAxes", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_rotateFromAxes), METH_VARARGS|METH_STATIC, nullptr},
    {"rotation", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_rotation), METH_NOARGS, nullptr},
    {"rotationX", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_rotationX), METH_NOARGS, nullptr},
    {"rotationY", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_rotationY), METH_NOARGS, nullptr},
    {"rotationZ", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_rotationZ), METH_NOARGS, nullptr},
    {"scale", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_scale), METH_NOARGS, nullptr},
    {"scale3D", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_scale3D), METH_NOARGS, nullptr},
    {"setMatrix", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_setMatrix), METH_O, nullptr},
    {"setRotation", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_setRotation), METH_O, nullptr},
    {"setRotationX", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_setRotationX), METH_O, nullptr},
    {"setRotationY", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_setRotationY), METH_O, nullptr},
    {"setRotationZ", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_setRotationZ), METH_O, nullptr},
    {"setScale", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_setScale), METH_O, nullptr},
    {"setScale3D", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_setScale3D), METH_O, nullptr},
    {"setTranslation", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_setTranslation), METH_O, nullptr},
    {"translation", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_translation), METH_NOARGS, nullptr},
    {"worldMatrix", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QTransformFunc_worldMatrix), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DCore_QTransform_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DCore::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QTransformWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DCore_QTransform_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DCore_QTransform_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DCore_QTransform_Type = nullptr;
static PyTypeObject *Sbk_Qt3DCore_QTransform_TypeF(void)
{
    return _Sbk_Qt3DCore_QTransform_Type;
}

static PyType_Slot Sbk_Qt3DCore_QTransform_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DCore_QTransform_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DCore_QTransform_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DCore_QTransform_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DCore_QTransform_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DCore_QTransform_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DCore_QTransform_spec = {
    "2:PySide6.Qt3DCore.Qt3DCore.QTransform",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DCore_QTransform_slots
};

} //extern "C"

static void *Sbk_Qt3DCore_QTransform_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DCore::QTransform *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTransform_PythonToCpp_QTransform_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DCore_QTransform_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTransform_PythonToCpp_QTransform_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DCore_QTransform_TypeF()))
        return QTransform_PythonToCpp_QTransform_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTransform_PTR_CppToPython_QTransform(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DCore::QTransform *>(const_cast<void *>(cppIn)), Sbk_Qt3DCore_QTransform_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DCore_QTransform_SignatureStrings[] = {
    "PySide6.Qt3DCore.Qt3DCore.QTransform(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,matrix:QMatrix4x4=None,scale:float=None,scale3D:QVector3D=None,rotation:QQuaternion=None,translation:QVector3D=None,rotationX:float=None,rotationY:float=None,rotationZ:float=None,worldMatrix:QMatrix4x4=None)",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.fromAxes(xAxis:PySide6.QtGui.QVector3D,yAxis:PySide6.QtGui.QVector3D,zAxis:PySide6.QtGui.QVector3D)->PySide6.QtGui.QQuaternion",
    "1:PySide6.Qt3DCore.Qt3DCore.QTransform.fromAxesAndAngles(axis1:PySide6.QtGui.QVector3D,angle1:float,axis2:PySide6.QtGui.QVector3D,angle2:float)->PySide6.QtGui.QQuaternion",
    "0:PySide6.Qt3DCore.Qt3DCore.QTransform.fromAxesAndAngles(axis1:PySide6.QtGui.QVector3D,angle1:float,axis2:PySide6.QtGui.QVector3D,angle2:float,axis3:PySide6.QtGui.QVector3D,angle3:float)->PySide6.QtGui.QQuaternion",
    "1:PySide6.Qt3DCore.Qt3DCore.QTransform.fromAxisAndAngle(axis:PySide6.QtGui.QVector3D,angle:float)->PySide6.QtGui.QQuaternion",
    "0:PySide6.Qt3DCore.Qt3DCore.QTransform.fromAxisAndAngle(x:float,y:float,z:float,angle:float)->PySide6.QtGui.QQuaternion",
    "1:PySide6.Qt3DCore.Qt3DCore.QTransform.fromEulerAngles(eulerAngles:PySide6.QtGui.QVector3D)->PySide6.QtGui.QQuaternion",
    "0:PySide6.Qt3DCore.Qt3DCore.QTransform.fromEulerAngles(pitch:float,yaw:float,roll:float)->PySide6.QtGui.QQuaternion",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.matrix(self)->PySide6.QtGui.QMatrix4x4",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.rotateAround(point:PySide6.QtGui.QVector3D,angle:float,axis:PySide6.QtGui.QVector3D)->PySide6.QtGui.QMatrix4x4",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.rotateFromAxes(xAxis:PySide6.QtGui.QVector3D,yAxis:PySide6.QtGui.QVector3D,zAxis:PySide6.QtGui.QVector3D)->PySide6.QtGui.QMatrix4x4",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.rotation(self)->PySide6.QtGui.QQuaternion",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.rotationX(self)->float",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.rotationY(self)->float",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.rotationZ(self)->float",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.scale(self)->float",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.scale3D(self)->PySide6.QtGui.QVector3D",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.setMatrix(self,matrix:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.setRotation(self,rotation:PySide6.QtGui.QQuaternion)",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.setRotationX(self,rotationX:float)",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.setRotationY(self,rotationY:float)",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.setRotationZ(self,rotationZ:float)",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.setScale(self,scale:float)",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.setScale3D(self,scale:PySide6.QtGui.QVector3D)",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.setTranslation(self,translation:PySide6.QtGui.QVector3D)",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.translation(self)->PySide6.QtGui.QVector3D",
    "PySide6.Qt3DCore.Qt3DCore.QTransform.worldMatrix(self)->PySide6.QtGui.QMatrix4x4",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DCore_QTransform_SignatureByteSize = 492;
static constexpr uint8_t Qt3DCore_QTransform_SignatureBytes[492] = {
    0x78, 0xda, 0xcd, 0x56, 0x5b, 0x4f, 0xc2, 0x30, 0x14, 0x7e, 0xf7, 0x57, 0xf8, 0x08, 0x66, 0x12,
    0x60, 0xc4, 0x87, 0x25, 0x98, 0x2c, 0x4e, 0x7d, 0x30, 0x20, 0x13, 0x34, 0x80, 0xf1, 0xa1, 0x61,
    0x05, 0x9b, 0x94, 0x76, 0xe9, 0xba, 0xb0, 0xf1, 0xeb, 0xdd, 0x7d, 0x05, 0xd9, 0x6c, 0x87, 0x89,
    0x3e, 0xb5, 0x39, 0x97, 0xef, 0x5c, 0x7b, 0x7a, 0x26, 0xe1, 0x14, 0x39, 0xf0, 0xa6, 0x63, 0x73,
    0xdd, 0xba, 0xa3, 0x0c, 0x0a, 0x97, 0x19, 0x03, 0xc4, 0x5b, 0x53, 0xb6, 0x6d, 0x79, 0x10, 0xaf,
    0x35, 0x17, 0x30, 0x48, 0xb8, 0x31, 0xa9, 0x56, 0x18, 0x53, 0x07, 0x0e, 0x89, 0x8f, 0xb1, 0xcb,
    0x99, 0x76, 0x65, 0x3c, 0xc1, 0x70, 0x47, 0x99, 0xf3, 0x4c, 0x70, 0x38, 0x1c, 0x53, 0x02, 0xb5,
    0x2d, 0xe0, 0x0c, 0x05, 0x86, 0x3d, 0x4a, 0xce, 0x41, 0x30, 0x48, 0xc9, 0xde, 0x0a, 0x60, 0x68,
    0xac, 0x31, 0x05, 0x5c, 0x20, 0xe8, 0x96, 0x61, 0xbf, 0xc1, 0x15, 0xa7, 0x4c, 0xb7, 0x52, 0x32,
    0xa3, 0x1c, 0x70, 0x44, 0x89, 0x61, 0xdb, 0x3e, 0xe0, 0x90, 0x91, 0xe8, 0x9e, 0x72, 0x78, 0xec,
    0x29, 0xce, 0x98, 0xa7, 0x95, 0xe6, 0xa2, 0x81, 0x9c, 0xb8, 0x38, 0x45, 0x5c, 0x8a, 0xc4, 0x28,
    0x00, 0xec, 0x8c, 0x4e, 0xfa, 0xdd, 0xbe, 0x98, 0x48, 0xe4, 0xae, 0xb3, 0x66, 0x74, 0x6b, 0x06,
    0xd0, 0x6b, 0x05, 0x66, 0x80, 0x3c, 0x21, 0x7d, 0x8f, 0x3e, 0xea, 0x14, 0xce, 0x6a, 0x61, 0x2d,
    0x77, 0x5f, 0xc7, 0x6d, 0x5f, 0xdf, 0x1e, 0x71, 0xca, 0xfc, 0x5c, 0xf4, 0x0c, 0x25, 0x2f, 0x4d,
    0xe2, 0x98, 0x64, 0x83, 0x23, 0x77, 0x41, 0x64, 0xb1, 0x57, 0xe9, 0x10, 0x88, 0x85, 0x7a, 0x69,
    0xa6, 0xb4, 0x58, 0xb4, 0x5f, 0x2f, 0xda, 0x4f, 0x45, 0x6b, 0x5d, 0xed, 0xfe, 0x2b, 0x57, 0x13,
    0x51, 0xbd, 0x5e, 0x54, 0x97, 0x88, 0x4a, 0xa9, 0x00, 0xa8, 0x88, 0x2a, 0x09, 0xaa, 0xde, 0xfa,
    0x6f, 0xa7, 0x54, 0x30, 0x1e, 0x64, 0x39, 0x08, 0xb3, 0x73, 0x9f, 0xe7, 0x44, 0xd2, 0xae, 0x42,
    0xd0, 0xf7, 0x3e, 0x86, 0x2c, 0x2b, 0x24, 0x2c, 0xef, 0x8d, 0x9a, 0xbd, 0xdb, 0xcc, 0xac, 0x8b,
    0xf8, 0xea, 0x33, 0x8f, 0x18, 0xec, 0xb2, 0x1b, 0xa3, 0x18, 0x4b, 0x84, 0x2a, 0x65, 0x31, 0x9d,
    0x7c, 0xc9, 0x1c, 0xfd, 0x0e, 0x56, 0x8c, 0x15, 0x39, 0xac, 0x64, 0x4e, 0x41, 0x93, 0x51, 0x9f,
    0x38, 0x2d, 0x97, 0xa2, 0x83, 0x99, 0x5c, 0xd9, 0x26, 0x1a, 0x50, 0x9a, 0x20, 0x8d, 0x7c, 0x7a,
    0xf8, 0x83, 0x51, 0xd7, 0xc4, 0xd1, 0xa8, 0x6c, 0x15, 0xa5, 0x50, 0xad, 0x6b, 0xf1, 0xbb, 0xe4,
    0x78, 0x49, 0xae, 0xd5, 0x74, 0x17, 0x67, 0xe8, 0x2e, 0x1b, 0xe8, 0x26, 0xbf, 0x6b, 0x53, 0x3d,
    0xdd, 0xaa, 0xc8, 0x5c, 0x5e, 0x21, 0x49, 0x2c, 0xc8, 0x47, 0xe5, 0x93, 0xc8, 0x17, 0x03, 0x1e,
    0xba, 0x88, 0x6c, 0x3a, 0xaf, 0x71, 0xfe, 0xdf, 0xab, 0xea, 0xac, 0x5d, 0x1e, 0x71, 0x0a, 0xd4,
    0x8f, 0xb6, 0xb4, 0xf1, 0x17, 0xb1, 0x0d, 0xca, 0xc5, 0xa2, 0xb2, 0x1b, 0xd4, 0x91, 0xe7, 0x87,
    0xd0, 0xd9, 0xfa, 0xa1, 0x8e, 0xb3, 0x38, 0xc4, 0x59, 0x34, 0xc5, 0x59, 0x1e, 0xe2, 0x2c, 0x55,
    0x71, 0xa6, 0x45, 0xd7, 0x88, 0xfb, 0x9a, 0xa2, 0x7e, 0xd6, 0x3d, 0x19, 0x42, 0xd5, 0x1b, 0x97,
    0xc6, 0x9c, 0x95, 0x6b, 0x5f, 0x8a, 0x2b, 0xee, 0x81, 0xe7, 0xa1, 0xf3, 0x23, 0xe8, 0x73, 0x1b,
    0x5e, 0xd8, 0x23, 0x7f, 0xfc, 0x05, 0xbe, 0x00, 0x0e, 0x5d, 0x19, 0x75
};
#endif

PyTypeObject *init_Qt3DCore_QTransform(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX].type != nullptr)
        return SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DCore_QTransform_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QComponent_IDX]))));

    _Sbk_Qt3DCore_QTransform_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QTransform",
        "Qt3DCore::QTransform*",
        &Sbk_Qt3DCore_QTransform_spec,
        &Shiboken::callCppDestructor< Qt3DCore::QTransform >,
        Sbk_Qt3DCore_QTransform_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DCore_QTransform_TypeF(); // references _Sbk_Qt3DCore_QTransform_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DCore_QTransform_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DCore_QTransform_SignatureBytes, Qt3DCore_QTransform_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DCore_QTransform_PropertyStrings);
    SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTransform_PythonToCpp_QTransform_PTR,
        is_QTransform_PythonToCpp_QTransform_PTR_Convertible,
        QTransform_PTR_CppToPython_QTransform);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QTransform");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QTransform*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QTransform&");
    Shiboken::Conversions::registerConverterAlias(converter, "QTransform");
    Shiboken::Conversions::registerConverterAlias(converter, "QTransform*");
    Shiboken::Conversions::registerConverterAlias(converter, "QTransform&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DCore::QTransform).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QTransformWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DCore_QTransform_TypeF(), &Sbk_Qt3DCore_QTransform_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Qt3DCore::QTransform::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DCore::QTransform::staticMetaObject, sizeof(QTransformWrapper));

    return pyType;
}
