// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dcore_python.h"

// main header
#include "qt3dcore_wrapper.h"

// inner classes
#include "qt3dcore_qbackendnode_wrapper.h"
#include "qt3dcore_qbackendnodemapper_wrapper.h"
#include "qt3dcore_qaspectjob_wrapper.h"
#include "qt3dcore_qaspectengine_wrapper.h"
#include "qt3dcore_qnode_wrapper.h"
#include "qt3dcore_qjoint_wrapper.h"
#include "qt3dcore_qentity_wrapper.h"
#include "qt3dcore_qgeometryview_wrapper.h"
#include "qt3dcore_qgeometry_wrapper.h"
#include "qt3dcore_qattribute_wrapper.h"
#include "qt3dcore_qbuffer_wrapper.h"
#include "qt3dcore_qcomponent_wrapper.h"
#include "qt3dcore_qtransform_wrapper.h"
#include "qt3dcore_qcoresettings_wrapper.h"
#include "qt3dcore_qboundingvolume_wrapper.h"
#include "qt3dcore_qarmature_wrapper.h"
#include "qt3dcore_qabstractskeleton_wrapper.h"
#include "qt3dcore_qskeletonloader_wrapper.h"
#include "qt3dcore_qskeleton_wrapper.h"
#include "qt3dcore_qabstractfunctor_wrapper.h"
#include "qt3dcore_qabstractaspect_wrapper.h"
#include "qt3dcore_qcoreaspect_wrapper.h"
#include "qt3dcore_qnodeid_wrapper.h"
#include "qt3dcore_qnodeidtypepair_wrapper.h"

// Argument includes
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_Qt3DCoreFunc_qHash(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "qHash", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCoreQt3DCore_IDX]);

    if (PyArg_ParseTuple(args, "|OO:qHash", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static Qt3DCore::qHash(Qt3DCore::QNodeId,size_t=)->size_t
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNodeId_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qHash(Qt3DCore::QNodeId,size_t)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), (pyArgs[1])))) {
            overloadId = 0; // qHash(Qt3DCore::QNodeId,size_t)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "qHash", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCoreQt3DCore_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_seed = Shiboken::String::createStaticString("seed");
            if (PyDict_Contains(kwds, key_seed) != 0) {
                value = PyDict_GetItem(kwds, key_seed);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_seed);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "qHash", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCoreQt3DCore_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "qHash", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCoreQt3DCore_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_seed);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "qHash", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCoreQt3DCore_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::Qt3DCore::QNodeId cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        size_t cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qHash(Qt3DCore::QNodeId,size_t)
            size_t cppResult = ::Qt3DCore::qHash(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCoreFunc_qIdForNode(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static Qt3DCore::qIdForNode(Qt3DCore::QNode*)->Qt3DCore::QNodeId
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArg)))) {
        overloadId = 0; // qIdForNode(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "qIdForNode", errInfo, SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCoreQt3DCore_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DCore::QNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qIdForNode(Qt3DCore::QNode*)
            Qt3DCore::QNodeId cppResult = ::Qt3DCore::qIdForNode(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNodeId_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DCore_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DCore_methods[] = {
    {"qHash", reinterpret_cast<PyCFunction>(Sbk_Qt3DCoreFunc_qHash), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"qIdForNode", reinterpret_cast<PyCFunction>(Sbk_Qt3DCoreFunc_qIdForNode), METH_O|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_Qt3DCore_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DCore_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DCore_Type = nullptr;
static PyTypeObject *Sbk_Qt3DCore_TypeF(void)
{
    return _Sbk_Qt3DCore_Type;
}

static PyType_Slot Sbk_Qt3DCore_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(Sbk_object_dealloc /* PYSIDE-832: Prevent replacement of "0" with subtype_dealloc. */)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DCore_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DCore_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DCore_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DCore_spec = {
    "2:PySide6.Qt3DCore.Qt3DCore",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DCore_slots
};

} //extern "C"

// Type conversion functions.

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DCoreQt3DCore_SignatureStrings[] = {
    "PySide6.Qt3DCore.Qt3DCore.qHash(id:PySide6.Qt3DCore.Qt3DCore.QNodeId,seed:size_t=0)->size_t",
    "PySide6.Qt3DCore.Qt3DCore.qIdForNode(node:PySide6.Qt3DCore.Qt3DCore.QNode)->PySide6.Qt3DCore.Qt3DCore.QNodeId",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DCoreQt3DCore_SignatureByteSize = 86;
static constexpr uint8_t Qt3DCoreQt3DCore_SignatureBytes[86] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x31, 0x76, 0x71, 0xce,
    0x2f, 0x4a, 0x45, 0x30, 0x0a, 0x3d, 0x12, 0x8b, 0x33, 0x34, 0x32, 0x53, 0xac, 0x02, 0x70, 0x2a,
    0x09, 0xf4, 0xcb, 0x4f, 0x49, 0xf5, 0x4c, 0xd1, 0x29, 0x4e, 0x4d, 0x4d, 0xb1, 0x2a, 0xce, 0xac,
    0x4a, 0x8d, 0x2f, 0xb1, 0x35, 0xd0, 0xd4, 0xb5, 0x83, 0x30, 0xb9, 0x70, 0x6b, 0x2c, 0xf4, 0x4c,
    0x71, 0xcb, 0x2f, 0x02, 0xe9, 0xd6, 0xc8, 0x03, 0x12, 0x84, 0xac, 0x00, 0x1a, 0x49, 0xd0, 0x11,
    0x5c, 0x00, 0x00, 0xd3, 0x43, 0x9b
};
#endif

PyTypeObject *init_Qt3DCoreQt3DCore(PyObject *module)
{
    if (SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCoreQt3DCore_IDX].type != nullptr)
        return SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCoreQt3DCore_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DCore_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_Qt3DCore_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "Qt3DCore",
        "Qt3DCore",
        &Sbk_Qt3DCore_spec,
        nullptr,
        Sbk_Qt3DCore_Type_bases.object(),
        0);
    auto *pyType = Sbk_Qt3DCore_TypeF(); // references _Sbk_Qt3DCore_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DCoreQt3DCore_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DCoreQt3DCore_SignatureBytes, Qt3DCoreQt3DCore_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DCore_PropertyStrings);
    SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCoreQt3DCore_IDX].type = pyType;



    return pyType;
}
