// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dextras_python.h"

// main header
#include "qt3dextras_qconegeometryview_wrapper.h"

// Argument includes
#include <Qt3DCore/qgeometry.h>
#include <Qt3DCore/qgeometryview.h>
#include <Qt3DCore/qnode.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DExtras;

// Native ---------------------------------------------------------

void QConeGeometryViewWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QConeGeometryViewWrapper::QConeGeometryViewWrapper(::Qt3DCore::QNode * parent) : Qt3DExtras::QConeGeometryView(parent)
{
}

void QConeGeometryViewWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QConeGeometryView", funcName);
        return;
    }
}

void QConeGeometryViewWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QConeGeometryView", funcName);
        return;
    }
}

void QConeGeometryViewWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QConeGeometryView", funcName);
        return;
    }
}

void QConeGeometryViewWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QConeGeometryView", funcName);
        return;
    }
}

bool QConeGeometryViewWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QConeGeometryView", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QConeGeometryView", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QConeGeometryViewWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QConeGeometryView", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QConeGeometryView", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QConeGeometryViewWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QConeGeometryView", funcName);
        return;
    }
}

const QMetaObject *QConeGeometryViewWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DExtras::QConeGeometryView::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QConeGeometryViewWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DExtras::QConeGeometryView::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QConeGeometryViewWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QConeGeometryViewWrapper *>(this));
    return Qt3DExtras::QConeGeometryView::qt_metacast(_clname);
}

QConeGeometryViewWrapper::~QConeGeometryViewWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DExtras_QConeGeometryView_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DExtras::QConeGeometryView >()))
        return -1;

    QConeGeometryViewWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QConeGeometryView", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QConeGeometryView::QConeGeometryView(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QConeGeometryView(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QConeGeometryView(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QConeGeometryView(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QConeGeometryViewWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QConeGeometryViewWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DExtras::QConeGeometryView >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_bottomRadius(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bottomRadius()const
        float cppResult = const_cast<const ::Qt3DExtras::QConeGeometryView *>(cppSelf)->bottomRadius();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_hasBottomEndcap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasBottomEndcap()const
        bool cppResult = const_cast<const ::Qt3DExtras::QConeGeometryView *>(cppSelf)->hasBottomEndcap();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_hasTopEndcap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasTopEndcap()const
        bool cppResult = const_cast<const ::Qt3DExtras::QConeGeometryView *>(cppSelf)->hasTopEndcap();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // length()const
        float cppResult = const_cast<const ::Qt3DExtras::QConeGeometryView *>(cppSelf)->length();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_rings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rings()const
        int cppResult = const_cast<const ::Qt3DExtras::QConeGeometryView *>(cppSelf)->rings();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_setBottomRadius(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QConeGeometryView::setBottomRadius(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setBottomRadius(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBottomRadius", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBottomRadius(float)
            cppSelf->setBottomRadius(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_setFirstInstance(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeometryView::setFirstInstance(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setFirstInstance(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFirstInstance", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("setFirstInstance(int firstInstance)");
        return {};
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_setGeometry(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeometryView::setGeometry(Qt3DCore::QGeometry*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QGeometry_IDX]), (pyArg)))) {
        overloadId = 0; // setGeometry(Qt3DCore::QGeometry*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGeometry", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("setGeometry(Qt3DCore.QGeometry *geometry)");
        return {};
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_setHasBottomEndcap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QConeGeometryView::setHasBottomEndcap(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setHasBottomEndcap(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHasBottomEndcap", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHasBottomEndcap(bool)
            cppSelf->setHasBottomEndcap(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_setHasTopEndcap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QConeGeometryView::setHasTopEndcap(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setHasTopEndcap(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHasTopEndcap", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHasTopEndcap(bool)
            cppSelf->setHasTopEndcap(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_setIndexOffset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeometryView::setIndexOffset(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setIndexOffset(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIndexOffset", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("setIndexOffset(int indexOffset)");
        return {};
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_setInstanceCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeometryView::setInstanceCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setInstanceCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInstanceCount", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("setInstanceCount(int instanceCount)");
        return {};
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_setLength(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QConeGeometryView::setLength(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setLength(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLength", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLength(float)
            cppSelf->setLength(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_setPrimitiveRestartEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeometryView::setPrimitiveRestartEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setPrimitiveRestartEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPrimitiveRestartEnabled", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("setPrimitiveRestartEnabled(bool enabled)");
        return {};
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_setPrimitiveType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeometryView::setPrimitiveType(Qt3DCore::QGeometryView::PrimitiveType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QGeometryView_PrimitiveType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPrimitiveType(Qt3DCore::QGeometryView::PrimitiveType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPrimitiveType", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("setPrimitiveType(Qt3DCore.QGeometryView.PrimitiveType primitiveType)");
        return {};
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_setRestartIndexValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeometryView::setRestartIndexValue(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setRestartIndexValue(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRestartIndexValue", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("setRestartIndexValue(int index)");
        return {};
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_setRings(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QConeGeometryView::setRings(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setRings(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRings", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRings(int)
            cppSelf->setRings(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_setSlices(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QConeGeometryView::setSlices(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSlices(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSlices", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSlices(int)
            cppSelf->setSlices(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_setTopRadius(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QConeGeometryView::setTopRadius(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setTopRadius(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTopRadius", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTopRadius(float)
            cppSelf->setTopRadius(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_setVertexCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeometryView::setVertexCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setVertexCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVertexCount", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("setVertexCount(int vertexCount)");
        return {};
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_slices(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // slices()const
        int cppResult = const_cast<const ::Qt3DExtras::QConeGeometryView *>(cppSelf)->slices();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DExtras_QConeGeometryViewFunc_topRadius(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // topRadius()const
        float cppResult = const_cast<const ::Qt3DExtras::QConeGeometryView *>(cppSelf)->topRadius();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DExtras_QConeGeometryView_PropertyStrings[] = {
    "bottomRadius::",
    "hasBottomEndcap::",
    "hasTopEndcap::",
    "length::",
    "rings::",
    "slices::",
    "topRadius::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DExtras_QConeGeometryView_methods[] = {
    {"bottomRadius", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_bottomRadius), METH_NOARGS, nullptr},
    {"hasBottomEndcap", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_hasBottomEndcap), METH_NOARGS, nullptr},
    {"hasTopEndcap", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_hasTopEndcap), METH_NOARGS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_length), METH_NOARGS, nullptr},
    {"rings", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_rings), METH_NOARGS, nullptr},
    {"setBottomRadius", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_setBottomRadius), METH_O, nullptr},
    {"setFirstInstance", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_setFirstInstance), METH_O, nullptr},
    {"setGeometry", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_setGeometry), METH_O, nullptr},
    {"setHasBottomEndcap", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_setHasBottomEndcap), METH_O, nullptr},
    {"setHasTopEndcap", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_setHasTopEndcap), METH_O, nullptr},
    {"setIndexOffset", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_setIndexOffset), METH_O, nullptr},
    {"setInstanceCount", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_setInstanceCount), METH_O, nullptr},
    {"setLength", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_setLength), METH_O, nullptr},
    {"setPrimitiveRestartEnabled", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_setPrimitiveRestartEnabled), METH_O, nullptr},
    {"setPrimitiveType", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_setPrimitiveType), METH_O, nullptr},
    {"setRestartIndexValue", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_setRestartIndexValue), METH_O, nullptr},
    {"setRings", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_setRings), METH_O, nullptr},
    {"setSlices", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_setSlices), METH_O, nullptr},
    {"setTopRadius", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_setTopRadius), METH_O, nullptr},
    {"setVertexCount", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_setVertexCount), METH_O, nullptr},
    {"slices", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_slices), METH_NOARGS, nullptr},
    {"topRadius", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QConeGeometryViewFunc_topRadius), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DExtras_QConeGeometryView_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DExtras::QConeGeometryView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QConeGeometryViewWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DExtras_QConeGeometryView_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DExtras_QConeGeometryView_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DExtras_QConeGeometryView_Type = nullptr;
static PyTypeObject *Sbk_Qt3DExtras_QConeGeometryView_TypeF(void)
{
    return _Sbk_Qt3DExtras_QConeGeometryView_Type;
}

static PyType_Slot Sbk_Qt3DExtras_QConeGeometryView_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DExtras_QConeGeometryView_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DExtras_QConeGeometryView_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DExtras_QConeGeometryView_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DExtras_QConeGeometryView_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DExtras_QConeGeometryView_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DExtras_QConeGeometryView_spec = {
    "2:PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DExtras_QConeGeometryView_slots
};

} //extern "C"

static void *Sbk_Qt3DExtras_QConeGeometryView_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DExtras::QConeGeometryView *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QConeGeometryView_PythonToCpp_QConeGeometryView_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DExtras_QConeGeometryView_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QConeGeometryView_PythonToCpp_QConeGeometryView_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DExtras_QConeGeometryView_TypeF()))
        return QConeGeometryView_PythonToCpp_QConeGeometryView_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QConeGeometryView_PTR_CppToPython_QConeGeometryView(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DExtras::QConeGeometryView *>(const_cast<void *>(cppIn)), Sbk_Qt3DExtras_QConeGeometryView_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DExtras_QConeGeometryView_SignatureStrings[] = {
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,rings:int=None,slices:int=None,hasTopEndcap:bool=None,hasBottomEndcap:bool=None,topRadius:float=None,bottomRadius:float=None,length:float=None)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.bottomRadius(self)->float",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.hasBottomEndcap(self)->bool",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.hasTopEndcap(self)->bool",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.length(self)->float",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.rings(self)->int",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.setBottomRadius(self,bottomRadius:float)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.setFirstInstance(self,firstInstance:int)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.setGeometry(self,geometry:PySide6.Qt3DCore.Qt3DCore.QGeometry)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.setHasBottomEndcap(self,hasBottomEndcap:bool)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.setHasTopEndcap(self,hasTopEndcap:bool)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.setIndexOffset(self,indexOffset:int)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.setInstanceCount(self,instanceCount:int)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.setLength(self,length:float)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.setPrimitiveRestartEnabled(self,enabled:bool)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.setPrimitiveType(self,primitiveType:PySide6.Qt3DCore.Qt3DCore.QGeometryView.PrimitiveType)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.setRestartIndexValue(self,index:int)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.setRings(self,rings:int)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.setSlices(self,slices:int)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.setTopRadius(self,topRadius:float)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.setVertexCount(self,vertexCount:int)",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.slices(self)->int",
    "PySide6.Qt3DExtras.Qt3DExtras.QConeGeometryView.topRadius(self)->float",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DExtras_QConeGeometryView_SignatureByteSize = 396;
static constexpr uint8_t Qt3DExtras_QConeGeometryView_SignatureBytes[396] = {
    0x78, 0xda, 0xa5, 0x95, 0x4d, 0x4f, 0x02, 0x31, 0x10, 0x86, 0xef, 0xfe, 0x12, 0x31, 0xe8, 0xc5,
    0xc4, 0xc3, 0x26, 0x78, 0x00, 0x51, 0x89, 0x06, 0x56, 0x20, 0xdc, 0x0b, 0x9d, 0x85, 0x26, 0xa5,
    0xdd, 0xb4, 0xb3, 0xc0, 0xfe, 0x7b, 0x97, 0x76, 0x3f, 0xba, 0x40, 0x8c, 0x0c, 0xb7, 0xce, 0xbb,
    0xdb, 0xa7, 0x9d, 0xaf, 0x4e, 0x9c, 0xcf, 0x04, 0x87, 0x97, 0xa7, 0x1f, 0x7c, 0x7e, 0x1b, 0x1e,
    0xd0, 0x30, 0xdb, 0x5a, 0x0e, 0xb4, 0x82, 0x0f, 0xd0, 0x5b, 0x40, 0x93, 0x2f, 0x04, 0xec, 0xef,
    0x2d, 0xc8, 0xa4, 0x9b, 0x32, 0x03, 0x0a, 0xa3, 0x38, 0xd8, 0x3b, 0xd0, 0x06, 0x82, 0xc5, 0x58,
    0x73, 0xe8, 0xa9, 0x4c, 0xca, 0x14, 0x4d, 0xf7, 0x21, 0xfa, 0x82, 0x7c, 0xaf, 0x0d, 0x9f, 0x28,
    0x99, 0xf7, 0xc6, 0x05, 0xb2, 0x6b, 0x84, 0x5a, 0xdb, 0x48, 0x28, 0xf4, 0xa6, 0x95, 0x62, 0x05,
    0x81, 0xbd, 0x61, 0x76, 0xae, 0xd3, 0xa1, 0xe2, 0x2b, 0x96, 0x46, 0x4b, 0xad, 0x65, 0x2d, 0xf7,
    0x35, 0xa2, 0xde, 0x9e, 0x7d, 0x41, 0x9d, 0x4e, 0x19, 0x17, 0x99, 0x8d, 0x12, 0xa9, 0x59, 0x49,
    0x59, 0xba, 0x7f, 0xcf, 0x75, 0x09, 0x6a, 0x8d, 0x9b, 0x40, 0xe9, 0xdc, 0xc5, 0xd7, 0x85, 0xe1,
    0x29, 0x44, 0xbb, 0x98, 0x74, 0x1e, 0x5f, 0x1d, 0xef, 0x6a, 0xd2, 0x89, 0x4f, 0x15, 0xec, 0xe8,
    0x1a, 0x85, 0x55, 0x87, 0xed, 0x26, 0x90, 0x8f, 0xd0, 0x6d, 0x8e, 0xb9, 0x14, 0x57, 0x88, 0x22,
    0xb3, 0x57, 0x03, 0x2c, 0x60, 0xff, 0x34, 0xcc, 0x17, 0x72, 0xda, 0xa1, 0x80, 0xdf, 0x85, 0xb1,
    0x38, 0x52, 0x16, 0x99, 0x5a, 0x81, 0x27, 0x27, 0xa1, 0x74, 0x2c, 0x45, 0x12, 0xb8, 0xb2, 0x3d,
    0x73, 0x5d, 0x5a, 0x7f, 0xb5, 0x4a, 0xb5, 0x83, 0x74, 0xdc, 0xe7, 0x85, 0xea, 0xb9, 0xd8, 0x26,
    0x54, 0x7a, 0xbb, 0x9e, 0xce, 0x1b, 0x93, 0xc4, 0x1d, 0x29, 0x0e, 0x87, 0x49, 0x92, 0x14, 0x4b,
    0x8f, 0x15, 0x8d, 0x40, 0x8e, 0x7c, 0x95, 0xba, 0x81, 0xce, 0x54, 0x8d, 0x0d, 0x24, 0x32, 0xf8,
    0xbb, 0x69, 0x86, 0xd6, 0xd3, 0x41, 0x82, 0xc5, 0x46, 0x6c, 0x05, 0x8a, 0x1d, 0x4c, 0xa1, 0xb8,
    0x9b, 0xc1, 0xa1, 0x62, 0x4b, 0x09, 0xdc, 0xd3, 0xc1, 0x1b, 0xf4, 0xc0, 0xd6, 0xf4, 0x79, 0x9e,
    0x96, 0x65, 0x9d, 0x86, 0xd2, 0x7f, 0xea, 0xd0, 0xb1, 0x5a, 0x20, 0xd2, 0x55, 0x4a, 0xff, 0x5c,
    0xaa, 0x17, 0x4c, 0x66, 0x10, 0x64, 0x9a, 0x9c, 0x8a, 0x69, 0xfd, 0xa6, 0x34, 0x13, 0x84, 0x04,
    0x9a, 0xb9, 0x81, 0xe3, 0x49, 0xcd, 0xf0, 0x21, 0xa1, 0xe6, 0xd5, 0xe8, 0xf1, 0xb4, 0x93, 0x49,
    0x44, 0x42, 0x2e, 0xc0, 0x20, 0x1c, 0x82, 0x42, 0xde, 0x35, 0x02, 0xf1, 0x9e, 0x8d, 0xbf, 0xc4,
    0xd7, 0x18, 0x5b, 0x6e, 0xd6, 0x53, 0xe1, 0x17, 0x8c, 0xfb, 0x04, 0xdc
};
#endif

PyTypeObject *init_Qt3DExtras_QConeGeometryView(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX].type != nullptr)
        return SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DExtras_QConeGeometryView_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QGeometryView_IDX]))));

    _Sbk_Qt3DExtras_QConeGeometryView_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QConeGeometryView",
        "Qt3DExtras::QConeGeometryView*",
        &Sbk_Qt3DExtras_QConeGeometryView_spec,
        &Shiboken::callCppDestructor< Qt3DExtras::QConeGeometryView >,
        Sbk_Qt3DExtras_QConeGeometryView_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DExtras_QConeGeometryView_TypeF(); // references _Sbk_Qt3DExtras_QConeGeometryView_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DExtras_QConeGeometryView_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DExtras_QConeGeometryView_SignatureBytes, Qt3DExtras_QConeGeometryView_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DExtras_QConeGeometryView_PropertyStrings);
    SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QConeGeometryView_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QConeGeometryView_PythonToCpp_QConeGeometryView_PTR,
        is_QConeGeometryView_PythonToCpp_QConeGeometryView_PTR_Convertible,
        QConeGeometryView_PTR_CppToPython_QConeGeometryView);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DExtras::QConeGeometryView");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DExtras::QConeGeometryView*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DExtras::QConeGeometryView&");
    Shiboken::Conversions::registerConverterAlias(converter, "QConeGeometryView");
    Shiboken::Conversions::registerConverterAlias(converter, "QConeGeometryView*");
    Shiboken::Conversions::registerConverterAlias(converter, "QConeGeometryView&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DExtras::QConeGeometryView).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QConeGeometryViewWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DExtras_QConeGeometryView_TypeF(), &Sbk_Qt3DExtras_QConeGeometryView_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Qt3DExtras::QConeGeometryView::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DExtras::QConeGeometryView::staticMetaObject, sizeof(QConeGeometryViewWrapper));

    return pyType;
}
