// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dextras_python.h"

// main header
#include "qt3dextras_qnormaldiffusemapmaterial_wrapper.h"

// Argument includes
#include <QList>
#include <Qt3DCore/qnode.h>
#include <Qt3DRender/qabstracttexture.h>
#include <Qt3DRender/qeffect.h>
#include <Qt3DRender/qparameter.h>
#include <QtGui/qcolor.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DExtras;

// Native ---------------------------------------------------------

void QNormalDiffuseMapMaterialWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QNormalDiffuseMapMaterialWrapper::QNormalDiffuseMapMaterialWrapper(::Qt3DCore::QNode * parent) : Qt3DExtras::QNormalDiffuseMapMaterial(parent)
{
}

void QNormalDiffuseMapMaterialWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNormalDiffuseMapMaterial", funcName);
        return;
    }
}

void QNormalDiffuseMapMaterialWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNormalDiffuseMapMaterial", funcName);
        return;
    }
}

void QNormalDiffuseMapMaterialWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNormalDiffuseMapMaterial", funcName);
        return;
    }
}

void QNormalDiffuseMapMaterialWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNormalDiffuseMapMaterial", funcName);
        return;
    }
}

bool QNormalDiffuseMapMaterialWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNormalDiffuseMapMaterial", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNormalDiffuseMapMaterial", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QNormalDiffuseMapMaterialWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNormalDiffuseMapMaterial", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNormalDiffuseMapMaterial", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QNormalDiffuseMapMaterialWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNormalDiffuseMapMaterial", funcName);
        return;
    }
}

const QMetaObject *QNormalDiffuseMapMaterialWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DExtras::QNormalDiffuseMapMaterial::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QNormalDiffuseMapMaterialWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DExtras::QNormalDiffuseMapMaterial::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QNormalDiffuseMapMaterialWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QNormalDiffuseMapMaterialWrapper *>(this));
    return Qt3DExtras::QNormalDiffuseMapMaterial::qt_metacast(_clname);
}

QNormalDiffuseMapMaterialWrapper::~QNormalDiffuseMapMaterialWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DExtras::QNormalDiffuseMapMaterial >()))
        return -1;

    QNormalDiffuseMapMaterialWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QNormalDiffuseMapMaterial", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNormalDiffuseMapMaterial::QNormalDiffuseMapMaterial(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QNormalDiffuseMapMaterial(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QNormalDiffuseMapMaterial(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QNormalDiffuseMapMaterial(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QNormalDiffuseMapMaterialWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QNormalDiffuseMapMaterialWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DExtras::QNormalDiffuseMapMaterial >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_ambient(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QNormalDiffuseMapMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ambient()const
        QColor cppResult = const_cast<const ::Qt3DExtras::QNormalDiffuseMapMaterial *>(cppSelf)->ambient();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_diffuse(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QNormalDiffuseMapMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // diffuse()const
        Qt3DRender::QAbstractTexture * cppResult = const_cast<const ::Qt3DExtras::QNormalDiffuseMapMaterial *>(cppSelf)->diffuse();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_normal(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QNormalDiffuseMapMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // normal()const
        Qt3DRender::QAbstractTexture * cppResult = const_cast<const ::Qt3DExtras::QNormalDiffuseMapMaterial *>(cppSelf)->normal();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_setAmbient(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QNormalDiffuseMapMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNormalDiffuseMapMaterial::setAmbient(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setAmbient(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAmbient", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setAmbient(QColor)
            cppSelf->setAmbient(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_setDiffuse(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QNormalDiffuseMapMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNormalDiffuseMapMaterial::setDiffuse(Qt3DRender::QAbstractTexture*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), (pyArg)))) {
        overloadId = 0; // setDiffuse(Qt3DRender::QAbstractTexture*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDiffuse", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QAbstractTexture *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDiffuse(Qt3DRender::QAbstractTexture*)
            cppSelf->setDiffuse(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_setNormal(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QNormalDiffuseMapMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNormalDiffuseMapMaterial::setNormal(Qt3DRender::QAbstractTexture*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), (pyArg)))) {
        overloadId = 0; // setNormal(Qt3DRender::QAbstractTexture*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNormal", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QAbstractTexture *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNormal(Qt3DRender::QAbstractTexture*)
            cppSelf->setNormal(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_setShininess(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QNormalDiffuseMapMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNormalDiffuseMapMaterial::setShininess(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setShininess(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShininess", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShininess(float)
            cppSelf->setShininess(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_setSpecular(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QNormalDiffuseMapMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNormalDiffuseMapMaterial::setSpecular(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setSpecular(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSpecular", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSpecular(QColor)
            cppSelf->setSpecular(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_setTextureScale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QNormalDiffuseMapMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNormalDiffuseMapMaterial::setTextureScale(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setTextureScale(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextureScale", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextureScale(float)
            cppSelf->setTextureScale(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_shininess(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QNormalDiffuseMapMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shininess()const
        float cppResult = const_cast<const ::Qt3DExtras::QNormalDiffuseMapMaterial *>(cppSelf)->shininess();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_specular(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QNormalDiffuseMapMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // specular()const
        QColor cppResult = const_cast<const ::Qt3DExtras::QNormalDiffuseMapMaterial *>(cppSelf)->specular();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_textureScale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QNormalDiffuseMapMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureScale()const
        float cppResult = const_cast<const ::Qt3DExtras::QNormalDiffuseMapMaterial *>(cppSelf)->textureScale();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_PropertyStrings[] = {
    "ambient::",
    "diffuse::",
    "normal::",
    "shininess::",
    "specular::",
    "textureScale::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_methods[] = {
    {"ambient", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_ambient), METH_NOARGS, nullptr},
    {"diffuse", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_diffuse), METH_NOARGS, nullptr},
    {"normal", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_normal), METH_NOARGS, nullptr},
    {"setAmbient", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_setAmbient), METH_O, nullptr},
    {"setDiffuse", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_setDiffuse), METH_O, nullptr},
    {"setNormal", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_setNormal), METH_O, nullptr},
    {"setShininess", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_setShininess), METH_O, nullptr},
    {"setSpecular", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_setSpecular), METH_O, nullptr},
    {"setTextureScale", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_setTextureScale), METH_O, nullptr},
    {"shininess", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_shininess), METH_NOARGS, nullptr},
    {"specular", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_specular), METH_NOARGS, nullptr},
    {"textureScale", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterialFunc_textureScale), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DExtras::QNormalDiffuseMapMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QNormalDiffuseMapMaterialWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_Type = nullptr;
static PyTypeObject *Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_TypeF(void)
{
    return _Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_Type;
}

static PyType_Slot Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_spec = {
    "2:PySide6.Qt3DExtras.Qt3DExtras.QNormalDiffuseMapMaterial",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_slots
};

} //extern "C"

static void *Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DExtras::QNormalDiffuseMapMaterial *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNormalDiffuseMapMaterial_PythonToCpp_QNormalDiffuseMapMaterial_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNormalDiffuseMapMaterial_PythonToCpp_QNormalDiffuseMapMaterial_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_TypeF()))
        return QNormalDiffuseMapMaterial_PythonToCpp_QNormalDiffuseMapMaterial_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNormalDiffuseMapMaterial_PTR_CppToPython_QNormalDiffuseMapMaterial(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DExtras::QNormalDiffuseMapMaterial *>(const_cast<void *>(cppIn)), Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DExtras_QNormalDiffuseMapMaterial_SignatureStrings[] = {
    "PySide6.Qt3DExtras.Qt3DExtras.QNormalDiffuseMapMaterial(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,ambient:QColor=None,specular:QColor=None,diffuse:Qt3DRender.QAbstractTexture=None,normal:Qt3DRender.QAbstractTexture=None,shininess:float=None,textureScale:float=None)",
    "PySide6.Qt3DExtras.Qt3DExtras.QNormalDiffuseMapMaterial.ambient(self)->PySide6.QtGui.QColor",
    "PySide6.Qt3DExtras.Qt3DExtras.QNormalDiffuseMapMaterial.diffuse(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture",
    "PySide6.Qt3DExtras.Qt3DExtras.QNormalDiffuseMapMaterial.normal(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture",
    "PySide6.Qt3DExtras.Qt3DExtras.QNormalDiffuseMapMaterial.setAmbient(self,ambient:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.Qt3DExtras.Qt3DExtras.QNormalDiffuseMapMaterial.setDiffuse(self,diffuse:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture)",
    "PySide6.Qt3DExtras.Qt3DExtras.QNormalDiffuseMapMaterial.setNormal(self,normal:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture)",
    "PySide6.Qt3DExtras.Qt3DExtras.QNormalDiffuseMapMaterial.setShininess(self,shininess:float)",
    "PySide6.Qt3DExtras.Qt3DExtras.QNormalDiffuseMapMaterial.setSpecular(self,specular:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.Qt3DExtras.Qt3DExtras.QNormalDiffuseMapMaterial.setTextureScale(self,textureScale:float)",
    "PySide6.Qt3DExtras.Qt3DExtras.QNormalDiffuseMapMaterial.shininess(self)->float",
    "PySide6.Qt3DExtras.Qt3DExtras.QNormalDiffuseMapMaterial.specular(self)->PySide6.QtGui.QColor",
    "PySide6.Qt3DExtras.Qt3DExtras.QNormalDiffuseMapMaterial.textureScale(self)->float",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DExtras_QNormalDiffuseMapMaterial_SignatureByteSize = 364;
static constexpr uint8_t Qt3DExtras_QNormalDiffuseMapMaterial_SignatureBytes[364] = {
    0x78, 0xda, 0xdd, 0x54, 0x4d, 0x4f, 0xc2, 0x40, 0x10, 0xbd, 0xfb, 0x2b, 0x38, 0x8a, 0xa9, 0x4d,
    0x8c, 0x86, 0x43, 0x13, 0x4c, 0x08, 0x18, 0x0e, 0x4a, 0xa5, 0x14, 0xb9, 0x18, 0x0f, 0x5b, 0x3a,
    0xc5, 0x4d, 0x96, 0xd9, 0x66, 0x77, 0x1a, 0xe9, 0xbf, 0xb7, 0xb0, 0x2d, 0x2c, 0x45, 0x63, 0x6c,
    0x0d, 0x07, 0x6f, 0x93, 0xc9, 0xcb, 0x7b, 0x33, 0x6f, 0x3e, 0xa6, 0x79, 0xc8, 0x63, 0xe8, 0xb9,
    0x01, 0xdd, 0x8e, 0x1e, 0x36, 0xa4, 0x98, 0x3e, 0x0a, 0x7d, 0xa9, 0xd6, 0x4c, 0x8c, 0x78, 0x92,
    0x64, 0x1a, 0x26, 0x2c, 0x9d, 0x30, 0x02, 0xc5, 0x99, 0xb8, 0xd4, 0x20, 0x12, 0x27, 0x65, 0x0a,
    0x90, 0xbc, 0xa9, 0xc5, 0x31, 0x94, 0x0a, 0xac, 0xc0, 0x97, 0x31, 0xf4, 0x31, 0x13, 0x22, 0x25,
    0xe5, 0x5c, 0x79, 0x8f, 0x90, 0x7f, 0x48, 0x15, 0x3f, 0xa3, 0xc8, 0xfb, 0xbe, 0x44, 0x70, 0xd8,
    0x3a, 0xe2, 0x5b, 0x8a, 0x60, 0x28, 0x85, 0x54, 0x26, 0xa7, 0x53, 0x58, 0x66, 0x82, 0xa9, 0xa3,
    0x64, 0x6c, 0x4a, 0xf0, 0xb6, 0xd4, 0x33, 0xc0, 0x18, 0x94, 0x1b, 0x0c, 0x22, 0x5d, 0x54, 0xb9,
    0xa4, 0x39, 0x6c, 0x28, 0x53, 0x60, 0x80, 0xb8, 0xab, 0xf8, 0x67, 0x9c, 0x7e, 0xe7, 0xc8, 0x11,
    0xb4, 0xf6, 0x12, 0x21, 0x19, 0x99, 0x24, 0x19, 0x44, 0xb8, 0x64, 0x02, 0xac, 0x7c, 0xf7, 0x62,
    0xda, 0xcc, 0x26, 0xb7, 0xec, 0x6f, 0x67, 0x57, 0xf7, 0xfa, 0xfe, 0x40, 0x33, 0xce, 0xb8, 0x6b,
    0xfa, 0x6b, 0xcc, 0x5d, 0x5a, 0x72, 0xca, 0x7d, 0xe8, 0xfc, 0x7b, 0x13, 0x1a, 0xab, 0x1a, 0x7f,
    0xcf, 0x2c, 0xaa, 0x81, 0x06, 0x96, 0x93, 0xfb, 0xb5, 0xa1, 0x3c, 0xe5, 0xb8, 0x72, 0x5f, 0x90,
    0x4b, 0x7c, 0xfd, 0xca, 0x5c, 0xa7, 0x13, 0x3c, 0x31, 0xe2, 0x78, 0x13, 0x92, 0x2a, 0x90, 0x4e,
    0xa7, 0x06, 0x9a, 0xad, 0x22, 0xd6, 0xbb, 0x2b, 0x50, 0x0b, 0x56, 0x08, 0x21, 0xd9, 0x80, 0x72,
    0x95, 0xdd, 0xb1, 0x90, 0x11, 0x13, 0x15, 0x5d, 0x45, 0x94, 0xa1, 0xe6, 0x2b, 0x84, 0xb8, 0xc3,
    0x91, 0xde, 0xba, 0x6d, 0x3a, 0x1b, 0x59, 0x73, 0xdc, 0xef, 0xf9, 0xef, 0x8c, 0x6d, 0xa5, 0xef,
    0x1f, 0x26, 0x5a, 0x5d, 0xcf, 0x19, 0xd5, 0xc3, 0xea, 0x0e, 0x4d, 0x01, 0xb5, 0xb3, 0x6c, 0x47,
    0x5d, 0x3e, 0x92, 0x92, 0xb9, 0x7a, 0x2b, 0xff, 0x62, 0x69, 0xe6, 0xd6, 0xa7, 0x32, 0xfd, 0x9d,
    0xfe, 0xae, 0x16, 0x02, 0x47, 0x43, 0x29, 0xee, 0x7c, 0xc7, 0xd7, 0x9c, 0xce, 0x1e, 0xc4, 0x5f,
    0xbf, 0x41, 0xaa, 0x3b, 0xb1, 0x2f, 0xf7, 0x13, 0x1d, 0xce, 0x7c, 0x44
};
#endif

PyTypeObject *init_Qt3DExtras_QNormalDiffuseMapMaterial(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX].type != nullptr)
        return SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QMaterial_IDX]))));

    _Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QNormalDiffuseMapMaterial",
        "Qt3DExtras::QNormalDiffuseMapMaterial*",
        &Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_spec,
        &Shiboken::callCppDestructor< Qt3DExtras::QNormalDiffuseMapMaterial >,
        Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_TypeF(); // references _Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DExtras_QNormalDiffuseMapMaterial_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DExtras_QNormalDiffuseMapMaterial_SignatureBytes, Qt3DExtras_QNormalDiffuseMapMaterial_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_PropertyStrings);
    SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QNormalDiffuseMapMaterial_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNormalDiffuseMapMaterial_PythonToCpp_QNormalDiffuseMapMaterial_PTR,
        is_QNormalDiffuseMapMaterial_PythonToCpp_QNormalDiffuseMapMaterial_PTR_Convertible,
        QNormalDiffuseMapMaterial_PTR_CppToPython_QNormalDiffuseMapMaterial);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DExtras::QNormalDiffuseMapMaterial");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DExtras::QNormalDiffuseMapMaterial*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DExtras::QNormalDiffuseMapMaterial&");
    Shiboken::Conversions::registerConverterAlias(converter, "QNormalDiffuseMapMaterial");
    Shiboken::Conversions::registerConverterAlias(converter, "QNormalDiffuseMapMaterial*");
    Shiboken::Conversions::registerConverterAlias(converter, "QNormalDiffuseMapMaterial&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DExtras::QNormalDiffuseMapMaterial).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QNormalDiffuseMapMaterialWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_TypeF(), &Sbk_Qt3DExtras_QNormalDiffuseMapMaterial_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Qt3DExtras::QNormalDiffuseMapMaterial::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DExtras::QNormalDiffuseMapMaterial::staticMetaObject, sizeof(QNormalDiffuseMapMaterialWrapper));

    return pyType;
}
