// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dinput_python.h"

// main header
#include "qt3dinput_qkeyevent_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGui/qevent.h>
#include <QtGui/qkeysequence.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DInput;

// Native ---------------------------------------------------------

void QKeyEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QKeyEventWrapper::QKeyEventWrapper(::QEvent::Type type, int key, ::QFlags<Qt::KeyboardModifier> modifiers, const ::QString & text, bool autorep, ushort count) : Qt3DInput::QKeyEvent(type, key, modifiers, text, autorep, count)
{
}

QKeyEventWrapper::QKeyEventWrapper(const ::QKeyEvent & ke) : Qt3DInput::QKeyEvent(ke)
{
}

void QKeyEventWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QKeyEvent", funcName);
        return;
    }
}

void QKeyEventWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QKeyEvent", funcName);
        return;
    }
}

void QKeyEventWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QKeyEvent", funcName);
        return;
    }
}

void QKeyEventWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QKeyEvent", funcName);
        return;
    }
}

bool QKeyEventWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QKeyEvent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QKeyEvent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QKeyEventWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QKeyEvent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QKeyEvent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QKeyEventWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QKeyEvent", funcName);
        return;
    }
}

const QMetaObject *QKeyEventWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DInput::QKeyEvent::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QKeyEventWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DInput::QKeyEvent::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QKeyEventWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QKeyEventWrapper *>(this));
    return Qt3DInput::QKeyEvent::qt_metacast(_clname);
}

QKeyEventWrapper::~QKeyEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DInput_QKeyEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DInput::QKeyEvent >()))
        return -1;

    QKeyEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:QKeyEvent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QKeyEvent::QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,const QString&=,bool=,ushort=)
    // 1: QKeyEvent::QKeyEvent(QKeyEvent)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QKeyEvent(QKeyEvent)
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_Type_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[5])))) {
                    overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QKeyEvent(QEvent::Type type, int key, QFlags<Qt::KeyboardModifier> modifiers, const QString &text, bool autorep, ushort count)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_text = Shiboken::String::createStaticString("text");
                if (PyDict_Contains(kwds, key_text) != 0) {
                    value = PyDict_GetItem(kwds, key_text);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_text);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_text);
                }
                static PyObject *const key_autorep = Shiboken::String::createStaticString("autorep");
                if (PyDict_Contains(kwds, key_autorep) != 0) {
                    value = PyDict_GetItem(kwds, key_autorep);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_autorep);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_autorep);
                }
                static PyObject *const key_count = Shiboken::String::createStaticString("count");
                if (PyDict_Contains(kwds, key_count) != 0) {
                    value = PyDict_GetItem(kwds, key_count);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_count);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_count);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::QEvent::Type cppArg0{QEvent::None};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3 = QString();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            bool cppArg4 = false;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            ushort cppArg5 = 1;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QKeyEventWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QKeyEventWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                }

            }
            break;
        }
        case 1: // QKeyEvent(const QKeyEvent &ke)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QKeyEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QKeyEvent(QKeyEvent)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QKeyEventWrapper(*cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QKeyEventWrapper(*cppArg0);
                }

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DInput::QKeyEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DInput_QKeyEventFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        int cppResult = const_cast<const ::Qt3DInput::QKeyEvent *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QKeyEventFunc_isAccepted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAccepted()const
        bool cppResult = const_cast<const ::Qt3DInput::QKeyEvent *>(cppSelf)->isAccepted();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QKeyEventFunc_isAutoRepeat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAutoRepeat()const
        bool cppResult = const_cast<const ::Qt3DInput::QKeyEvent *>(cppSelf)->isAutoRepeat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QKeyEventFunc_key(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // key()const
        int cppResult = const_cast<const ::Qt3DInput::QKeyEvent *>(cppSelf)->key();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QKeyEventFunc_matches(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QKeyEvent::matches(QKeySequence::StandardKey)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_StandardKey_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // matches(QKeySequence::StandardKey)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "matches", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]);

    // Call function/method
    {
        ::QKeySequence::StandardKey cppArg0{QKeySequence::UnknownKey};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // matches(QKeySequence::StandardKey)const
            bool cppResult = const_cast<const ::Qt3DInput::QKeyEvent *>(cppSelf)->matches(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QKeyEventFunc_modifiers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // modifiers()const
        int cppResult = const_cast<const ::Qt3DInput::QKeyEvent *>(cppSelf)->modifiers();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QKeyEventFunc_nativeScanCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nativeScanCode()const
        quint32 cppResult = const_cast<const ::Qt3DInput::QKeyEvent *>(cppSelf)->nativeScanCode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QKeyEventFunc_setAccepted(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QKeyEvent::setAccepted(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAccepted(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAccepted", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAccepted(bool)
            cppSelf->setAccepted(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DInput_QKeyEventFunc_text(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // text()const
        QString cppResult = const_cast<const ::Qt3DInput::QKeyEvent *>(cppSelf)->text();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QKeyEventFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QEvent::Type cppResult = const_cast<const ::Qt3DInput::QKeyEvent *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DInput_QKeyEvent_PropertyStrings[] = {
    "accepted:isAccepted:",
    "count:",
    "isAutoRepeat:",
    "key:",
    "modifiers:",
    "nativeScanCode:",
    "text:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DInput_QKeyEvent_methods[] = {
    {"count", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QKeyEventFunc_count), METH_NOARGS, nullptr},
    {"isAccepted", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QKeyEventFunc_isAccepted), METH_NOARGS, nullptr},
    {"isAutoRepeat", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QKeyEventFunc_isAutoRepeat), METH_NOARGS, nullptr},
    {"key", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QKeyEventFunc_key), METH_NOARGS, nullptr},
    {"matches", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QKeyEventFunc_matches), METH_O, nullptr},
    {"modifiers", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QKeyEventFunc_modifiers), METH_NOARGS, nullptr},
    {"nativeScanCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QKeyEventFunc_nativeScanCode), METH_NOARGS, nullptr},
    {"setAccepted", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QKeyEventFunc_setAccepted), METH_O, nullptr},
    {"text", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QKeyEventFunc_text), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QKeyEventFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DInput_QKeyEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DInput::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QKeyEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DInput_QKeyEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DInput_QKeyEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DInput_QKeyEvent_Type = nullptr;
static PyTypeObject *Sbk_Qt3DInput_QKeyEvent_TypeF(void)
{
    return _Sbk_Qt3DInput_QKeyEvent_Type;
}

static PyType_Slot Sbk_Qt3DInput_QKeyEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DInput_QKeyEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DInput_QKeyEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DInput_QKeyEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DInput_QKeyEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DInput_QKeyEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DInput_QKeyEvent_spec = {
    "2:PySide6.Qt3DInput.Qt3DInput.QKeyEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DInput_QKeyEvent_slots
};

} //extern "C"

static void *Sbk_Qt3DInput_QKeyEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DInput::QKeyEvent *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QKeyEvent_PythonToCpp_QKeyEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DInput_QKeyEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QKeyEvent_PythonToCpp_QKeyEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DInput_QKeyEvent_TypeF()))
        return QKeyEvent_PythonToCpp_QKeyEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QKeyEvent_PTR_CppToPython_QKeyEvent(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DInput::QKeyEvent *>(const_cast<void *>(cppIn)), Sbk_Qt3DInput_QKeyEvent_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DInput_QKeyEvent_SignatureStrings[] = {
    "1:PySide6.Qt3DInput.Qt3DInput.QKeyEvent(self,type:PySide6.QtCore.QEvent.Type,key:int,modifiers:PySide6.QtCore.Qt.KeyboardModifier,text:QString=QString(),autorep:bool=false,count:ushort=1,*:KeywordOnly=None,key:int=None,text:QString=None,modifiers:int=None,isAutoRepeat:bool=None,count:int=None,nativeScanCode:quint32=None,accepted:bool=None)",
    "0:PySide6.Qt3DInput.Qt3DInput.QKeyEvent(self,ke:PySide6.QtGui.QKeyEvent,*:KeywordOnly=None,key:int=None,text:QString=None,modifiers:int=None,isAutoRepeat:bool=None,count:int=None,nativeScanCode:quint32=None,accepted:bool=None)",
    "PySide6.Qt3DInput.Qt3DInput.QKeyEvent.count(self)->int",
    "PySide6.Qt3DInput.Qt3DInput.QKeyEvent.isAccepted(self)->bool",
    "PySide6.Qt3DInput.Qt3DInput.QKeyEvent.isAutoRepeat(self)->bool",
    "PySide6.Qt3DInput.Qt3DInput.QKeyEvent.key(self)->int",
    "PySide6.Qt3DInput.Qt3DInput.QKeyEvent.matches(self,key_:PySide6.QtGui.QKeySequence.StandardKey)->bool",
    "PySide6.Qt3DInput.Qt3DInput.QKeyEvent.modifiers(self)->int",
    "PySide6.Qt3DInput.Qt3DInput.QKeyEvent.nativeScanCode(self)->quint32",
    "PySide6.Qt3DInput.Qt3DInput.QKeyEvent.setAccepted(self,accepted:bool)",
    "PySide6.Qt3DInput.Qt3DInput.QKeyEvent.text(self)->QString",
    "PySide6.Qt3DInput.Qt3DInput.QKeyEvent.type(self)->PySide6.QtCore.QEvent.Type",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DInput_QKeyEvent_SignatureByteSize = 326;
static constexpr uint8_t Qt3DInput_QKeyEvent_SignatureBytes[326] = {
    0x78, 0xda, 0xcd, 0x54, 0xcb, 0x4e, 0xc3, 0x30, 0x10, 0xbc, 0xf7, 0x4b, 0x1a, 0x64, 0x22, 0x4a,
    0x25, 0x0e, 0x96, 0x82, 0x84, 0x0a, 0x42, 0x08, 0xf1, 0x08, 0xe1, 0x8e, 0x5c, 0x7b, 0x43, 0xad,
    0xa6, 0x76, 0x1a, 0xaf, 0x0b, 0xfe, 0x7b, 0xdc, 0xbc, 0x23, 0x40, 0x4a, 0x38, 0x71, 0x4a, 0xb2,
    0xbb, 0xb3, 0x33, 0xeb, 0xd9, 0x78, 0x41, 0x9f, 0x5d, 0x22, 0x05, 0x5c, 0x84, 0x31, 0x2e, 0xaf,
    0xef, 0x54, 0x6e, 0xb1, 0xff, 0x76, 0x0f, 0xee, 0xe6, 0x00, 0x0a, 0xe7, 0x06, 0xb2, 0x94, 0xa0,
    0xcb, 0xa1, 0x57, 0xbf, 0xd2, 0x05, 0x84, 0x71, 0x99, 0x0f, 0x5f, 0x7d, 0x8a, 0x6c, 0xc1, 0x51,
    0xa9, 0x90, 0xec, 0xb4, 0x90, 0xa9, 0x84, 0xc2, 0x7c, 0x2b, 0xc6, 0xd0, 0x77, 0x5c, 0x6b, 0x56,
    0x88, 0x87, 0xba, 0x86, 0x20, 0x7c, 0x22, 0x8d, 0x13, 0x2c, 0xa4, 0x7a, 0x8f, 0xea, 0xe7, 0x3c,
    0x20, 0xcc, 0xa2, 0x47, 0xe4, 0x74, 0xad, 0x75, 0x16, 0xa5, 0x2c, 0x33, 0x40, 0xb8, 0xb6, 0x0a,
    0xa9, 0x35, 0x1b, 0x5d, 0x60, 0xb4, 0x20, 0x27, 0xd4, 0xf7, 0xfa, 0xd0, 0x85, 0x78, 0x52, 0x99,
    0x8b, 0x1e, 0xb5, 0x6a, 0x05, 0x54, 0x1f, 0x83, 0xc6, 0x65, 0xa4, 0xd3, 0xd5, 0x16, 0x49, 0x73,
    0xe5, 0x89, 0x5e, 0x20, 0x07, 0x86, 0x15, 0x57, 0x19, 0xae, 0xa8, 0xda, 0x2a, 0xc5, 0x50, 0x1e,
    0x20, 0xe1, 0x4c, 0xad, 0xb4, 0x00, 0xba, 0xb7, 0x3e, 0xb3, 0x3c, 0xaf, 0x72, 0x8c, 0x73, 0xc8,
    0x11, 0x44, 0x87, 0x0e, 0x66, 0x67, 0x53, 0x4e, 0x75, 0xdb, 0x3f, 0xd3, 0x5b, 0x2b, 0xbb, 0xfc,
    0x7f, 0x1e, 0x71, 0xd4, 0x80, 0x61, 0x49, 0x52, 0x8e, 0x19, 0x9c, 0x5e, 0xfa, 0x8e, 0x23, 0x61,
    0x5e, 0x72, 0x4d, 0xd9, 0x60, 0x8f, 0xcc, 0xe3, 0xc1, 0xed, 0xbc, 0x7f, 0x80, 0xfb, 0x03, 0x9e,
    0x2e, 0x78, 0xc7, 0x90, 0x6f, 0xc0, 0x34, 0x86, 0xba, 0xb7, 0x1f, 0x2c, 0x4d, 0x60, 0x6f, 0x41,
    0x71, 0x08, 0x13, 0x64, 0x4a, 0xf8, 0x5f, 0xc0, 0xc7, 0xa6, 0x49, 0x6b, 0xcd, 0x9d, 0x2e, 0x70,
    0x68, 0x6f, 0x83, 0xaf, 0x5d, 0x1e, 0xd9, 0xc3, 0x00, 0x0e, 0x6c, 0x19, 0xee, 0xc5, 0xd8, 0x95,
    0x38, 0xee, 0x6c, 0xc3, 0x5f, 0xaf, 0xee, 0x58, 0xa4, 0xbf, 0x63, 0x1a, 0xe4, 0xef, 0xb7, 0xd0,
    0xec, 0x0b, 0x2d, 0xcf, 0xba, 0x4c
};
#endif

PyTypeObject *init_Qt3DInput_QKeyEvent(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX].type != nullptr)
        return SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DInput_QKeyEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_Qt3DInput_QKeyEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QKeyEvent",
        "Qt3DInput::QKeyEvent*",
        &Sbk_Qt3DInput_QKeyEvent_spec,
        &Shiboken::callCppDestructor< Qt3DInput::QKeyEvent >,
        Sbk_Qt3DInput_QKeyEvent_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DInput_QKeyEvent_TypeF(); // references _Sbk_Qt3DInput_QKeyEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DInput_QKeyEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DInput_QKeyEvent_SignatureBytes, Qt3DInput_QKeyEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DInput_QKeyEvent_PropertyStrings);
    SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QKeyEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QKeyEvent_PythonToCpp_QKeyEvent_PTR,
        is_QKeyEvent_PythonToCpp_QKeyEvent_PTR_Convertible,
        QKeyEvent_PTR_CppToPython_QKeyEvent);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QKeyEvent");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QKeyEvent*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QKeyEvent&");
    Shiboken::Conversions::registerConverterAlias(converter, "QKeyEvent");
    Shiboken::Conversions::registerConverterAlias(converter, "QKeyEvent*");
    Shiboken::Conversions::registerConverterAlias(converter, "QKeyEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DInput::QKeyEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QKeyEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DInput_QKeyEvent_TypeF(), &Sbk_Qt3DInput_QKeyEvent_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DInput::QKeyEvent::staticMetaObject, sizeof(QKeyEventWrapper));

    return pyType;
}
