// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dinput_python.h"

// main header
#include "qt3dinput_qwheelevent_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <Qt3DInput/qmouseevent.h>
#include <QtGui/qevent.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DInput;

// Native ---------------------------------------------------------

void QWheelEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QWheelEventWrapper::QWheelEventWrapper(const ::QWheelEvent & e) : Qt3DInput::QWheelEvent(e)
{
}

void QWheelEventWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWheelEvent", funcName);
        return;
    }
}

void QWheelEventWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWheelEvent", funcName);
        return;
    }
}

void QWheelEventWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWheelEvent", funcName);
        return;
    }
}

void QWheelEventWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWheelEvent", funcName);
        return;
    }
}

bool QWheelEventWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWheelEvent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWheelEvent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QWheelEventWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWheelEvent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWheelEvent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWheelEventWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QWheelEvent", funcName);
        return;
    }
}

const QMetaObject *QWheelEventWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DInput::QWheelEvent::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QWheelEventWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DInput::QWheelEvent::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QWheelEventWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QWheelEventWrapper *>(this));
    return Qt3DInput::QWheelEvent::qt_metacast(_clname);
}

QWheelEventWrapper::~QWheelEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DInput_QWheelEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DInput::QWheelEvent >()))
        return -1;

    QWheelEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QWheelEvent", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWheelEvent::QWheelEvent(QWheelEvent)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QWheelEvent(QWheelEvent)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWheelEvent *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QWheelEvent(QWheelEvent)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QWheelEventWrapper(*cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QWheelEventWrapper(*cppArg0);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DInput::QWheelEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DInput_QWheelEventFunc_angleDelta(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // angleDelta()const
        QPoint cppResult = const_cast<const ::Qt3DInput::QWheelEvent *>(cppSelf)->angleDelta();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QWheelEventFunc_buttons(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // buttons()const
        int cppResult = const_cast<const ::Qt3DInput::QWheelEvent *>(cppSelf)->buttons();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QWheelEventFunc_isAccepted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAccepted()const
        bool cppResult = const_cast<const ::Qt3DInput::QWheelEvent *>(cppSelf)->isAccepted();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QWheelEventFunc_modifiers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // modifiers()const
        Qt3DInput::QWheelEvent::Modifiers cppResult = const_cast<const ::Qt3DInput::QWheelEvent *>(cppSelf)->modifiers();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_Modifiers_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QWheelEventFunc_setAccepted(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWheelEvent::setAccepted(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAccepted(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAccepted", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAccepted(bool)
            cppSelf->setAccepted(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DInput_QWheelEventFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QEvent::Type cppResult = const_cast<const ::Qt3DInput::QWheelEvent *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QWheelEventFunc_x(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // x()const
        int cppResult = const_cast<const ::Qt3DInput::QWheelEvent *>(cppSelf)->x();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QWheelEventFunc_y(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // y()const
        int cppResult = const_cast<const ::Qt3DInput::QWheelEvent *>(cppSelf)->y();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DInput_QWheelEvent_PropertyStrings[] = {
    "accepted:isAccepted:",
    "angleDelta:",
    "buttons:",
    "modifiers:",
    "x:",
    "y:",
    nullptr // Sentinel
};

static const char *Sbk_Qt3DInput_QWheelEvent_EnumFlagInfo[] = {
    "Buttons:Enum",
    "Modifiers:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DInput_QWheelEvent_methods[] = {
    {"angleDelta", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QWheelEventFunc_angleDelta), METH_NOARGS, nullptr},
    {"buttons", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QWheelEventFunc_buttons), METH_NOARGS, nullptr},
    {"isAccepted", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QWheelEventFunc_isAccepted), METH_NOARGS, nullptr},
    {"modifiers", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QWheelEventFunc_modifiers), METH_NOARGS, nullptr},
    {"setAccepted", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QWheelEventFunc_setAccepted), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QWheelEventFunc_type), METH_NOARGS, nullptr},
    {"x", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QWheelEventFunc_x), METH_NOARGS, nullptr},
    {"y", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QWheelEventFunc_y), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DInput_QWheelEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DInput::QWheelEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QWheelEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DInput_QWheelEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DInput_QWheelEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DInput_QWheelEvent_Type = nullptr;
static PyTypeObject *Sbk_Qt3DInput_QWheelEvent_TypeF(void)
{
    return _Sbk_Qt3DInput_QWheelEvent_Type;
}

static PyType_Slot Sbk_Qt3DInput_QWheelEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DInput_QWheelEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DInput_QWheelEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DInput_QWheelEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DInput_QWheelEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DInput_QWheelEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DInput_QWheelEvent_spec = {
    "2:PySide6.Qt3DInput.Qt3DInput.QWheelEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DInput_QWheelEvent_slots
};

} //extern "C"

static void *Sbk_Qt3DInput_QWheelEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DInput::QWheelEvent *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Qt3DInput_QWheelEvent_Buttons(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DInput::QWheelEvent::Buttons>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DInput::QWheelEvent::Buttons *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DInput_QWheelEvent_Buttons_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_Buttons_IDX])))
        return Enum_PythonToCpp_Qt3DInput_QWheelEvent_Buttons;
    return {};
}

static PyObject *Qt3DInput_QWheelEvent_Buttons_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DInput::QWheelEvent::Buttons>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DInput::QWheelEvent::Buttons *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_Buttons_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DInput_QWheelEvent_Modifiers(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DInput::QWheelEvent::Modifiers>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DInput::QWheelEvent::Modifiers *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DInput_QWheelEvent_Modifiers_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_Modifiers_IDX])))
        return Enum_PythonToCpp_Qt3DInput_QWheelEvent_Modifiers;
    return {};
}

static PyObject *Qt3DInput_QWheelEvent_Modifiers_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DInput::QWheelEvent::Modifiers>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DInput::QWheelEvent::Modifiers *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_Modifiers_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWheelEvent_PythonToCpp_QWheelEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DInput_QWheelEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWheelEvent_PythonToCpp_QWheelEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DInput_QWheelEvent_TypeF()))
        return QWheelEvent_PythonToCpp_QWheelEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWheelEvent_PTR_CppToPython_QWheelEvent(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DInput::QWheelEvent *>(const_cast<void *>(cppIn)), Sbk_Qt3DInput_QWheelEvent_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DInput_QWheelEvent_SignatureStrings[] = {
    "PySide6.Qt3DInput.Qt3DInput.QWheelEvent(self,e:PySide6.QtGui.QWheelEvent,*:KeywordOnly=None,x:int=None,y:int=None,angleDelta:QPoint=None,buttons:int=None,modifiers:Qt3DInput.QWheelEvent.Modifiers=None,accepted:bool=None)",
    "PySide6.Qt3DInput.Qt3DInput.QWheelEvent.angleDelta(self)->PySide6.QtCore.QPoint",
    "PySide6.Qt3DInput.Qt3DInput.QWheelEvent.buttons(self)->int",
    "PySide6.Qt3DInput.Qt3DInput.QWheelEvent.isAccepted(self)->bool",
    "PySide6.Qt3DInput.Qt3DInput.QWheelEvent.modifiers(self)->PySide6.Qt3DInput.Qt3DInput.QWheelEvent.Modifiers",
    "PySide6.Qt3DInput.Qt3DInput.QWheelEvent.setAccepted(self,accepted:bool)",
    "PySide6.Qt3DInput.Qt3DInput.QWheelEvent.type(self)->PySide6.QtCore.QEvent.Type",
    "PySide6.Qt3DInput.Qt3DInput.QWheelEvent.x(self)->int",
    "PySide6.Qt3DInput.Qt3DInput.QWheelEvent.y(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DInput_QWheelEvent_SignatureByteSize = 217;
static constexpr uint8_t Qt3DInput_QWheelEvent_SignatureBytes[217] = {
    0x78, 0xda, 0x9d, 0x51, 0xcb, 0x0a, 0xc2, 0x30, 0x10, 0xbc, 0xfb, 0x25, 0x56, 0x6a, 0x2f, 0x82,
    0x87, 0x80, 0x82, 0x58, 0x11, 0x11, 0xb5, 0x45, 0xc1, 0x73, 0x1f, 0x5b, 0x0d, 0xc4, 0xa4, 0x34,
    0x5b, 0x6d, 0xfe, 0x5e, 0xed, 0xbb, 0xf8, 0x20, 0x7a, 0x5b, 0x36, 0x33, 0x93, 0x99, 0x59, 0x47,
    0xed, 0x69, 0x08, 0x63, 0xcb, 0xc5, 0x91, 0xbd, 0xe2, 0x71, 0x8a, 0xed, 0xe9, 0x78, 0x06, 0x60,
    0x8b, 0x2b, 0x70, 0xec, 0x4b, 0x60, 0x91, 0x09, 0xc4, 0xa9, 0xe1, 0xcb, 0x94, 0xb6, 0x01, 0xe6,
    0x80, 0xac, 0x41, 0xdd, 0x44, 0x12, 0xee, 0x38, 0x53, 0x93, 0xad, 0xe0, 0x60, 0x66, 0x84, 0x72,
    0x2c, 0x46, 0xd5, 0x8c, 0x1e, 0x3f, 0x31, 0xb0, 0x81, 0xa1, 0x47, 0x5c, 0x47, 0xd4, 0x6b, 0x3f,
    0x45, 0x14, 0x5c, 0x36, 0xb8, 0x8b, 0x08, 0x69, 0x44, 0x21, 0x91, 0xe4, 0xad, 0x23, 0x6b, 0x53,
    0xbd, 0x97, 0xb2, 0x41, 0x00, 0x31, 0x42, 0x48, 0x7c, 0x21, 0x58, 0xbe, 0x32, 0x7a, 0x8e, 0x5e,
    0x38, 0xab, 0xb1, 0x94, 0xe7, 0x34, 0x86, 0xd3, 0x86, 0x39, 0x17, 0x09, 0x58, 0x85, 0x51, 0x6d,
    0xbd, 0x32, 0x4b, 0x25, 0xf6, 0x0b, 0x95, 0xca, 0x59, 0x19, 0xa4, 0x62, 0x3f, 0xf3, 0x68, 0xd3,
    0xeb, 0xd2, 0x5e, 0x83, 0x7c, 0x27, 0xd6, 0x6d, 0x6a, 0x7f, 0x25, 0x01, 0x3b, 0x56, 0xbb, 0x17,
    0xd0, 0x2f, 0x1f, 0x55, 0x0c, 0x9f, 0x6a, 0x2f, 0x10, 0x87, 0x07, 0x42, 0x5b, 0x2e, 0xfb, 0xa7,
    0x75, 0xd5, 0x26, 0xdd, 0x01, 0x64, 0x1f, 0x17, 0x90
};
#endif

PyTypeObject *init_Qt3DInput_QWheelEvent(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX].type != nullptr)
        return SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DInput_QWheelEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_Qt3DInput_QWheelEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QWheelEvent",
        "Qt3DInput::QWheelEvent*",
        &Sbk_Qt3DInput_QWheelEvent_spec,
        &Shiboken::callCppDestructor< Qt3DInput::QWheelEvent >,
        Sbk_Qt3DInput_QWheelEvent_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DInput_QWheelEvent_TypeF(); // references _Sbk_Qt3DInput_QWheelEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DInput_QWheelEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DInput_QWheelEvent_SignatureBytes, Qt3DInput_QWheelEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DInput_QWheelEvent_PropertyStrings);
    SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWheelEvent_PythonToCpp_QWheelEvent_PTR,
        is_QWheelEvent_PythonToCpp_QWheelEvent_PTR_Convertible,
        QWheelEvent_PTR_CppToPython_QWheelEvent);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QWheelEvent");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QWheelEvent*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QWheelEvent&");
    Shiboken::Conversions::registerConverterAlias(converter, "QWheelEvent");
    Shiboken::Conversions::registerConverterAlias(converter, "QWheelEvent*");
    Shiboken::Conversions::registerConverterAlias(converter, "QWheelEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DInput::QWheelEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QWheelEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DInput_QWheelEvent_TypeF(), &Sbk_Qt3DInput_QWheelEvent_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DInput_QWheelEvent_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Buttons'.
    const char *Buttons_Initializer[] = {
        "LeftButton",
        "RightButton",
        "MiddleButton",
        "BackButton",
        "NoButton",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Buttons_InitializerValues[] = {
        uint8_t(Qt3DInput::QWheelEvent::Buttons::LeftButton),   //  0x01  1
        uint8_t(Qt3DInput::QWheelEvent::Buttons::RightButton),  //  0x02  2
        uint8_t(Qt3DInput::QWheelEvent::Buttons::MiddleButton), //  0x04  4
        uint8_t(Qt3DInput::QWheelEvent::Buttons::BackButton),   //  0x08  8
        uint8_t(Qt3DInput::QWheelEvent::Buttons::NoButton)      //  0x00  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DInput_QWheelEvent_TypeF(),
        "2:PySide6.Qt3DInput.Qt3DInput.QWheelEvent.Buttons",
        Buttons_Initializer, Buttons_InitializerValues);
    SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_Buttons_IDX].type = EType;
    // Register converter for enum 'Qt3DInput::QWheelEvent::Buttons'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DInput_QWheelEvent_Buttons_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DInput_QWheelEvent_Buttons,
            is_Enum_PythonToCpp_Qt3DInput_QWheelEvent_Buttons_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QWheelEvent::Buttons");
        Shiboken::Conversions::registerConverterAlias(converter, "QWheelEvent::Buttons");
        Shiboken::Conversions::registerConverterAlias(converter, "Buttons");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Buttons' enum.

    // Initialization of enum 'Modifiers'.
    const char *Modifiers_Initializer[] = {
        "NoModifier",
        "ShiftModifier",
        "ControlModifier",
        "AltModifier",
        "MetaModifier",
        "KeypadModifier",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t Modifiers_InitializerValues[] = {
        uint32_t(Qt3DInput::QWheelEvent::Modifiers::NoModifier),      //  0x00000000  0
        uint32_t(Qt3DInput::QWheelEvent::Modifiers::ShiftModifier),   //  0x02000000  33554432
        uint32_t(Qt3DInput::QWheelEvent::Modifiers::ControlModifier), //  0x04000000  67108864
        uint32_t(Qt3DInput::QWheelEvent::Modifiers::AltModifier),     //  0x08000000  134217728
        uint32_t(Qt3DInput::QWheelEvent::Modifiers::MetaModifier),    //  0x10000000  268435456
        uint32_t(Qt3DInput::QWheelEvent::Modifiers::KeypadModifier)   //  0x20000000  536870912
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DInput_QWheelEvent_TypeF(),
        "2:PySide6.Qt3DInput.Qt3DInput.QWheelEvent.Modifiers",
        Modifiers_Initializer, Modifiers_InitializerValues);
    SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QWheelEvent_Modifiers_IDX].type = EType;
    // Register converter for enum 'Qt3DInput::QWheelEvent::Modifiers'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DInput_QWheelEvent_Modifiers_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DInput_QWheelEvent_Modifiers,
            is_Enum_PythonToCpp_Qt3DInput_QWheelEvent_Modifiers_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QWheelEvent::Modifiers");
        Shiboken::Conversions::registerConverterAlias(converter, "QWheelEvent::Modifiers");
        Shiboken::Conversions::registerConverterAlias(converter, "Modifiers");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Modifiers' enum.

    qRegisterMetaType< ::Qt3DInput::QWheelEvent::Buttons >("QWheelEvent::Buttons");
    qRegisterMetaType< ::Qt3DInput::QWheelEvent::Buttons >("Qt3DInput::QWheelEvent::Buttons");
    qRegisterMetaType< ::Qt3DInput::QWheelEvent::Modifiers >("QWheelEvent::Modifiers");
    qRegisterMetaType< ::Qt3DInput::QWheelEvent::Modifiers >("Qt3DInput::QWheelEvent::Modifiers");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DInput::QWheelEvent::staticMetaObject, sizeof(QWheelEventWrapper));

    return pyType;
}
