// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qsharedpointer_propertyreaderinterface_wrapper.h"

// Extra includes
#include <Qt3DRender/qshaderdata.h>
#include <sbksmartpointer.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DRender_PropertyReaderInterfacePtr_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSharedPointer<Qt3DRender::PropertyReaderInterface> >()))
        return -1;

    ::QSharedPointer<Qt3DRender::PropertyReaderInterface> *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "PropertyReaderInterfacePtr", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: PropertyReaderInterfacePtr::PropertyReaderInterfacePtr()
    // 1: PropertyReaderInterfacePtr::PropertyReaderInterfacePtr(Qt3DRender::PropertyReaderInterface*)
    if (numArgs == 0) {
        overloadId = 0; // PropertyReaderInterfacePtr()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_PropertyReaderInterface_IDX]), (pyArgs[0])))) {
        overloadId = 1; // PropertyReaderInterfacePtr(Qt3DRender::PropertyReaderInterface*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // PropertyReaderInterfacePtr()
        {

            // PropertyReaderInterfacePtr()
            cptr = new ::QSharedPointer<Qt3DRender::PropertyReaderInterface>();
            break;
        }
        case 1: // PropertyReaderInterfacePtr(Qt3DRender::PropertyReaderInterface *pointee)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Qt3DRender::PropertyReaderInterface *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // PropertyReaderInterfacePtr(Qt3DRender::PropertyReaderInterface*)
                cptr = new ::QSharedPointer<Qt3DRender::PropertyReaderInterface>(cppArg0);

                // Ownership transferences.
                Shiboken::Object::releaseOwnership(pyArgs[0]);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSharedPointer<Qt3DRender::PropertyReaderInterface> >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Qt3DRender_PropertyReaderInterfacePtrFunc_reset(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSharedPointer<Qt3DRender::PropertyReaderInterface> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "reset", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: PropertyReaderInterfacePtr::reset()
    // 1: PropertyReaderInterfacePtr::reset(Qt3DRender::PropertyReaderInterface*)
    if (numArgs == 0) {
        overloadId = 0; // reset()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_PropertyReaderInterface_IDX]), (pyArgs[0])))) {
        overloadId = 1; // reset(Qt3DRender::PropertyReaderInterface*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "reset", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // reset()
        {

            // reset()
            cppSelf->reset();
            break;
        }
        case 1: // reset(Qt3DRender::PropertyReaderInterface *t)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::Qt3DRender::PropertyReaderInterface *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // reset(Qt3DRender::PropertyReaderInterface*)
                cppSelf->reset(cppArg0);

                // Ownership transferences.
                Shiboken::Object::releaseOwnership(pyArgs[0]);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_PropertyReaderInterfacePtrFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSharedPointer<Qt3DRender::PropertyReaderInterface> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()const
        Qt3DRender::PropertyReaderInterface * cppResult = const_cast<const ::QSharedPointer<Qt3DRender::PropertyReaderInterface> *>(cppSelf)->data();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_PropertyReaderInterface_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_PropertyReaderInterfacePtr__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSharedPointer<Qt3DRender::PropertyReaderInterface> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

extern "C"
{
static PyObject *Sbk_Qt3DRender_PropertyReaderInterfacePtr__dir__(PyObject *self)
{
    Shiboken::AutoDecRef pointee(PyObject_CallMethod(self, "data", 0));
    return Shiboken::SmartPointer::dir(self, pointee);
}
} // extern C

static PyMethodDef Sbk_Qt3DRender_PropertyReaderInterfacePtr_methods[] = {
    {"reset", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_PropertyReaderInterfacePtrFunc_reset), METH_VARARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_PropertyReaderInterfacePtrFunc_data), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_PropertyReaderInterfacePtr__copy__), METH_NOARGS, nullptr},
    {"__dir__", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_PropertyReaderInterfacePtr__dir__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_Qt3DRender_PropertyReaderInterfacePtr_getattro(PyObject *self, PyObject *name)
{
    PyObject *tmp = PyObject_GenericGetAttr(self, name);
    if (tmp)
        return tmp;
    if (PyErr_ExceptionMatches(PyExc_AttributeError) == 0)
        return nullptr;
    PyErr_Clear();
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSharedPointer<Qt3DRender::PropertyReaderInterface> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    if (cppSelf->isNull()) {
        PyTypeObject *tp = Py_TYPE(self);
        PyErr_Format(PyExc_AttributeError, "Attempt to retrieve '%s' from null object '%s'.",
                     Shiboken::String::toCString(name), tp->tp_name);
        return nullptr;
    }
    // Try to find the 'name' attribute, by retrieving the PyObject for the corresponding C++ object held by the smart pointer.
    if (auto *rawObj = PyObject_CallMethod(self, "data", 0)) {
        if (auto *attribute = PyObject_GetAttr(rawObj, name))
            tmp = attribute;
        Py_DECREF(rawObj);
    }
    if (!tmp) {
        PyTypeObject *tp = Py_TYPE(self);
        PyErr_Format(PyExc_AttributeError,
                     "'%.50s' object has no attribute '%.400s'",
                     tp->tp_name, Shiboken::String::toCString(name));
    }
    return tmp;
}

static int Sbk_Qt3DRender_PropertyReaderInterfacePtr_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    // Try to find the 'name' attribute, by retrieving the PyObject for the corresponding C++ object held by the smart pointer.
    if (auto *rawObj = PyObject_CallMethod(self, "data", 0)) {
        if (PyObject_HasAttr(rawObj, name) != 0)
            return PyObject_GenericSetAttr(rawObj, name, value);
        Py_DECREF(rawObj);
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static int Sbk_Qt3DRender_PropertyReaderInterfacePtr___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QSharedPointer<Qt3DRender::PropertyReaderInterface> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    return !cppSelf->isNull() ? 1 : 0;
}

static PyObject * Sbk_Qt3DRender_PropertyReaderInterfacePtr_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSharedPointer<Qt3DRender::PropertyReaderInterface> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX]), (pyArg)))) {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSharedPointer<Qt3DRender::PropertyReaderInterface> cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        const auto *cppSelfPointee = cppSelf.data();
        const auto *cppArg0Pointee = cppArg0.data();
        bool cppResult= false;
        switch (op) {
        case Py_EQ:
            cppResult = cppSelfPointee == cppArg0Pointee;
            break;
        case Py_NE:
            cppResult = cppSelfPointee != cppArg0Pointee;
            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
        }
        pyResult = cppResult ? Py_True : Py_False;
        Py_INCREF(pyResult);
    }
    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_Qt3DRender_PropertyReaderInterfacePtr_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_PropertyReaderInterfacePtr_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_Qt3DRender_PropertyReaderInterfacePtr__repr__(PyObject *self)
{
    Shiboken::AutoDecRef pointee(PyObject_CallMethod(self, "data", 0));
    return Shiboken::SmartPointer::repr(self, pointee);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_PropertyReaderInterfacePtr_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_PropertyReaderInterfacePtr_TypeF(void)
{
    return _Sbk_Qt3DRender_PropertyReaderInterfacePtr_Type;
}

static PyType_Slot Sbk_Qt3DRender_PropertyReaderInterfacePtr_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_Qt3DRender_PropertyReaderInterfacePtr__repr__)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_PropertyReaderInterfacePtr_getattro)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_PropertyReaderInterfacePtr_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_PropertyReaderInterfacePtr_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_PropertyReaderInterfacePtr_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_Qt3DRender_PropertyReaderInterfacePtr_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_PropertyReaderInterfacePtr_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_PropertyReaderInterfacePtr_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_Qt3DRender_PropertyReaderInterfacePtr___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_PropertyReaderInterfacePtr_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.PropertyReaderInterfacePtr",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_PropertyReaderInterfacePtr_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void PropertyReaderInterfacePtr_PythonToCpp_PropertyReaderInterfacePtr_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_PropertyReaderInterfacePtr_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_PropertyReaderInterfacePtr_PythonToCpp_PropertyReaderInterfacePtr_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_PropertyReaderInterfacePtr_TypeF()))
        return PropertyReaderInterfacePtr_PythonToCpp_PropertyReaderInterfacePtr_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *PropertyReaderInterfacePtr_PTR_CppToPython_PropertyReaderInterfacePtr(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_Qt3DRender_PropertyReaderInterfacePtr_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *PropertyReaderInterfacePtr_COPY_CppToPython_PropertyReaderInterfacePtr(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSharedPointer<Qt3DRender::PropertyReaderInterface> *>(cppIn);
    return Shiboken::Object::newObject(Sbk_Qt3DRender_PropertyReaderInterfacePtr_TypeF(), new ::QSharedPointer<Qt3DRender::PropertyReaderInterface>(*source), true, true);
}

// Python to C++ copy conversion.
static void PropertyReaderInterfacePtr_PythonToCpp_PropertyReaderInterfacePtr_COPY(PyObject *pyIn, void *cppOut)
{
    auto *ptr = reinterpret_cast<::QSharedPointer<Qt3DRender::PropertyReaderInterface> *>(cppOut);
    if (pyIn == Py_None)
        ptr->reset();
    else
        *ptr = *reinterpret_cast< ::QSharedPointer<Qt3DRender::PropertyReaderInterface> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_PropertyReaderInterfacePtr_PythonToCpp_PropertyReaderInterfacePtr_COPY_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None || PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_PropertyReaderInterfacePtr_TypeF()))
        return PropertyReaderInterfacePtr_PythonToCpp_PropertyReaderInterfacePtr_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_PropertyReaderInterfacePtr_SignatureStrings[] = {
    "1:PySide6.Qt3DRender.Qt3DRender.PropertyReaderInterfacePtr(self)",
    "0:PySide6.Qt3DRender.Qt3DRender.PropertyReaderInterfacePtr(self,pointee:PySide6.Qt3DRender.Qt3DRender.PropertyReaderInterface)",
    "1:PySide6.Qt3DRender.Qt3DRender.PropertyReaderInterfacePtr.reset(self)",
    "0:PySide6.Qt3DRender.Qt3DRender.PropertyReaderInterfacePtr.reset(self,t:PySide6.Qt3DRender.Qt3DRender.PropertyReaderInterface)",
    "PySide6.Qt3DRender.Qt3DRender.PropertyReaderInterfacePtr.data(self)->PySide6.Qt3DRender.Qt3DRender.PropertyReaderInterface",
    "PySide6.Qt3DRender.Qt3DRender.PropertyReaderInterfacePtr.__copy__(self)->typing.Self",
    "PySide6.Qt3DRender.Qt3DRender.PropertyReaderInterfacePtr.__dir__()",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_PropertyReaderInterfacePtr_SignatureByteSize = 138;
static constexpr uint8_t Qt3DRender_PropertyReaderInterfacePtr_SignatureBytes[138] = {
    0x78, 0xda, 0xa5, 0x8f, 0xb1, 0x0a, 0xc2, 0x30, 0x14, 0x45, 0xf7, 0x7c, 0x89, 0x81, 0x1a, 0x2c,
    0x82, 0x83, 0x83, 0x93, 0x8b, 0x5b, 0xda, 0x7e, 0x40, 0x08, 0xcd, 0xad, 0x04, 0x24, 0x09, 0xaf,
    0x6f, 0xc9, 0xdf, 0x1b, 0x10, 0xa1, 0xf3, 0xcb, 0xf6, 0xee, 0x1b, 0xce, 0xe1, 0x8c, 0x77, 0x5b,
    0x97, 0x18, 0x70, 0x33, 0x13, 0x5f, 0x9f, 0x33, 0x52, 0x00, 0x1d, 0x4f, 0x4b, 0xb9, 0x80, 0xb8,
    0xce, 0xf0, 0x6d, 0xbe, 0x12, 0x83, 0x36, 0xbf, 0xc2, 0x32, 0x9d, 0x76, 0x7c, 0x36, 0xad, 0x2e,
    0x7d, 0x80, 0xa1, 0xe4, 0xd8, 0x7e, 0x90, 0x51, 0xb4, 0x1a, 0xc5, 0x7a, 0x43, 0xd8, 0xc1, 0xdd,
    0x15, 0x07, 0xcc, 0xc0, 0xd2, 0x0a, 0xb1, 0x3c, 0x78, 0xf6, 0xbf, 0x84, 0xf3, 0x43, 0x04, 0x91,
    0xab, 0x9d, 0x5b, 0x73, 0xa9, 0xce, 0xfd, 0xf5, 0x5c, 0x4b, 0x4c, 0x6f, 0xb3, 0xb4, 0xd5, 0x03,
    0x0d, 0x91, 0x1a, 0x53, 0xab, 0x2f, 0xfa, 0x1a, 0xf0, 0x49
};
#endif

PyTypeObject *init_Qt3DRender_PropertyReaderInterfacePtr(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_PropertyReaderInterfacePtr_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_Qt3DRender_PropertyReaderInterfacePtr_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "PropertyReaderInterfacePtr",
        "QSharedPointer<Qt3DRender::PropertyReaderInterface>",
        &Sbk_Qt3DRender_PropertyReaderInterfacePtr_spec,
        &Shiboken::callCppDestructor< ::QSharedPointer<Qt3DRender::PropertyReaderInterface> >,
        Sbk_Qt3DRender_PropertyReaderInterfacePtr_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_PropertyReaderInterfacePtr_TypeF(); // references _Sbk_Qt3DRender_PropertyReaderInterfacePtr_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_PropertyReaderInterfacePtr_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_PropertyReaderInterfacePtr_SignatureBytes, Qt3DRender_PropertyReaderInterfacePtr_SignatureByteSize);
#endif
    SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        PropertyReaderInterfacePtr_PythonToCpp_PropertyReaderInterfacePtr_PTR,
        is_PropertyReaderInterfacePtr_PythonToCpp_PropertyReaderInterfacePtr_PTR_Convertible,
        PropertyReaderInterfacePtr_PTR_CppToPython_PropertyReaderInterfacePtr,
        PropertyReaderInterfacePtr_COPY_CppToPython_PropertyReaderInterfacePtr);

    Shiboken::Conversions::registerConverterName(converter, "QSharedPointer<Qt3DRender::PropertyReaderInterface>");
    Shiboken::Conversions::registerConverterName(converter, "QSharedPointer<Qt3DRender::PropertyReaderInterface>*");
    Shiboken::Conversions::registerConverterName(converter, "QSharedPointer<Qt3DRender::PropertyReaderInterface>&");
    Shiboken::Conversions::registerConverterAlias(converter, "QSharedPointer<PropertyReaderInterface>");
    Shiboken::Conversions::registerConverterAlias(converter, "QSharedPointer<PropertyReaderInterface>*");
    Shiboken::Conversions::registerConverterAlias(converter, "QSharedPointer<PropertyReaderInterface>&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSharedPointer<Qt3DRender::PropertyReaderInterface>).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PropertyReaderInterfacePtr_PythonToCpp_PropertyReaderInterfacePtr_COPY,
        is_PropertyReaderInterfacePtr_PythonToCpp_PropertyReaderInterfacePtr_COPY_Convertible);

    qRegisterMetaType< ::QSharedPointer<Qt3DRender::PropertyReaderInterface> >("QSharedPointer<Qt3DRender::PropertyReaderInterface>");
    qRegisterMetaType< ::QSharedPointer<Qt3DRender::PropertyReaderInterface> >("Qt3DRender::QSharedPointer<Qt3DRender::PropertyReaderInterface>");

    return pyType;
}
