// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qabstracttexture_wrapper.h"

// Argument includes
#include <QList>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DRender/qabstracttexture.h>
#include <Qt3DRender/qabstracttextureimage.h>
#include <Qt3DRender/qtexturedataupdate.h>
#include <Qt3DRender/qtexturewrapmode.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QAbstractTextureWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstractTextureWrapper::QAbstractTextureWrapper(::Qt3DCore::QNode * parent) : Qt3DRender::QAbstractTexture(parent)
{
}

QAbstractTextureWrapper::QAbstractTextureWrapper(::Qt3DRender::QAbstractTexture::Target target, ::Qt3DCore::QNode * parent) : Qt3DRender::QAbstractTexture(target, parent)
{
}

void QAbstractTextureWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractTexture", funcName);
        return;
    }
}

void QAbstractTextureWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractTexture", funcName);
        return;
    }
}

void QAbstractTextureWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractTexture", funcName);
        return;
    }
}

void QAbstractTextureWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractTexture", funcName);
        return;
    }
}

bool QAbstractTextureWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractTexture", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractTexture", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAbstractTextureWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractTexture", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractTexture", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractTextureWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractTexture", funcName);
        return;
    }
}

const QMetaObject *QAbstractTextureWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DRender::QAbstractTexture::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAbstractTextureWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DRender::QAbstractTexture::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAbstractTextureWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAbstractTextureWrapper *>(this));
    return Qt3DRender::QAbstractTexture::qt_metacast(_clname);
}

QAbstractTextureWrapper::~QAbstractTextureWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DRender_QAbstractTexture_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DRender::QAbstractTexture >()))
        return -1;

    QAbstractTextureWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QAbstractTexture", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAbstractTexture::QAbstractTexture(Qt3DCore::QNode*=)
    // 1: QAbstractTexture::QAbstractTexture(Qt3DRender::QAbstractTexture::Target,Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QAbstractTexture(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Target_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QAbstractTexture(Qt3DRender::QAbstractTexture::Target,Qt3DCore::QNode*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QAbstractTexture(Qt3DRender::QAbstractTexture::Target,Qt3DCore::QNode*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QAbstractTexture(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAbstractTexture(Qt3DCore::QNode *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Qt3DCore::QNode *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAbstractTexture(Qt3DCore::QNode*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QAbstractTextureWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QAbstractTextureWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QAbstractTexture(Qt3DRender::QAbstractTexture::Target target, Qt3DCore::QNode *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::Qt3DRender::QAbstractTexture::Target cppArg0{Qt3DRender::QAbstractTexture::TargetAutomatic};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::Qt3DCore::QNode *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAbstractTexture(Qt3DRender::QAbstractTexture::Target,Qt3DCore::QNode*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QAbstractTextureWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QAbstractTextureWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DRender::QAbstractTexture >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_addTextureImage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::addTextureImage(Qt3DRender::QAbstractTextureImage*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTextureImage_IDX]), (pyArg)))) {
        overloadId = 0; // addTextureImage(Qt3DRender::QAbstractTextureImage*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addTextureImage", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QAbstractTextureImage *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addTextureImage(Qt3DRender::QAbstractTextureImage*)
            cppSelf->addTextureImage(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_comparisonFunction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // comparisonFunction()const
        Qt3DRender::QAbstractTexture::ComparisonFunction cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->comparisonFunction();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_ComparisonFunction_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_comparisonMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // comparisonMode()const
        Qt3DRender::QAbstractTexture::ComparisonMode cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->comparisonMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_ComparisonMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_depth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // depth()const
        int cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->depth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // format()const
        Qt3DRender::QAbstractTexture::TextureFormat cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->format();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_TextureFormat_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_generateMipMaps(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // generateMipMaps()const
        bool cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->generateMipMaps();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_handle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // handle()const
        QVariant cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->handle();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_handleType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // handleType()const
        Qt3DRender::QAbstractTexture::HandleType cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->handleType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_HandleType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_height(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // height()const
        int cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->height();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_layers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // layers()const
        int cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->layers();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_magnificationFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // magnificationFilter()const
        Qt3DRender::QAbstractTexture::Filter cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->magnificationFilter();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Filter_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_maximumAnisotropy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumAnisotropy()const
        float cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->maximumAnisotropy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_minificationFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minificationFilter()const
        Qt3DRender::QAbstractTexture::Filter cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->minificationFilter();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Filter_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_mipLevels(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mipLevels()const
        int cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->mipLevels();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_removeTextureImage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::removeTextureImage(Qt3DRender::QAbstractTextureImage*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTextureImage_IDX]), (pyArg)))) {
        overloadId = 0; // removeTextureImage(Qt3DRender::QAbstractTextureImage*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeTextureImage", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QAbstractTextureImage *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeTextureImage(Qt3DRender::QAbstractTextureImage*)
            cppSelf->removeTextureImage(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_samples(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // samples()const
        int cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->samples();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setComparisonFunction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setComparisonFunction(Qt3DRender::QAbstractTexture::ComparisonFunction)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_ComparisonFunction_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setComparisonFunction(Qt3DRender::QAbstractTexture::ComparisonFunction)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setComparisonFunction", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QAbstractTexture::ComparisonFunction cppArg0 = static_cast< ::Qt3DRender::QAbstractTexture::ComparisonFunction>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setComparisonFunction(Qt3DRender::QAbstractTexture::ComparisonFunction)
            cppSelf->setComparisonFunction(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setComparisonMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setComparisonMode(Qt3DRender::QAbstractTexture::ComparisonMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_ComparisonMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setComparisonMode(Qt3DRender::QAbstractTexture::ComparisonMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setComparisonMode", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QAbstractTexture::ComparisonMode cppArg0{Qt3DRender::QAbstractTexture::CompareNone};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setComparisonMode(Qt3DRender::QAbstractTexture::ComparisonMode)
            cppSelf->setComparisonMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setDepth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setDepth(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setDepth(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDepth", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepth(int)
            cppSelf->setDepth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setFormat(Qt3DRender::QAbstractTexture::TextureFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_TextureFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFormat(Qt3DRender::QAbstractTexture::TextureFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFormat", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QAbstractTexture::TextureFormat cppArg0{Qt3DRender::QAbstractTexture::NoFormat};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFormat(Qt3DRender::QAbstractTexture::TextureFormat)
            cppSelf->setFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setGenerateMipMaps(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setGenerateMipMaps(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setGenerateMipMaps(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGenerateMipMaps", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGenerateMipMaps(bool)
            cppSelf->setGenerateMipMaps(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setHandle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setHandle(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setHandle(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHandle", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHandle(QVariant)
            cppSelf->setHandle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setHandleType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setHandleType(Qt3DRender::QAbstractTexture::HandleType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_HandleType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setHandleType(Qt3DRender::QAbstractTexture::HandleType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHandleType", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QAbstractTexture::HandleType cppArg0{Qt3DRender::QAbstractTexture::NoHandle};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHandleType(Qt3DRender::QAbstractTexture::HandleType)
            cppSelf->setHandleType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setHeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setHeight(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setHeight(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeight", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeight(int)
            cppSelf->setHeight(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setLayers(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setLayers(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLayers(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLayers", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLayers(int)
            cppSelf->setLayers(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setMagnificationFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setMagnificationFilter(Qt3DRender::QAbstractTexture::Filter)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Filter_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMagnificationFilter(Qt3DRender::QAbstractTexture::Filter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMagnificationFilter", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QAbstractTexture::Filter cppArg0 = static_cast< ::Qt3DRender::QAbstractTexture::Filter>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMagnificationFilter(Qt3DRender::QAbstractTexture::Filter)
            cppSelf->setMagnificationFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setMaximumAnisotropy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setMaximumAnisotropy(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMaximumAnisotropy(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaximumAnisotropy", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximumAnisotropy(float)
            cppSelf->setMaximumAnisotropy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setMinificationFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setMinificationFilter(Qt3DRender::QAbstractTexture::Filter)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Filter_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMinificationFilter(Qt3DRender::QAbstractTexture::Filter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinificationFilter", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QAbstractTexture::Filter cppArg0 = static_cast< ::Qt3DRender::QAbstractTexture::Filter>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinificationFilter(Qt3DRender::QAbstractTexture::Filter)
            cppSelf->setMinificationFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setMipLevels(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setMipLevels(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMipLevels(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMipLevels", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMipLevels(int)
            cppSelf->setMipLevels(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setSamples(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setSamples(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSamples(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSamples", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSamples(int)
            cppSelf->setSamples(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setSize(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setSize", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setSize", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractTexture::setSize(int,int=,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setSize(int,int,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setSize(int,int,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 0; // setSize(int,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSize", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_height = Shiboken::String::createStaticString("height");
            if (PyDict_Contains(kwds, key_height) != 0) {
                value = PyDict_GetItem(kwds, key_height);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_height);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setSize", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setSize", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_height);
            }
            static PyObject *const key_depth = Shiboken::String::createStaticString("depth");
            if (PyDict_Contains(kwds, key_depth) != 0) {
                value = PyDict_GetItem(kwds, key_depth);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_depth);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setSize", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "setSize", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_depth);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setSize", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = 1;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSize(int,int,int)
            cppSelf->setSize(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setStatus(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setStatus(Qt3DRender::QAbstractTexture::Status)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Status_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setStatus(Qt3DRender::QAbstractTexture::Status)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStatus", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QAbstractTexture::Status cppArg0{Qt3DRender::QAbstractTexture::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStatus(Qt3DRender::QAbstractTexture::Status)
            cppSelf->setStatus(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setWidth(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWidth", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWidth(int)
            cppSelf->setWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_setWrapMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::setWrapMode(Qt3DRender::QTextureWrapMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureWrapMode_IDX]), (pyArg)))) {
        overloadId = 0; // setWrapMode(Qt3DRender::QTextureWrapMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWrapMode", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QTextureWrapMode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWrapMode(Qt3DRender::QTextureWrapMode)
            cppSelf->setWrapMode(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_status(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // status()const
        Qt3DRender::QAbstractTexture::Status cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->status();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Status_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_target(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // target()const
        Qt3DRender::QAbstractTexture::Target cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->target();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Target_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_textureImages(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureImages()const
        QList<Qt3DRender::QAbstractTextureImage*> cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->textureImages();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QAbstractTextureImagePTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_updateData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractTexture::updateData(Qt3DRender::QTextureDataUpdate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureDataUpdate_IDX]), (pyArg)))) {
        overloadId = 0; // updateData(Qt3DRender::QTextureDataUpdate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "updateData", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QTextureDataUpdate cppArg0_local;
        ::Qt3DRender::QTextureDataUpdate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // updateData(Qt3DRender::QTextureDataUpdate)
            cppSelf->updateData(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_width(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // width()const
        int cppResult = const_cast<const ::Qt3DRender::QAbstractTexture *>(cppSelf)->width();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QAbstractTextureFunc_wrapMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wrapMode()
        Qt3DRender::QTextureWrapMode * cppResult = cppSelf->wrapMode();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureWrapMode_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DRender_QAbstractTexture_PropertyStrings[] = {
    "comparisonFunction::",
    "comparisonMode::",
    "depth::",
    "format::",
    "generateMipMaps::",
    "handle:",
    "handleType:",
    "height::",
    "layers::",
    "magnificationFilter::",
    "maximumAnisotropy::",
    "minificationFilter::",
    "mipLevels::",
    "samples::",
    "status:",
    "target:",
    "width::",
    "wrapMode:",
    nullptr // Sentinel
};

static const char *Sbk_Qt3DRender_QAbstractTexture_EnumFlagInfo[] = {
    "ComparisonFunction:Enum",
    "ComparisonMode:Enum",
    "CubeMapFace:Enum",
    "Filter:Enum",
    "HandleType:Enum",
    "Status:Enum",
    "Target:Enum",
    "TextureFormat:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QAbstractTexture_methods[] = {
    {"addTextureImage", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_addTextureImage), METH_O, nullptr},
    {"comparisonFunction", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_comparisonFunction), METH_NOARGS, nullptr},
    {"comparisonMode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_comparisonMode), METH_NOARGS, nullptr},
    {"depth", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_depth), METH_NOARGS, nullptr},
    {"format", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_format), METH_NOARGS, nullptr},
    {"generateMipMaps", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_generateMipMaps), METH_NOARGS, nullptr},
    {"handle", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_handle), METH_NOARGS, nullptr},
    {"handleType", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_handleType), METH_NOARGS, nullptr},
    {"height", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_height), METH_NOARGS, nullptr},
    {"layers", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_layers), METH_NOARGS, nullptr},
    {"magnificationFilter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_magnificationFilter), METH_NOARGS, nullptr},
    {"maximumAnisotropy", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_maximumAnisotropy), METH_NOARGS, nullptr},
    {"minificationFilter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_minificationFilter), METH_NOARGS, nullptr},
    {"mipLevels", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_mipLevels), METH_NOARGS, nullptr},
    {"removeTextureImage", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_removeTextureImage), METH_O, nullptr},
    {"samples", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_samples), METH_NOARGS, nullptr},
    {"setComparisonFunction", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setComparisonFunction), METH_O, nullptr},
    {"setComparisonMode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setComparisonMode), METH_O, nullptr},
    {"setDepth", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setDepth), METH_O, nullptr},
    {"setFormat", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setFormat), METH_O, nullptr},
    {"setGenerateMipMaps", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setGenerateMipMaps), METH_O, nullptr},
    {"setHandle", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setHandle), METH_O, nullptr},
    {"setHandleType", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setHandleType), METH_O, nullptr},
    {"setHeight", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setHeight), METH_O, nullptr},
    {"setLayers", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setLayers), METH_O, nullptr},
    {"setMagnificationFilter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setMagnificationFilter), METH_O, nullptr},
    {"setMaximumAnisotropy", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setMaximumAnisotropy), METH_O, nullptr},
    {"setMinificationFilter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setMinificationFilter), METH_O, nullptr},
    {"setMipLevels", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setMipLevels), METH_O, nullptr},
    {"setSamples", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setSamples), METH_O, nullptr},
    {"setSize", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setSize), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setStatus", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setStatus), METH_O, nullptr},
    {"setWidth", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setWidth), METH_O, nullptr},
    {"setWrapMode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_setWrapMode), METH_O, nullptr},
    {"status", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_status), METH_NOARGS, nullptr},
    {"target", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_target), METH_NOARGS, nullptr},
    {"textureImages", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_textureImages), METH_NOARGS, nullptr},
    {"updateData", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_updateData), METH_O, nullptr},
    {"width", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_width), METH_NOARGS, nullptr},
    {"wrapMode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QAbstractTextureFunc_wrapMode), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QAbstractTexture_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QAbstractTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractTextureWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DRender_QAbstractTexture_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QAbstractTexture_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QAbstractTexture_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QAbstractTexture_TypeF(void)
{
    return _Sbk_Qt3DRender_QAbstractTexture_Type;
}

static PyType_Slot Sbk_Qt3DRender_QAbstractTexture_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QAbstractTexture_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QAbstractTexture_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QAbstractTexture_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QAbstractTexture_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QAbstractTexture_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QAbstractTexture_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QAbstractTexture_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QAbstractTexture_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DRender::QAbstractTexture *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Qt3DRender_QAbstractTexture_Status(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QAbstractTexture::Status>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QAbstractTexture::Status *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_Status_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Status_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QAbstractTexture_Status;
    return {};
}

static PyObject *Qt3DRender_QAbstractTexture_Status_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QAbstractTexture::Status>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QAbstractTexture::Status *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Status_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DRender_QAbstractTexture_Target(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QAbstractTexture::Target>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QAbstractTexture::Target *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_Target_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Target_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QAbstractTexture_Target;
    return {};
}

static PyObject *Qt3DRender_QAbstractTexture_Target_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QAbstractTexture::Target>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QAbstractTexture::Target *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Target_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DRender_QAbstractTexture_TextureFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QAbstractTexture::TextureFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QAbstractTexture::TextureFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_TextureFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_TextureFormat_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QAbstractTexture_TextureFormat;
    return {};
}

static PyObject *Qt3DRender_QAbstractTexture_TextureFormat_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QAbstractTexture::TextureFormat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QAbstractTexture::TextureFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_TextureFormat_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DRender_QAbstractTexture_Filter(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QAbstractTexture::Filter>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QAbstractTexture::Filter *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_Filter_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Filter_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QAbstractTexture_Filter;
    return {};
}

static PyObject *Qt3DRender_QAbstractTexture_Filter_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QAbstractTexture::Filter>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QAbstractTexture::Filter *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Filter_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DRender_QAbstractTexture_CubeMapFace(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QAbstractTexture::CubeMapFace>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QAbstractTexture::CubeMapFace *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_CubeMapFace_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_CubeMapFace_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QAbstractTexture_CubeMapFace;
    return {};
}

static PyObject *Qt3DRender_QAbstractTexture_CubeMapFace_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QAbstractTexture::CubeMapFace>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QAbstractTexture::CubeMapFace *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_CubeMapFace_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DRender_QAbstractTexture_ComparisonFunction(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QAbstractTexture::ComparisonFunction>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QAbstractTexture::ComparisonFunction *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_ComparisonFunction_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_ComparisonFunction_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QAbstractTexture_ComparisonFunction;
    return {};
}

static PyObject *Qt3DRender_QAbstractTexture_ComparisonFunction_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QAbstractTexture::ComparisonFunction>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QAbstractTexture::ComparisonFunction *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_ComparisonFunction_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DRender_QAbstractTexture_ComparisonMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QAbstractTexture::ComparisonMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QAbstractTexture::ComparisonMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_ComparisonMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_ComparisonMode_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QAbstractTexture_ComparisonMode;
    return {};
}

static PyObject *Qt3DRender_QAbstractTexture_ComparisonMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QAbstractTexture::ComparisonMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QAbstractTexture::ComparisonMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_ComparisonMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DRender_QAbstractTexture_HandleType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QAbstractTexture::HandleType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QAbstractTexture::HandleType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_HandleType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_HandleType_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QAbstractTexture_HandleType;
    return {};
}

static PyObject *Qt3DRender_QAbstractTexture_HandleType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QAbstractTexture::HandleType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QAbstractTexture::HandleType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_HandleType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractTexture_PythonToCpp_QAbstractTexture_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QAbstractTexture_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractTexture_PythonToCpp_QAbstractTexture_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QAbstractTexture_TypeF()))
        return QAbstractTexture_PythonToCpp_QAbstractTexture_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractTexture_PTR_CppToPython_QAbstractTexture(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DRender::QAbstractTexture *>(const_cast<void *>(cppIn)), Sbk_Qt3DRender_QAbstractTexture_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QAbstractTexture_SignatureStrings[] = {
    "1:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,target:Qt3DRender.QAbstractTexture.Target=None,format:Qt3DRender.QAbstractTexture.TextureFormat=None,generateMipMaps:bool=None,wrapMode:Qt3DRender.QTextureWrapMode=None,status:Qt3DRender.QAbstractTexture.Status=None,width:int=None,height:int=None,depth:int=None,mipLevels:int=None,magnificationFilter:Qt3DRender.QAbstractTexture.Filter=None,minificationFilter:Qt3DRender.QAbstractTexture.Filter=None,maximumAnisotropy:float=None,comparisonFunction:Qt3DRender.QAbstractTexture.ComparisonFunction=None,comparisonMode:Qt3DRender.QAbstractTexture.ComparisonMode=None,layers:int=None,samples:int=None,handleType:Qt3DRender.QAbstractTexture.HandleType=None,handle:QVariant=None)",
    "0:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture(self,target:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Target,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,target:Qt3DRender.QAbstractTexture.Target=None,format:Qt3DRender.QAbstractTexture.TextureFormat=None,generateMipMaps:bool=None,wrapMode:Qt3DRender.QTextureWrapMode=None,status:Qt3DRender.QAbstractTexture.Status=None,width:int=None,height:int=None,depth:int=None,mipLevels:int=None,magnificationFilter:Qt3DRender.QAbstractTexture.Filter=None,minificationFilter:Qt3DRender.QAbstractTexture.Filter=None,maximumAnisotropy:float=None,comparisonFunction:Qt3DRender.QAbstractTexture.ComparisonFunction=None,comparisonMode:Qt3DRender.QAbstractTexture.ComparisonMode=None,layers:int=None,samples:int=None,handleType:Qt3DRender.QAbstractTexture.HandleType=None,handle:QVariant=None)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.addTextureImage(self,textureImage:PySide6.Qt3DRender.Qt3DRender.QAbstractTextureImage)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.comparisonFunction(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.ComparisonFunction",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.comparisonMode(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.ComparisonMode",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.depth(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.format(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.TextureFormat",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.generateMipMaps(self)->bool",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.handle(self)->QVariant",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.handleType(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.HandleType",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.height(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.layers(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.magnificationFilter(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Filter",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.maximumAnisotropy(self)->float",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.minificationFilter(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Filter",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.mipLevels(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.removeTextureImage(self,textureImage:PySide6.Qt3DRender.Qt3DRender.QAbstractTextureImage)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.samples(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setComparisonFunction(self,function:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.ComparisonFunction)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setComparisonMode(self,mode:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.ComparisonMode)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setDepth(self,depth:int)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setFormat(self,format:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.TextureFormat)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setGenerateMipMaps(self,gen:bool)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setHandle(self,handle:QVariant)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setHandleType(self,type:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.HandleType)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setHeight(self,height:int)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setLayers(self,layers:int)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setMagnificationFilter(self,f:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Filter)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setMaximumAnisotropy(self,anisotropy:float)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setMinificationFilter(self,f:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Filter)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setMipLevels(self,mipLevels:int)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setSamples(self,samples:int)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setSize(self,width:int,height:int=1,depth:int=1)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setStatus(self,status:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Status)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setWidth(self,width:int)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.setWrapMode(self,wrapMode:PySide6.Qt3DRender.Qt3DRender.QTextureWrapMode)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.status(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Status",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.target(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Target",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.textureImages(self)->QList[PySide6.Qt3DRender.Qt3DRender.QAbstractTextureImage]",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.updateData(self,update:PySide6.Qt3DRender.Qt3DRender.QTextureDataUpdate)",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.width(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.wrapMode(self)->PySide6.Qt3DRender.Qt3DRender.QTextureWrapMode",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QAbstractTexture_SignatureByteSize = 710;
static constexpr uint8_t Qt3DRender_QAbstractTexture_SignatureBytes[710] = {
    0x78, 0xda, 0xed, 0x58, 0x4d, 0x6f, 0xdb, 0x30, 0x0c, 0xbd, 0xf7, 0x97, 0x2c, 0x83, 0x57, 0x2c,
    0x18, 0xb0, 0x83, 0x81, 0x0e, 0x28, 0x12, 0x64, 0x1d, 0x96, 0x74, 0xcb, 0x92, 0xad, 0x87, 0x61,
    0x07, 0x35, 0xa6, 0x13, 0x01, 0xb6, 0x64, 0xc8, 0x72, 0x53, 0xef, 0xd7, 0xcf, 0xd6, 0x87, 0x2d,
    0x3b, 0x69, 0x32, 0xd1, 0x87, 0x0e, 0x43, 0x4f, 0xb1, 0x2d, 0xf2, 0x91, 0x12, 0xc9, 0x27, 0x32,
    0xe3, 0xf0, 0x6b, 0xb9, 0xa2, 0x11, 0xbc, 0xbf, 0x5c, 0xca, 0x77, 0xd3, 0x6f, 0xc0, 0x22, 0x10,
    0x9d, 0xc7, 0xeb, 0xfb, 0x5c, 0x0a, 0xb2, 0x91, 0x6b, 0x78, 0x94, 0x85, 0x80, 0x57, 0x39, 0x24,
    0x71, 0x90, 0x11, 0x01, 0x4c, 0x76, 0x54, 0x27, 0x5c, 0x80, 0xf3, 0x70, 0xcb, 0x23, 0xb8, 0x62,
    0x45, 0x92, 0x64, 0x52, 0x04, 0xaf, 0xc3, 0xcf, 0x50, 0xee, 0xb9, 0x88, 0xbe, 0xb0, 0xa4, 0xbc,
    0xba, 0xe5, 0x0c, 0x02, 0x49, 0xc4, 0x16, 0x64, 0x78, 0xc2, 0xd2, 0xe5, 0x5a, 0x89, 0x68, 0xf1,
    0x98, 0x8b, 0x94, 0x9c, 0x11, 0xd7, 0xbf, 0x33, 0x25, 0xa9, 0xb5, 0xb6, 0xc0, 0x40, 0x10, 0x09,
    0x0b, 0x9a, 0x2d, 0x48, 0x96, 0x87, 0xf7, 0x9c, 0x27, 0x7a, 0x65, 0x2f, 0x48, 0xb6, 0xa8, 0x5c,
    0xec, 0x20, 0x1a, 0x84, 0x3b, 0xb3, 0xa6, 0x25, 0x73, 0x49, 0x64, 0x91, 0x9f, 0xb4, 0xbc, 0x52,
    0x22, 0x06, 0x98, 0x46, 0x72, 0x17, 0x52, 0x66, 0x3c, 0xd8, 0x01, 0xdd, 0xee, 0x64, 0xfb, 0x1e,
    0x41, 0xe6, 0x2e, 0xa7, 0x34, 0x9b, 0xc3, 0x03, 0x24, 0xb9, 0xf3, 0x89, 0x6c, 0x19, 0x8d, 0xe9,
    0x86, 0x48, 0xca, 0xd9, 0x8c, 0x26, 0x12, 0xc4, 0x49, 0xe3, 0x5a, 0xc4, 0xc2, 0xe1, 0x55, 0xc9,
    0x23, 0x4d, 0x8b, 0xf4, 0x9a, 0xd1, 0x9c, 0x4b, 0xc1, 0xb3, 0x32, 0x8c, 0x13, 0x6e, 0xcf, 0x71,
    0xc3, 0xd3, 0x2a, 0xe2, 0xd5, 0x0a, 0x9b, 0x15, 0x6c, 0x53, 0xa3, 0x9f, 0xc4, 0x9d, 0x1c, 0x88,
    0xf7, 0x61, 0x0e, 0x8e, 0xfe, 0x69, 0x88, 0x36, 0x12, 0x09, 0x29, 0x41, 0x38, 0x27, 0x95, 0x93,
    0x34, 0x4b, 0xc0, 0xf9, 0xb0, 0x23, 0x2c, 0x4a, 0x60, 0x5d, 0x66, 0xa7, 0xb1, 0x6f, 0x1a, 0x31,
    0x57, 0x2d, 0x5c, 0xfe, 0xa8, 0x0c, 0x12, 0x83, 0x35, 0xba, 0x78, 0x8b, 0x2a, 0x0c, 0x93, 0xd6,
    0x7e, 0xaa, 0x26, 0xd3, 0x5f, 0xaa, 0xea, 0xa5, 0xaa, 0xfe, 0xf7, 0xaa, 0xf2, 0x2c, 0x0c, 0x12,
    0x45, 0xe6, 0xf1, 0x53, 0x15, 0x41, 0x5b, 0x63, 0xce, 0x17, 0xcf, 0x4a, 0x53, 0x3a, 0xde, 0x5e,
    0x1c, 0x06, 0x4a, 0x39, 0x32, 0x7a, 0xf3, 0xc1, 0x13, 0xe8, 0x30, 0x84, 0x78, 0x57, 0xea, 0x08,
    0x0e, 0x76, 0xa3, 0x06, 0xf1, 0x75, 0x41, 0x15, 0x9b, 0xb5, 0x5c, 0x65, 0x89, 0xaf, 0xbe, 0x26,
    0x1d, 0xa4, 0xeb, 0x1d, 0x3a, 0xf2, 0xb5, 0xdc, 0x23, 0x2e, 0xeb, 0x42, 0xcd, 0x5f, 0xbe, 0x50,
    0x3a, 0xbb, 0x2d, 0x82, 0x4d, 0x72, 0x1c, 0x4a, 0x5d, 0x33, 0xc8, 0xe3, 0x68, 0x8b, 0xce, 0xdb,
    0xb4, 0xa2, 0xd0, 0x01, 0x61, 0xd4, 0xbc, 0x31, 0x00, 0xe0, 0x08, 0x25, 0x23, 0x4f, 0x41, 0x2b,
    0xfb, 0xdb, 0xef, 0x71, 0xb3, 0xb5, 0xae, 0x28, 0xda, 0x1b, 0x8d, 0x3e, 0xef, 0x66, 0xec, 0x95,
    0x37, 0x20, 0x20, 0x02, 0x52, 0xfe, 0x00, 0xff, 0x00, 0xdf, 0x9a, 0x2b, 0x68, 0xc0, 0x56, 0x72,
    0x90, 0x93, 0xe3, 0xa4, 0x1d, 0xc4, 0xf6, 0xae, 0x1d, 0xcc, 0xdd, 0xa3, 0x41, 0x5e, 0x35, 0xfc,
    0x1d, 0xa4, 0xf5, 0xb5, 0x3d, 0x88, 0xc2, 0x31, 0x9e, 0x4c, 0x1b, 0x1a, 0x6f, 0xdb, 0x27, 0x0c,
    0xce, 0xac, 0xa5, 0x73, 0xdb, 0x4f, 0x0e, 0xe1, 0x74, 0x8c, 0x0b, 0x1f, 0x8f, 0xf0, 0x7a, 0xdd,
    0xa5, 0xaa, 0xce, 0x14, 0x03, 0x78, 0xd3, 0xb2, 0x7b, 0xbf, 0x8f, 0xc1, 0xc3, 0x35, 0x34, 0x1f,
    0xc8, 0xba, 0x97, 0x42, 0x33, 0x3d, 0xca, 0x83, 0x96, 0xed, 0x9d, 0xe6, 0x19, 0x83, 0x34, 0x6f,
    0x69, 0xdf, 0x69, 0x1d, 0x31, 0x48, 0x8b, 0x27, 0xf8, 0x3f, 0x88, 0x43, 0x14, 0x65, 0xe2, 0x7c,
    0x38, 0x76, 0x07, 0x04, 0xa4, 0xd7, 0xaf, 0xa3, 0xa0, 0xe9, 0xf3, 0xef, 0xae, 0x73, 0x29, 0x74,
    0xc7, 0x22, 0x0c, 0xde, 0xca, 0xe1, 0x65, 0x77, 0x4e, 0x40, 0x61, 0xd1, 0xdf, 0xa6, 0x1a, 0x9a,
    0xd9, 0xce, 0x1d, 0xeb, 0xc6, 0xce, 0x4c, 0x37, 0x46, 0xe1, 0xab, 0xe9, 0xd1, 0xb8, 0xaa, 0x87,
    0x4d, 0x4f, 0x10, 0x8d, 0x80, 0xb1, 0x7d, 0x57, 0xef, 0xa8, 0xb7, 0x39, 0x14, 0x8e, 0x19, 0x99,
    0x0d, 0x94, 0x1d, 0xae, 0xcf, 0x00, 0xf5, 0xe6, 0x6d, 0x7f, 0xc3, 0xed, 0xc9, 0xf9, 0x77, 0x2f,
    0xfa, 0xd0, 0x7c, 0x4d, 0xea, 0xbf, 0x2d, 0xb0, 0x23, 0x81, 0x52, 0xf6, 0x36, 0xe9, 0x34, 0x28,
    0xcd, 0x66, 0x97, 0x73, 0x9a, 0xcb, 0x9f, 0x88, 0x16, 0xe7, 0x97, 0xaf, 0xf9, 0x22, 0x8b, 0xaa,
    0x0b, 0x6b, 0x4a, 0x24, 0xd1, 0xc1, 0xd5, 0xef, 0x7f, 0x19, 0xda, 0x5a, 0xed, 0xbb, 0x52, 0xf0,
    0x0e, 0xee, 0xbe, 0x49, 0x4d, 0x5c, 0x63, 0xb5, 0x77, 0x53, 0xf2, 0x7c, 0xac, 0x7a, 0xb9, 0x78,
    0xf1, 0x07, 0x6e, 0x07, 0x36, 0xa1
};
#endif

PyTypeObject *init_Qt3DRender_QAbstractTexture(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QAbstractTexture_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]))));

    _Sbk_Qt3DRender_QAbstractTexture_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QAbstractTexture",
        "Qt3DRender::QAbstractTexture*",
        &Sbk_Qt3DRender_QAbstractTexture_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QAbstractTexture >,
        Sbk_Qt3DRender_QAbstractTexture_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QAbstractTexture_TypeF(); // references _Sbk_Qt3DRender_QAbstractTexture_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QAbstractTexture_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QAbstractTexture_SignatureBytes, Qt3DRender_QAbstractTexture_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QAbstractTexture_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractTexture_PythonToCpp_QAbstractTexture_PTR,
        is_QAbstractTexture_PythonToCpp_QAbstractTexture_PTR_Convertible,
        QAbstractTexture_PTR_CppToPython_QAbstractTexture);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QAbstractTexture");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QAbstractTexture*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QAbstractTexture&");
    Shiboken::Conversions::registerConverterAlias(converter, "QAbstractTexture");
    Shiboken::Conversions::registerConverterAlias(converter, "QAbstractTexture*");
    Shiboken::Conversions::registerConverterAlias(converter, "QAbstractTexture&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QAbstractTexture).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractTextureWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QAbstractTexture_TypeF(), &Sbk_Qt3DRender_QAbstractTexture_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DRender_QAbstractTexture_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Status'.
    const char *Status_Initializer[] = {
        "None_",
        "Loading",
        "Ready",
        "Error",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Status_InitializerValues[] = {
        uint8_t(Qt3DRender::QAbstractTexture::Status::None),    //  0x00  0
        uint8_t(Qt3DRender::QAbstractTexture::Status::Loading), //  0x01  1
        uint8_t(Qt3DRender::QAbstractTexture::Status::Ready),   //  0x02  2
        uint8_t(Qt3DRender::QAbstractTexture::Status::Error)    //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QAbstractTexture_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Status",
        Status_Initializer, Status_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Status_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QAbstractTexture::Status'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QAbstractTexture_Status_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QAbstractTexture_Status,
            is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_Status_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QAbstractTexture::Status");
        Shiboken::Conversions::registerConverterAlias(converter, "QAbstractTexture::Status");
        Shiboken::Conversions::registerConverterAlias(converter, "Status");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Status' enum.

    // Initialization of enum 'Target'.
    const char *Target_Initializer[] = {
        "TargetAutomatic",
        "Target1D",
        "Target1DArray",
        "Target2D",
        "Target2DArray",
        "Target3D",
        "TargetCubeMap",
        "TargetCubeMapArray",
        "Target2DMultisample",
        "Target2DMultisampleArray",
        "TargetRectangle",
        "TargetBuffer",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Target_InitializerValues[] = {
        uint16_t(Qt3DRender::QAbstractTexture::Target::TargetAutomatic),          //  0x0000  0
        uint16_t(Qt3DRender::QAbstractTexture::Target::Target1D),                 //  0x0de0  3552
        uint16_t(Qt3DRender::QAbstractTexture::Target::Target1DArray),            //  0x8c18  35864
        uint16_t(Qt3DRender::QAbstractTexture::Target::Target2D),                 //  0x0de1  3553
        uint16_t(Qt3DRender::QAbstractTexture::Target::Target2DArray),            //  0x8c1a  35866
        uint16_t(Qt3DRender::QAbstractTexture::Target::Target3D),                 //  0x806f  32879
        uint16_t(Qt3DRender::QAbstractTexture::Target::TargetCubeMap),            //  0x8513  34067
        uint16_t(Qt3DRender::QAbstractTexture::Target::TargetCubeMapArray),       //  0x9009  36873
        uint16_t(Qt3DRender::QAbstractTexture::Target::Target2DMultisample),      //  0x9100  37120
        uint16_t(Qt3DRender::QAbstractTexture::Target::Target2DMultisampleArray), //  0x9102  37122
        uint16_t(Qt3DRender::QAbstractTexture::Target::TargetRectangle),          //  0x84f5  34037
        uint16_t(Qt3DRender::QAbstractTexture::Target::TargetBuffer)              //  0x8c2a  35882
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QAbstractTexture_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Target",
        Target_Initializer, Target_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Target_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QAbstractTexture::Target'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QAbstractTexture_Target_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QAbstractTexture_Target,
            is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_Target_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QAbstractTexture::Target");
        Shiboken::Conversions::registerConverterAlias(converter, "QAbstractTexture::Target");
        Shiboken::Conversions::registerConverterAlias(converter, "Target");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Target' enum.

    // Initialization of enum 'TextureFormat'.
    const char *TextureFormat_Initializer[] = {
        "NoFormat",
        "Automatic",
        "R8_UNorm",
        "RG8_UNorm",
        "RGB8_UNorm",
        "RGBA8_UNorm",
        "R16_UNorm",
        "RG16_UNorm",
        "RGB16_UNorm",
        "RGBA16_UNorm",
        "R8_SNorm",
        "RG8_SNorm",
        "RGB8_SNorm",
        "RGBA8_SNorm",
        "R16_SNorm",
        "RG16_SNorm",
        "RGB16_SNorm",
        "RGBA16_SNorm",
        "R8U",
        "RG8U",
        "RGB8U",
        "RGBA8U",
        "R16U",
        "RG16U",
        "RGB16U",
        "RGBA16U",
        "R32U",
        "RG32U",
        "RGB32U",
        "RGBA32U",
        "R8I",
        "RG8I",
        "RGB8I",
        "RGBA8I",
        "R16I",
        "RG16I",
        "RGB16I",
        "RGBA16I",
        "R32I",
        "RG32I",
        "RGB32I",
        "RGBA32I",
        "R16F",
        "RG16F",
        "RGB16F",
        "RGBA16F",
        "R32F",
        "RG32F",
        "RGB32F",
        "RGBA32F",
        "RGB9E5",
        "RG11B10F",
        "RG3B2",
        "R5G6B5",
        "RGB5A1",
        "RGBA4",
        "RGB10A2",
        "RGB10A2U",
        "D16",
        "D24",
        "D24S8",
        "D32",
        "D32F",
        "D32FS8X24",
        "RGB_DXT1",
        "RGBA_DXT1",
        "RGBA_DXT3",
        "RGBA_DXT5",
        "R_ATI1N_UNorm",
        "R_ATI1N_SNorm",
        "RG_ATI2N_UNorm",
        "RG_ATI2N_SNorm",
        "RGB_BP_UNSIGNED_FLOAT",
        "RGB_BP_SIGNED_FLOAT",
        "RGB_BP_UNorm",
        "R11_EAC_UNorm",
        "R11_EAC_SNorm",
        "RG11_EAC_UNorm",
        "RG11_EAC_SNorm",
        "RGB8_ETC2",
        "SRGB8_ETC2",
        "RGB8_PunchThrough_Alpha1_ETC2",
        "SRGB8_PunchThrough_Alpha1_ETC2",
        "RGBA8_ETC2_EAC",
        "SRGB8_Alpha8_ETC2_EAC",
        "RGB8_ETC1",
        "SRGB8",
        "SRGB8_Alpha8",
        "SRGB_DXT1",
        "SRGB_Alpha_DXT1",
        "SRGB_Alpha_DXT3",
        "SRGB_Alpha_DXT5",
        "SRGB_BP_UNorm",
        "DepthFormat",
        "AlphaFormat",
        "RGBFormat",
        "RGBAFormat",
        "LuminanceFormat",
        "LuminanceAlphaFormat",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t TextureFormat_InitializerValues[] = {
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::NoFormat),                       //  0x0000  0
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::Automatic),                      //  0x0001  1
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R8_UNorm),                       //  0x8229  33321
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG8_UNorm),                      //  0x822b  33323
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB8_UNorm),                     //  0x8051  32849
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA8_UNorm),                    //  0x8058  32856
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R16_UNorm),                      //  0x822a  33322
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG16_UNorm),                     //  0x822c  33324
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB16_UNorm),                    //  0x8054  32852
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA16_UNorm),                   //  0x805b  32859
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R8_SNorm),                       //  0x8f94  36756
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG8_SNorm),                      //  0x8f95  36757
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB8_SNorm),                     //  0x8f96  36758
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA8_SNorm),                    //  0x8f97  36759
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R16_SNorm),                      //  0x8f98  36760
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG16_SNorm),                     //  0x8f99  36761
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB16_SNorm),                    //  0x8f9a  36762
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA16_SNorm),                   //  0x8f9b  36763
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R8U),                            //  0x8232  33330
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG8U),                           //  0x8238  33336
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB8U),                          //  0x8d7d  36221
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA8U),                         //  0x8d7c  36220
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R16U),                           //  0x8234  33332
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG16U),                          //  0x823a  33338
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB16U),                         //  0x8d77  36215
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA16U),                        //  0x8d76  36214
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R32U),                           //  0x8236  33334
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG32U),                          //  0x823c  33340
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB32U),                         //  0x8d71  36209
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA32U),                        //  0x8d70  36208
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R8I),                            //  0x8231  33329
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG8I),                           //  0x8237  33335
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB8I),                          //  0x8d8f  36239
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA8I),                         //  0x8d8e  36238
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R16I),                           //  0x8233  33331
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG16I),                          //  0x8239  33337
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB16I),                         //  0x8d89  36233
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA16I),                        //  0x8d88  36232
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R32I),                           //  0x8235  33333
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG32I),                          //  0x823b  33339
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB32I),                         //  0x8d83  36227
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA32I),                        //  0x8d82  36226
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R16F),                           //  0x822d  33325
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG16F),                          //  0x822f  33327
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB16F),                         //  0x881b  34843
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA16F),                        //  0x881a  34842
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R32F),                           //  0x822e  33326
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG32F),                          //  0x8230  33328
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB32F),                         //  0x8815  34837
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA32F),                        //  0x8814  34836
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB9E5),                         //  0x8c3d  35901
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG11B10F),                       //  0x8c3a  35898
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG3B2),                          //  0x2a10  10768
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R5G6B5),                         //  0x8d62  36194
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB5A1),                         //  0x8057  32855
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA4),                          //  0x8056  32854
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB10A2),                        //  0x8059  32857
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB10A2U),                       //  0x906f  36975
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::D16),                            //  0x81a5  33189
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::D24),                            //  0x81a6  33190
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::D24S8),                          //  0x88f0  35056
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::D32),                            //  0x81a7  33191
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::D32F),                           //  0x8cac  36012
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::D32FS8X24),                      //  0x8cad  36013
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB_DXT1),                       //  0x83f0  33776
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA_DXT1),                      //  0x83f1  33777
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA_DXT3),                      //  0x83f2  33778
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA_DXT5),                      //  0x83f3  33779
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R_ATI1N_UNorm),                  //  0x8dbb  36283
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R_ATI1N_SNorm),                  //  0x8dbc  36284
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG_ATI2N_UNorm),                 //  0x8dbd  36285
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG_ATI2N_SNorm),                 //  0x8dbe  36286
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB_BP_UNSIGNED_FLOAT),          //  0x8e8f  36495
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB_BP_SIGNED_FLOAT),            //  0x8e8e  36494
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB_BP_UNorm),                   //  0x8e8c  36492
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R11_EAC_UNorm),                  //  0x9270  37488
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::R11_EAC_SNorm),                  //  0x9271  37489
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG11_EAC_UNorm),                 //  0x9272  37490
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RG11_EAC_SNorm),                 //  0x9273  37491
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB8_ETC2),                      //  0x9274  37492
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::SRGB8_ETC2),                     //  0x9275  37493
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB8_PunchThrough_Alpha1_ETC2),  //  0x9276  37494
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::SRGB8_PunchThrough_Alpha1_ETC2), //  0x9277  37495
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBA8_ETC2_EAC),                 //  0x9278  37496
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::SRGB8_Alpha8_ETC2_EAC),          //  0x9279  37497
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGB8_ETC1),                      //  0x8d64  36196
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::SRGB8),                          //  0x8c41  35905
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::SRGB8_Alpha8),                   //  0x8c43  35907
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::SRGB_DXT1),                      //  0x8c4c  35916
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::SRGB_Alpha_DXT1),                //  0x8c4d  35917
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::SRGB_Alpha_DXT3),                //  0x8c4e  35918
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::SRGB_Alpha_DXT5),                //  0x8c4f  35919
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::SRGB_BP_UNorm),                  //  0x8e8d  36493
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::DepthFormat),                    //  0x1902  6402
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::AlphaFormat),                    //  0x1906  6406
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBFormat),                      //  0x1907  6407
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::RGBAFormat),                     //  0x1908  6408
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::LuminanceFormat),                //  0x1909  6409
        uint16_t(Qt3DRender::QAbstractTexture::TextureFormat::LuminanceAlphaFormat)            //  0x190a  6410
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QAbstractTexture_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.TextureFormat",
        TextureFormat_Initializer, TextureFormat_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_TextureFormat_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QAbstractTexture::TextureFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QAbstractTexture_TextureFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QAbstractTexture_TextureFormat,
            is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_TextureFormat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QAbstractTexture::TextureFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "QAbstractTexture::TextureFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "TextureFormat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'TextureFormat' enum.

    // Initialization of enum 'Filter'.
    const char *Filter_Initializer[] = {
        "Nearest",
        "Linear",
        "NearestMipMapNearest",
        "NearestMipMapLinear",
        "LinearMipMapNearest",
        "LinearMipMapLinear",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Filter_InitializerValues[] = {
        uint16_t(Qt3DRender::QAbstractTexture::Filter::Nearest),              //  0x2600  9728
        uint16_t(Qt3DRender::QAbstractTexture::Filter::Linear),               //  0x2601  9729
        uint16_t(Qt3DRender::QAbstractTexture::Filter::NearestMipMapNearest), //  0x2700  9984
        uint16_t(Qt3DRender::QAbstractTexture::Filter::NearestMipMapLinear),  //  0x2702  9986
        uint16_t(Qt3DRender::QAbstractTexture::Filter::LinearMipMapNearest),  //  0x2701  9985
        uint16_t(Qt3DRender::QAbstractTexture::Filter::LinearMipMapLinear)    //  0x2703  9987
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QAbstractTexture_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Filter",
        Filter_Initializer, Filter_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Filter_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QAbstractTexture::Filter'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QAbstractTexture_Filter_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QAbstractTexture_Filter,
            is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_Filter_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QAbstractTexture::Filter");
        Shiboken::Conversions::registerConverterAlias(converter, "QAbstractTexture::Filter");
        Shiboken::Conversions::registerConverterAlias(converter, "Filter");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Filter' enum.

    // Initialization of enum 'CubeMapFace'.
    const char *CubeMapFace_Initializer[] = {
        "CubeMapPositiveX",
        "CubeMapNegativeX",
        "CubeMapPositiveY",
        "CubeMapNegativeY",
        "CubeMapPositiveZ",
        "CubeMapNegativeZ",
        "AllFaces",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t CubeMapFace_InitializerValues[] = {
        uint16_t(Qt3DRender::QAbstractTexture::CubeMapFace::CubeMapPositiveX), //  0x8515  34069
        uint16_t(Qt3DRender::QAbstractTexture::CubeMapFace::CubeMapNegativeX), //  0x8516  34070
        uint16_t(Qt3DRender::QAbstractTexture::CubeMapFace::CubeMapPositiveY), //  0x8517  34071
        uint16_t(Qt3DRender::QAbstractTexture::CubeMapFace::CubeMapNegativeY), //  0x8518  34072
        uint16_t(Qt3DRender::QAbstractTexture::CubeMapFace::CubeMapPositiveZ), //  0x8519  34073
        uint16_t(Qt3DRender::QAbstractTexture::CubeMapFace::CubeMapNegativeZ), //  0x851a  34074
        uint16_t(Qt3DRender::QAbstractTexture::CubeMapFace::AllFaces)          //  0x851b  34075
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QAbstractTexture_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.CubeMapFace",
        CubeMapFace_Initializer, CubeMapFace_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_CubeMapFace_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QAbstractTexture::CubeMapFace'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QAbstractTexture_CubeMapFace_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QAbstractTexture_CubeMapFace,
            is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_CubeMapFace_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QAbstractTexture::CubeMapFace");
        Shiboken::Conversions::registerConverterAlias(converter, "QAbstractTexture::CubeMapFace");
        Shiboken::Conversions::registerConverterAlias(converter, "CubeMapFace");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CubeMapFace' enum.

    // Initialization of enum 'ComparisonFunction'.
    const char *ComparisonFunction_Initializer[] = {
        "CompareLessEqual",
        "CompareGreaterEqual",
        "CompareLess",
        "CompareGreater",
        "CompareEqual",
        "CommpareNotEqual",
        "CompareAlways",
        "CompareNever",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t ComparisonFunction_InitializerValues[] = {
        uint16_t(Qt3DRender::QAbstractTexture::ComparisonFunction::CompareLessEqual),    //  0x0203  515
        uint16_t(Qt3DRender::QAbstractTexture::ComparisonFunction::CompareGreaterEqual), //  0x0206  518
        uint16_t(Qt3DRender::QAbstractTexture::ComparisonFunction::CompareLess),         //  0x0201  513
        uint16_t(Qt3DRender::QAbstractTexture::ComparisonFunction::CompareGreater),      //  0x0204  516
        uint16_t(Qt3DRender::QAbstractTexture::ComparisonFunction::CompareEqual),        //  0x0202  514
        uint16_t(Qt3DRender::QAbstractTexture::ComparisonFunction::CommpareNotEqual),    //  0x0205  517
        uint16_t(Qt3DRender::QAbstractTexture::ComparisonFunction::CompareAlways),       //  0x0207  519
        uint16_t(Qt3DRender::QAbstractTexture::ComparisonFunction::CompareNever)         //  0x0200  512
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QAbstractTexture_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.ComparisonFunction",
        ComparisonFunction_Initializer, ComparisonFunction_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_ComparisonFunction_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QAbstractTexture::ComparisonFunction'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QAbstractTexture_ComparisonFunction_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QAbstractTexture_ComparisonFunction,
            is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_ComparisonFunction_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QAbstractTexture::ComparisonFunction");
        Shiboken::Conversions::registerConverterAlias(converter, "QAbstractTexture::ComparisonFunction");
        Shiboken::Conversions::registerConverterAlias(converter, "ComparisonFunction");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ComparisonFunction' enum.

    // Initialization of enum 'ComparisonMode'.
    const char *ComparisonMode_Initializer[] = {
        "CompareRefToTexture",
        "CompareNone",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t ComparisonMode_InitializerValues[] = {
        uint16_t(Qt3DRender::QAbstractTexture::ComparisonMode::CompareRefToTexture), //  0x884e  34894
        uint16_t(Qt3DRender::QAbstractTexture::ComparisonMode::CompareNone)          //  0x0000  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QAbstractTexture_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.ComparisonMode",
        ComparisonMode_Initializer, ComparisonMode_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_ComparisonMode_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QAbstractTexture::ComparisonMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QAbstractTexture_ComparisonMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QAbstractTexture_ComparisonMode,
            is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_ComparisonMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QAbstractTexture::ComparisonMode");
        Shiboken::Conversions::registerConverterAlias(converter, "QAbstractTexture::ComparisonMode");
        Shiboken::Conversions::registerConverterAlias(converter, "ComparisonMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ComparisonMode' enum.

    // Initialization of enum 'HandleType'.
    const char *HandleType_Initializer[] = {
        "NoHandle",
        "OpenGLTextureId",
        "RHITextureId",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t HandleType_InitializerValues[] = {
        uint8_t(Qt3DRender::QAbstractTexture::HandleType::NoHandle),        //  0x00  0
        uint8_t(Qt3DRender::QAbstractTexture::HandleType::OpenGLTextureId), //  0x01  1
        uint8_t(Qt3DRender::QAbstractTexture::HandleType::RHITextureId)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QAbstractTexture_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.HandleType",
        HandleType_Initializer, HandleType_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_HandleType_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QAbstractTexture::HandleType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QAbstractTexture_HandleType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QAbstractTexture_HandleType,
            is_Enum_PythonToCpp_Qt3DRender_QAbstractTexture_HandleType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QAbstractTexture::HandleType");
        Shiboken::Conversions::registerConverterAlias(converter, "QAbstractTexture::HandleType");
        Shiboken::Conversions::registerConverterAlias(converter, "HandleType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'HandleType' enum.

    PySide::Signal::registerSignals(pyType, &::Qt3DRender::QAbstractTexture::staticMetaObject);
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::Status >("QAbstractTexture::Status");
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::Status >("Qt3DRender::QAbstractTexture::Status");
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::Target >("QAbstractTexture::Target");
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::Target >("Qt3DRender::QAbstractTexture::Target");
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::TextureFormat >("QAbstractTexture::TextureFormat");
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::TextureFormat >("Qt3DRender::QAbstractTexture::TextureFormat");
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::Filter >("QAbstractTexture::Filter");
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::Filter >("Qt3DRender::QAbstractTexture::Filter");
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::CubeMapFace >("QAbstractTexture::CubeMapFace");
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::CubeMapFace >("Qt3DRender::QAbstractTexture::CubeMapFace");
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::ComparisonFunction >("QAbstractTexture::ComparisonFunction");
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::ComparisonFunction >("Qt3DRender::QAbstractTexture::ComparisonFunction");
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::ComparisonMode >("QAbstractTexture::ComparisonMode");
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::ComparisonMode >("Qt3DRender::QAbstractTexture::ComparisonMode");
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::HandleType >("QAbstractTexture::HandleType");
    qRegisterMetaType< ::Qt3DRender::QAbstractTexture::HandleType >("Qt3DRender::QAbstractTexture::HandleType");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DRender::QAbstractTexture::staticMetaObject, sizeof(QAbstractTextureWrapper));

    return pyType;
}
