// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qblendequationarguments_wrapper.h"

// Argument includes
#include <Qt3DCore/qnode.h>
#include <Qt3DRender/qblendequationarguments.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QBlendEquationArgumentsWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QBlendEquationArgumentsWrapper::QBlendEquationArgumentsWrapper(::Qt3DCore::QNode * parent) : Qt3DRender::QBlendEquationArguments(parent)
{
}

void QBlendEquationArgumentsWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBlendEquationArguments", funcName);
        return;
    }
}

void QBlendEquationArgumentsWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBlendEquationArguments", funcName);
        return;
    }
}

void QBlendEquationArgumentsWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBlendEquationArguments", funcName);
        return;
    }
}

void QBlendEquationArgumentsWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBlendEquationArguments", funcName);
        return;
    }
}

bool QBlendEquationArgumentsWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBlendEquationArguments", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QBlendEquationArguments", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QBlendEquationArgumentsWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBlendEquationArguments", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QBlendEquationArguments", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QBlendEquationArgumentsWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBlendEquationArguments", funcName);
        return;
    }
}

const QMetaObject *QBlendEquationArgumentsWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DRender::QBlendEquationArguments::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QBlendEquationArgumentsWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DRender::QBlendEquationArguments::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QBlendEquationArgumentsWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QBlendEquationArgumentsWrapper *>(this));
    return Qt3DRender::QBlendEquationArguments::qt_metacast(_clname);
}

QBlendEquationArgumentsWrapper::~QBlendEquationArgumentsWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DRender_QBlendEquationArguments_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DRender::QBlendEquationArguments >()))
        return -1;

    QBlendEquationArgumentsWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QBlendEquationArguments", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBlendEquationArguments::QBlendEquationArguments(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QBlendEquationArguments(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QBlendEquationArguments(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QBlendEquationArguments(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QBlendEquationArgumentsWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QBlendEquationArgumentsWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DRender::QBlendEquationArguments >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DRender_QBlendEquationArgumentsFunc_bufferIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bufferIndex()const
        int cppResult = const_cast<const ::Qt3DRender::QBlendEquationArguments *>(cppSelf)->bufferIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QBlendEquationArgumentsFunc_destinationAlpha(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // destinationAlpha()const
        Qt3DRender::QBlendEquationArguments::Blending cppResult = const_cast<const ::Qt3DRender::QBlendEquationArguments *>(cppSelf)->destinationAlpha();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_Blending_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QBlendEquationArgumentsFunc_destinationRgb(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // destinationRgb()const
        Qt3DRender::QBlendEquationArguments::Blending cppResult = const_cast<const ::Qt3DRender::QBlendEquationArguments *>(cppSelf)->destinationRgb();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_Blending_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QBlendEquationArgumentsFunc_setBufferIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBlendEquationArguments::setBufferIndex(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setBufferIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBufferIndex", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBufferIndex(int)
            cppSelf->setBufferIndex(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QBlendEquationArgumentsFunc_setDestinationAlpha(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBlendEquationArguments::setDestinationAlpha(Qt3DRender::QBlendEquationArguments::Blending)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_Blending_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDestinationAlpha(Qt3DRender::QBlendEquationArguments::Blending)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDestinationAlpha", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QBlendEquationArguments::Blending cppArg0{Qt3DRender::QBlendEquationArguments::Zero};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDestinationAlpha(Qt3DRender::QBlendEquationArguments::Blending)
            cppSelf->setDestinationAlpha(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QBlendEquationArgumentsFunc_setDestinationRgb(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBlendEquationArguments::setDestinationRgb(Qt3DRender::QBlendEquationArguments::Blending)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_Blending_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDestinationRgb(Qt3DRender::QBlendEquationArguments::Blending)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDestinationRgb", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QBlendEquationArguments::Blending cppArg0{Qt3DRender::QBlendEquationArguments::Zero};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDestinationRgb(Qt3DRender::QBlendEquationArguments::Blending)
            cppSelf->setDestinationRgb(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QBlendEquationArgumentsFunc_setDestinationRgba(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBlendEquationArguments::setDestinationRgba(Qt3DRender::QBlendEquationArguments::Blending)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_Blending_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDestinationRgba(Qt3DRender::QBlendEquationArguments::Blending)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDestinationRgba", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QBlendEquationArguments::Blending cppArg0{Qt3DRender::QBlendEquationArguments::Zero};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDestinationRgba(Qt3DRender::QBlendEquationArguments::Blending)
            cppSelf->setDestinationRgba(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QBlendEquationArgumentsFunc_setSourceAlpha(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBlendEquationArguments::setSourceAlpha(Qt3DRender::QBlendEquationArguments::Blending)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_Blending_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSourceAlpha(Qt3DRender::QBlendEquationArguments::Blending)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSourceAlpha", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QBlendEquationArguments::Blending cppArg0{Qt3DRender::QBlendEquationArguments::Zero};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSourceAlpha(Qt3DRender::QBlendEquationArguments::Blending)
            cppSelf->setSourceAlpha(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QBlendEquationArgumentsFunc_setSourceRgb(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBlendEquationArguments::setSourceRgb(Qt3DRender::QBlendEquationArguments::Blending)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_Blending_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSourceRgb(Qt3DRender::QBlendEquationArguments::Blending)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSourceRgb", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QBlendEquationArguments::Blending cppArg0{Qt3DRender::QBlendEquationArguments::Zero};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSourceRgb(Qt3DRender::QBlendEquationArguments::Blending)
            cppSelf->setSourceRgb(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QBlendEquationArgumentsFunc_setSourceRgba(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBlendEquationArguments::setSourceRgba(Qt3DRender::QBlendEquationArguments::Blending)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_Blending_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSourceRgba(Qt3DRender::QBlendEquationArguments::Blending)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSourceRgba", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QBlendEquationArguments::Blending cppArg0{Qt3DRender::QBlendEquationArguments::Zero};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSourceRgba(Qt3DRender::QBlendEquationArguments::Blending)
            cppSelf->setSourceRgba(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QBlendEquationArgumentsFunc_sourceAlpha(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sourceAlpha()const
        Qt3DRender::QBlendEquationArguments::Blending cppResult = const_cast<const ::Qt3DRender::QBlendEquationArguments *>(cppSelf)->sourceAlpha();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_Blending_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QBlendEquationArgumentsFunc_sourceRgb(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sourceRgb()const
        Qt3DRender::QBlendEquationArguments::Blending cppResult = const_cast<const ::Qt3DRender::QBlendEquationArguments *>(cppSelf)->sourceRgb();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_Blending_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DRender_QBlendEquationArguments_PropertyStrings[] = {
    "bufferIndex::",
    "destinationAlpha::",
    "destinationRgb::",
    "sourceAlpha::",
    "sourceRgb::",
    nullptr // Sentinel
};

static const char *Sbk_Qt3DRender_QBlendEquationArguments_EnumFlagInfo[] = {
    "Blending:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QBlendEquationArguments_methods[] = {
    {"bufferIndex", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QBlendEquationArgumentsFunc_bufferIndex), METH_NOARGS, nullptr},
    {"destinationAlpha", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QBlendEquationArgumentsFunc_destinationAlpha), METH_NOARGS, nullptr},
    {"destinationRgb", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QBlendEquationArgumentsFunc_destinationRgb), METH_NOARGS, nullptr},
    {"setBufferIndex", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QBlendEquationArgumentsFunc_setBufferIndex), METH_O, nullptr},
    {"setDestinationAlpha", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QBlendEquationArgumentsFunc_setDestinationAlpha), METH_O, nullptr},
    {"setDestinationRgb", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QBlendEquationArgumentsFunc_setDestinationRgb), METH_O, nullptr},
    {"setDestinationRgba", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QBlendEquationArgumentsFunc_setDestinationRgba), METH_O, nullptr},
    {"setSourceAlpha", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QBlendEquationArgumentsFunc_setSourceAlpha), METH_O, nullptr},
    {"setSourceRgb", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QBlendEquationArgumentsFunc_setSourceRgb), METH_O, nullptr},
    {"setSourceRgba", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QBlendEquationArgumentsFunc_setSourceRgba), METH_O, nullptr},
    {"sourceAlpha", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QBlendEquationArgumentsFunc_sourceAlpha), METH_NOARGS, nullptr},
    {"sourceRgb", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QBlendEquationArgumentsFunc_sourceRgb), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QBlendEquationArguments_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QBlendEquationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QBlendEquationArgumentsWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DRender_QBlendEquationArguments_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QBlendEquationArguments_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QBlendEquationArguments_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QBlendEquationArguments_TypeF(void)
{
    return _Sbk_Qt3DRender_QBlendEquationArguments_Type;
}

static PyType_Slot Sbk_Qt3DRender_QBlendEquationArguments_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QBlendEquationArguments_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QBlendEquationArguments_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QBlendEquationArguments_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QBlendEquationArguments_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QBlendEquationArguments_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QBlendEquationArguments_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QBlendEquationArguments_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QBlendEquationArguments_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DRender::QBlendEquationArguments *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Qt3DRender_QBlendEquationArguments_Blending(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QBlendEquationArguments::Blending>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QBlendEquationArguments::Blending *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QBlendEquationArguments_Blending_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_Blending_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QBlendEquationArguments_Blending;
    return {};
}

static PyObject *Qt3DRender_QBlendEquationArguments_Blending_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QBlendEquationArguments::Blending>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QBlendEquationArguments::Blending *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_Blending_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBlendEquationArguments_PythonToCpp_QBlendEquationArguments_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QBlendEquationArguments_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBlendEquationArguments_PythonToCpp_QBlendEquationArguments_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QBlendEquationArguments_TypeF()))
        return QBlendEquationArguments_PythonToCpp_QBlendEquationArguments_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBlendEquationArguments_PTR_CppToPython_QBlendEquationArguments(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DRender::QBlendEquationArguments *>(const_cast<void *>(cppIn)), Sbk_Qt3DRender_QBlendEquationArguments_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QBlendEquationArguments_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,sourceRgb:Qt3DRender.QBlendEquationArguments.Blending=None,sourceAlpha:Qt3DRender.QBlendEquationArguments.Blending=None,destinationRgb:Qt3DRender.QBlendEquationArguments.Blending=None,destinationAlpha:Qt3DRender.QBlendEquationArguments.Blending=None,bufferIndex:int=None)",
    "PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.bufferIndex(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.destinationAlpha(self)->PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending",
    "PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.destinationRgb(self)->PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending",
    "PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.setBufferIndex(self,index:int)",
    "PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.setDestinationAlpha(self,destinationAlpha:PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending)",
    "PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.setDestinationRgb(self,destinationRgb:PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending)",
    "PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.setDestinationRgba(self,destinationRgba:PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending)",
    "PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.setSourceAlpha(self,sourceAlpha:PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending)",
    "PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.setSourceRgb(self,sourceRgb:PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending)",
    "PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.setSourceRgba(self,sourceRgba:PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending)",
    "PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.sourceAlpha(self)->PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending",
    "PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.sourceRgb(self)->PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QBlendEquationArguments_SignatureByteSize = 266;
static constexpr uint8_t Qt3DRender_QBlendEquationArguments_SignatureBytes[266] = {
    0x78, 0xda, 0xcd, 0x94, 0xdb, 0x6a, 0x02, 0x31, 0x10, 0x86, 0xef, 0x7d, 0x92, 0x6e, 0x59, 0xf7,
    0xa6, 0xe0, 0xc5, 0x82, 0x05, 0x0f, 0xbd, 0x10, 0x41, 0x57, 0x7d, 0x82, 0x68, 0x66, 0xb7, 0x81,
    0x38, 0xd9, 0xe6, 0x80, 0xee, 0xdb, 0x37, 0x6c, 0x59, 0x8d, 0x51, 0x28, 0xcd, 0x0a, 0xe9, 0xdd,
    0x24, 0x64, 0xfe, 0x7c, 0x33, 0x7f, 0x32, 0x45, 0xb3, 0x63, 0x14, 0x46, 0xd9, 0x46, 0xbf, 0xcd,
    0xb7, 0x80, 0x14, 0xe4, 0x4d, 0x38, 0xe5, 0x36, 0xf8, 0xf8, 0x32, 0x44, 0x33, 0x81, 0x13, 0x59,
    0x99, 0x23, 0xa0, 0x56, 0x2f, 0x0a, 0x78, 0x99, 0xd6, 0x44, 0xda, 0x45, 0x5e, 0x38, 0x0a, 0x33,
    0x21, 0xc1, 0x09, 0x56, 0x82, 0xc2, 0x18, 0x0d, 0xe7, 0xb5, 0x96, 0xe9, 0x6b, 0xbe, 0x84, 0xe6,
    0x24, 0x24, 0x5d, 0x23, 0x6f, 0xc6, 0x2b, 0x81, 0x90, 0x2a, 0x61, 0xe4, 0x01, 0xb6, 0xd5, 0x3e,
    0xff, 0xfd, 0xce, 0xac, 0xdd, 0x66, 0x58, 0xb9, 0xa9, 0x13, 0x5e, 0x7f, 0x92, 0xbf, 0x27, 0x53,
    0x50, 0x9a, 0x61, 0x7b, 0x24, 0xe8, 0x72, 0x27, 0x3f, 0x90, 0x60, 0x6f, 0xca, 0x12, 0xe4, 0xc2,
    0x66, 0x9c, 0x73, 0x86, 0xba, 0xdd, 0x4c, 0x06, 0x45, 0x88, 0x19, 0x99, 0xa3, 0xd5, 0x1a, 0x93,
    0x0c, 0xdf, 0xad, 0x64, 0xa0, 0x98, 0x5f, 0x5a, 0xa7, 0x18, 0xa6, 0xd6, 0x15, 0xdd, 0x1f, 0xc6,
    0xfa, 0x14, 0x15, 0x45, 0x81, 0x9e, 0x7a, 0x7d, 0x4e, 0x59, 0x67, 0x5f, 0x12, 0x2e, 0x3a, 0x7f,
    0xd4, 0xef, 0xfb, 0x07, 0xd6, 0xaf, 0xe6, 0xe7, 0xf0, 0x75, 0x16, 0xf8, 0xdf, 0xe7, 0x9f, 0xb0,
    0x91, 0x47, 0x70, 0x11, 0x3b, 0xb7, 0xbb, 0x4e, 0xa8, 0x1f, 0x32, 0x77, 0x64, 0x45, 0xa6, 0xba,
    0x58, 0x79, 0x9d, 0xc0, 0xf1, 0x89, 0x88, 0x87, 0x14, 0xad, 0x4b, 0x9e, 0x71, 0xd1, 0x46, 0xce,
    0x8d, 0x55, 0xfd, 0x29, 0xbe, 0x01, 0x4d, 0xc1, 0xe7, 0x98
};
#endif

PyTypeObject *init_Qt3DRender_QBlendEquationArguments(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QBlendEquationArguments_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderState_IDX]))));

    _Sbk_Qt3DRender_QBlendEquationArguments_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QBlendEquationArguments",
        "Qt3DRender::QBlendEquationArguments*",
        &Sbk_Qt3DRender_QBlendEquationArguments_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QBlendEquationArguments >,
        Sbk_Qt3DRender_QBlendEquationArguments_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QBlendEquationArguments_TypeF(); // references _Sbk_Qt3DRender_QBlendEquationArguments_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QBlendEquationArguments_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QBlendEquationArguments_SignatureBytes, Qt3DRender_QBlendEquationArguments_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QBlendEquationArguments_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBlendEquationArguments_PythonToCpp_QBlendEquationArguments_PTR,
        is_QBlendEquationArguments_PythonToCpp_QBlendEquationArguments_PTR_Convertible,
        QBlendEquationArguments_PTR_CppToPython_QBlendEquationArguments);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QBlendEquationArguments");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QBlendEquationArguments*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QBlendEquationArguments&");
    Shiboken::Conversions::registerConverterAlias(converter, "QBlendEquationArguments");
    Shiboken::Conversions::registerConverterAlias(converter, "QBlendEquationArguments*");
    Shiboken::Conversions::registerConverterAlias(converter, "QBlendEquationArguments&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QBlendEquationArguments).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QBlendEquationArgumentsWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QBlendEquationArguments_TypeF(), &Sbk_Qt3DRender_QBlendEquationArguments_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DRender_QBlendEquationArguments_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Blending'.
    const char *Blending_Initializer[] = {
        "Zero",
        "One",
        "SourceColor",
        "SourceAlpha",
        "Source1Alpha",
        "Source1Color",
        "DestinationColor",
        "DestinationAlpha",
        "SourceAlphaSaturate",
        "ConstantColor",
        "ConstantAlpha",
        "OneMinusSourceColor",
        "OneMinusSourceAlpha",
        "OneMinusDestinationAlpha",
        "OneMinusDestinationColor",
        "OneMinusConstantColor",
        "OneMinusConstantAlpha",
        "OneMinusSource1Alpha",
        "OneMinusSource1Color",
        "OneMinusSource1Color0",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Blending_InitializerValues[] = {
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::Zero),                     //  0x0000  0
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::One),                      //  0x0001  1
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::SourceColor),              //  0x0300  768
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::SourceAlpha),              //  0x0302  770
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::Source1Alpha),             //  0x0303  771
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::Source1Color),             //  0x0304  772
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::DestinationColor),         //  0x0306  774
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::DestinationAlpha),         //  0x0304  772
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::SourceAlphaSaturate),      //  0x0308  776
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::ConstantColor),            //  0x8001  32769
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::ConstantAlpha),            //  0x8003  32771
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::OneMinusSourceColor),      //  0x0301  769
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::OneMinusSourceAlpha),      //  0x0303  771
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::OneMinusDestinationAlpha), //  0x0305  773
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::OneMinusDestinationColor), //  0x0307  775
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::OneMinusConstantColor),    //  0x8002  32770
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::OneMinusConstantAlpha),    //  0x8004  32772
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::OneMinusSource1Alpha),     //  0x8005  32773
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::OneMinusSource1Color),     //  0x8006  32774
        uint16_t(Qt3DRender::QBlendEquationArguments::Blending::OneMinusSource1Color0)     //  0x8006  32774
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QBlendEquationArguments_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending",
        Blending_Initializer, Blending_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QBlendEquationArguments_Blending_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QBlendEquationArguments::Blending'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QBlendEquationArguments_Blending_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QBlendEquationArguments_Blending,
            is_Enum_PythonToCpp_Qt3DRender_QBlendEquationArguments_Blending_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QBlendEquationArguments::Blending");
        Shiboken::Conversions::registerConverterAlias(converter, "QBlendEquationArguments::Blending");
        Shiboken::Conversions::registerConverterAlias(converter, "Blending");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Blending' enum.

    PySide::Signal::registerSignals(pyType, &::Qt3DRender::QBlendEquationArguments::staticMetaObject);
    qRegisterMetaType< ::Qt3DRender::QBlendEquationArguments::Blending >("QBlendEquationArguments::Blending");
    qRegisterMetaType< ::Qt3DRender::QBlendEquationArguments::Blending >("Qt3DRender::QBlendEquationArguments::Blending");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DRender::QBlendEquationArguments::staticMetaObject, sizeof(QBlendEquationArgumentsWrapper));

    return pyType;
}
