// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qcamera_wrapper.h"

// Argument includes
#include <QList>
#include <Qt3DCore/qcomponent.h>
#include <Qt3DCore/qentity.h>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qtransform.h>
#include <Qt3DRender/qcamera.h>
#include <Qt3DRender/qcameralens.h>
#include <QtGui/qmatrix4x4.h>
#include <QtGui/qquaternion.h>
#include <QtGui/qvectornd.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QCameraWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QCameraWrapper::QCameraWrapper(::Qt3DCore::QNode * parent) : Qt3DRender::QCamera(parent)
{
}

void QCameraWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCamera", funcName);
        return;
    }
}

void QCameraWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCamera", funcName);
        return;
    }
}

void QCameraWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCamera", funcName);
        return;
    }
}

void QCameraWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCamera", funcName);
        return;
    }
}

bool QCameraWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCamera", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCamera", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QCameraWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCamera", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCamera", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCameraWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCamera", funcName);
        return;
    }
}

const QMetaObject *QCameraWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DRender::QCamera::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QCameraWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DRender::QCamera::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QCameraWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QCameraWrapper *>(this));
    return Qt3DRender::QCamera::qt_metacast(_clname);
}

QCameraWrapper::~QCameraWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DRender_QCamera_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DRender::QCamera >()))
        return -1;

    QCameraWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QCamera", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCamera::QCamera(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QCamera(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QCamera(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QCamera(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QCameraWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QCameraWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DRender::QCamera >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_aspectRatio(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // aspectRatio()const
        float cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->aspectRatio();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_bottom(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bottom()const
        float cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->bottom();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_exposure(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // exposure()const
        float cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->exposure();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_farPlane(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // farPlane()const
        float cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->farPlane();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_fieldOfView(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fieldOfView()const
        float cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->fieldOfView();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_left(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // left()const
        float cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->left();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_lens(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lens()const
        Qt3DRender::QCameraLens * cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->lens();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCameraLens_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_nearPlane(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nearPlane()const
        float cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->nearPlane();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_pan(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "pan", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCamera::pan(float)
    // 1: QCamera::pan(float,QVector3D)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // pan(float)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))) {
            overloadId = 1; // pan(float,QVector3D)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "pan", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // pan(float angle)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // pan(float)
                cppSelf->pan(cppArg0);
            }
            break;
        }
        case 1: // pan(float angle, const QVector3D &axis)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector3D cppArg1_local;
            ::QVector3D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // pan(float,QVector3D)
                cppSelf->pan(cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_panAboutViewCenter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "panAboutViewCenter", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCamera::panAboutViewCenter(float)
    // 1: QCamera::panAboutViewCenter(float,QVector3D)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // panAboutViewCenter(float)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))) {
            overloadId = 1; // panAboutViewCenter(float,QVector3D)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "panAboutViewCenter", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // panAboutViewCenter(float angle)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // panAboutViewCenter(float)
                cppSelf->panAboutViewCenter(cppArg0);
            }
            break;
        }
        case 1: // panAboutViewCenter(float angle, const QVector3D &axis)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector3D cppArg1_local;
            ::QVector3D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // panAboutViewCenter(float,QVector3D)
                cppSelf->panAboutViewCenter(cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_panRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::panRotation(float)const->QQuaternion
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // panRotation(float)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "panRotation", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // panRotation(float)const
            QQuaternion cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->panRotation(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // position()const
        QVector3D cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->position();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_projectionMatrix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // projectionMatrix()const
        QMatrix4x4 cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->projectionMatrix();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_projectionType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // projectionType()const
        Qt3DRender::QCameraLens::ProjectionType cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->projectionType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCameraLens_ProjectionType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_right(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // right()const
        float cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->right();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_roll(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::roll(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // roll(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "roll", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // roll(float)
            cppSelf->roll(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_rollAboutViewCenter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::rollAboutViewCenter(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // rollAboutViewCenter(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rollAboutViewCenter", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rollAboutViewCenter(float)
            cppSelf->rollAboutViewCenter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_rollRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::rollRotation(float)const->QQuaternion
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // rollRotation(float)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rollRotation", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rollRotation(float)const
            QQuaternion cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->rollRotation(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_rotate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::rotate(QQuaternion)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArg)))) {
        overloadId = 0; // rotate(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rotate", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuaternion cppArg0_local;
        ::QQuaternion *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // rotate(QQuaternion)
            cppSelf->rotate(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_rotateAboutViewCenter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::rotateAboutViewCenter(QQuaternion)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArg)))) {
        overloadId = 0; // rotateAboutViewCenter(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rotateAboutViewCenter", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuaternion cppArg0_local;
        ::QQuaternion *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // rotateAboutViewCenter(QQuaternion)
            cppSelf->rotateAboutViewCenter(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_rotation(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "rotation", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCamera::rotation(float,QVector3D)const->QQuaternion
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))) {
        overloadId = 0; // rotation(float,QVector3D)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rotation", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QVector3D cppArg1_local;
        ::QVector3D *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // rotation(float,QVector3D)const
            QQuaternion cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->rotation(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_setAspectRatio(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setAspectRatio(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setAspectRatio(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAspectRatio", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAspectRatio(float)
            cppSelf->setAspectRatio(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_setBottom(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setBottom(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setBottom(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBottom", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBottom(float)
            cppSelf->setBottom(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_setExposure(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setExposure(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setExposure(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExposure", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExposure(float)
            cppSelf->setExposure(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_setFarPlane(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setFarPlane(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setFarPlane(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFarPlane", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFarPlane(float)
            cppSelf->setFarPlane(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_setFieldOfView(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setFieldOfView(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setFieldOfView(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFieldOfView", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFieldOfView(float)
            cppSelf->setFieldOfView(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_setLeft(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setLeft(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setLeft(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLeft", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLeft(float)
            cppSelf->setLeft(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_setNearPlane(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setNearPlane(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setNearPlane(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNearPlane", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNearPlane(float)
            cppSelf->setNearPlane(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_setPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setPosition(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setPosition(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPosition", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPosition(QVector3D)
            cppSelf->setPosition(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_setProjectionMatrix(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setProjectionMatrix(QMatrix4x4)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArg)))) {
        overloadId = 0; // setProjectionMatrix(QMatrix4x4)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProjectionMatrix", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMatrix4x4 cppArg0_local;
        ::QMatrix4x4 *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setProjectionMatrix(QMatrix4x4)
            cppSelf->setProjectionMatrix(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_setProjectionType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setProjectionType(Qt3DRender::QCameraLens::ProjectionType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCameraLens_ProjectionType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setProjectionType(Qt3DRender::QCameraLens::ProjectionType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProjectionType", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QCameraLens::ProjectionType cppArg0{Qt3DRender::QCameraLens::OrthographicProjection};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProjectionType(Qt3DRender::QCameraLens::ProjectionType)
            cppSelf->setProjectionType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_setRight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setRight(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setRight(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRight", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRight(float)
            cppSelf->setRight(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_setTop(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setTop(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setTop(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTop", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTop(float)
            cppSelf->setTop(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_setUpVector(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setUpVector(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setUpVector(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUpVector", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUpVector(QVector3D)
            cppSelf->setUpVector(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_setViewCenter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setViewCenter(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setViewCenter(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setViewCenter", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setViewCenter(QVector3D)
            cppSelf->setViewCenter(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_tilt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::tilt(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // tilt(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "tilt", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // tilt(float)
            cppSelf->tilt(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_tiltAboutViewCenter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::tiltAboutViewCenter(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // tiltAboutViewCenter(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "tiltAboutViewCenter", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // tiltAboutViewCenter(float)
            cppSelf->tiltAboutViewCenter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_tiltRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::tiltRotation(float)const->QQuaternion
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // tiltRotation(float)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "tiltRotation", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // tiltRotation(float)const
            QQuaternion cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->tiltRotation(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_top(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // top()const
        float cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->top();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_transform(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // transform()const
        Qt3DCore::QTransform * cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->transform();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QTransform_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_translate(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "translate", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    if (PyArg_ParseTuple(args, "|OO:translate", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCamera::translate(QVector3D,Qt3DRender::QCamera::CameraTranslationOption=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // translate(QVector3D,Qt3DRender::QCamera::CameraTranslationOption)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_CameraTranslationOption_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // translate(QVector3D,Qt3DRender::QCamera::CameraTranslationOption)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "translate", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_option = Shiboken::String::createStaticString("option");
            if (PyDict_Contains(kwds, key_option) != 0) {
                value = PyDict_GetItem(kwds, key_option);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_option);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "translate", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_CameraTranslationOption_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "translate", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_option);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "translate", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::Qt3DRender::QCamera::CameraTranslationOption cppArg1(Qt3DRender::QCamera::CameraTranslationOption::TranslateViewCenter);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // translate(QVector3D,Qt3DRender::QCamera::CameraTranslationOption)
            cppSelf->translate(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_translateWorld(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "translateWorld", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    if (PyArg_ParseTuple(args, "|OO:translateWorld", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCamera::translateWorld(QVector3D,Qt3DRender::QCamera::CameraTranslationOption=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // translateWorld(QVector3D,Qt3DRender::QCamera::CameraTranslationOption)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_CameraTranslationOption_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // translateWorld(QVector3D,Qt3DRender::QCamera::CameraTranslationOption)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "translateWorld", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_option = Shiboken::String::createStaticString("option");
            if (PyDict_Contains(kwds, key_option) != 0) {
                value = PyDict_GetItem(kwds, key_option);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_option);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "translateWorld", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_CameraTranslationOption_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "translateWorld", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_option);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "translateWorld", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::Qt3DRender::QCamera::CameraTranslationOption cppArg1(Qt3DRender::QCamera::CameraTranslationOption::TranslateViewCenter);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // translateWorld(QVector3D,Qt3DRender::QCamera::CameraTranslationOption)
            cppSelf->translateWorld(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_upVector(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // upVector()const
        QVector3D cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->upVector();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_viewAll(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewAll()
        cppSelf->viewAll();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_viewCenter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewCenter()const
        QVector3D cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->viewCenter();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_viewEntity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::viewEntity(Qt3DCore::QEntity*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QEntity_IDX]), (pyArg)))) {
        overloadId = 0; // viewEntity(Qt3DCore::QEntity*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "viewEntity", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DCore::QEntity *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // viewEntity(Qt3DCore::QEntity*)
            cppSelf->viewEntity(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_viewMatrix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewMatrix()const
        QMatrix4x4 cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->viewMatrix();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_viewSphere(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "viewSphere", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCamera::viewSphere(QVector3D,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // viewSphere(QVector3D,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "viewSphere", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // viewSphere(QVector3D,float)
            cppSelf->viewSphere(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QCameraFunc_viewVector(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewVector()const
        QVector3D cppResult = const_cast<const ::Qt3DRender::QCamera *>(cppSelf)->viewVector();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DRender_QCamera_PropertyStrings[] = {
    "aspectRatio::",
    "bottom::",
    "exposure::",
    "farPlane::",
    "fieldOfView::",
    "left::",
    "lens:",
    "nearPlane::",
    "position::",
    "projectionMatrix::",
    "projectionType::",
    "right::",
    "top::",
    "transform:",
    "upVector::",
    "viewCenter::",
    "viewMatrix:",
    "viewVector:",
    nullptr // Sentinel
};

static const char *Sbk_Qt3DRender_QCamera_EnumFlagInfo[] = {
    "CameraTranslationOption:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QCamera_methods[] = {
    {"aspectRatio", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_aspectRatio), METH_NOARGS, nullptr},
    {"bottom", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_bottom), METH_NOARGS, nullptr},
    {"exposure", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_exposure), METH_NOARGS, nullptr},
    {"farPlane", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_farPlane), METH_NOARGS, nullptr},
    {"fieldOfView", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_fieldOfView), METH_NOARGS, nullptr},
    {"left", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_left), METH_NOARGS, nullptr},
    {"lens", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_lens), METH_NOARGS, nullptr},
    {"nearPlane", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_nearPlane), METH_NOARGS, nullptr},
    {"pan", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_pan), METH_VARARGS, nullptr},
    {"panAboutViewCenter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_panAboutViewCenter), METH_VARARGS, nullptr},
    {"panRotation", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_panRotation), METH_O, nullptr},
    {"position", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_position), METH_NOARGS, nullptr},
    {"projectionMatrix", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_projectionMatrix), METH_NOARGS, nullptr},
    {"projectionType", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_projectionType), METH_NOARGS, nullptr},
    {"right", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_right), METH_NOARGS, nullptr},
    {"roll", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_roll), METH_O, nullptr},
    {"rollAboutViewCenter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_rollAboutViewCenter), METH_O, nullptr},
    {"rollRotation", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_rollRotation), METH_O, nullptr},
    {"rotate", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_rotate), METH_O, nullptr},
    {"rotateAboutViewCenter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_rotateAboutViewCenter), METH_O, nullptr},
    {"rotation", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_rotation), METH_VARARGS, nullptr},
    {"setAspectRatio", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_setAspectRatio), METH_O, nullptr},
    {"setBottom", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_setBottom), METH_O, nullptr},
    {"setExposure", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_setExposure), METH_O, nullptr},
    {"setFarPlane", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_setFarPlane), METH_O, nullptr},
    {"setFieldOfView", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_setFieldOfView), METH_O, nullptr},
    {"setLeft", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_setLeft), METH_O, nullptr},
    {"setNearPlane", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_setNearPlane), METH_O, nullptr},
    {"setPosition", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_setPosition), METH_O, nullptr},
    {"setProjectionMatrix", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_setProjectionMatrix), METH_O, nullptr},
    {"setProjectionType", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_setProjectionType), METH_O, nullptr},
    {"setRight", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_setRight), METH_O, nullptr},
    {"setTop", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_setTop), METH_O, nullptr},
    {"setUpVector", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_setUpVector), METH_O, nullptr},
    {"setViewCenter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_setViewCenter), METH_O, nullptr},
    {"tilt", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_tilt), METH_O, nullptr},
    {"tiltAboutViewCenter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_tiltAboutViewCenter), METH_O, nullptr},
    {"tiltRotation", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_tiltRotation), METH_O, nullptr},
    {"top", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_top), METH_NOARGS, nullptr},
    {"transform", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_transform), METH_NOARGS, nullptr},
    {"translate", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_translate), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"translateWorld", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_translateWorld), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"upVector", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_upVector), METH_NOARGS, nullptr},
    {"viewAll", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_viewAll), METH_NOARGS, nullptr},
    {"viewCenter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_viewCenter), METH_NOARGS, nullptr},
    {"viewEntity", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_viewEntity), METH_O, nullptr},
    {"viewMatrix", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_viewMatrix), METH_NOARGS, nullptr},
    {"viewSphere", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_viewSphere), METH_VARARGS, nullptr},
    {"viewVector", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QCameraFunc_viewVector), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QCamera_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QCameraWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DRender_QCamera_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QCamera_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QCamera_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QCamera_TypeF(void)
{
    return _Sbk_Qt3DRender_QCamera_Type;
}

static PyType_Slot Sbk_Qt3DRender_QCamera_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QCamera_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QCamera_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QCamera_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QCamera_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QCamera_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QCamera_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QCamera",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QCamera_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QCamera_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DRender::QCamera *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Qt3DRender_QCamera_CameraTranslationOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QCamera::CameraTranslationOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QCamera::CameraTranslationOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QCamera_CameraTranslationOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_CameraTranslationOption_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QCamera_CameraTranslationOption;
    return {};
}

static PyObject *Qt3DRender_QCamera_CameraTranslationOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QCamera::CameraTranslationOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QCamera::CameraTranslationOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_CameraTranslationOption_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCamera_PythonToCpp_QCamera_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QCamera_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCamera_PythonToCpp_QCamera_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QCamera_TypeF()))
        return QCamera_PythonToCpp_QCamera_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCamera_PTR_CppToPython_QCamera(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DRender::QCamera *>(const_cast<void *>(cppIn)), Sbk_Qt3DRender_QCamera_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QCamera_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QCamera(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,projectionType:Qt3DRender.QCameraLens.ProjectionType=None,nearPlane:float=None,farPlane:float=None,fieldOfView:float=None,aspectRatio:float=None,left:float=None,right:float=None,bottom:float=None,top:float=None,projectionMatrix:QMatrix4x4=None,exposure:float=None,position:QVector3D=None,upVector:QVector3D=None,viewCenter:QVector3D=None,viewVector:QVector3D=None,viewMatrix:QMatrix4x4=None,lens:Qt3DRender.QCameraLens=None,transform:Qt3DCore.QTransform=None)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.aspectRatio(self)->float",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.bottom(self)->float",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.exposure(self)->float",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.farPlane(self)->float",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.fieldOfView(self)->float",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.left(self)->float",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.lens(self)->PySide6.Qt3DRender.Qt3DRender.QCameraLens",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.nearPlane(self)->float",
    "1:PySide6.Qt3DRender.Qt3DRender.QCamera.pan(self,angle:float)",
    "0:PySide6.Qt3DRender.Qt3DRender.QCamera.pan(self,angle:float,axis:PySide6.QtGui.QVector3D)",
    "1:PySide6.Qt3DRender.Qt3DRender.QCamera.panAboutViewCenter(self,angle:float)",
    "0:PySide6.Qt3DRender.Qt3DRender.QCamera.panAboutViewCenter(self,angle:float,axis:PySide6.QtGui.QVector3D)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.panRotation(self,angle:float)->PySide6.QtGui.QQuaternion",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.position(self)->PySide6.QtGui.QVector3D",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.projectionMatrix(self)->PySide6.QtGui.QMatrix4x4",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.projectionType(self)->PySide6.Qt3DRender.Qt3DRender.QCameraLens.ProjectionType",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.right(self)->float",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.roll(self,angle:float)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.rollAboutViewCenter(self,angle:float)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.rollRotation(self,angle:float)->PySide6.QtGui.QQuaternion",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.rotate(self,q:PySide6.QtGui.QQuaternion)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.rotateAboutViewCenter(self,q:PySide6.QtGui.QQuaternion)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.rotation(self,angle:float,axis:PySide6.QtGui.QVector3D)->PySide6.QtGui.QQuaternion",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.setAspectRatio(self,aspectRatio:float)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.setBottom(self,bottom:float)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.setExposure(self,exposure:float)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.setFarPlane(self,farPlane:float)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.setFieldOfView(self,fieldOfView:float)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.setLeft(self,left:float)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.setNearPlane(self,nearPlane:float)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.setPosition(self,position:PySide6.QtGui.QVector3D)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.setProjectionMatrix(self,projectionMatrix:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.setProjectionType(self,type:PySide6.Qt3DRender.Qt3DRender.QCameraLens.ProjectionType)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.setRight(self,right:float)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.setTop(self,top:float)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.setUpVector(self,upVector:PySide6.QtGui.QVector3D)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.setViewCenter(self,viewCenter:PySide6.QtGui.QVector3D)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.tilt(self,angle:float)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.tiltAboutViewCenter(self,angle:float)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.tiltRotation(self,angle:float)->PySide6.QtGui.QQuaternion",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.top(self)->float",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.transform(self)->PySide6.Qt3DCore.Qt3DCore.QTransform",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.translate(self,vLocal:PySide6.QtGui.QVector3D,option:PySide6.Qt3DRender.Qt3DRender.QCamera.CameraTranslationOption=Qt3DRender.QCamera.CameraTranslationOption.TranslateViewCenter)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.translateWorld(self,vWorld:PySide6.QtGui.QVector3D,option:PySide6.Qt3DRender.Qt3DRender.QCamera.CameraTranslationOption=Qt3DRender.QCamera.CameraTranslationOption.TranslateViewCenter)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.upVector(self)->PySide6.QtGui.QVector3D",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.viewAll(self)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.viewCenter(self)->PySide6.QtGui.QVector3D",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.viewEntity(self,entity:PySide6.Qt3DCore.Qt3DCore.QEntity)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.viewMatrix(self)->PySide6.QtGui.QMatrix4x4",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.viewSphere(self,center:PySide6.QtGui.QVector3D,radius:float)",
    "PySide6.Qt3DRender.Qt3DRender.QCamera.viewVector(self)->PySide6.QtGui.QVector3D",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QCamera_SignatureByteSize = 741;
static constexpr uint8_t Qt3DRender_QCamera_SignatureBytes[741] = {
    0x78, 0xda, 0xdd, 0x58, 0xcb, 0x72, 0x9b, 0x30, 0x14, 0xdd, 0xe7, 0x2b, 0xba, 0x2c, 0x1d, 0xca,
    0xb4, 0x93, 0x4c, 0x17, 0xcc, 0xb8, 0x33, 0xae, 0x93, 0x76, 0x51, 0xd7, 0xc6, 0x8e, 0xe3, 0x2e,
    0x3a, 0x5d, 0x28, 0x46, 0x38, 0xea, 0xc8, 0x92, 0x2a, 0x44, 0x62, 0xff, 0x7d, 0x11, 0xe2, 0x21,
    0x30, 0xd8, 0x12, 0x38, 0x9b, 0xae, 0x0c, 0xd7, 0x3a, 0x87, 0xab, 0xab, 0xfb, 0x38, 0x10, 0x1c,
    0xee, 0x51, 0x08, 0x3f, 0x79, 0x0b, 0x71, 0x7d, 0xbb, 0x84, 0x24, 0x84, 0xbc, 0x76, 0x39, 0x01,
    0x3b, 0xc8, 0xc1, 0xdb, 0x18, 0xe2, 0xc8, 0x65, 0x80, 0x43, 0x22, 0xfc, 0x40, 0x43, 0x4c, 0x28,
    0x87, 0xda, 0xc5, 0x8c, 0x86, 0x70, 0x44, 0x12, 0x8c, 0x99, 0xe0, 0xee, 0x3b, 0xff, 0x3b, 0x3c,
    0xbc, 0x50, 0x1e, 0xce, 0x09, 0x3e, 0x8c, 0x66, 0x94, 0x40, 0x97, 0x71, 0xfa, 0x07, 0x6e, 0x04,
    0xa2, 0x64, 0x75, 0x60, 0xd0, 0x3f, 0x7e, 0xd0, 0x14, 0x92, 0xd8, 0x0b, 0x6a, 0xab, 0x14, 0x92,
    0x40, 0xc0, 0x03, 0x0c, 0x08, 0xf4, 0x23, 0x4c, 0x81, 0x50, 0xc6, 0xa8, 0xcd, 0x86, 0x20, 0x0e,
    0xe7, 0xd1, 0x1a, 0xc1, 0x17, 0xdd, 0x0c, 0x62, 0x96, 0x52, 0x2e, 0x41, 0xca, 0xaa, 0x9b, 0x31,
    0x8c, 0x84, 0x7e, 0xcf, 0xd1, 0xf6, 0xa9, 0x66, 0x78, 0xa4, 0x42, 0xd0, 0x9d, 0x6e, 0x11, 0x94,
    0xe9, 0xb7, 0xd5, 0x96, 0x7e, 0x00, 0xc1, 0xd1, 0xde, 0x5f, 0xa8, 0xdf, 0x9b, 0xfd, 0x8d, 0x5a,
    0x00, 0xf7, 0x8c, 0xc6, 0x09, 0xaf, 0x39, 0x99, 0x5a, 0x90, 0x84, 0xf8, 0x8b, 0x75, 0x8a, 0xa5,
    0xfc, 0xfa, 0x56, 0xd9, 0x13, 0xa6, 0xee, 0x9b, 0xf6, 0xe7, 0x74, 0x37, 0x93, 0x34, 0xf6, 0xb0,
    0xf5, 0x9f, 0x6e, 0x4c, 0x87, 0x4b, 0x38, 0x8d, 0x72, 0x47, 0xf0, 0xf3, 0x3d, 0x72, 0x40, 0xe2,
    0x88, 0xf2, 0x9d, 0x5f, 0x9d, 0xed, 0xaa, 0xb0, 0x65, 0x4b, 0x9c, 0xab, 0xc0, 0x24, 0x71, 0x3c,
    0x2d, 0xee, 0x59, 0x12, 0x39, 0xef, 0x3f, 0x67, 0x71, 0x30, 0x84, 0xab, 0xf0, 0xf7, 0x41, 0x16,
    0x61, 0xef, 0x83, 0x2d, 0xf2, 0xaa, 0x17, 0xb6, 0xca, 0xbf, 0x3e, 0x70, 0x99, 0x90, 0xfd, 0x70,
    0x24, 0x2e, 0x70, 0x46, 0x08, 0x79, 0xd8, 0x86, 0xdc, 0x65, 0xed, 0xd5, 0x1d, 0xfb, 0xe8, 0x9b,
    0xc1, 0x19, 0x20, 0xaa, 0x7f, 0x00, 0xb2, 0xc5, 0x79, 0x19, 0x38, 0x57, 0x1f, 0x06, 0xa0, 0x5d,
    0xb0, 0x47, 0xb1, 0x86, 0xff, 0x96, 0x20, 0xaf, 0xcc, 0x7e, 0xc7, 0xc6, 0xb1, 0xf1, 0x23, 0x4d,
    0xc4, 0xba, 0xac, 0xae, 0x61, 0x7e, 0x9e, 0x23, 0x3b, 0xe3, 0xb6, 0xf1, 0x73, 0x96, 0x54, 0xc8,
    0x7a, 0x6a, 0x89, 0xaa, 0x7e, 0xf6, 0x19, 0xfb, 0x22, 0x01, 0xa9, 0x27, 0x24, 0x5d, 0x6c, 0x4a,
    0x9f, 0x77, 0xa6, 0xe3, 0x5c, 0xaa, 0x79, 0x6b, 0xca, 0xd6, 0x68, 0x8e, 0x1d, 0xac, 0x65, 0x7b,
    0xb2, 0xa6, 0x95, 0x03, 0xc2, 0x3a, 0xed, 0x1b, 0x03, 0xc6, 0xf0, 0xa1, 0xd9, 0x68, 0xe8, 0x53,
    0x9a, 0x9c, 0x62, 0xdc, 0x92, 0x58, 0xe6, 0xe0, 0xf3, 0x49, 0x6a, 0xce, 0xf5, 0x9a, 0xb9, 0xc3,
    0x25, 0xb7, 0x3a, 0x0e, 0xf7, 0xaf, 0xdf, 0xc9, 0xe6, 0x58, 0xd1, 0xb5, 0x6e, 0xfe, 0x52, 0xec,
    0x6d, 0x81, 0x38, 0x5d, 0xa5, 0xc3, 0xa3, 0x14, 0x43, 0x31, 0x6e, 0x0c, 0xc5, 0x63, 0x75, 0xe2,
    0x98, 0x93, 0x7d, 0xa9, 0x46, 0x64, 0x4d, 0xad, 0x58, 0x50, 0xdc, 0xe9, 0xb3, 0xb2, 0x21, 0x58,
    0x2c, 0x68, 0xbe, 0xea, 0x63, 0xa2, 0x21, 0xce, 0x6c, 0x68, 0x1a, 0x13, 0xf4, 0x58, 0xd2, 0x59,
    0x90, 0x4d, 0x8b, 0x79, 0xaa, 0x49, 0x3d, 0x0b, 0xf8, 0xac, 0x36, 0xfa, 0x9a, 0x2a, 0xd4, 0x82,
    0x28, 0xd0, 0xfb, 0x6a, 0xa5, 0xff, 0x06, 0x0e, 0x03, 0x49, 0xdc, 0xd6, 0x62, 0x8f, 0x55, 0xa9,
    0x38, 0x30, 0x44, 0xb6, 0xde, 0x83, 0x4c, 0xd4, 0x5f, 0x5d, 0xed, 0xd7, 0x7d, 0xd3, 0xf8, 0xa7,
    0xd4, 0x7c, 0xbf, 0x7b, 0x79, 0x54, 0x76, 0x67, 0x57, 0x48, 0xb9, 0xdf, 0xb7, 0x41, 0x5b, 0x3c,
    0x7b, 0x59, 0x36, 0x69, 0x5d, 0xca, 0x5b, 0x10, 0xac, 0x28, 0xcb, 0x3d, 0x2e, 0x64, 0xbe, 0x05,
    0xf8, 0x21, 0x97, 0xef, 0x8a, 0xa1, 0x14, 0xf3, 0xc3, 0x0f, 0xb9, 0xd9, 0xff, 0xb4, 0xf7, 0x81,
    0x81, 0xe4, 0x02, 0x61, 0xd1, 0x7b, 0xa0, 0x48, 0xf0, 0xa5, 0x86, 0x93, 0xe4, 0x7a, 0xcd, 0xe1,
    0x24, 0xf2, 0x83, 0xb5, 0x1c, 0xde, 0xe5, 0x9b, 0x50, 0x9b, 0xca, 0x68, 0xbc, 0xfd, 0x96, 0xd5,
    0x62, 0xc3, 0x8d, 0xcb, 0x91, 0xf9, 0x3c, 0xa5, 0x1b, 0x80, 0xbb, 0x0e, 0xd4, 0xa5, 0xac, 0xd1,
    0x31, 0x4e, 0x51, 0xab, 0x9f, 0x55, 0xfe, 0x80, 0x14, 0x37, 0xcf, 0xd0, 0x23, 0xf3, 0xa5, 0x5e,
    0x61, 0x81, 0xd5, 0xe1, 0x3a, 0xb6, 0x1b, 0xfb, 0x49, 0x39, 0x0e, 0xf3, 0xdd, 0x65, 0xd7, 0xff,
    0xc3, 0xee, 0x12, 0xbd, 0xca, 0x07, 0x4b, 0x64, 0x59, 0xca, 0xe3, 0x5c, 0x20, 0x3a, 0x16, 0x18,
    0xad, 0xdc, 0x2e, 0xe2, 0xc3, 0x1d, 0x11, 0x48, 0x1c, 0x72, 0x05, 0x90, 0x5d, 0x9f, 0xfa, 0xd0,
    0xa3, 0x56, 0xdb, 0xf8, 0x7b, 0xd1, 0x17, 0x00, 0x49, 0x78, 0xcf, 0x9e, 0x60, 0x21, 0x59, 0x36,
    0x27, 0x7b, 0xa1, 0xcb, 0x41, 0x88, 0x92, 0xd8, 0xae, 0x1f, 0x55, 0x1f, 0x56, 0xce, 0xc5, 0xf8,
    0x1f, 0x01, 0xb3, 0xd8, 0x2d
};
#endif

PyTypeObject *init_Qt3DRender_QCamera(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QCamera_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QEntity_IDX]))));

    _Sbk_Qt3DRender_QCamera_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QCamera",
        "Qt3DRender::QCamera*",
        &Sbk_Qt3DRender_QCamera_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QCamera >,
        Sbk_Qt3DRender_QCamera_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QCamera_TypeF(); // references _Sbk_Qt3DRender_QCamera_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QCamera_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QCamera_SignatureBytes, Qt3DRender_QCamera_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QCamera_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCamera_PythonToCpp_QCamera_PTR,
        is_QCamera_PythonToCpp_QCamera_PTR_Convertible,
        QCamera_PTR_CppToPython_QCamera);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QCamera");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QCamera*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QCamera&");
    Shiboken::Conversions::registerConverterAlias(converter, "QCamera");
    Shiboken::Conversions::registerConverterAlias(converter, "QCamera*");
    Shiboken::Conversions::registerConverterAlias(converter, "QCamera&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QCamera).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QCameraWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QCamera_TypeF(), &Sbk_Qt3DRender_QCamera_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DRender_QCamera_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'CameraTranslationOption'.
    const char *CameraTranslationOption_Initializer[] = {
        "TranslateViewCenter",
        "DontTranslateViewCenter",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CameraTranslationOption_InitializerValues[] = {
        uint8_t(Qt3DRender::QCamera::CameraTranslationOption::TranslateViewCenter),    //  0x00  0
        uint8_t(Qt3DRender::QCamera::CameraTranslationOption::DontTranslateViewCenter) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QCamera_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QCamera.CameraTranslationOption",
        CameraTranslationOption_Initializer, CameraTranslationOption_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QCamera_CameraTranslationOption_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QCamera::CameraTranslationOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QCamera_CameraTranslationOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QCamera_CameraTranslationOption,
            is_Enum_PythonToCpp_Qt3DRender_QCamera_CameraTranslationOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QCamera::CameraTranslationOption");
        Shiboken::Conversions::registerConverterAlias(converter, "QCamera::CameraTranslationOption");
        Shiboken::Conversions::registerConverterAlias(converter, "CameraTranslationOption");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CameraTranslationOption' enum.

    PySide::Signal::registerSignals(pyType, &::Qt3DRender::QCamera::staticMetaObject);
    qRegisterMetaType< ::Qt3DRender::QCamera::CameraTranslationOption >("QCamera::CameraTranslationOption");
    qRegisterMetaType< ::Qt3DRender::QCamera::CameraTranslationOption >("Qt3DRender::QCamera::CameraTranslationOption");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DRender::QCamera::staticMetaObject, sizeof(QCameraWrapper));

    return pyType;
}
