// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qgraphicsapifilter_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <Qt3DRender/qgraphicsapifilter.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QGraphicsApiFilterWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGraphicsApiFilterWrapper::QGraphicsApiFilterWrapper(::QObject * parent) : Qt3DRender::QGraphicsApiFilter(parent)
{
}

void QGraphicsApiFilterWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsApiFilter", funcName);
        return;
    }
}

void QGraphicsApiFilterWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsApiFilter", funcName);
        return;
    }
}

void QGraphicsApiFilterWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsApiFilter", funcName);
        return;
    }
}

void QGraphicsApiFilterWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsApiFilter", funcName);
        return;
    }
}

bool QGraphicsApiFilterWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsApiFilter", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGraphicsApiFilter", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QGraphicsApiFilterWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsApiFilter", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGraphicsApiFilter", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGraphicsApiFilterWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsApiFilter", funcName);
        return;
    }
}

const QMetaObject *QGraphicsApiFilterWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DRender::QGraphicsApiFilter::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QGraphicsApiFilterWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DRender::QGraphicsApiFilter::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QGraphicsApiFilterWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QGraphicsApiFilterWrapper *>(this));
    return Qt3DRender::QGraphicsApiFilter::qt_metacast(_clname);
}

QGraphicsApiFilterWrapper::~QGraphicsApiFilterWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DRender_QGraphicsApiFilter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DRender::QGraphicsApiFilter >()))
        return -1;

    QGraphicsApiFilterWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QGraphicsApiFilter", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGraphicsApiFilter::QGraphicsApiFilter(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsApiFilter(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QGraphicsApiFilter(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QGraphicsApiFilter(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QGraphicsApiFilterWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QGraphicsApiFilterWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DRender::QGraphicsApiFilter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DRender_QGraphicsApiFilterFunc_api(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // api()const
        Qt3DRender::QGraphicsApiFilter::Api cppResult = const_cast<const ::Qt3DRender::QGraphicsApiFilter *>(cppSelf)->api();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_Api_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QGraphicsApiFilterFunc_extensions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // extensions()const
        QStringList cppResult = const_cast<const ::Qt3DRender::QGraphicsApiFilter *>(cppSelf)->extensions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QGraphicsApiFilterFunc_majorVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // majorVersion()const
        int cppResult = const_cast<const ::Qt3DRender::QGraphicsApiFilter *>(cppSelf)->majorVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QGraphicsApiFilterFunc_minorVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minorVersion()const
        int cppResult = const_cast<const ::Qt3DRender::QGraphicsApiFilter *>(cppSelf)->minorVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QGraphicsApiFilterFunc_profile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // profile()const
        Qt3DRender::QGraphicsApiFilter::OpenGLProfile cppResult = const_cast<const ::Qt3DRender::QGraphicsApiFilter *>(cppSelf)->profile();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_OpenGLProfile_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QGraphicsApiFilterFunc_setApi(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsApiFilter::setApi(Qt3DRender::QGraphicsApiFilter::Api)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_Api_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setApi(Qt3DRender::QGraphicsApiFilter::Api)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setApi", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QGraphicsApiFilter::Api cppArg0 = static_cast< ::Qt3DRender::QGraphicsApiFilter::Api>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setApi(Qt3DRender::QGraphicsApiFilter::Api)
            cppSelf->setApi(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QGraphicsApiFilterFunc_setExtensions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsApiFilter::setExtensions(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setExtensions(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExtensions", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExtensions(QStringList)
            cppSelf->setExtensions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QGraphicsApiFilterFunc_setMajorVersion(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsApiFilter::setMajorVersion(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMajorVersion(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMajorVersion", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMajorVersion(int)
            cppSelf->setMajorVersion(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QGraphicsApiFilterFunc_setMinorVersion(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsApiFilter::setMinorVersion(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMinorVersion(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinorVersion", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinorVersion(int)
            cppSelf->setMinorVersion(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QGraphicsApiFilterFunc_setProfile(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsApiFilter::setProfile(Qt3DRender::QGraphicsApiFilter::OpenGLProfile)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_OpenGLProfile_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setProfile(Qt3DRender::QGraphicsApiFilter::OpenGLProfile)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProfile", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QGraphicsApiFilter::OpenGLProfile cppArg0{Qt3DRender::QGraphicsApiFilter::NoProfile};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProfile(Qt3DRender::QGraphicsApiFilter::OpenGLProfile)
            cppSelf->setProfile(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QGraphicsApiFilterFunc_setVendor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsApiFilter::setVendor(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setVendor(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVendor", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVendor(QString)
            cppSelf->setVendor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QGraphicsApiFilterFunc_vendor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vendor()const
        QString cppResult = const_cast<const ::Qt3DRender::QGraphicsApiFilter *>(cppSelf)->vendor();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DRender_QGraphicsApiFilter_PropertyStrings[] = {
    "api::",
    "extensions::",
    "majorVersion::",
    "minorVersion::",
    "profile::",
    "vendor::",
    nullptr // Sentinel
};

static const char *Sbk_Qt3DRender_QGraphicsApiFilter_EnumFlagInfo[] = {
    "Api:Enum",
    "OpenGLProfile:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QGraphicsApiFilter_methods[] = {
    {"api", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QGraphicsApiFilterFunc_api), METH_NOARGS, nullptr},
    {"extensions", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QGraphicsApiFilterFunc_extensions), METH_NOARGS, nullptr},
    {"majorVersion", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QGraphicsApiFilterFunc_majorVersion), METH_NOARGS, nullptr},
    {"minorVersion", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QGraphicsApiFilterFunc_minorVersion), METH_NOARGS, nullptr},
    {"profile", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QGraphicsApiFilterFunc_profile), METH_NOARGS, nullptr},
    {"setApi", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QGraphicsApiFilterFunc_setApi), METH_O, nullptr},
    {"setExtensions", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QGraphicsApiFilterFunc_setExtensions), METH_O, nullptr},
    {"setMajorVersion", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QGraphicsApiFilterFunc_setMajorVersion), METH_O, nullptr},
    {"setMinorVersion", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QGraphicsApiFilterFunc_setMinorVersion), METH_O, nullptr},
    {"setProfile", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QGraphicsApiFilterFunc_setProfile), METH_O, nullptr},
    {"setVendor", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QGraphicsApiFilterFunc_setVendor), METH_O, nullptr},
    {"vendor", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QGraphicsApiFilterFunc_vendor), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QGraphicsApiFilter_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGraphicsApiFilterWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

// Rich comparison
static PyObject * Sbk_Qt3DRender_QGraphicsApiFilter_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::Qt3DRender::QGraphicsApiFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_Qt3DRender_QGraphicsApiFilter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QGraphicsApiFilter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QGraphicsApiFilter_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QGraphicsApiFilter_TypeF(void)
{
    return _Sbk_Qt3DRender_QGraphicsApiFilter_Type;
}

static PyType_Slot Sbk_Qt3DRender_QGraphicsApiFilter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QGraphicsApiFilter_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QGraphicsApiFilter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QGraphicsApiFilter_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_Qt3DRender_QGraphicsApiFilter_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QGraphicsApiFilter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QGraphicsApiFilter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QGraphicsApiFilter_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QGraphicsApiFilter_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QGraphicsApiFilter_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DRender::QGraphicsApiFilter *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Qt3DRender_QGraphicsApiFilter_Api(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QGraphicsApiFilter::Api>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QGraphicsApiFilter::Api *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QGraphicsApiFilter_Api_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_Api_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QGraphicsApiFilter_Api;
    return {};
}

static PyObject *Qt3DRender_QGraphicsApiFilter_Api_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QGraphicsApiFilter::Api>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QGraphicsApiFilter::Api *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_Api_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DRender_QGraphicsApiFilter_OpenGLProfile(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QGraphicsApiFilter::OpenGLProfile>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QGraphicsApiFilter::OpenGLProfile *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QGraphicsApiFilter_OpenGLProfile_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_OpenGLProfile_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QGraphicsApiFilter_OpenGLProfile;
    return {};
}

static PyObject *Qt3DRender_QGraphicsApiFilter_OpenGLProfile_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QGraphicsApiFilter::OpenGLProfile>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QGraphicsApiFilter::OpenGLProfile *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_OpenGLProfile_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGraphicsApiFilter_PythonToCpp_QGraphicsApiFilter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QGraphicsApiFilter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGraphicsApiFilter_PythonToCpp_QGraphicsApiFilter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QGraphicsApiFilter_TypeF()))
        return QGraphicsApiFilter_PythonToCpp_QGraphicsApiFilter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGraphicsApiFilter_PTR_CppToPython_QGraphicsApiFilter(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DRender::QGraphicsApiFilter *>(const_cast<void *>(cppIn)), Sbk_Qt3DRender_QGraphicsApiFilter_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QGraphicsApiFilter_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,api:Qt3DRender.QGraphicsApiFilter.Api=None,profile:Qt3DRender.QGraphicsApiFilter.OpenGLProfile=None,minorVersion:int=None,majorVersion:int=None,extensions:QStringList=None,vendor:QString=None)",
    "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.api(self)->PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.Api",
    "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.extensions(self)->QStringList",
    "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.majorVersion(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.minorVersion(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.profile(self)->PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.OpenGLProfile",
    "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.setApi(self,api:PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.Api)",
    "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.setExtensions(self,extensions:QStringList)",
    "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.setMajorVersion(self,majorVersion:int)",
    "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.setMinorVersion(self,minorVersion:int)",
    "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.setProfile(self,profile:PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.OpenGLProfile)",
    "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.setVendor(self,vendor:QString)",
    "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.vendor(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QGraphicsApiFilter_SignatureByteSize = 291;
static constexpr uint8_t Qt3DRender_QGraphicsApiFilter_SignatureBytes[291] = {
    0x78, 0xda, 0xa5, 0x54, 0x4d, 0x4f, 0xc3, 0x30, 0x0c, 0xbd, 0xef, 0x97, 0x50, 0x54, 0x7a, 0x99,
    0xc4, 0xa1, 0xd2, 0x90, 0x26, 0x60, 0x3b, 0x30, 0x68, 0xca, 0xa4, 0xdd, 0xcb, 0xea, 0x81, 0xa7,
    0xe0, 0x44, 0x4e, 0x18, 0xf4, 0xdf, 0x13, 0xfa, 0xb1, 0xb6, 0xdb, 0x00, 0x35, 0xbb, 0x59, 0x8e,
    0xfd, 0x1c, 0xfb, 0x3d, 0x5b, 0x14, 0x4b, 0xcc, 0xe1, 0x3a, 0x4a, 0xed, 0xf8, 0xee, 0x19, 0x28,
    0x07, 0xee, 0x99, 0x73, 0xce, 0xf4, 0x1b, 0xae, 0xcd, 0x54, 0xe3, 0x0c, 0xa5, 0x05, 0xbe, 0x30,
    0x20, 0x37, 0xa1, 0xce, 0x18, 0xc8, 0xc6, 0x62, 0x9f, 0x7c, 0xab, 0x18, 0xa2, 0x34, 0x79, 0xd9,
    0xc2, 0xda, 0x4e, 0xe8, 0x43, 0x4a, 0x6d, 0x39, 0xbc, 0x8c, 0x1f, 0xa0, 0xf8, 0x54, 0x9c, 0x27,
    0x24, 0x8b, 0xc9, 0x93, 0x22, 0x08, 0x33, 0x8d, 0xf1, 0x9f, 0xf8, 0x91, 0xb3, 0xaa, 0x50, 0xcd,
    0x6a, 0x83, 0x12, 0xfe, 0x09, 0x4f, 0x34, 0xd0, 0x7c, 0x21, 0xaa, 0xd8, 0x2a, 0xf1, 0x1d, 0x49,
    0xf1, 0x0a, 0xd8, 0xa0, 0xa2, 0x18, 0xc9, 0xd6, 0xde, 0x6c, 0x7b, 0xc2, 0x0b, 0x5f, 0x16, 0xe8,
    0xc7, 0x65, 0xe2, 0x74, 0x69, 0x19, 0xe9, 0x75, 0x81, 0xa6, 0x7e, 0xdb, 0xb9, 0xa2, 0x8a, 0x1b,
    0x7f, 0xe9, 0x0b, 0x46, 0x62, 0xe0, 0xbc, 0x22, 0xd7, 0x71, 0x39, 0xb3, 0xe0, 0xea, 0x66, 0x70,
    0xae, 0xb3, 0x86, 0x17, 0x6c, 0x5b, 0x6a, 0xea, 0x76, 0x3a, 0x1b, 0x0e, 0xd7, 0x9d, 0x5b, 0x03,
    0xe8, 0xc6, 0xe7, 0x01, 0xd4, 0xa1, 0xe5, 0x2c, 0xa0, 0x5a, 0x18, 0xde, 0x53, 0xed, 0x49, 0x66,
    0x78, 0x79, 0x03, 0x76, 0x5a, 0x73, 0x5a, 0xca, 0xd9, 0x87, 0xd5, 0xc0, 0xab, 0xec, 0x7d, 0x9f,
    0xd9, 0x5f, 0xc4, 0xeb, 0x87, 0xfd, 0x78, 0x48, 0xf3, 0xd1, 0xc2, 0x78, 0xe2, 0x1e, 0xb2, 0x7e,
    0xb4, 0x9e, 0x7e, 0xb8, 0xa2, 0x23, 0x82, 0xfd, 0xa9, 0x38, 0x4f, 0x0a, 0x7e, 0x1f, 0x59, 0x95,
    0x57, 0xa2, 0xfa, 0x47, 0xff, 0x62, 0x78, 0xe0, 0xed, 0x5a, 0xb0, 0x76, 0x6f, 0x47, 0xdf, 0x8a,
    0xfc, 0x0a, 0xd6
};
#endif

PyTypeObject *init_Qt3DRender_QGraphicsApiFilter(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QGraphicsApiFilter_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_Qt3DRender_QGraphicsApiFilter_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QGraphicsApiFilter",
        "Qt3DRender::QGraphicsApiFilter*",
        &Sbk_Qt3DRender_QGraphicsApiFilter_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QGraphicsApiFilter >,
        Sbk_Qt3DRender_QGraphicsApiFilter_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QGraphicsApiFilter_TypeF(); // references _Sbk_Qt3DRender_QGraphicsApiFilter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QGraphicsApiFilter_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QGraphicsApiFilter_SignatureBytes, Qt3DRender_QGraphicsApiFilter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QGraphicsApiFilter_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGraphicsApiFilter_PythonToCpp_QGraphicsApiFilter_PTR,
        is_QGraphicsApiFilter_PythonToCpp_QGraphicsApiFilter_PTR_Convertible,
        QGraphicsApiFilter_PTR_CppToPython_QGraphicsApiFilter);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QGraphicsApiFilter");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QGraphicsApiFilter*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QGraphicsApiFilter&");
    Shiboken::Conversions::registerConverterAlias(converter, "QGraphicsApiFilter");
    Shiboken::Conversions::registerConverterAlias(converter, "QGraphicsApiFilter*");
    Shiboken::Conversions::registerConverterAlias(converter, "QGraphicsApiFilter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QGraphicsApiFilter).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGraphicsApiFilterWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QGraphicsApiFilter_TypeF(), &Sbk_Qt3DRender_QGraphicsApiFilter_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DRender_QGraphicsApiFilter_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Api'.
    const char *Api_Initializer[] = {
        "OpenGLES",
        "OpenGL",
        "Vulkan",
        "DirectX",
        "RHI",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Api_InitializerValues[] = {
        uint8_t(Qt3DRender::QGraphicsApiFilter::Api::OpenGLES), //  0x02  2
        uint8_t(Qt3DRender::QGraphicsApiFilter::Api::OpenGL),   //  0x01  1
        uint8_t(Qt3DRender::QGraphicsApiFilter::Api::Vulkan),   //  0x03  3
        uint8_t(Qt3DRender::QGraphicsApiFilter::Api::DirectX),  //  0x04  4
        uint8_t(Qt3DRender::QGraphicsApiFilter::Api::RHI)       //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QGraphicsApiFilter_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.Api",
        Api_Initializer, Api_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_Api_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QGraphicsApiFilter::Api'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QGraphicsApiFilter_Api_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QGraphicsApiFilter_Api,
            is_Enum_PythonToCpp_Qt3DRender_QGraphicsApiFilter_Api_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QGraphicsApiFilter::Api");
        Shiboken::Conversions::registerConverterAlias(converter, "QGraphicsApiFilter::Api");
        Shiboken::Conversions::registerConverterAlias(converter, "Api");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Api' enum.

    // Initialization of enum 'OpenGLProfile'.
    const char *OpenGLProfile_Initializer[] = {
        "NoProfile",
        "CoreProfile",
        "CompatibilityProfile",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t OpenGLProfile_InitializerValues[] = {
        uint8_t(Qt3DRender::QGraphicsApiFilter::OpenGLProfile::NoProfile),           //  0x00  0
        uint8_t(Qt3DRender::QGraphicsApiFilter::OpenGLProfile::CoreProfile),         //  0x01  1
        uint8_t(Qt3DRender::QGraphicsApiFilter::OpenGLProfile::CompatibilityProfile) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QGraphicsApiFilter_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.OpenGLProfile",
        OpenGLProfile_Initializer, OpenGLProfile_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_OpenGLProfile_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QGraphicsApiFilter::OpenGLProfile'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QGraphicsApiFilter_OpenGLProfile_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QGraphicsApiFilter_OpenGLProfile,
            is_Enum_PythonToCpp_Qt3DRender_QGraphicsApiFilter_OpenGLProfile_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QGraphicsApiFilter::OpenGLProfile");
        Shiboken::Conversions::registerConverterAlias(converter, "QGraphicsApiFilter::OpenGLProfile");
        Shiboken::Conversions::registerConverterAlias(converter, "OpenGLProfile");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'OpenGLProfile' enum.

    PySide::Signal::registerSignals(pyType, &::Qt3DRender::QGraphicsApiFilter::staticMetaObject);
    qRegisterMetaType< ::Qt3DRender::QGraphicsApiFilter::Api >("QGraphicsApiFilter::Api");
    qRegisterMetaType< ::Qt3DRender::QGraphicsApiFilter::Api >("Qt3DRender::QGraphicsApiFilter::Api");
    qRegisterMetaType< ::Qt3DRender::QGraphicsApiFilter::OpenGLProfile >("QGraphicsApiFilter::OpenGLProfile");
    qRegisterMetaType< ::Qt3DRender::QGraphicsApiFilter::OpenGLProfile >("Qt3DRender::QGraphicsApiFilter::OpenGLProfile");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DRender::QGraphicsApiFilter::staticMetaObject, sizeof(QGraphicsApiFilterWrapper));

    return pyType;
}
