// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qpickingsettings_wrapper.h"

// Argument includes
#include <QList>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DRender/qpickingsettings.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QPickingSettingsWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPickingSettingsWrapper::QPickingSettingsWrapper(::Qt3DCore::QNode * parent) : Qt3DRender::QPickingSettings(parent)
{
}

void QPickingSettingsWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPickingSettings", funcName);
        return;
    }
}

void QPickingSettingsWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPickingSettings", funcName);
        return;
    }
}

void QPickingSettingsWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPickingSettings", funcName);
        return;
    }
}

void QPickingSettingsWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPickingSettings", funcName);
        return;
    }
}

bool QPickingSettingsWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPickingSettings", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPickingSettings", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QPickingSettingsWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPickingSettings", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPickingSettings", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPickingSettingsWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPickingSettings", funcName);
        return;
    }
}

const QMetaObject *QPickingSettingsWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DRender::QPickingSettings::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QPickingSettingsWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DRender::QPickingSettings::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QPickingSettingsWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QPickingSettingsWrapper *>(this));
    return Qt3DRender::QPickingSettings::qt_metacast(_clname);
}

QPickingSettingsWrapper::~QPickingSettingsWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DRender_QPickingSettings_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DRender::QPickingSettings >()))
        return -1;

    QPickingSettingsWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QPickingSettings", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPickingSettings::QPickingSettings(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QPickingSettings(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QPickingSettings(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QPickingSettings(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QPickingSettingsWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QPickingSettingsWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DRender::QPickingSettings >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DRender_QPickingSettingsFunc_faceOrientationPickingMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QPickingSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // faceOrientationPickingMode()const
        Qt3DRender::QPickingSettings::FaceOrientationPickingMode cppResult = const_cast<const ::Qt3DRender::QPickingSettings *>(cppSelf)->faceOrientationPickingMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_FaceOrientationPickingMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QPickingSettingsFunc_pickMethod(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QPickingSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pickMethod()const
        Qt3DRender::QPickingSettings::PickMethod cppResult = const_cast<const ::Qt3DRender::QPickingSettings *>(cppSelf)->pickMethod();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_PickMethod_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QPickingSettingsFunc_pickResultMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QPickingSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pickResultMode()const
        Qt3DRender::QPickingSettings::PickResultMode cppResult = const_cast<const ::Qt3DRender::QPickingSettings *>(cppSelf)->pickResultMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_PickResultMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QPickingSettingsFunc_setFaceOrientationPickingMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QPickingSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPickingSettings::setFaceOrientationPickingMode(Qt3DRender::QPickingSettings::FaceOrientationPickingMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_FaceOrientationPickingMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFaceOrientationPickingMode(Qt3DRender::QPickingSettings::FaceOrientationPickingMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFaceOrientationPickingMode", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QPickingSettings::FaceOrientationPickingMode cppArg0 = static_cast< ::Qt3DRender::QPickingSettings::FaceOrientationPickingMode>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFaceOrientationPickingMode(Qt3DRender::QPickingSettings::FaceOrientationPickingMode)
            cppSelf->setFaceOrientationPickingMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QPickingSettingsFunc_setPickMethod(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QPickingSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPickingSettings::setPickMethod(Qt3DRender::QPickingSettings::PickMethod)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_PickMethod_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPickMethod(Qt3DRender::QPickingSettings::PickMethod)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPickMethod", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QPickingSettings::PickMethod cppArg0{Qt3DRender::QPickingSettings::BoundingVolumePicking};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPickMethod(Qt3DRender::QPickingSettings::PickMethod)
            cppSelf->setPickMethod(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QPickingSettingsFunc_setPickResultMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QPickingSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPickingSettings::setPickResultMode(Qt3DRender::QPickingSettings::PickResultMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_PickResultMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPickResultMode(Qt3DRender::QPickingSettings::PickResultMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPickResultMode", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QPickingSettings::PickResultMode cppArg0{Qt3DRender::QPickingSettings::NearestPick};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPickResultMode(Qt3DRender::QPickingSettings::PickResultMode)
            cppSelf->setPickResultMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QPickingSettingsFunc_setWorldSpaceTolerance(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QPickingSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPickingSettings::setWorldSpaceTolerance(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setWorldSpaceTolerance(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWorldSpaceTolerance", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWorldSpaceTolerance(float)
            cppSelf->setWorldSpaceTolerance(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QPickingSettingsFunc_worldSpaceTolerance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QPickingSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // worldSpaceTolerance()const
        float cppResult = const_cast<const ::Qt3DRender::QPickingSettings *>(cppSelf)->worldSpaceTolerance();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DRender_QPickingSettings_PropertyStrings[] = {
    "faceOrientationPickingMode::",
    "pickMethod::",
    "pickResultMode::",
    "worldSpaceTolerance::",
    nullptr // Sentinel
};

static const char *Sbk_Qt3DRender_QPickingSettings_EnumFlagInfo[] = {
    "FaceOrientationPickingMode:Enum",
    "PickMethod:Enum",
    "PickResultMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QPickingSettings_methods[] = {
    {"faceOrientationPickingMode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QPickingSettingsFunc_faceOrientationPickingMode), METH_NOARGS, nullptr},
    {"pickMethod", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QPickingSettingsFunc_pickMethod), METH_NOARGS, nullptr},
    {"pickResultMode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QPickingSettingsFunc_pickResultMode), METH_NOARGS, nullptr},
    {"setFaceOrientationPickingMode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QPickingSettingsFunc_setFaceOrientationPickingMode), METH_O, nullptr},
    {"setPickMethod", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QPickingSettingsFunc_setPickMethod), METH_O, nullptr},
    {"setPickResultMode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QPickingSettingsFunc_setPickResultMode), METH_O, nullptr},
    {"setWorldSpaceTolerance", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QPickingSettingsFunc_setWorldSpaceTolerance), METH_O, nullptr},
    {"worldSpaceTolerance", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QPickingSettingsFunc_worldSpaceTolerance), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QPickingSettings_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QPickingSettings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPickingSettingsWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DRender_QPickingSettings_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QPickingSettings_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QPickingSettings_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QPickingSettings_TypeF(void)
{
    return _Sbk_Qt3DRender_QPickingSettings_Type;
}

static PyType_Slot Sbk_Qt3DRender_QPickingSettings_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QPickingSettings_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QPickingSettings_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QPickingSettings_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QPickingSettings_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QPickingSettings_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QPickingSettings_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QPickingSettings",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QPickingSettings_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QPickingSettings_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DRender::QPickingSettings *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Qt3DRender_QPickingSettings_PickMethod(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QPickingSettings::PickMethod>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QPickingSettings::PickMethod *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QPickingSettings_PickMethod_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_PickMethod_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QPickingSettings_PickMethod;
    return {};
}

static PyObject *Qt3DRender_QPickingSettings_PickMethod_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QPickingSettings::PickMethod>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QPickingSettings::PickMethod *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_PickMethod_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DRender_QPickingSettings_PickResultMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QPickingSettings::PickResultMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QPickingSettings::PickResultMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QPickingSettings_PickResultMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_PickResultMode_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QPickingSettings_PickResultMode;
    return {};
}

static PyObject *Qt3DRender_QPickingSettings_PickResultMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QPickingSettings::PickResultMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QPickingSettings::PickResultMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_PickResultMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DRender_QPickingSettings_FaceOrientationPickingMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QPickingSettings::FaceOrientationPickingMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QPickingSettings::FaceOrientationPickingMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QPickingSettings_FaceOrientationPickingMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_FaceOrientationPickingMode_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QPickingSettings_FaceOrientationPickingMode;
    return {};
}

static PyObject *Qt3DRender_QPickingSettings_FaceOrientationPickingMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QPickingSettings::FaceOrientationPickingMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QPickingSettings::FaceOrientationPickingMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_FaceOrientationPickingMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPickingSettings_PythonToCpp_QPickingSettings_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QPickingSettings_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPickingSettings_PythonToCpp_QPickingSettings_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QPickingSettings_TypeF()))
        return QPickingSettings_PythonToCpp_QPickingSettings_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPickingSettings_PTR_CppToPython_QPickingSettings(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DRender::QPickingSettings *>(const_cast<void *>(cppIn)), Sbk_Qt3DRender_QPickingSettings_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QPickingSettings_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QPickingSettings(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,pickMethod:Qt3DRender.QPickingSettings.PickMethod=None,pickResultMode:Qt3DRender.QPickingSettings.PickResultMode=None,faceOrientationPickingMode:Qt3DRender.QPickingSettings.FaceOrientationPickingMode=None,worldSpaceTolerance:float=None)",
    "PySide6.Qt3DRender.Qt3DRender.QPickingSettings.faceOrientationPickingMode(self)->PySide6.Qt3DRender.Qt3DRender.QPickingSettings.FaceOrientationPickingMode",
    "PySide6.Qt3DRender.Qt3DRender.QPickingSettings.pickMethod(self)->PySide6.Qt3DRender.Qt3DRender.QPickingSettings.PickMethod",
    "PySide6.Qt3DRender.Qt3DRender.QPickingSettings.pickResultMode(self)->PySide6.Qt3DRender.Qt3DRender.QPickingSettings.PickResultMode",
    "PySide6.Qt3DRender.Qt3DRender.QPickingSettings.setFaceOrientationPickingMode(self,faceOrientationPickingMode:PySide6.Qt3DRender.Qt3DRender.QPickingSettings.FaceOrientationPickingMode)",
    "PySide6.Qt3DRender.Qt3DRender.QPickingSettings.setPickMethod(self,pickMethod:PySide6.Qt3DRender.Qt3DRender.QPickingSettings.PickMethod)",
    "PySide6.Qt3DRender.Qt3DRender.QPickingSettings.setPickResultMode(self,pickResultMode:PySide6.Qt3DRender.Qt3DRender.QPickingSettings.PickResultMode)",
    "PySide6.Qt3DRender.Qt3DRender.QPickingSettings.setWorldSpaceTolerance(self,worldSpaceTolerance:float)",
    "PySide6.Qt3DRender.Qt3DRender.QPickingSettings.worldSpaceTolerance(self)->float",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QPickingSettings_SignatureByteSize = 264;
static constexpr uint8_t Qt3DRender_QPickingSettings_SignatureBytes[264] = {
    0x78, 0xda, 0xad, 0x93, 0xc1, 0x6b, 0x83, 0x30, 0x18, 0xc5, 0xef, 0xfe, 0x25, 0xb3, 0x58, 0x2f,
    0x83, 0x1e, 0x84, 0xf6, 0xb2, 0xd2, 0xcb, 0xa8, 0x66, 0x75, 0xd0, 0x73, 0x30, 0x9f, 0x5b, 0x58,
    0x48, 0x24, 0x7e, 0x22, 0xfe, 0xf7, 0x0b, 0x3a, 0x16, 0xdb, 0x11, 0x25, 0xe9, 0x4e, 0x06, 0xcc,
    0x7b, 0xef, 0x97, 0xbc, 0x7c, 0x64, 0x28, 0x39, 0x83, 0x5d, 0xfa, 0x86, 0xcf, 0xc7, 0x0b, 0x48,
    0x06, 0xfa, 0x66, 0x49, 0x78, 0xf5, 0xc5, 0xe5, 0x47, 0x09, 0x88, 0xe6, 0xd3, 0x3e, 0xb5, 0x20,
    0xea, 0xa4, 0xa1, 0x1a, 0x24, 0x66, 0x64, 0x26, 0x7d, 0x51, 0x1a, 0x66, 0x8b, 0x5c, 0x31, 0xd8,
    0xcb, 0x4e, 0x88, 0x06, 0x75, 0xb2, 0xc9, 0x5e, 0x61, 0xe8, 0x95, 0x66, 0x85, 0x14, 0xc3, 0x3e,
    0x57, 0x12, 0x92, 0xc6, 0xd8, 0x9e, 0x01, 0x3f, 0x15, 0xcb, 0x16, 0xd2, 0x52, 0xf2, 0xbb, 0xcd,
    0xca, 0x2e, 0xd0, 0x76, 0x02, 0xcf, 0x26, 0x60, 0x55, 0x6a, 0xb7, 0x4e, 0xf2, 0x9a, 0x56, 0x50,
    0x68, 0x6e, 0xd8, 0x29, 0x72, 0x25, 0x7f, 0x24, 0xab, 0x56, 0x27, 0xa7, 0x6c, 0xb2, 0x35, 0x47,
    0x13, 0xac, 0x6c, 0xcc, 0xae, 0x77, 0x25, 0x40, 0x53, 0x59, 0x41, 0x56, 0x0b, 0x45, 0x71, 0xfc,
    0x1d, 0x47, 0xc4, 0xeb, 0x8a, 0x53, 0x37, 0xe5, 0x78, 0xfb, 0xf1, 0xf6, 0xe0, 0x69, 0xe8, 0xe6,
    0xf7, 0x45, 0xb3, 0xb5, 0x05, 0xa2, 0xd8, 0x42, 0x43, 0xa2, 0x6d, 0x9f, 0x0f, 0xc4, 0x5b, 0x13,
    0x5f, 0x84, 0x16, 0xf0, 0xb4, 0xdc, 0xcd, 0xd2, 0x0b, 0xfb, 0xb7, 0xd2, 0xe2, 0x00, 0x6e, 0x72,
    0x5b, 0xdc, 0x7c, 0xfe, 0x82, 0x1b, 0x0c, 0xe5, 0xb8, 0x6b, 0xf1, 0x7e, 0xa8, 0x1f, 0xaa, 0x34,
    0x84, 0xe9, 0xfa, 0x77, 0x7c, 0x27, 0x30, 0xe7, 0x5c, 0x7b, 0xa7, 0xf4, 0x8e, 0x08, 0xf3, 0x82,
    0x47, 0xc3, 0xe8, 0x1b, 0x11, 0x7b, 0x06, 0xef
};
#endif

PyTypeObject *init_Qt3DRender_QPickingSettings(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QPickingSettings_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]))));

    _Sbk_Qt3DRender_QPickingSettings_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QPickingSettings",
        "Qt3DRender::QPickingSettings*",
        &Sbk_Qt3DRender_QPickingSettings_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QPickingSettings >,
        Sbk_Qt3DRender_QPickingSettings_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QPickingSettings_TypeF(); // references _Sbk_Qt3DRender_QPickingSettings_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QPickingSettings_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QPickingSettings_SignatureBytes, Qt3DRender_QPickingSettings_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QPickingSettings_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPickingSettings_PythonToCpp_QPickingSettings_PTR,
        is_QPickingSettings_PythonToCpp_QPickingSettings_PTR_Convertible,
        QPickingSettings_PTR_CppToPython_QPickingSettings);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QPickingSettings");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QPickingSettings*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QPickingSettings&");
    Shiboken::Conversions::registerConverterAlias(converter, "QPickingSettings");
    Shiboken::Conversions::registerConverterAlias(converter, "QPickingSettings*");
    Shiboken::Conversions::registerConverterAlias(converter, "QPickingSettings&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QPickingSettings).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPickingSettingsWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QPickingSettings_TypeF(), &Sbk_Qt3DRender_QPickingSettings_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DRender_QPickingSettings_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'PickMethod'.
    const char *PickMethod_Initializer[] = {
        "BoundingVolumePicking",
        "TrianglePicking",
        "LinePicking",
        "PointPicking",
        "PrimitivePicking",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PickMethod_InitializerValues[] = {
        uint8_t(Qt3DRender::QPickingSettings::PickMethod::BoundingVolumePicking), //  0x00  0
        uint8_t(Qt3DRender::QPickingSettings::PickMethod::TrianglePicking),       //  0x01  1
        uint8_t(Qt3DRender::QPickingSettings::PickMethod::LinePicking),           //  0x02  2
        uint8_t(Qt3DRender::QPickingSettings::PickMethod::PointPicking),          //  0x04  4
        uint8_t(Qt3DRender::QPickingSettings::PickMethod::PrimitivePicking)       //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QPickingSettings_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QPickingSettings.PickMethod",
        PickMethod_Initializer, PickMethod_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_PickMethod_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QPickingSettings::PickMethod'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QPickingSettings_PickMethod_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QPickingSettings_PickMethod,
            is_Enum_PythonToCpp_Qt3DRender_QPickingSettings_PickMethod_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QPickingSettings::PickMethod");
        Shiboken::Conversions::registerConverterAlias(converter, "QPickingSettings::PickMethod");
        Shiboken::Conversions::registerConverterAlias(converter, "PickMethod");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PickMethod' enum.

    // Initialization of enum 'PickResultMode'.
    const char *PickResultMode_Initializer[] = {
        "NearestPick",
        "AllPicks",
        "NearestPriorityPick",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PickResultMode_InitializerValues[] = {
        uint8_t(Qt3DRender::QPickingSettings::PickResultMode::NearestPick),        //  0x00  0
        uint8_t(Qt3DRender::QPickingSettings::PickResultMode::AllPicks),           //  0x01  1
        uint8_t(Qt3DRender::QPickingSettings::PickResultMode::NearestPriorityPick) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QPickingSettings_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QPickingSettings.PickResultMode",
        PickResultMode_Initializer, PickResultMode_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_PickResultMode_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QPickingSettings::PickResultMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QPickingSettings_PickResultMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QPickingSettings_PickResultMode,
            is_Enum_PythonToCpp_Qt3DRender_QPickingSettings_PickResultMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QPickingSettings::PickResultMode");
        Shiboken::Conversions::registerConverterAlias(converter, "QPickingSettings::PickResultMode");
        Shiboken::Conversions::registerConverterAlias(converter, "PickResultMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PickResultMode' enum.

    // Initialization of enum 'FaceOrientationPickingMode'.
    const char *FaceOrientationPickingMode_Initializer[] = {
        "FrontFace",
        "BackFace",
        "FrontAndBackFace",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FaceOrientationPickingMode_InitializerValues[] = {
        uint8_t(Qt3DRender::QPickingSettings::FaceOrientationPickingMode::FrontFace),       //  0x01  1
        uint8_t(Qt3DRender::QPickingSettings::FaceOrientationPickingMode::BackFace),        //  0x02  2
        uint8_t(Qt3DRender::QPickingSettings::FaceOrientationPickingMode::FrontAndBackFace) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QPickingSettings_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QPickingSettings.FaceOrientationPickingMode",
        FaceOrientationPickingMode_Initializer, FaceOrientationPickingMode_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QPickingSettings_FaceOrientationPickingMode_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QPickingSettings::FaceOrientationPickingMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QPickingSettings_FaceOrientationPickingMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QPickingSettings_FaceOrientationPickingMode,
            is_Enum_PythonToCpp_Qt3DRender_QPickingSettings_FaceOrientationPickingMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QPickingSettings::FaceOrientationPickingMode");
        Shiboken::Conversions::registerConverterAlias(converter, "QPickingSettings::FaceOrientationPickingMode");
        Shiboken::Conversions::registerConverterAlias(converter, "FaceOrientationPickingMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FaceOrientationPickingMode' enum.

    PySide::Signal::registerSignals(pyType, &::Qt3DRender::QPickingSettings::staticMetaObject);
    qRegisterMetaType< ::Qt3DRender::QPickingSettings::PickMethod >("QPickingSettings::PickMethod");
    qRegisterMetaType< ::Qt3DRender::QPickingSettings::PickMethod >("Qt3DRender::QPickingSettings::PickMethod");
    qRegisterMetaType< ::Qt3DRender::QPickingSettings::PickResultMode >("QPickingSettings::PickResultMode");
    qRegisterMetaType< ::Qt3DRender::QPickingSettings::PickResultMode >("Qt3DRender::QPickingSettings::PickResultMode");
    qRegisterMetaType< ::Qt3DRender::QPickingSettings::FaceOrientationPickingMode >("QPickingSettings::FaceOrientationPickingMode");
    qRegisterMetaType< ::Qt3DRender::QPickingSettings::FaceOrientationPickingMode >("Qt3DRender::QPickingSettings::FaceOrientationPickingMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DRender::QPickingSettings::staticMetaObject, sizeof(QPickingSettingsWrapper));

    return pyType;
}
