// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qrendercapabilities_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <Qt3DRender/qrendercapabilities.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QRenderCapabilitiesWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QRenderCapabilitiesWrapper::QRenderCapabilitiesWrapper(::QObject * parent) : Qt3DRender::QRenderCapabilities(parent)
{
}

void QRenderCapabilitiesWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRenderCapabilities", funcName);
        return;
    }
}

void QRenderCapabilitiesWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRenderCapabilities", funcName);
        return;
    }
}

void QRenderCapabilitiesWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRenderCapabilities", funcName);
        return;
    }
}

void QRenderCapabilitiesWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRenderCapabilities", funcName);
        return;
    }
}

bool QRenderCapabilitiesWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRenderCapabilities", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRenderCapabilities", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QRenderCapabilitiesWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRenderCapabilities", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRenderCapabilities", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRenderCapabilitiesWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRenderCapabilities", funcName);
        return;
    }
}

const QMetaObject *QRenderCapabilitiesWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DRender::QRenderCapabilities::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QRenderCapabilitiesWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DRender::QRenderCapabilities::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QRenderCapabilitiesWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QRenderCapabilitiesWrapper *>(this));
    return Qt3DRender::QRenderCapabilities::qt_metacast(_clname);
}

QRenderCapabilitiesWrapper::~QRenderCapabilitiesWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DRender_QRenderCapabilities_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DRender::QRenderCapabilities >()))
        return -1;

    QRenderCapabilitiesWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QRenderCapabilities", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRenderCapabilities::QRenderCapabilities(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QRenderCapabilities(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QRenderCapabilities(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QRenderCapabilities(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QRenderCapabilitiesWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QRenderCapabilitiesWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DRender::QRenderCapabilities >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_api(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // api()const
        Qt3DRender::QRenderCapabilities::API cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->api();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_API_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_driverVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // driverVersion()const
        QString cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->driverVersion();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_extensions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // extensions()const
        QStringList cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->extensions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_glslVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // glslVersion()const
        QString cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->glslVersion();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_majorVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // majorVersion()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->majorVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxComputeInvocations(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxComputeInvocations()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxComputeInvocations();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxComputeSharedMemorySize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxComputeSharedMemorySize()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxComputeSharedMemorySize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxImageUnits(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxImageUnits()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxImageUnits();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxSSBOBindings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxSSBOBindings()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxSSBOBindings();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxSSBOSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxSSBOSize()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxSSBOSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxSamples(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxSamples()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxSamples();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxTextureLayers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxTextureLayers()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxTextureLayers();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxTextureSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxTextureSize()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxTextureSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxTextureUnits(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxTextureUnits()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxTextureUnits();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxUBOBindings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxUBOBindings()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxUBOBindings();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxUBOSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxUBOSize()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxUBOSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxWorkGroupCountX(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxWorkGroupCountX()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxWorkGroupCountX();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxWorkGroupCountY(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxWorkGroupCountY()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxWorkGroupCountY();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxWorkGroupCountZ(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxWorkGroupCountZ()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxWorkGroupCountZ();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxWorkGroupSizeX(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxWorkGroupSizeX()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxWorkGroupSizeX();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxWorkGroupSizeY(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxWorkGroupSizeY()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxWorkGroupSizeY();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxWorkGroupSizeZ(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxWorkGroupSizeZ()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->maxWorkGroupSizeZ();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_minorVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minorVersion()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->minorVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_profile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // profile()const
        Qt3DRender::QRenderCapabilities::Profile cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->profile();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_Profile_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_renderer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // renderer()const
        QString cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->renderer();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_supportsCompute(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportsCompute()const
        bool cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->supportsCompute();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_supportsImageStore(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportsImageStore()const
        bool cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->supportsImageStore();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_supportsSSBO(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportsSSBO()const
        bool cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->supportsSSBO();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_supportsUBO(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportsUBO()const
        bool cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->supportsUBO();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QRenderCapabilitiesFunc_vendor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vendor()const
        QString cppResult = const_cast<const ::Qt3DRender::QRenderCapabilities *>(cppSelf)->vendor();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DRender_QRenderCapabilities_PropertyStrings[] = {
    "api:",
    "driverVersion:",
    "extensions:",
    "glslVersion:",
    "majorVersion:",
    "maxComputeInvocations:",
    "maxComputeSharedMemorySize:",
    "maxImageUnits:",
    "maxSSBOBindings:",
    "maxSSBOSize:",
    "maxSamples:",
    "maxTextureLayers:",
    "maxTextureSize:",
    "maxTextureUnits:",
    "maxUBOBindings:",
    "maxUBOSize:",
    "maxWorkGroupCountX:",
    "maxWorkGroupCountY:",
    "maxWorkGroupCountZ:",
    "maxWorkGroupSizeX:",
    "maxWorkGroupSizeY:",
    "maxWorkGroupSizeZ:",
    "minorVersion:",
    "profile:",
    "renderer:",
    "supportsCompute:",
    "supportsImageStore:",
    "supportsSSBO:",
    "supportsUBO:",
    "valid:isValid",
    "vendor:",
    nullptr // Sentinel
};

static const char *Sbk_Qt3DRender_QRenderCapabilities_EnumFlagInfo[] = {
    "API:Enum",
    "Profile:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QRenderCapabilities_methods[] = {
    {"api", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_api), METH_NOARGS, nullptr},
    {"driverVersion", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_driverVersion), METH_NOARGS, nullptr},
    {"extensions", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_extensions), METH_NOARGS, nullptr},
    {"glslVersion", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_glslVersion), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_isValid), METH_NOARGS, nullptr},
    {"majorVersion", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_majorVersion), METH_NOARGS, nullptr},
    {"maxComputeInvocations", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxComputeInvocations), METH_NOARGS, nullptr},
    {"maxComputeSharedMemorySize", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxComputeSharedMemorySize), METH_NOARGS, nullptr},
    {"maxImageUnits", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxImageUnits), METH_NOARGS, nullptr},
    {"maxSSBOBindings", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxSSBOBindings), METH_NOARGS, nullptr},
    {"maxSSBOSize", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxSSBOSize), METH_NOARGS, nullptr},
    {"maxSamples", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxSamples), METH_NOARGS, nullptr},
    {"maxTextureLayers", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxTextureLayers), METH_NOARGS, nullptr},
    {"maxTextureSize", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxTextureSize), METH_NOARGS, nullptr},
    {"maxTextureUnits", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxTextureUnits), METH_NOARGS, nullptr},
    {"maxUBOBindings", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxUBOBindings), METH_NOARGS, nullptr},
    {"maxUBOSize", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxUBOSize), METH_NOARGS, nullptr},
    {"maxWorkGroupCountX", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxWorkGroupCountX), METH_NOARGS, nullptr},
    {"maxWorkGroupCountY", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxWorkGroupCountY), METH_NOARGS, nullptr},
    {"maxWorkGroupCountZ", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxWorkGroupCountZ), METH_NOARGS, nullptr},
    {"maxWorkGroupSizeX", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxWorkGroupSizeX), METH_NOARGS, nullptr},
    {"maxWorkGroupSizeY", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxWorkGroupSizeY), METH_NOARGS, nullptr},
    {"maxWorkGroupSizeZ", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_maxWorkGroupSizeZ), METH_NOARGS, nullptr},
    {"minorVersion", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_minorVersion), METH_NOARGS, nullptr},
    {"profile", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_profile), METH_NOARGS, nullptr},
    {"renderer", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_renderer), METH_NOARGS, nullptr},
    {"supportsCompute", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_supportsCompute), METH_NOARGS, nullptr},
    {"supportsImageStore", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_supportsImageStore), METH_NOARGS, nullptr},
    {"supportsSSBO", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_supportsSSBO), METH_NOARGS, nullptr},
    {"supportsUBO", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_supportsUBO), METH_NOARGS, nullptr},
    {"vendor", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCapabilitiesFunc_vendor), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QRenderCapabilities_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QRenderCapabilities *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRenderCapabilitiesWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DRender_QRenderCapabilities_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QRenderCapabilities_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QRenderCapabilities_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QRenderCapabilities_TypeF(void)
{
    return _Sbk_Qt3DRender_QRenderCapabilities_Type;
}

static PyType_Slot Sbk_Qt3DRender_QRenderCapabilities_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QRenderCapabilities_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QRenderCapabilities_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QRenderCapabilities_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QRenderCapabilities_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QRenderCapabilities_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QRenderCapabilities_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QRenderCapabilities_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QRenderCapabilities_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DRender::QRenderCapabilities *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Qt3DRender_QRenderCapabilities_API(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QRenderCapabilities::API>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QRenderCapabilities::API *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QRenderCapabilities_API_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_API_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QRenderCapabilities_API;
    return {};
}

static PyObject *Qt3DRender_QRenderCapabilities_API_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QRenderCapabilities::API>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QRenderCapabilities::API *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_API_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DRender_QRenderCapabilities_Profile(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QRenderCapabilities::Profile>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QRenderCapabilities::Profile *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QRenderCapabilities_Profile_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_Profile_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QRenderCapabilities_Profile;
    return {};
}

static PyObject *Qt3DRender_QRenderCapabilities_Profile_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QRenderCapabilities::Profile>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QRenderCapabilities::Profile *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_Profile_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRenderCapabilities_PythonToCpp_QRenderCapabilities_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QRenderCapabilities_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRenderCapabilities_PythonToCpp_QRenderCapabilities_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QRenderCapabilities_TypeF()))
        return QRenderCapabilities_PythonToCpp_QRenderCapabilities_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRenderCapabilities_PTR_CppToPython_QRenderCapabilities(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DRender::QRenderCapabilities *>(const_cast<void *>(cppIn)), Sbk_Qt3DRender_QRenderCapabilities_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QRenderCapabilities_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,valid:bool=None,api:Qt3DRender.QRenderCapabilities.API=None,profile:Qt3DRender.QRenderCapabilities.Profile=None,majorVersion:int=None,minorVersion:int=None,extensions:QStringList=None,vendor:QString=None,renderer:QString=None,driverVersion:QString=None,glslVersion:QString=None,maxSamples:int=None,maxTextureSize:int=None,maxTextureUnits:int=None,maxTextureLayers:int=None,supportsUBO:bool=None,maxUBOSize:int=None,maxUBOBindings:int=None,supportsSSBO:bool=None,maxSSBOSize:int=None,maxSSBOBindings:int=None,supportsImageStore:bool=None,maxImageUnits:int=None,supportsCompute:bool=None,maxWorkGroupCountX:int=None,maxWorkGroupCountY:int=None,maxWorkGroupCountZ:int=None,maxWorkGroupSizeX:int=None,maxWorkGroupSizeY:int=None,maxWorkGroupSizeZ:int=None,maxComputeInvocations:int=None,maxComputeSharedMemorySize:int=None)",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.api(self)->PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.API",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.driverVersion(self)->QString",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.extensions(self)->QStringList",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.glslVersion(self)->QString",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.isValid(self)->bool",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.majorVersion(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxComputeInvocations(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxComputeSharedMemorySize(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxImageUnits(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxSSBOBindings(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxSSBOSize(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxSamples(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxTextureLayers(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxTextureSize(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxTextureUnits(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxUBOBindings(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxUBOSize(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxWorkGroupCountX(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxWorkGroupCountY(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxWorkGroupCountZ(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxWorkGroupSizeX(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxWorkGroupSizeY(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.maxWorkGroupSizeZ(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.minorVersion(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.profile(self)->PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.Profile",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.renderer(self)->QString",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.supportsCompute(self)->bool",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.supportsImageStore(self)->bool",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.supportsSSBO(self)->bool",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.supportsUBO(self)->bool",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.vendor(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QRenderCapabilities_SignatureByteSize = 517;
static constexpr uint8_t Qt3DRender_QRenderCapabilities_SignatureBytes[517] = {
    0x78, 0xda, 0xad, 0x97, 0xdd, 0x4f, 0xdb, 0x30, 0x10, 0xc0, 0xdf, 0xf9, 0x4b, 0xc6, 0x54, 0xfa,
    0x32, 0x69, 0x0f, 0x91, 0x98, 0x04, 0x45, 0x42, 0xd5, 0xd8, 0x9a, 0x2e, 0x04, 0x28, 0x6f, 0x2e,
    0x39, 0xba, 0x63, 0x8e, 0x6d, 0xd9, 0x4e, 0x69, 0xf6, 0xd7, 0xcf, 0xf9, 0xa2, 0xb1, 0x9b, 0x32,
    0x11, 0xfb, 0xa9, 0xed, 0x9d, 0xfd, 0xbb, 0xb3, 0x7d, 0x5f, 0x8d, 0xcb, 0x04, 0x33, 0xf8, 0x3a,
    0x5d, 0xea, 0x2f, 0x57, 0xbf, 0x80, 0x65, 0x20, 0xad, 0xaf, 0xcd, 0xe7, 0x8c, 0x08, 0xb2, 0x46,
    0x8a, 0x1a, 0x41, 0x7d, 0x52, 0x40, 0x9f, 0x27, 0x82, 0x48, 0x60, 0x3a, 0x8a, 0xdf, 0x76, 0xcf,
    0xb8, 0x84, 0xe9, 0x72, 0xb1, 0x7e, 0x81, 0x27, 0x7d, 0xce, 0x0a, 0x4a, 0x85, 0x96, 0x93, 0xcf,
    0xd1, 0x77, 0x28, 0x5f, 0xb9, 0xcc, 0x16, 0x8c, 0x96, 0xe7, 0x3f, 0x39, 0x83, 0xc9, 0x96, 0x50,
    0xcc, 0xa2, 0x35, 0xe7, 0xb4, 0xf9, 0x4d, 0x04, 0x46, 0xef, 0x1b, 0x9c, 0x5e, 0xc4, 0xf3, 0x66,
    0xad, 0x90, 0xfc, 0x19, 0x29, 0xfc, 0x6f, 0x7d, 0xdc, 0x2c, 0x6b, 0xf6, 0xe4, 0xe4, 0x85, 0xcb,
    0x3b, 0x90, 0x0a, 0x39, 0x8b, 0x90, 0xe9, 0x56, 0x8a, 0x6c, 0x40, 0x0a, 0x3b, 0x0d, 0xac, 0x12,
    0xa9, 0x68, 0x99, 0x68, 0x89, 0x6c, 0x73, 0x83, 0xaa, 0xd5, 0x6d, 0x8d, 0x1d, 0x2e, 0x3b, 0x79,
    0x23, 0x93, 0xb5, 0x6d, 0x70, 0xa4, 0x99, 0xc4, 0x2d, 0xbc, 0xc1, 0x2d, 0xd5, 0x86, 0x2a, 0x3a,
    0xa8, 0xc8, 0xc9, 0x2e, 0x21, 0xb9, 0xa0, 0xa0, 0x7a, 0x3e, 0x92, 0xdd, 0xad, 0xf1, 0xa8, 0x90,
    0x90, 0xe0, 0x5f, 0x18, 0x92, 0xa7, 0x0c, 0xf5, 0xe0, 0x86, 0x1b, 0x52, 0x1a, 0x2b, 0x7b, 0x8d,
    0x2a, 0x84, 0xe0, 0x52, 0xab, 0xf4, 0x72, 0xd1, 0xbb, 0x7a, 0xb3, 0xde, 0x08, 0x0e, 0xe0, 0x46,
    0x76, 0x89, 0x2c, 0x33, 0xbe, 0x0d, 0x10, 0x92, 0xc4, 0x45, 0x54, 0x92, 0x03, 0x46, 0x25, 0x3c,
    0x0e, 0x99, 0xe7, 0x64, 0x03, 0x89, 0x36, 0x11, 0x63, 0xa3, 0x6a, 0xb9, 0x73, 0xa8, 0x6e, 0xcf,
    0x8c, 0xe7, 0xa2, 0xd0, 0xce, 0x86, 0x7b, 0x2e, 0xff, 0x5c, 0x4b, 0x5e, 0x88, 0x19, 0x2f, 0x98,
    0x7e, 0xb0, 0x5c, 0xb0, 0x75, 0xab, 0x77, 0x74, 0x8f, 0xc3, 0xba, 0xea, 0x50, 0x0f, 0xc7, 0x55,
    0xab, 0xe3, 0x2a, 0x1b, 0xd8, 0x7a, 0x3e, 0x67, 0x5b, 0xfe, 0x44, 0x74, 0x1d, 0x5d, 0x03, 0xea,
    0xe4, 0xb7, 0xc9, 0xa8, 0xec, 0x07, 0xe4, 0x5c, 0x96, 0xd6, 0x75, 0x9e, 0x9e, 0xc4, 0x1f, 0x4d,
    0xd1, 0xa9, 0x49, 0xaa, 0x3a, 0x4d, 0x4f, 0xcf, 0xbe, 0x7d, 0x7c, 0xb3, 0x49, 0xb7, 0x11, 0x26,
    0xad, 0xa8, 0xef, 0x8c, 0xb7, 0x31, 0x3e, 0x02, 0xb7, 0x4f, 0x45, 0x87, 0x55, 0x65, 0xe4, 0x08,
    0x5e, 0x2f, 0xf3, 0xfc, 0x9d, 0x43, 0x75, 0x57, 0x55, 0xb1, 0x0e, 0x54, 0x85, 0xe4, 0x08, 0x4a,
    0xbf, 0x32, 0x75, 0x28, 0xf3, 0xe8, 0xa3, 0x48, 0x03, 0x41, 0x16, 0x0a, 0xe9, 0x06, 0xa6, 0x37,
    0x77, 0x9f, 0xe5, 0xde, 0xa8, 0x7e, 0x99, 0x09, 0x02, 0x0b, 0x72, 0xc0, 0xb6, 0x92, 0x7b, 0x73,
    0xac, 0x62, 0x1e, 0x8a, 0x16, 0xe4, 0x84, 0xfd, 0xfe, 0xe3, 0x0d, 0x4b, 0x03, 0xbe, 0x61, 0x1a,
    0xe8, 0x09, 0x9d, 0xc6, 0x12, 0x98, 0xb7, 0x0a, 0xcc, 0x7b, 0x0c, 0xc7, 0xab, 0x9b, 0x5e, 0x58,
    0xdc, 0x2a, 0x2c, 0xce, 0xf7, 0xb0, 0xbd, 0xc9, 0xcf, 0x8f, 0xd4, 0x4e, 0xa3, 0xe3, 0x1b, 0x6d,
    0x3b, 0xa7, 0x8e, 0x30, 0xdd, 0x0d, 0x9e, 0xfe, 0xad, 0xcc, 0x19, 0xaf, 0x3c, 0x5b, 0xda, 0xe1,
    0x80, 0x17, 0x08, 0x58, 0xd5, 0xe6, 0x40, 0xa8, 0xd4, 0x9b, 0xd4, 0xfc, 0x15, 0x70, 0xef, 0xfe,
    0x1f, 0xd2, 0xf8, 0xd9, 0xc1
};
#endif

PyTypeObject *init_Qt3DRender_QRenderCapabilities(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QRenderCapabilities_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_Qt3DRender_QRenderCapabilities_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QRenderCapabilities",
        "Qt3DRender::QRenderCapabilities*",
        &Sbk_Qt3DRender_QRenderCapabilities_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QRenderCapabilities >,
        Sbk_Qt3DRender_QRenderCapabilities_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QRenderCapabilities_TypeF(); // references _Sbk_Qt3DRender_QRenderCapabilities_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QRenderCapabilities_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QRenderCapabilities_SignatureBytes, Qt3DRender_QRenderCapabilities_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QRenderCapabilities_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRenderCapabilities_PythonToCpp_QRenderCapabilities_PTR,
        is_QRenderCapabilities_PythonToCpp_QRenderCapabilities_PTR_Convertible,
        QRenderCapabilities_PTR_CppToPython_QRenderCapabilities);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QRenderCapabilities");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QRenderCapabilities*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QRenderCapabilities&");
    Shiboken::Conversions::registerConverterAlias(converter, "QRenderCapabilities");
    Shiboken::Conversions::registerConverterAlias(converter, "QRenderCapabilities*");
    Shiboken::Conversions::registerConverterAlias(converter, "QRenderCapabilities&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QRenderCapabilities).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRenderCapabilitiesWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QRenderCapabilities_TypeF(), &Sbk_Qt3DRender_QRenderCapabilities_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DRender_QRenderCapabilities_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'API'.
    const char *API_Initializer[] = {
        "OpenGL",
        "OpenGLES",
        "Vulkan",
        "DirectX",
        "RHI",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t API_InitializerValues[] = {
        uint8_t(Qt3DRender::QRenderCapabilities::API::OpenGL),   //  0x01  1
        uint8_t(Qt3DRender::QRenderCapabilities::API::OpenGLES), //  0x02  2
        uint8_t(Qt3DRender::QRenderCapabilities::API::Vulkan),   //  0x03  3
        uint8_t(Qt3DRender::QRenderCapabilities::API::DirectX),  //  0x04  4
        uint8_t(Qt3DRender::QRenderCapabilities::API::RHI)       //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QRenderCapabilities_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.API",
        API_Initializer, API_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_API_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QRenderCapabilities::API'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QRenderCapabilities_API_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QRenderCapabilities_API,
            is_Enum_PythonToCpp_Qt3DRender_QRenderCapabilities_API_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QRenderCapabilities::API");
        Shiboken::Conversions::registerConverterAlias(converter, "QRenderCapabilities::API");
        Shiboken::Conversions::registerConverterAlias(converter, "API");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'API' enum.

    // Initialization of enum 'Profile'.
    const char *Profile_Initializer[] = {
        "NoProfile",
        "CoreProfile",
        "CompatibilityProfile",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Profile_InitializerValues[] = {
        uint8_t(Qt3DRender::QRenderCapabilities::Profile::NoProfile),           //  0x00  0
        uint8_t(Qt3DRender::QRenderCapabilities::Profile::CoreProfile),         //  0x01  1
        uint8_t(Qt3DRender::QRenderCapabilities::Profile::CompatibilityProfile) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QRenderCapabilities_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.Profile",
        Profile_Initializer, Profile_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCapabilities_Profile_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QRenderCapabilities::Profile'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QRenderCapabilities_Profile_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QRenderCapabilities_Profile,
            is_Enum_PythonToCpp_Qt3DRender_QRenderCapabilities_Profile_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QRenderCapabilities::Profile");
        Shiboken::Conversions::registerConverterAlias(converter, "QRenderCapabilities::Profile");
        Shiboken::Conversions::registerConverterAlias(converter, "Profile");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Profile' enum.

    qRegisterMetaType< ::Qt3DRender::QRenderCapabilities::API >("QRenderCapabilities::API");
    qRegisterMetaType< ::Qt3DRender::QRenderCapabilities::API >("Qt3DRender::QRenderCapabilities::API");
    qRegisterMetaType< ::Qt3DRender::QRenderCapabilities::Profile >("QRenderCapabilities::Profile");
    qRegisterMetaType< ::Qt3DRender::QRenderCapabilities::Profile >("Qt3DRender::QRenderCapabilities::Profile");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DRender::QRenderCapabilities::staticMetaObject, sizeof(QRenderCapabilitiesWrapper));

    return pyType;
}
