// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qshaderprogram_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DRender/qshaderprogram.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QShaderProgramWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QShaderProgramWrapper::QShaderProgramWrapper(::Qt3DCore::QNode * parent) : Qt3DRender::QShaderProgram(parent)
{
}

void QShaderProgramWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QShaderProgram", funcName);
        return;
    }
}

void QShaderProgramWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QShaderProgram", funcName);
        return;
    }
}

void QShaderProgramWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QShaderProgram", funcName);
        return;
    }
}

void QShaderProgramWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QShaderProgram", funcName);
        return;
    }
}

bool QShaderProgramWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QShaderProgram", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QShaderProgram", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QShaderProgramWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QShaderProgram", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QShaderProgram", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QShaderProgramWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QShaderProgram", funcName);
        return;
    }
}

const QMetaObject *QShaderProgramWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DRender::QShaderProgram::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QShaderProgramWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DRender::QShaderProgram::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QShaderProgramWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QShaderProgramWrapper *>(this));
    return Qt3DRender::QShaderProgram::qt_metacast(_clname);
}

QShaderProgramWrapper::~QShaderProgramWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DRender_QShaderProgram_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DRender::QShaderProgram >()))
        return -1;

    QShaderProgramWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QShaderProgram", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QShaderProgram::QShaderProgram(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QShaderProgram(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QShaderProgram(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QShaderProgram(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QShaderProgramWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QShaderProgramWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DRender::QShaderProgram >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_computeShaderCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // computeShaderCode()const
        QByteArray cppResult = const_cast<const ::Qt3DRender::QShaderProgram *>(cppSelf)->computeShaderCode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // format()const
        Qt3DRender::QShaderProgram::Format cppResult = const_cast<const ::Qt3DRender::QShaderProgram *>(cppSelf)->format();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_Format_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_fragmentShaderCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fragmentShaderCode()const
        QByteArray cppResult = const_cast<const ::Qt3DRender::QShaderProgram *>(cppSelf)->fragmentShaderCode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_geometryShaderCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // geometryShaderCode()const
        QByteArray cppResult = const_cast<const ::Qt3DRender::QShaderProgram *>(cppSelf)->geometryShaderCode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_loadSource(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QShaderProgram::loadSource(QUrl)->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // loadSource(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "loadSource", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // loadSource(QUrl)
            QByteArray cppResult = ::Qt3DRender::QShaderProgram::loadSource(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_log(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // log()const
        QString cppResult = const_cast<const ::Qt3DRender::QShaderProgram *>(cppSelf)->log();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_setComputeShaderCode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgram::setComputeShaderCode(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setComputeShaderCode(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setComputeShaderCode", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setComputeShaderCode(QByteArray)
            cppSelf->setComputeShaderCode(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_setFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgram::setFormat(Qt3DRender::QShaderProgram::Format)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_Format_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFormat(Qt3DRender::QShaderProgram::Format)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFormat", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QShaderProgram::Format cppArg0{Qt3DRender::QShaderProgram::GLSL};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFormat(Qt3DRender::QShaderProgram::Format)
            cppSelf->setFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_setFragmentShaderCode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgram::setFragmentShaderCode(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setFragmentShaderCode(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFragmentShaderCode", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setFragmentShaderCode(QByteArray)
            cppSelf->setFragmentShaderCode(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_setGeometryShaderCode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgram::setGeometryShaderCode(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setGeometryShaderCode(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGeometryShaderCode", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setGeometryShaderCode(QByteArray)
            cppSelf->setGeometryShaderCode(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_setShaderCode(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setShaderCode", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QShaderProgram::setShaderCode(Qt3DRender::QShaderProgram::ShaderType,QByteArray)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_ShaderType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setShaderCode(Qt3DRender::QShaderProgram::ShaderType,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setShaderCode", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QShaderProgram::ShaderType cppArg0{Qt3DRender::QShaderProgram::Vertex};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setShaderCode(Qt3DRender::QShaderProgram::ShaderType,QByteArray)
            cppSelf->setShaderCode(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_setTessellationControlShaderCode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgram::setTessellationControlShaderCode(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setTessellationControlShaderCode(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTessellationControlShaderCode", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTessellationControlShaderCode(QByteArray)
            cppSelf->setTessellationControlShaderCode(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_setTessellationEvaluationShaderCode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgram::setTessellationEvaluationShaderCode(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setTessellationEvaluationShaderCode(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTessellationEvaluationShaderCode", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTessellationEvaluationShaderCode(QByteArray)
            cppSelf->setTessellationEvaluationShaderCode(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_setVertexShaderCode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgram::setVertexShaderCode(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setVertexShaderCode(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVertexShaderCode", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setVertexShaderCode(QByteArray)
            cppSelf->setVertexShaderCode(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_shaderCode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgram::shaderCode(Qt3DRender::QShaderProgram::ShaderType)const->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_ShaderType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // shaderCode(Qt3DRender::QShaderProgram::ShaderType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "shaderCode", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QShaderProgram::ShaderType cppArg0{Qt3DRender::QShaderProgram::Vertex};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // shaderCode(Qt3DRender::QShaderProgram::ShaderType)const
            QByteArray cppResult = const_cast<const ::Qt3DRender::QShaderProgram *>(cppSelf)->shaderCode(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_status(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // status()const
        Qt3DRender::QShaderProgram::Status cppResult = const_cast<const ::Qt3DRender::QShaderProgram *>(cppSelf)->status();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_Status_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_tessellationControlShaderCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tessellationControlShaderCode()const
        QByteArray cppResult = const_cast<const ::Qt3DRender::QShaderProgram *>(cppSelf)->tessellationControlShaderCode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_tessellationEvaluationShaderCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tessellationEvaluationShaderCode()const
        QByteArray cppResult = const_cast<const ::Qt3DRender::QShaderProgram *>(cppSelf)->tessellationEvaluationShaderCode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramFunc_vertexShaderCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vertexShaderCode()const
        QByteArray cppResult = const_cast<const ::Qt3DRender::QShaderProgram *>(cppSelf)->vertexShaderCode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DRender_QShaderProgram_PropertyStrings[] = {
    "computeShaderCode::",
    "format::",
    "fragmentShaderCode::",
    "geometryShaderCode::",
    "log:",
    "status:",
    "tessellationControlShaderCode::",
    "tessellationEvaluationShaderCode::",
    "vertexShaderCode::",
    nullptr // Sentinel
};

static const char *Sbk_Qt3DRender_QShaderProgram_EnumFlagInfo[] = {
    "Format:Enum",
    "ShaderType:Enum",
    "Status:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QShaderProgram_methods[] = {
    {"computeShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_computeShaderCode), METH_NOARGS, nullptr},
    {"format", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_format), METH_NOARGS, nullptr},
    {"fragmentShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_fragmentShaderCode), METH_NOARGS, nullptr},
    {"geometryShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_geometryShaderCode), METH_NOARGS, nullptr},
    {"loadSource", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_loadSource), METH_O|METH_STATIC, nullptr},
    {"log", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_log), METH_NOARGS, nullptr},
    {"setComputeShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_setComputeShaderCode), METH_O, nullptr},
    {"setFormat", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_setFormat), METH_O, nullptr},
    {"setFragmentShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_setFragmentShaderCode), METH_O, nullptr},
    {"setGeometryShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_setGeometryShaderCode), METH_O, nullptr},
    {"setShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_setShaderCode), METH_VARARGS, nullptr},
    {"setTessellationControlShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_setTessellationControlShaderCode), METH_O, nullptr},
    {"setTessellationEvaluationShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_setTessellationEvaluationShaderCode), METH_O, nullptr},
    {"setVertexShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_setVertexShaderCode), METH_O, nullptr},
    {"shaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_shaderCode), METH_O, nullptr},
    {"status", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_status), METH_NOARGS, nullptr},
    {"tessellationControlShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_tessellationControlShaderCode), METH_NOARGS, nullptr},
    {"tessellationEvaluationShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_tessellationEvaluationShaderCode), METH_NOARGS, nullptr},
    {"vertexShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramFunc_vertexShaderCode), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QShaderProgram_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QShaderProgramWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DRender_QShaderProgram_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QShaderProgram_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QShaderProgram_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QShaderProgram_TypeF(void)
{
    return _Sbk_Qt3DRender_QShaderProgram_Type;
}

static PyType_Slot Sbk_Qt3DRender_QShaderProgram_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QShaderProgram_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QShaderProgram_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QShaderProgram_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QShaderProgram_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QShaderProgram_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QShaderProgram_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QShaderProgram",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QShaderProgram_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QShaderProgram_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DRender::QShaderProgram *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Qt3DRender_QShaderProgram_ShaderType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QShaderProgram::ShaderType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QShaderProgram::ShaderType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QShaderProgram_ShaderType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_ShaderType_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QShaderProgram_ShaderType;
    return {};
}

static PyObject *Qt3DRender_QShaderProgram_ShaderType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QShaderProgram::ShaderType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QShaderProgram::ShaderType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_ShaderType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DRender_QShaderProgram_Status(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QShaderProgram::Status>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QShaderProgram::Status *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QShaderProgram_Status_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_Status_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QShaderProgram_Status;
    return {};
}

static PyObject *Qt3DRender_QShaderProgram_Status_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QShaderProgram::Status>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QShaderProgram::Status *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_Status_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DRender_QShaderProgram_Format(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QShaderProgram::Format>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QShaderProgram::Format *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QShaderProgram_Format_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_Format_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QShaderProgram_Format;
    return {};
}

static PyObject *Qt3DRender_QShaderProgram_Format_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QShaderProgram::Format>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QShaderProgram::Format *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_Format_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QShaderProgram_PythonToCpp_QShaderProgram_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QShaderProgram_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QShaderProgram_PythonToCpp_QShaderProgram_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QShaderProgram_TypeF()))
        return QShaderProgram_PythonToCpp_QShaderProgram_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QShaderProgram_PTR_CppToPython_QShaderProgram(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DRender::QShaderProgram *>(const_cast<void *>(cppIn)), Sbk_Qt3DRender_QShaderProgram_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QShaderProgram_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,vertexShaderCode:QByteArray=None,tessellationControlShaderCode:QByteArray=None,tessellationEvaluationShaderCode:QByteArray=None,geometryShaderCode:QByteArray=None,fragmentShaderCode:QByteArray=None,computeShaderCode:QByteArray=None,log:QString=None,status:Qt3DRender.QShaderProgram.Status=None,format:Qt3DRender.QShaderProgram.Format=None)",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.computeShaderCode(self)->PySide6.QtCore.QByteArray",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.format(self)->PySide6.Qt3DRender.Qt3DRender.QShaderProgram.Format",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.fragmentShaderCode(self)->PySide6.QtCore.QByteArray",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.geometryShaderCode(self)->PySide6.QtCore.QByteArray",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.loadSource(sourceUrl:typing.Union[PySide6.QtCore.QUrl, QString])->PySide6.QtCore.QByteArray",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.log(self)->QString",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.setComputeShaderCode(self,computeShaderCode:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.setFormat(self,format:PySide6.Qt3DRender.Qt3DRender.QShaderProgram.Format)",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.setFragmentShaderCode(self,fragmentShaderCode:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.setGeometryShaderCode(self,geometryShaderCode:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.setShaderCode(self,type:PySide6.Qt3DRender.Qt3DRender.QShaderProgram.ShaderType,shaderCode:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.setTessellationControlShaderCode(self,tessellationControlShaderCode:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.setTessellationEvaluationShaderCode(self,tessellationEvaluationShaderCode:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.setVertexShaderCode(self,vertexShaderCode:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.shaderCode(self,type:PySide6.Qt3DRender.Qt3DRender.QShaderProgram.ShaderType)->PySide6.QtCore.QByteArray",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.status(self)->PySide6.Qt3DRender.Qt3DRender.QShaderProgram.Status",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.tessellationControlShaderCode(self)->PySide6.QtCore.QByteArray",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.tessellationEvaluationShaderCode(self)->PySide6.QtCore.QByteArray",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.vertexShaderCode(self)->PySide6.QtCore.QByteArray",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QShaderProgram_SignatureByteSize = 418;
static constexpr uint8_t Qt3DRender_QShaderProgram_SignatureBytes[418] = {
    0x78, 0xda, 0xbd, 0x56, 0x4d, 0x4f, 0x83, 0x40, 0x10, 0xbd, 0xfb, 0x2b, 0x7a, 0xb4, 0x0d, 0x72,
    0x31, 0xf1, 0x40, 0x52, 0x13, 0xad, 0xd6, 0x83, 0x49, 0xa5, 0xd2, 0x7a, 0x31, 0x3d, 0x6c, 0xca,
    0x94, 0x36, 0x59, 0x76, 0xc9, 0x30, 0x54, 0xf9, 0xf7, 0x6e, 0x58, 0xfa, 0x21, 0xac, 0x6b, 0x69,
    0xa0, 0x27, 0x16, 0xf2, 0x66, 0xde, 0x9b, 0x9d, 0xc7, 0xce, 0xfa, 0x79, 0xb0, 0x09, 0xe1, 0xce,
    0x9d, 0xd2, 0xed, 0xd3, 0x3b, 0x88, 0x10, 0xf0, 0xd7, 0x32, 0x58, 0x33, 0xf5, 0xf4, 0x51, 0x46,
    0xc8, 0xe2, 0xeb, 0x14, 0xf8, 0xca, 0x49, 0x18, 0x82, 0x20, 0xcf, 0x3f, 0x0a, 0x1c, 0x49, 0x84,
    0xa3, 0xc5, 0x44, 0x86, 0x30, 0x14, 0x19, 0xe7, 0x09, 0xa1, 0x33, 0xf0, 0x5e, 0x21, 0xff, 0x92,
    0x18, 0xbe, 0x09, 0x9e, 0x0f, 0x27, 0x52, 0x80, 0xb3, 0x05, 0x24, 0xf8, 0xd6, 0xa9, 0x47, 0x0a,
    0xeb, 0x4d, 0x1f, 0x73, 0x82, 0x07, 0x44, 0x56, 0x02, 0x08, 0x52, 0x45, 0xc5, 0x19, 0x6d, 0xa4,
    0x18, 0x49, 0x41, 0x28, 0xf9, 0x89, 0xe8, 0xe7, 0x2d, 0xe3, 0x59, 0xb1, 0xb2, 0x04, 0x44, 0x20,
    0x63, 0x20, 0xcc, 0x2d, 0x90, 0x15, 0xb2, 0x28, 0x56, 0x65, 0x5a, 0x20, 0x4b, 0x19, 0x27, 0x19,
    0x81, 0x05, 0xc1, 0x65, 0xe4, 0x4d, 0x03, 0xc2, 0x8d, 0x88, 0xf4, 0x87, 0x94, 0x18, 0x65, 0xa9,
    0xf7, 0xe7, 0x06, 0xbb, 0x41, 0x01, 0x28, 0x25, 0x48, 0x8c, 0x19, 0x59, 0xc0, 0xe3, 0x02, 0x50,
    0x80, 0xfb, 0x57, 0x7e, 0x83, 0x3e, 0xba, 0x35, 0xe9, 0x45, 0x67, 0xfb, 0x37, 0xf7, 0x87, 0x2c,
    0xba, 0x93, 0xfb, 0x82, 0x9a, 0xe5, 0xd7, 0xd2, 0xeb, 0x49, 0x4f, 0x08, 0xd5, 0x45, 0x35, 0xa4,
    0xab, 0x35, 0xab, 0xe5, 0x7a, 0xea, 0x86, 0x69, 0x99, 0x80, 0x4b, 0x16, 0x06, 0x32, 0xc3, 0xa5,
    0x4a, 0x5c, 0x3c, 0xe6, 0xc8, 0x3d, 0xca, 0x13, 0xe5, 0x1c, 0x77, 0x2e, 0x94, 0x9b, 0x3f, 0xab,
    0x44, 0x0a, 0xe0, 0xf4, 0x4a, 0x73, 0x2d, 0xda, 0x14, 0x12, 0xed, 0x4a, 0x2b, 0x93, 0x37, 0x8b,
    0x4f, 0x41, 0xf1, 0x9b, 0xcc, 0x65, 0xf8, 0x5d, 0xac, 0xf5, 0xed, 0xf5, 0x3b, 0xbd, 0xe5, 0x9a,
    0xe1, 0x60, 0xd1, 0x6f, 0x2c, 0x64, 0x7c, 0x70, 0xe1, 0xee, 0x67, 0x3a, 0xc3, 0x8a, 0x67, 0xf0,
    0x9a, 0xed, 0x68, 0x3a, 0x53, 0xba, 0xde, 0x82, 0x17, 0xb3, 0x71, 0x4d, 0x27, 0x60, 0xd7, 0x52,
    0xaa, 0x12, 0x14, 0x1f, 0x34, 0xeb, 0x87, 0x7e, 0x9b, 0xa9, 0x38, 0x27, 0xbd, 0x9c, 0xee, 0x99,
    0x6d, 0x16, 0x95, 0xa5, 0x58, 0xc7, 0xd5, 0x25, 0x05, 0x9a, 0xc6, 0x5f, 0x5d, 0xa3, 0x71, 0x48,
    0x76, 0x2d, 0xf3, 0xa3, 0x32, 0xf4, 0xb5, 0xac, 0xda, 0x55, 0xa0, 0x5b, 0x19, 0x2d, 0x7a, 0xb0,
    0xbd, 0x33, 0x57, 0xdf, 0x0a, 0xce, 0x9a, 0x96, 0xfa, 0xbe, 0xd0, 0x8c, 0x8e, 0xfe, 0x35, 0x74,
    0x7b, 0xa5, 0xd1, 0x29, 0xde, 0x6c, 0x8f, 0x6e, 0x6b, 0xf2, 0x98, 0x35, 0xfd, 0x0f, 0x59, 0x6a,
    0xfe, 0xad
};
#endif

PyTypeObject *init_Qt3DRender_QShaderProgram(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QShaderProgram_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]))));

    _Sbk_Qt3DRender_QShaderProgram_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QShaderProgram",
        "Qt3DRender::QShaderProgram*",
        &Sbk_Qt3DRender_QShaderProgram_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QShaderProgram >,
        Sbk_Qt3DRender_QShaderProgram_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QShaderProgram_TypeF(); // references _Sbk_Qt3DRender_QShaderProgram_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QShaderProgram_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QShaderProgram_SignatureBytes, Qt3DRender_QShaderProgram_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QShaderProgram_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QShaderProgram_PythonToCpp_QShaderProgram_PTR,
        is_QShaderProgram_PythonToCpp_QShaderProgram_PTR_Convertible,
        QShaderProgram_PTR_CppToPython_QShaderProgram);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QShaderProgram");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QShaderProgram*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QShaderProgram&");
    Shiboken::Conversions::registerConverterAlias(converter, "QShaderProgram");
    Shiboken::Conversions::registerConverterAlias(converter, "QShaderProgram*");
    Shiboken::Conversions::registerConverterAlias(converter, "QShaderProgram&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QShaderProgram).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QShaderProgramWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QShaderProgram_TypeF(), &Sbk_Qt3DRender_QShaderProgram_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DRender_QShaderProgram_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ShaderType'.
    const char *ShaderType_Initializer[] = {
        "Vertex",
        "Fragment",
        "TessellationControl",
        "TessellationEvaluation",
        "Geometry",
        "Compute",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ShaderType_InitializerValues[] = {
        uint8_t(Qt3DRender::QShaderProgram::ShaderType::Vertex),                 //  0x00  0
        uint8_t(Qt3DRender::QShaderProgram::ShaderType::Fragment),               //  0x01  1
        uint8_t(Qt3DRender::QShaderProgram::ShaderType::TessellationControl),    //  0x02  2
        uint8_t(Qt3DRender::QShaderProgram::ShaderType::TessellationEvaluation), //  0x03  3
        uint8_t(Qt3DRender::QShaderProgram::ShaderType::Geometry),               //  0x04  4
        uint8_t(Qt3DRender::QShaderProgram::ShaderType::Compute)                 //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QShaderProgram_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QShaderProgram.ShaderType",
        ShaderType_Initializer, ShaderType_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_ShaderType_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QShaderProgram::ShaderType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QShaderProgram_ShaderType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QShaderProgram_ShaderType,
            is_Enum_PythonToCpp_Qt3DRender_QShaderProgram_ShaderType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QShaderProgram::ShaderType");
        Shiboken::Conversions::registerConverterAlias(converter, "QShaderProgram::ShaderType");
        Shiboken::Conversions::registerConverterAlias(converter, "ShaderType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ShaderType' enum.

    // Initialization of enum 'Status'.
    const char *Status_Initializer[] = {
        "NotReady",
        "Ready",
        "Error",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Status_InitializerValues[] = {
        uint8_t(Qt3DRender::QShaderProgram::Status::NotReady), //  0x00  0
        uint8_t(Qt3DRender::QShaderProgram::Status::Ready),    //  0x01  1
        uint8_t(Qt3DRender::QShaderProgram::Status::Error)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QShaderProgram_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QShaderProgram.Status",
        Status_Initializer, Status_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_Status_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QShaderProgram::Status'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QShaderProgram_Status_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QShaderProgram_Status,
            is_Enum_PythonToCpp_Qt3DRender_QShaderProgram_Status_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QShaderProgram::Status");
        Shiboken::Conversions::registerConverterAlias(converter, "QShaderProgram::Status");
        Shiboken::Conversions::registerConverterAlias(converter, "Status");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Status' enum.

    // Initialization of enum 'Format'.
    const char *Format_Initializer[] = {
        "GLSL",
        "SPIRV",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Format_InitializerValues[] = {
        uint8_t(Qt3DRender::QShaderProgram::Format::GLSL), //  0x00  0
        uint8_t(Qt3DRender::QShaderProgram::Format::SPIRV) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QShaderProgram_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QShaderProgram.Format",
        Format_Initializer, Format_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_Format_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QShaderProgram::Format'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QShaderProgram_Format_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QShaderProgram_Format,
            is_Enum_PythonToCpp_Qt3DRender_QShaderProgram_Format_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QShaderProgram::Format");
        Shiboken::Conversions::registerConverterAlias(converter, "QShaderProgram::Format");
        Shiboken::Conversions::registerConverterAlias(converter, "Format");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Format' enum.

    PySide::Signal::registerSignals(pyType, &::Qt3DRender::QShaderProgram::staticMetaObject);
    qRegisterMetaType< ::Qt3DRender::QShaderProgram::ShaderType >("QShaderProgram::ShaderType");
    qRegisterMetaType< ::Qt3DRender::QShaderProgram::ShaderType >("Qt3DRender::QShaderProgram::ShaderType");
    qRegisterMetaType< ::Qt3DRender::QShaderProgram::Status >("QShaderProgram::Status");
    qRegisterMetaType< ::Qt3DRender::QShaderProgram::Status >("Qt3DRender::QShaderProgram::Status");
    qRegisterMetaType< ::Qt3DRender::QShaderProgram::Format >("QShaderProgram::Format");
    qRegisterMetaType< ::Qt3DRender::QShaderProgram::Format >("Qt3DRender::QShaderProgram::Format");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DRender::QShaderProgram::staticMetaObject, sizeof(QShaderProgramWrapper));

    return pyType;
}
