// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qshaderprogrambuilder_wrapper.h"

// Argument includes
#include <QList>
#include <QStringList>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DRender/qshaderprogram.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QShaderProgramBuilderWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QShaderProgramBuilderWrapper::QShaderProgramBuilderWrapper(::Qt3DCore::QNode * parent) : Qt3DRender::QShaderProgramBuilder(parent)
{
}

void QShaderProgramBuilderWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QShaderProgramBuilder", funcName);
        return;
    }
}

void QShaderProgramBuilderWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QShaderProgramBuilder", funcName);
        return;
    }
}

void QShaderProgramBuilderWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QShaderProgramBuilder", funcName);
        return;
    }
}

void QShaderProgramBuilderWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QShaderProgramBuilder", funcName);
        return;
    }
}

bool QShaderProgramBuilderWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QShaderProgramBuilder", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QShaderProgramBuilder", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QShaderProgramBuilderWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QShaderProgramBuilder", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QShaderProgramBuilder", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QShaderProgramBuilderWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QShaderProgramBuilder", funcName);
        return;
    }
}

const QMetaObject *QShaderProgramBuilderWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DRender::QShaderProgramBuilder::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QShaderProgramBuilderWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DRender::QShaderProgramBuilder::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QShaderProgramBuilderWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QShaderProgramBuilderWrapper *>(this));
    return Qt3DRender::QShaderProgramBuilder::qt_metacast(_clname);
}

QShaderProgramBuilderWrapper::~QShaderProgramBuilderWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DRender_QShaderProgramBuilder_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DRender::QShaderProgramBuilder >()))
        return -1;

    QShaderProgramBuilderWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QShaderProgramBuilder", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QShaderProgramBuilder::QShaderProgramBuilder(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QShaderProgramBuilder(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QShaderProgramBuilder(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QShaderProgramBuilder(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QShaderProgramBuilderWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QShaderProgramBuilderWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DRender::QShaderProgramBuilder >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_computeShaderCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // computeShaderCode()const
        QByteArray cppResult = const_cast<const ::Qt3DRender::QShaderProgramBuilder *>(cppSelf)->computeShaderCode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_computeShaderGraph(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // computeShaderGraph()const
        QUrl cppResult = const_cast<const ::Qt3DRender::QShaderProgramBuilder *>(cppSelf)->computeShaderGraph();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_enabledLayers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // enabledLayers()const
        QStringList cppResult = const_cast<const ::Qt3DRender::QShaderProgramBuilder *>(cppSelf)->enabledLayers();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_fragmentShaderCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fragmentShaderCode()const
        QByteArray cppResult = const_cast<const ::Qt3DRender::QShaderProgramBuilder *>(cppSelf)->fragmentShaderCode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_fragmentShaderGraph(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fragmentShaderGraph()const
        QUrl cppResult = const_cast<const ::Qt3DRender::QShaderProgramBuilder *>(cppSelf)->fragmentShaderGraph();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_geometryShaderCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // geometryShaderCode()const
        QByteArray cppResult = const_cast<const ::Qt3DRender::QShaderProgramBuilder *>(cppSelf)->geometryShaderCode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_geometryShaderGraph(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // geometryShaderGraph()const
        QUrl cppResult = const_cast<const ::Qt3DRender::QShaderProgramBuilder *>(cppSelf)->geometryShaderGraph();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_setComputeShaderGraph(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgramBuilder::setComputeShaderGraph(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setComputeShaderGraph(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setComputeShaderGraph", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setComputeShaderGraph(QUrl)
            cppSelf->setComputeShaderGraph(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_setEnabledLayers(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgramBuilder::setEnabledLayers(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setEnabledLayers(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEnabledLayers", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEnabledLayers(QStringList)
            cppSelf->setEnabledLayers(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_setFragmentShaderGraph(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgramBuilder::setFragmentShaderGraph(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setFragmentShaderGraph(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFragmentShaderGraph", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setFragmentShaderGraph(QUrl)
            cppSelf->setFragmentShaderGraph(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_setGeometryShaderGraph(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgramBuilder::setGeometryShaderGraph(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setGeometryShaderGraph(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGeometryShaderGraph", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setGeometryShaderGraph(QUrl)
            cppSelf->setGeometryShaderGraph(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_setShaderProgram(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgramBuilder::setShaderProgram(Qt3DRender::QShaderProgram*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), (pyArg)))) {
        overloadId = 0; // setShaderProgram(Qt3DRender::QShaderProgram*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShaderProgram", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QShaderProgram *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShaderProgram(Qt3DRender::QShaderProgram*)
            cppSelf->setShaderProgram(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_setTessellationControlShaderGraph(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgramBuilder::setTessellationControlShaderGraph(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setTessellationControlShaderGraph(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTessellationControlShaderGraph", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTessellationControlShaderGraph(QUrl)
            cppSelf->setTessellationControlShaderGraph(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_setTessellationEvaluationShaderGraph(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgramBuilder::setTessellationEvaluationShaderGraph(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setTessellationEvaluationShaderGraph(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTessellationEvaluationShaderGraph", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTessellationEvaluationShaderGraph(QUrl)
            cppSelf->setTessellationEvaluationShaderGraph(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_setVertexShaderGraph(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderProgramBuilder::setVertexShaderGraph(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setVertexShaderGraph(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVertexShaderGraph", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setVertexShaderGraph(QUrl)
            cppSelf->setVertexShaderGraph(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_shaderProgram(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shaderProgram()const
        Qt3DRender::QShaderProgram * cppResult = const_cast<const ::Qt3DRender::QShaderProgramBuilder *>(cppSelf)->shaderProgram();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgram_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_tessellationControlShaderCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tessellationControlShaderCode()const
        QByteArray cppResult = const_cast<const ::Qt3DRender::QShaderProgramBuilder *>(cppSelf)->tessellationControlShaderCode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_tessellationControlShaderGraph(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tessellationControlShaderGraph()const
        QUrl cppResult = const_cast<const ::Qt3DRender::QShaderProgramBuilder *>(cppSelf)->tessellationControlShaderGraph();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_tessellationEvaluationShaderCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tessellationEvaluationShaderCode()const
        QByteArray cppResult = const_cast<const ::Qt3DRender::QShaderProgramBuilder *>(cppSelf)->tessellationEvaluationShaderCode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_tessellationEvaluationShaderGraph(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tessellationEvaluationShaderGraph()const
        QUrl cppResult = const_cast<const ::Qt3DRender::QShaderProgramBuilder *>(cppSelf)->tessellationEvaluationShaderGraph();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_vertexShaderCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vertexShaderCode()const
        QByteArray cppResult = const_cast<const ::Qt3DRender::QShaderProgramBuilder *>(cppSelf)->vertexShaderCode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderProgramBuilderFunc_vertexShaderGraph(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vertexShaderGraph()const
        QUrl cppResult = const_cast<const ::Qt3DRender::QShaderProgramBuilder *>(cppSelf)->vertexShaderGraph();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DRender_QShaderProgramBuilder_PropertyStrings[] = {
    "computeShaderCode:",
    "computeShaderGraph::",
    "enabledLayers::",
    "fragmentShaderCode:",
    "fragmentShaderGraph::",
    "geometryShaderCode:",
    "geometryShaderGraph::",
    "shaderProgram::",
    "tessellationControlShaderCode:",
    "tessellationControlShaderGraph::",
    "tessellationEvaluationShaderCode:",
    "tessellationEvaluationShaderGraph::",
    "vertexShaderCode:",
    "vertexShaderGraph::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QShaderProgramBuilder_methods[] = {
    {"computeShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_computeShaderCode), METH_NOARGS, nullptr},
    {"computeShaderGraph", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_computeShaderGraph), METH_NOARGS, nullptr},
    {"enabledLayers", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_enabledLayers), METH_NOARGS, nullptr},
    {"fragmentShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_fragmentShaderCode), METH_NOARGS, nullptr},
    {"fragmentShaderGraph", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_fragmentShaderGraph), METH_NOARGS, nullptr},
    {"geometryShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_geometryShaderCode), METH_NOARGS, nullptr},
    {"geometryShaderGraph", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_geometryShaderGraph), METH_NOARGS, nullptr},
    {"setComputeShaderGraph", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_setComputeShaderGraph), METH_O, nullptr},
    {"setEnabledLayers", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_setEnabledLayers), METH_O, nullptr},
    {"setFragmentShaderGraph", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_setFragmentShaderGraph), METH_O, nullptr},
    {"setGeometryShaderGraph", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_setGeometryShaderGraph), METH_O, nullptr},
    {"setShaderProgram", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_setShaderProgram), METH_O, nullptr},
    {"setTessellationControlShaderGraph", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_setTessellationControlShaderGraph), METH_O, nullptr},
    {"setTessellationEvaluationShaderGraph", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_setTessellationEvaluationShaderGraph), METH_O, nullptr},
    {"setVertexShaderGraph", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_setVertexShaderGraph), METH_O, nullptr},
    {"shaderProgram", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_shaderProgram), METH_NOARGS, nullptr},
    {"tessellationControlShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_tessellationControlShaderCode), METH_NOARGS, nullptr},
    {"tessellationControlShaderGraph", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_tessellationControlShaderGraph), METH_NOARGS, nullptr},
    {"tessellationEvaluationShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_tessellationEvaluationShaderCode), METH_NOARGS, nullptr},
    {"tessellationEvaluationShaderGraph", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_tessellationEvaluationShaderGraph), METH_NOARGS, nullptr},
    {"vertexShaderCode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_vertexShaderCode), METH_NOARGS, nullptr},
    {"vertexShaderGraph", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderProgramBuilderFunc_vertexShaderGraph), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QShaderProgramBuilder_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QShaderProgramBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QShaderProgramBuilderWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DRender_QShaderProgramBuilder_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QShaderProgramBuilder_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QShaderProgramBuilder_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QShaderProgramBuilder_TypeF(void)
{
    return _Sbk_Qt3DRender_QShaderProgramBuilder_Type;
}

static PyType_Slot Sbk_Qt3DRender_QShaderProgramBuilder_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QShaderProgramBuilder_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QShaderProgramBuilder_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QShaderProgramBuilder_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QShaderProgramBuilder_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QShaderProgramBuilder_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QShaderProgramBuilder_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QShaderProgramBuilder_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QShaderProgramBuilder_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DRender::QShaderProgramBuilder *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QShaderProgramBuilder_PythonToCpp_QShaderProgramBuilder_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QShaderProgramBuilder_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QShaderProgramBuilder_PythonToCpp_QShaderProgramBuilder_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QShaderProgramBuilder_TypeF()))
        return QShaderProgramBuilder_PythonToCpp_QShaderProgramBuilder_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QShaderProgramBuilder_PTR_CppToPython_QShaderProgramBuilder(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DRender::QShaderProgramBuilder *>(const_cast<void *>(cppIn)), Sbk_Qt3DRender_QShaderProgramBuilder_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QShaderProgramBuilder_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,shaderProgram:Qt3DRender.QShaderProgram=None,enabledLayers:QStringList=None,vertexShaderGraph:QUrl=None,tessellationControlShaderGraph:QUrl=None,tessellationEvaluationShaderGraph:QUrl=None,geometryShaderGraph:QUrl=None,fragmentShaderGraph:QUrl=None,computeShaderGraph:QUrl=None,vertexShaderCode:QByteArray=None,tessellationControlShaderCode:QByteArray=None,tessellationEvaluationShaderCode:QByteArray=None,geometryShaderCode:QByteArray=None,fragmentShaderCode:QByteArray=None,computeShaderCode:QByteArray=None)",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.computeShaderCode(self)->PySide6.QtCore.QByteArray",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.computeShaderGraph(self)->PySide6.QtCore.QUrl",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.enabledLayers(self)->QStringList",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.fragmentShaderCode(self)->PySide6.QtCore.QByteArray",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.fragmentShaderGraph(self)->PySide6.QtCore.QUrl",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.geometryShaderCode(self)->PySide6.QtCore.QByteArray",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.geometryShaderGraph(self)->PySide6.QtCore.QUrl",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.setComputeShaderGraph(self,computeShaderGraph:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.setEnabledLayers(self,layers:QStringList)",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.setFragmentShaderGraph(self,fragmentShaderGraph:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.setGeometryShaderGraph(self,geometryShaderGraph:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.setShaderProgram(self,program:PySide6.Qt3DRender.Qt3DRender.QShaderProgram)",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.setTessellationControlShaderGraph(self,tessellationControlShaderGraph:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.setTessellationEvaluationShaderGraph(self,tessellationEvaluationShaderGraph:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.setVertexShaderGraph(self,vertexShaderGraph:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.shaderProgram(self)->PySide6.Qt3DRender.Qt3DRender.QShaderProgram",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.tessellationControlShaderCode(self)->PySide6.QtCore.QByteArray",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.tessellationControlShaderGraph(self)->PySide6.QtCore.QUrl",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.tessellationEvaluationShaderCode(self)->PySide6.QtCore.QByteArray",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.tessellationEvaluationShaderGraph(self)->PySide6.QtCore.QUrl",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.vertexShaderCode(self)->PySide6.QtCore.QByteArray",
    "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder.vertexShaderGraph(self)->PySide6.QtCore.QUrl",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QShaderProgramBuilder_SignatureByteSize = 440;
static constexpr uint8_t Qt3DRender_QShaderProgramBuilder_SignatureBytes[440] = {
    0x78, 0xda, 0xbd, 0x56, 0xc1, 0x4e, 0xc3, 0x30, 0x0c, 0xbd, 0xf3, 0x15, 0x1c, 0x19, 0x2a, 0xbb,
    0x20, 0x71, 0xa8, 0x34, 0x24, 0x36, 0xc6, 0x0e, 0x4c, 0xa3, 0x65, 0x1b, 0x17, 0xc4, 0x21, 0x50,
    0xaf, 0xab, 0x94, 0x26, 0x95, 0x9b, 0x0e, 0xf2, 0xf7, 0x44, 0xeb, 0x80, 0x76, 0x75, 0x17, 0xad,
    0xac, 0x3d, 0x2d, 0xab, 0x1d, 0xdb, 0xcf, 0x7e, 0xb1, 0xed, 0xe9, 0x79, 0x14, 0xc0, 0x4d, 0xdf,
    0x57, 0xd7, 0xf7, 0xcf, 0x20, 0x02, 0xc0, 0xd2, 0x71, 0xbe, 0x66, 0xe6, 0xd7, 0x43, 0x19, 0x22,
    0x8b, 0x87, 0x59, 0xc4, 0xcd, 0xbf, 0x8b, 0x14, 0xf8, 0xca, 0x49, 0x18, 0x82, 0x50, 0xae, 0x57,
    0xb8, 0x3f, 0x92, 0x08, 0x85, 0xc3, 0x4c, 0x06, 0x30, 0x10, 0x19, 0xe7, 0x89, 0x42, 0xe7, 0xd2,
    0x7d, 0x04, 0xfd, 0x29, 0x31, 0x78, 0x12, 0x5c, 0x0f, 0x66, 0x52, 0x80, 0x93, 0x16, 0x6d, 0xbb,
    0xb5, 0x5e, 0x73, 0x65, 0x10, 0xec, 0x9d, 0x43, 0x30, 0x65, 0x1a, 0x30, 0x75, 0xfd, 0xb9, 0xc2,
    0x48, 0x84, 0xd3, 0x28, 0x55, 0xb9, 0x78, 0x03, 0xa8, 0xe0, 0x2b, 0xbf, 0x37, 0x41, 0x96, 0xac,
    0x5d, 0x7f, 0x89, 0x3c, 0x97, 0x29, 0x48, 0x4d, 0xc4, 0x9c, 0xa9, 0x48, 0x8a, 0x91, 0x14, 0x0a,
    0x25, 0xb7, 0x2b, 0x8e, 0x37, 0x8c, 0x67, 0xdb, 0x13, 0xad, 0x1b, 0x82, 0x8c, 0x41, 0xa1, 0xa6,
    0xa5, 0x2b, 0x64, 0x61, 0x6c, 0xd2, 0x43, 0x4b, 0x3f, 0x64, 0x9c, 0x64, 0x0a, 0x68, 0x61, 0x11,
    0xc9, 0xc8, 0x64, 0xd0, 0xf5, 0x87, 0x5a, 0xc1, 0x1d, 0x22, 0xd3, 0x16, 0x38, 0x56, 0xed, 0x7d,
    0x4c, 0xe4, 0x85, 0x32, 0x30, 0x52, 0xa5, 0x8c, 0x8e, 0x54, 0x29, 0x41, 0xa4, 0x34, 0x7a, 0x67,
    0xde, 0xf1, 0xcc, 0xeb, 0x57, 0xcc, 0x6e, 0xb9, 0xd8, 0xbb, 0xba, 0xfd, 0x33, 0x96, 0x73, 0xef,
    0xd7, 0xd9, 0xff, 0xdd, 0x6c, 0x0b, 0x54, 0xe7, 0xc7, 0x94, 0xad, 0x91, 0x87, 0x12, 0x9d, 0x7f,
    0x8c, 0x17, 0x58, 0xdd, 0xc8, 0x68, 0xb5, 0x2e, 0xed, 0xa4, 0x87, 0x60, 0xf7, 0xa9, 0xf3, 0x53,
    0x65, 0x61, 0x3b, 0x50, 0x88, 0x67, 0x7c, 0x6a, 0x28, 0x29, 0x18, 0x03, 0x24, 0x9f, 0xa8, 0x46,
    0xa0, 0x74, 0x62, 0x28, 0xd0, 0x5f, 0x0a, 0xf3, 0x4a, 0x5f, 0x89, 0x10, 0x9c, 0xf3, 0x1d, 0x4b,
    0xde, 0x7a, 0x4d, 0xa3, 0x19, 0x57, 0xb8, 0xe7, 0xf0, 0x4a, 0x5b, 0x6d, 0x6c, 0xfd, 0xa1, 0x86,
    0x1c, 0x64, 0x4f, 0xec, 0x00, 0xed, 0xa4, 0xa6, 0xc2, 0x64, 0x07, 0xef, 0x20, 0x9e, 0xd2, 0xf7,
    0xdd, 0x28, 0xdd, 0x8d, 0xc0, 0x63, 0x2c, 0x36, 0xf6, 0xbf, 0x38, 0x38, 0x0d, 0xf3, 0x80, 0x2c,
    0x13, 0xb3, 0x83, 0x2c, 0x2d, 0x6c, 0xa3, 0xb8, 0x1a, 0x28, 0x3d, 0xb1, 0x3b, 0x88, 0xf5, 0x65,
    0x7f, 0xf7, 0xc8, 0x63, 0xab, 0xae, 0x24, 0xad, 0xc7, 0x52, 0xa1, 0x56, 0xa9, 0x8d, 0xd9, 0x0d,
    0x35, 0xf2, 0x7a, 0x70, 0x1f, 0x69, 0xa7, 0x6b, 0x2b, 0x3b, 0x87, 0x4f, 0xd8, 0xc0, 0x6d, 0x2b,
    0x54, 0xfb, 0x18, 0xeb, 0x5f, 0xc0, 0x09, 0x61, 0xee, 0x2f, 0x9e, 0xed, 0xc0, 0xda, 0x90, 0x8f,
    0xa5, 0x06, 0xc6, 0x37, 0x96, 0x9d, 0xa1, 0xe0
};
#endif

PyTypeObject *init_Qt3DRender_QShaderProgramBuilder(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QShaderProgramBuilder_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]))));

    _Sbk_Qt3DRender_QShaderProgramBuilder_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QShaderProgramBuilder",
        "Qt3DRender::QShaderProgramBuilder*",
        &Sbk_Qt3DRender_QShaderProgramBuilder_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QShaderProgramBuilder >,
        Sbk_Qt3DRender_QShaderProgramBuilder_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QShaderProgramBuilder_TypeF(); // references _Sbk_Qt3DRender_QShaderProgramBuilder_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QShaderProgramBuilder_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QShaderProgramBuilder_SignatureBytes, Qt3DRender_QShaderProgramBuilder_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QShaderProgramBuilder_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderProgramBuilder_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QShaderProgramBuilder_PythonToCpp_QShaderProgramBuilder_PTR,
        is_QShaderProgramBuilder_PythonToCpp_QShaderProgramBuilder_PTR_Convertible,
        QShaderProgramBuilder_PTR_CppToPython_QShaderProgramBuilder);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QShaderProgramBuilder");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QShaderProgramBuilder*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QShaderProgramBuilder&");
    Shiboken::Conversions::registerConverterAlias(converter, "QShaderProgramBuilder");
    Shiboken::Conversions::registerConverterAlias(converter, "QShaderProgramBuilder*");
    Shiboken::Conversions::registerConverterAlias(converter, "QShaderProgramBuilder&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QShaderProgramBuilder).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QShaderProgramBuilderWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QShaderProgramBuilder_TypeF(), &Sbk_Qt3DRender_QShaderProgramBuilder_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Qt3DRender::QShaderProgramBuilder::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DRender::QShaderProgramBuilder::staticMetaObject, sizeof(QShaderProgramBuilderWrapper));

    return pyType;
}
