// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qstenciloperationarguments_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <Qt3DRender/qstenciloperationarguments.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QStencilOperationArgumentsWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QStencilOperationArgumentsWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStencilOperationArguments", funcName);
        return;
    }
}

void QStencilOperationArgumentsWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStencilOperationArguments", funcName);
        return;
    }
}

void QStencilOperationArgumentsWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStencilOperationArguments", funcName);
        return;
    }
}

void QStencilOperationArgumentsWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStencilOperationArguments", funcName);
        return;
    }
}

bool QStencilOperationArgumentsWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStencilOperationArguments", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStencilOperationArguments", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QStencilOperationArgumentsWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStencilOperationArguments", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStencilOperationArguments", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QStencilOperationArgumentsWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QStencilOperationArguments", funcName);
        return;
    }
}

const QMetaObject *QStencilOperationArgumentsWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DRender::QStencilOperationArguments::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QStencilOperationArgumentsWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DRender::QStencilOperationArguments::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QStencilOperationArgumentsWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QStencilOperationArgumentsWrapper *>(this));
    return Qt3DRender::QStencilOperationArguments::qt_metacast(_clname);
}

QStencilOperationArgumentsWrapper::~QStencilOperationArgumentsWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_Qt3DRender_QStencilOperationArgumentsFunc_allTestsPassOperation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QStencilOperationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // allTestsPassOperation()const
        Qt3DRender::QStencilOperationArguments::Operation cppResult = const_cast<const ::Qt3DRender::QStencilOperationArguments *>(cppSelf)->allTestsPassOperation();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_Operation_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QStencilOperationArgumentsFunc_depthTestFailureOperation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QStencilOperationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // depthTestFailureOperation()const
        Qt3DRender::QStencilOperationArguments::Operation cppResult = const_cast<const ::Qt3DRender::QStencilOperationArguments *>(cppSelf)->depthTestFailureOperation();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_Operation_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QStencilOperationArgumentsFunc_faceMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QStencilOperationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // faceMode()const
        Qt3DRender::QStencilOperationArguments::FaceMode cppResult = const_cast<const ::Qt3DRender::QStencilOperationArguments *>(cppSelf)->faceMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_FaceMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QStencilOperationArgumentsFunc_setAllTestsPassOperation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QStencilOperationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStencilOperationArguments::setAllTestsPassOperation(Qt3DRender::QStencilOperationArguments::Operation)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_Operation_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAllTestsPassOperation(Qt3DRender::QStencilOperationArguments::Operation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAllTestsPassOperation", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QStencilOperationArguments::Operation cppArg0{Qt3DRender::QStencilOperationArguments::Zero};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAllTestsPassOperation(Qt3DRender::QStencilOperationArguments::Operation)
            cppSelf->setAllTestsPassOperation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QStencilOperationArgumentsFunc_setDepthTestFailureOperation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QStencilOperationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStencilOperationArguments::setDepthTestFailureOperation(Qt3DRender::QStencilOperationArguments::Operation)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_Operation_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDepthTestFailureOperation(Qt3DRender::QStencilOperationArguments::Operation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDepthTestFailureOperation", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QStencilOperationArguments::Operation cppArg0{Qt3DRender::QStencilOperationArguments::Zero};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthTestFailureOperation(Qt3DRender::QStencilOperationArguments::Operation)
            cppSelf->setDepthTestFailureOperation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QStencilOperationArgumentsFunc_setStencilTestFailureOperation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QStencilOperationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStencilOperationArguments::setStencilTestFailureOperation(Qt3DRender::QStencilOperationArguments::Operation)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_Operation_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setStencilTestFailureOperation(Qt3DRender::QStencilOperationArguments::Operation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStencilTestFailureOperation", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QStencilOperationArguments::Operation cppArg0{Qt3DRender::QStencilOperationArguments::Zero};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStencilTestFailureOperation(Qt3DRender::QStencilOperationArguments::Operation)
            cppSelf->setStencilTestFailureOperation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QStencilOperationArgumentsFunc_stencilTestFailureOperation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QStencilOperationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stencilTestFailureOperation()const
        Qt3DRender::QStencilOperationArguments::Operation cppResult = const_cast<const ::Qt3DRender::QStencilOperationArguments *>(cppSelf)->stencilTestFailureOperation();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_Operation_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DRender_QStencilOperationArguments_PropertyStrings[] = {
    "allTestsPassOperation::",
    "depthTestFailureOperation::",
    "faceMode:",
    "stencilTestFailureOperation::",
    nullptr // Sentinel
};

static const char *Sbk_Qt3DRender_QStencilOperationArguments_EnumFlagInfo[] = {
    "FaceMode:Enum",
    "Operation:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QStencilOperationArguments_methods[] = {
    {"allTestsPassOperation", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QStencilOperationArgumentsFunc_allTestsPassOperation), METH_NOARGS, nullptr},
    {"depthTestFailureOperation", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QStencilOperationArgumentsFunc_depthTestFailureOperation), METH_NOARGS, nullptr},
    {"faceMode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QStencilOperationArgumentsFunc_faceMode), METH_NOARGS, nullptr},
    {"setAllTestsPassOperation", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QStencilOperationArgumentsFunc_setAllTestsPassOperation), METH_O, nullptr},
    {"setDepthTestFailureOperation", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QStencilOperationArgumentsFunc_setDepthTestFailureOperation), METH_O, nullptr},
    {"setStencilTestFailureOperation", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QStencilOperationArgumentsFunc_setStencilTestFailureOperation), METH_O, nullptr},
    {"stencilTestFailureOperation", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QStencilOperationArgumentsFunc_stencilTestFailureOperation), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QStencilOperationArguments_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QStencilOperationArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QStencilOperationArgumentsWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DRender_QStencilOperationArguments_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QStencilOperationArguments_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QStencilOperationArguments_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QStencilOperationArguments_TypeF(void)
{
    return _Sbk_Qt3DRender_QStencilOperationArguments_Type;
}

static PyType_Slot Sbk_Qt3DRender_QStencilOperationArguments_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QStencilOperationArguments_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QStencilOperationArguments_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QStencilOperationArguments_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QStencilOperationArguments_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QStencilOperationArguments_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QStencilOperationArguments_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QStencilOperationArguments_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DRender::QStencilOperationArguments *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Qt3DRender_QStencilOperationArguments_FaceMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QStencilOperationArguments::FaceMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QStencilOperationArguments::FaceMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QStencilOperationArguments_FaceMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_FaceMode_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QStencilOperationArguments_FaceMode;
    return {};
}

static PyObject *Qt3DRender_QStencilOperationArguments_FaceMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QStencilOperationArguments::FaceMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QStencilOperationArguments::FaceMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_FaceMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DRender_QStencilOperationArguments_Operation(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QStencilOperationArguments::Operation>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QStencilOperationArguments::Operation *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QStencilOperationArguments_Operation_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_Operation_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QStencilOperationArguments_Operation;
    return {};
}

static PyObject *Qt3DRender_QStencilOperationArguments_Operation_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QStencilOperationArguments::Operation>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QStencilOperationArguments::Operation *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_Operation_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStencilOperationArguments_PythonToCpp_QStencilOperationArguments_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QStencilOperationArguments_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStencilOperationArguments_PythonToCpp_QStencilOperationArguments_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QStencilOperationArguments_TypeF()))
        return QStencilOperationArguments_PythonToCpp_QStencilOperationArguments_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStencilOperationArguments_PTR_CppToPython_QStencilOperationArguments(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DRender::QStencilOperationArguments *>(const_cast<void *>(cppIn)), Sbk_Qt3DRender_QStencilOperationArguments_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QStencilOperationArguments_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.allTestsPassOperation(self)->PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.Operation",
    "PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.depthTestFailureOperation(self)->PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.Operation",
    "PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.faceMode(self)->PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.FaceMode",
    "PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.setAllTestsPassOperation(self,operation:PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.Operation)",
    "PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.setDepthTestFailureOperation(self,operation:PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.Operation)",
    "PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.setStencilTestFailureOperation(self,operation:PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.Operation)",
    "PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.stencilTestFailureOperation(self)->PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.Operation",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QStencilOperationArguments_SignatureByteSize = 153;
static constexpr uint8_t Qt3DRender_QStencilOperationArguments_SignatureBytes[153] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x31, 0x76, 0x09, 0x4a,
    0xcd, 0x4b, 0x49, 0x2d, 0x42, 0x61, 0x06, 0x97, 0xa4, 0xe6, 0x25, 0x67, 0xe6, 0xf8, 0x17, 0xa4,
    0x16, 0x25, 0x96, 0x64, 0xe6, 0xe7, 0x39, 0x16, 0xa5, 0x97, 0xe6, 0xa6, 0xe6, 0x95, 0x14, 0xeb,
    0x25, 0xe6, 0xe4, 0x84, 0xa4, 0x16, 0x97, 0x14, 0x07, 0x24, 0x16, 0x17, 0xc3, 0xa5, 0x35, 0x8a,
    0x53, 0x73, 0xd2, 0x34, 0x75, 0xed, 0x02, 0xc8, 0x35, 0x15, 0x2e, 0xc4, 0x45, 0xb6, 0x11, 0x29,
    0xa9, 0x05, 0x25, 0x19, 0x20, 0xa7, 0xb9, 0x25, 0x66, 0xe6, 0x94, 0x16, 0xa5, 0x0e, 0x2a, 0xc7,
    0xa5, 0x25, 0x26, 0xa7, 0xfa, 0xe6, 0xa7, 0xa4, 0x52, 0xec, 0x16, 0x37, 0xa8, 0x41, 0xe4, 0x3b,
    0xa5, 0x38, 0xb5, 0xc4, 0x11, 0x67, 0x1c, 0xea, 0xe4, 0xc3, 0xb8, 0x56, 0x94, 0x07, 0x97, 0x26,
    0x45, 0x8e, 0x74, 0xc1, 0x1b, 0x9f, 0x83, 0xc8, 0xa1, 0x50, 0xc9, 0xc1, 0xef, 0x54, 0x02, 0xee,
    0xa4, 0x4e, 0x16, 0x01, 0x00, 0x3a, 0x67, 0x9d, 0xb4
};
#endif

PyTypeObject *init_Qt3DRender_QStencilOperationArguments(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QStencilOperationArguments_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_Qt3DRender_QStencilOperationArguments_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QStencilOperationArguments",
        "Qt3DRender::QStencilOperationArguments*",
        &Sbk_Qt3DRender_QStencilOperationArguments_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QStencilOperationArguments >,
        Sbk_Qt3DRender_QStencilOperationArguments_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QStencilOperationArguments_TypeF(); // references _Sbk_Qt3DRender_QStencilOperationArguments_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QStencilOperationArguments_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QStencilOperationArguments_SignatureBytes, Qt3DRender_QStencilOperationArguments_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QStencilOperationArguments_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStencilOperationArguments_PythonToCpp_QStencilOperationArguments_PTR,
        is_QStencilOperationArguments_PythonToCpp_QStencilOperationArguments_PTR_Convertible,
        QStencilOperationArguments_PTR_CppToPython_QStencilOperationArguments);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QStencilOperationArguments");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QStencilOperationArguments*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QStencilOperationArguments&");
    Shiboken::Conversions::registerConverterAlias(converter, "QStencilOperationArguments");
    Shiboken::Conversions::registerConverterAlias(converter, "QStencilOperationArguments*");
    Shiboken::Conversions::registerConverterAlias(converter, "QStencilOperationArguments&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QStencilOperationArguments).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QStencilOperationArgumentsWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QStencilOperationArguments_TypeF(), &Sbk_Qt3DRender_QStencilOperationArguments_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DRender_QStencilOperationArguments_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'FaceMode'.
    const char *FaceMode_Initializer[] = {
        "Front",
        "Back",
        "FrontAndBack",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t FaceMode_InitializerValues[] = {
        uint16_t(Qt3DRender::QStencilOperationArguments::FaceMode::Front),       //  0x0404  1028
        uint16_t(Qt3DRender::QStencilOperationArguments::FaceMode::Back),        //  0x0405  1029
        uint16_t(Qt3DRender::QStencilOperationArguments::FaceMode::FrontAndBack) //  0x0408  1032
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QStencilOperationArguments_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.FaceMode",
        FaceMode_Initializer, FaceMode_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_FaceMode_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QStencilOperationArguments::FaceMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QStencilOperationArguments_FaceMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QStencilOperationArguments_FaceMode,
            is_Enum_PythonToCpp_Qt3DRender_QStencilOperationArguments_FaceMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QStencilOperationArguments::FaceMode");
        Shiboken::Conversions::registerConverterAlias(converter, "QStencilOperationArguments::FaceMode");
        Shiboken::Conversions::registerConverterAlias(converter, "FaceMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FaceMode' enum.

    // Initialization of enum 'Operation'.
    const char *Operation_Initializer[] = {
        "Zero",
        "Keep",
        "Replace",
        "Increment",
        "Decrement",
        "IncrementWrap",
        "DecrementWrap",
        "Invert",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Operation_InitializerValues[] = {
        uint16_t(Qt3DRender::QStencilOperationArguments::Operation::Zero),          //  0x0000  0
        uint16_t(Qt3DRender::QStencilOperationArguments::Operation::Keep),          //  0x1e00  7680
        uint16_t(Qt3DRender::QStencilOperationArguments::Operation::Replace),       //  0x1e01  7681
        uint16_t(Qt3DRender::QStencilOperationArguments::Operation::Increment),     //  0x1e02  7682
        uint16_t(Qt3DRender::QStencilOperationArguments::Operation::Decrement),     //  0x1e03  7683
        uint16_t(Qt3DRender::QStencilOperationArguments::Operation::IncrementWrap), //  0x8507  34055
        uint16_t(Qt3DRender::QStencilOperationArguments::Operation::DecrementWrap), //  0x8508  34056
        uint16_t(Qt3DRender::QStencilOperationArguments::Operation::Invert)         //  0x150a  5386
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QStencilOperationArguments_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.Operation",
        Operation_Initializer, Operation_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilOperationArguments_Operation_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QStencilOperationArguments::Operation'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QStencilOperationArguments_Operation_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QStencilOperationArguments_Operation,
            is_Enum_PythonToCpp_Qt3DRender_QStencilOperationArguments_Operation_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QStencilOperationArguments::Operation");
        Shiboken::Conversions::registerConverterAlias(converter, "QStencilOperationArguments::Operation");
        Shiboken::Conversions::registerConverterAlias(converter, "Operation");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Operation' enum.

    PySide::Signal::registerSignals(pyType, &::Qt3DRender::QStencilOperationArguments::staticMetaObject);
    qRegisterMetaType< ::Qt3DRender::QStencilOperationArguments::FaceMode >("QStencilOperationArguments::FaceMode");
    qRegisterMetaType< ::Qt3DRender::QStencilOperationArguments::FaceMode >("Qt3DRender::QStencilOperationArguments::FaceMode");
    qRegisterMetaType< ::Qt3DRender::QStencilOperationArguments::Operation >("QStencilOperationArguments::Operation");
    qRegisterMetaType< ::Qt3DRender::QStencilOperationArguments::Operation >("Qt3DRender::QStencilOperationArguments::Operation");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DRender::QStencilOperationArguments::staticMetaObject, sizeof(QStencilOperationArgumentsWrapper));

    return pyType;
}
