// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qtechnique_wrapper.h"

// Argument includes
#include <QList>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DRender/qfilterkey.h>
#include <Qt3DRender/qgraphicsapifilter.h>
#include <Qt3DRender/qparameter.h>
#include <Qt3DRender/qrenderpass.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QTechniqueWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QTechniqueWrapper::QTechniqueWrapper(::Qt3DCore::QNode * parent) : Qt3DRender::QTechnique(parent)
{
}

void QTechniqueWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTechnique", funcName);
        return;
    }
}

void QTechniqueWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTechnique", funcName);
        return;
    }
}

void QTechniqueWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTechnique", funcName);
        return;
    }
}

void QTechniqueWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTechnique", funcName);
        return;
    }
}

bool QTechniqueWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTechnique", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QTechnique", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QTechniqueWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTechnique", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QTechnique", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QTechniqueWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTechnique", funcName);
        return;
    }
}

const QMetaObject *QTechniqueWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DRender::QTechnique::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QTechniqueWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DRender::QTechnique::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QTechniqueWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QTechniqueWrapper *>(this));
    return Qt3DRender::QTechnique::qt_metacast(_clname);
}

QTechniqueWrapper::~QTechniqueWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DRender_QTechnique_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DRender::QTechnique >()))
        return -1;

    QTechniqueWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QTechnique", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTechnique::QTechnique(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QTechnique(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QTechnique(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QTechnique(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QTechniqueWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QTechniqueWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DRender::QTechnique >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DRender_QTechniqueFunc_addFilterKey(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTechnique *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTechnique::addFilterKey(Qt3DRender::QFilterKey*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QFilterKey_IDX]), (pyArg)))) {
        overloadId = 0; // addFilterKey(Qt3DRender::QFilterKey*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addFilterKey", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QFilterKey *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addFilterKey(Qt3DRender::QFilterKey*)
            cppSelf->addFilterKey(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTechniqueFunc_addParameter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTechnique *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTechnique::addParameter(Qt3DRender::QParameter*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QParameter_IDX]), (pyArg)))) {
        overloadId = 0; // addParameter(Qt3DRender::QParameter*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addParameter", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QParameter *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addParameter(Qt3DRender::QParameter*)
            cppSelf->addParameter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTechniqueFunc_addRenderPass(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTechnique *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTechnique::addRenderPass(Qt3DRender::QRenderPass*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderPass_IDX]), (pyArg)))) {
        overloadId = 0; // addRenderPass(Qt3DRender::QRenderPass*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addRenderPass", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QRenderPass *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addRenderPass(Qt3DRender::QRenderPass*)
            cppSelf->addRenderPass(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTechniqueFunc_filterKeys(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTechnique *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // filterKeys()const
        QList<Qt3DRender::QFilterKey*> cppResult = const_cast<const ::Qt3DRender::QTechnique *>(cppSelf)->filterKeys();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QFilterKeyPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTechniqueFunc_graphicsApiFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTechnique *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // graphicsApiFilter()
        Qt3DRender::QGraphicsApiFilter * cppResult = cppSelf->graphicsApiFilter();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QGraphicsApiFilter_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTechniqueFunc_parameters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTechnique *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parameters()const
        QList<Qt3DRender::QParameter*> cppResult = const_cast<const ::Qt3DRender::QTechnique *>(cppSelf)->parameters();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QParameterPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTechniqueFunc_removeFilterKey(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTechnique *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTechnique::removeFilterKey(Qt3DRender::QFilterKey*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QFilterKey_IDX]), (pyArg)))) {
        overloadId = 0; // removeFilterKey(Qt3DRender::QFilterKey*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeFilterKey", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QFilterKey *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeFilterKey(Qt3DRender::QFilterKey*)
            cppSelf->removeFilterKey(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTechniqueFunc_removeParameter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTechnique *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTechnique::removeParameter(Qt3DRender::QParameter*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QParameter_IDX]), (pyArg)))) {
        overloadId = 0; // removeParameter(Qt3DRender::QParameter*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeParameter", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QParameter *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeParameter(Qt3DRender::QParameter*)
            cppSelf->removeParameter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTechniqueFunc_removeRenderPass(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTechnique *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTechnique::removeRenderPass(Qt3DRender::QRenderPass*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderPass_IDX]), (pyArg)))) {
        overloadId = 0; // removeRenderPass(Qt3DRender::QRenderPass*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeRenderPass", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QRenderPass *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeRenderPass(Qt3DRender::QRenderPass*)
            cppSelf->removeRenderPass(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTechniqueFunc_renderPasses(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTechnique *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // renderPasses()const
        QList<Qt3DRender::QRenderPass*> cppResult = const_cast<const ::Qt3DRender::QTechnique *>(cppSelf)->renderPasses();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QRenderPassPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DRender_QTechnique_PropertyStrings[] = {
    "graphicsApiFilter:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QTechnique_methods[] = {
    {"addFilterKey", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTechniqueFunc_addFilterKey), METH_O, nullptr},
    {"addParameter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTechniqueFunc_addParameter), METH_O, nullptr},
    {"addRenderPass", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTechniqueFunc_addRenderPass), METH_O, nullptr},
    {"filterKeys", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTechniqueFunc_filterKeys), METH_NOARGS, nullptr},
    {"graphicsApiFilter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTechniqueFunc_graphicsApiFilter), METH_NOARGS, nullptr},
    {"parameters", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTechniqueFunc_parameters), METH_NOARGS, nullptr},
    {"removeFilterKey", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTechniqueFunc_removeFilterKey), METH_O, nullptr},
    {"removeParameter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTechniqueFunc_removeParameter), METH_O, nullptr},
    {"removeRenderPass", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTechniqueFunc_removeRenderPass), METH_O, nullptr},
    {"renderPasses", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTechniqueFunc_renderPasses), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QTechnique_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QTechnique *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QTechniqueWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DRender_QTechnique_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QTechnique_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QTechnique_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QTechnique_TypeF(void)
{
    return _Sbk_Qt3DRender_QTechnique_Type;
}

static PyType_Slot Sbk_Qt3DRender_QTechnique_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QTechnique_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QTechnique_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QTechnique_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QTechnique_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QTechnique_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QTechnique_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QTechnique",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QTechnique_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QTechnique_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DRender::QTechnique *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTechnique_PythonToCpp_QTechnique_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QTechnique_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTechnique_PythonToCpp_QTechnique_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QTechnique_TypeF()))
        return QTechnique_PythonToCpp_QTechnique_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTechnique_PTR_CppToPython_QTechnique(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DRender::QTechnique *>(const_cast<void *>(cppIn)), Sbk_Qt3DRender_QTechnique_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QTechnique_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QTechnique(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,graphicsApiFilter:Qt3DRender.QGraphicsApiFilter=None)",
    "PySide6.Qt3DRender.Qt3DRender.QTechnique.addFilterKey(self,filterKey:PySide6.Qt3DRender.Qt3DRender.QFilterKey)",
    "PySide6.Qt3DRender.Qt3DRender.QTechnique.addParameter(self,p:PySide6.Qt3DRender.Qt3DRender.QParameter)",
    "PySide6.Qt3DRender.Qt3DRender.QTechnique.addRenderPass(self,pass:PySide6.Qt3DRender.Qt3DRender.QRenderPass)",
    "PySide6.Qt3DRender.Qt3DRender.QTechnique.filterKeys(self)->QList[PySide6.Qt3DRender.Qt3DRender.QFilterKey]",
    "PySide6.Qt3DRender.Qt3DRender.QTechnique.graphicsApiFilter(self)->PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter",
    "PySide6.Qt3DRender.Qt3DRender.QTechnique.parameters(self)->QList[PySide6.Qt3DRender.Qt3DRender.QParameter]",
    "PySide6.Qt3DRender.Qt3DRender.QTechnique.removeFilterKey(self,filterKey:PySide6.Qt3DRender.Qt3DRender.QFilterKey)",
    "PySide6.Qt3DRender.Qt3DRender.QTechnique.removeParameter(self,p:PySide6.Qt3DRender.Qt3DRender.QParameter)",
    "PySide6.Qt3DRender.Qt3DRender.QTechnique.removeRenderPass(self,pass:PySide6.Qt3DRender.Qt3DRender.QRenderPass)",
    "PySide6.Qt3DRender.Qt3DRender.QTechnique.renderPasses(self)->QList[PySide6.Qt3DRender.Qt3DRender.QRenderPass]",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QTechnique_SignatureByteSize = 237;
static constexpr uint8_t Qt3DRender_QTechnique_SignatureBytes[237] = {
    0x78, 0xda, 0xbd, 0x92, 0x4d, 0x0f, 0x01, 0x31, 0x10, 0x86, 0xef, 0x7e, 0x09, 0xb2, 0x5c, 0x24,
    0x0e, 0x9b, 0x90, 0x08, 0xe1, 0x40, 0xe8, 0xe2, 0x26, 0x0e, 0x8d, 0x0e, 0x9a, 0x54, 0x5b, 0xd3,
    0x2e, 0xd9, 0x7f, 0x4f, 0xd4, 0xd6, 0xe2, 0xb0, 0xdb, 0xcb, 0xde, 0xa6, 0x1f, 0xef, 0x3c, 0xf3,
    0xf1, 0x92, 0x6c, 0xc3, 0x19, 0xf4, 0xbb, 0x89, 0xed, 0x4d, 0xd6, 0x20, 0x19, 0xe0, 0x57, 0xb8,
    0x85, 0xc3, 0x59, 0xf2, 0x6b, 0x0a, 0x4d, 0x03, 0xe2, 0x18, 0x69, 0x8a, 0x20, 0x6d, 0x4c, 0x0a,
    0xa2, 0xb1, 0x42, 0x28, 0x04, 0x4b, 0xc5, 0x60, 0x20, 0x53, 0x21, 0xb4, 0xc5, 0xa8, 0x1d, 0xcf,
    0x21, 0xbb, 0x2b, 0x64, 0x2b, 0x29, 0xb2, 0xc1, 0x52, 0x49, 0x88, 0x4e, 0x48, 0xf5, 0x99, 0x1f,
    0xcc, 0x48, 0xf3, 0x29, 0x17, 0x16, 0x30, 0x2e, 0xe2, 0x66, 0xbf, 0xaf, 0x2f, 0x51, 0xab, 0x41,
    0x2a, 0x56, 0xd9, 0xa5, 0x8c, 0x39, 0xe1, 0x13, 0xec, 0x4a, 0x3e, 0xe6, 0xc7, 0xb8, 0x24, 0x89,
    0xd7, 0x85, 0xe1, 0x08, 0x45, 0x7a, 0x81, 0xa7, 0xf2, 0x3d, 0xa1, 0x32, 0x8c, 0xff, 0x1f, 0x86,
    0x71, 0x97, 0x84, 0x1a, 0x93, 0x6f, 0xc2, 0x98, 0x32, 0xd4, 0x47, 0x13, 0xc0, 0xf2, 0xf3, 0x72,
    0xa0, 0x56, 0x67, 0x98, 0x2c, 0xb8, 0xb1, 0xbb, 0xaa, 0xd3, 0xdb, 0x57, 0x47, 0xfd, 0x79, 0x21,
    0x27, 0x96, 0x64, 0xf8, 0x73, 0x49, 0x75, 0xa4, 0xce, 0xa7, 0x1f, 0xd6, 0x9d, 0x5f, 0x5a, 0x40,
    0x77, 0x08, 0x17, 0x75, 0x83, 0x3a, 0xdd, 0xe8, 0x88, 0x75, 0x18, 0xd2, 0x91, 0x6a, 0xf3, 0x24,
    0x7a, 0x11, 0x84, 0xed, 0xed, 0x43, 0xdb, 0x37, 0x1e, 0xa0, 0x0d, 0xbf, 0x53
};
#endif

PyTypeObject *init_Qt3DRender_QTechnique(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QTechnique_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]))));

    _Sbk_Qt3DRender_QTechnique_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QTechnique",
        "Qt3DRender::QTechnique*",
        &Sbk_Qt3DRender_QTechnique_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QTechnique >,
        Sbk_Qt3DRender_QTechnique_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QTechnique_TypeF(); // references _Sbk_Qt3DRender_QTechnique_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QTechnique_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QTechnique_SignatureBytes, Qt3DRender_QTechnique_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QTechnique_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTechnique_PythonToCpp_QTechnique_PTR,
        is_QTechnique_PythonToCpp_QTechnique_PTR_Convertible,
        QTechnique_PTR_CppToPython_QTechnique);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QTechnique");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QTechnique*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QTechnique&");
    Shiboken::Conversions::registerConverterAlias(converter, "QTechnique");
    Shiboken::Conversions::registerConverterAlias(converter, "QTechnique*");
    Shiboken::Conversions::registerConverterAlias(converter, "QTechnique&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QTechnique).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QTechniqueWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QTechnique_TypeF(), &Sbk_Qt3DRender_QTechnique_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DRender::QTechnique::staticMetaObject, sizeof(QTechniqueWrapper));

    return pyType;
}
