// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qtexturedata_wrapper.h"

// Argument includes
#include <QList>
#include <Qt3DRender/qabstracttexture.h>
#include <Qt3DRender/qtextureimagedata.h>
#include <Qt3DRender/qtexturewrapmode.h>
#include <qsharedpointer.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DRender_QTextureData_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DRender::QTextureData >()))
        return -1;

    ::Qt3DRender::QTextureData *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QTextureData()
        cptr = new ::Qt3DRender::QTextureData();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Qt3DRender::QTextureData >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_addImageData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::addImageData(QSharedPointer<Qt3DRender::QTextureImageData>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_QTextureImageData_IDX]), (pyArg)))) {
        overloadId = 0; // addImageData(QSharedPointer<Qt3DRender::QTextureImageData>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addImageData", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSharedPointer<Qt3DRender::QTextureImageData> cppArg0_local;
        ::QSharedPointer<Qt3DRender::QTextureImageData> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // addImageData(QSharedPointer<Qt3DRender::QTextureImageData>)
            cppSelf->addImageData(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_comparisonFunction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // comparisonFunction()const
        Qt3DRender::QAbstractTexture::ComparisonFunction cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->comparisonFunction();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_ComparisonFunction_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_comparisonMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // comparisonMode()const
        Qt3DRender::QAbstractTexture::ComparisonMode cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->comparisonMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_ComparisonMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_depth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // depth()const
        int cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->depth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // format()const
        Qt3DRender::QAbstractTexture::TextureFormat cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->format();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_TextureFormat_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_height(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // height()const
        int cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->height();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_imageData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // imageData()const
        QList<QSharedPointer<Qt3DRender::QTextureImageData>> cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->imageData();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QSharedPointer_Qt3DRender_QTextureImageData_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_isAutoMipMapGenerationEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAutoMipMapGenerationEnabled()const
        bool cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->isAutoMipMapGenerationEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_layers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // layers()const
        int cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->layers();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_magnificationFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // magnificationFilter()const
        Qt3DRender::QAbstractTexture::Filter cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->magnificationFilter();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Filter_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_maximumAnisotropy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumAnisotropy()const
        float cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->maximumAnisotropy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_minificationFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minificationFilter()const
        Qt3DRender::QAbstractTexture::Filter cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->minificationFilter();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Filter_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_setAutoMipMapGenerationEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::setAutoMipMapGenerationEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoMipMapGenerationEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoMipMapGenerationEnabled", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoMipMapGenerationEnabled(bool)
            cppSelf->setAutoMipMapGenerationEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_setComparisonFunction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::setComparisonFunction(Qt3DRender::QAbstractTexture::ComparisonFunction)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_ComparisonFunction_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setComparisonFunction(Qt3DRender::QAbstractTexture::ComparisonFunction)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setComparisonFunction", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QAbstractTexture::ComparisonFunction cppArg0 = static_cast< ::Qt3DRender::QAbstractTexture::ComparisonFunction>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setComparisonFunction(Qt3DRender::QAbstractTexture::ComparisonFunction)
            cppSelf->setComparisonFunction(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_setComparisonMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::setComparisonMode(Qt3DRender::QAbstractTexture::ComparisonMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_ComparisonMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setComparisonMode(Qt3DRender::QAbstractTexture::ComparisonMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setComparisonMode", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QAbstractTexture::ComparisonMode cppArg0{Qt3DRender::QAbstractTexture::CompareNone};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setComparisonMode(Qt3DRender::QAbstractTexture::ComparisonMode)
            cppSelf->setComparisonMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_setDepth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::setDepth(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setDepth(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDepth", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepth(int)
            cppSelf->setDepth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_setFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::setFormat(Qt3DRender::QAbstractTexture::TextureFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_TextureFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFormat(Qt3DRender::QAbstractTexture::TextureFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFormat", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QAbstractTexture::TextureFormat cppArg0{Qt3DRender::QAbstractTexture::NoFormat};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFormat(Qt3DRender::QAbstractTexture::TextureFormat)
            cppSelf->setFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_setHeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::setHeight(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setHeight(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeight", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeight(int)
            cppSelf->setHeight(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_setLayers(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::setLayers(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLayers(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLayers", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLayers(int)
            cppSelf->setLayers(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_setMagnificationFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::setMagnificationFilter(Qt3DRender::QAbstractTexture::Filter)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Filter_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMagnificationFilter(Qt3DRender::QAbstractTexture::Filter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMagnificationFilter", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QAbstractTexture::Filter cppArg0 = static_cast< ::Qt3DRender::QAbstractTexture::Filter>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMagnificationFilter(Qt3DRender::QAbstractTexture::Filter)
            cppSelf->setMagnificationFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_setMaximumAnisotropy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::setMaximumAnisotropy(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMaximumAnisotropy(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaximumAnisotropy", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximumAnisotropy(float)
            cppSelf->setMaximumAnisotropy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_setMinificationFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::setMinificationFilter(Qt3DRender::QAbstractTexture::Filter)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Filter_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMinificationFilter(Qt3DRender::QAbstractTexture::Filter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinificationFilter", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QAbstractTexture::Filter cppArg0 = static_cast< ::Qt3DRender::QAbstractTexture::Filter>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinificationFilter(Qt3DRender::QAbstractTexture::Filter)
            cppSelf->setMinificationFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_setTarget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::setTarget(Qt3DRender::QAbstractTexture::Target)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Target_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTarget(Qt3DRender::QAbstractTexture::Target)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTarget", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QAbstractTexture::Target cppArg0{Qt3DRender::QAbstractTexture::TargetAutomatic};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTarget(Qt3DRender::QAbstractTexture::Target)
            cppSelf->setTarget(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_setWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::setWidth(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWidth", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWidth(int)
            cppSelf->setWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_setWrapModeX(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::setWrapModeX(Qt3DRender::QTextureWrapMode::WrapMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureWrapMode_WrapMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setWrapModeX(Qt3DRender::QTextureWrapMode::WrapMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWrapModeX", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QTextureWrapMode::WrapMode cppArg0 = static_cast< ::Qt3DRender::QTextureWrapMode::WrapMode>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWrapModeX(Qt3DRender::QTextureWrapMode::WrapMode)
            cppSelf->setWrapModeX(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_setWrapModeY(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::setWrapModeY(Qt3DRender::QTextureWrapMode::WrapMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureWrapMode_WrapMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setWrapModeY(Qt3DRender::QTextureWrapMode::WrapMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWrapModeY", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QTextureWrapMode::WrapMode cppArg0 = static_cast< ::Qt3DRender::QTextureWrapMode::WrapMode>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWrapModeY(Qt3DRender::QTextureWrapMode::WrapMode)
            cppSelf->setWrapModeY(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_setWrapModeZ(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextureData::setWrapModeZ(Qt3DRender::QTextureWrapMode::WrapMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureWrapMode_WrapMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setWrapModeZ(Qt3DRender::QTextureWrapMode::WrapMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWrapModeZ", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QTextureWrapMode::WrapMode cppArg0 = static_cast< ::Qt3DRender::QTextureWrapMode::WrapMode>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWrapModeZ(Qt3DRender::QTextureWrapMode::WrapMode)
            cppSelf->setWrapModeZ(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_target(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // target()const
        Qt3DRender::QAbstractTexture::Target cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->target();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_Target_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_width(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // width()const
        int cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->width();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_wrapModeX(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wrapModeX()const
        Qt3DRender::QTextureWrapMode::WrapMode cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->wrapModeX();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureWrapMode_WrapMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_wrapModeY(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wrapModeY()const
        Qt3DRender::QTextureWrapMode::WrapMode cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->wrapModeY();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureWrapMode_WrapMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QTextureDataFunc_wrapModeZ(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wrapModeZ()const
        Qt3DRender::QTextureWrapMode::WrapMode cppResult = const_cast<const ::Qt3DRender::QTextureData *>(cppSelf)->wrapModeZ();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureWrapMode_WrapMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DRender_QTextureData_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QTextureData_methods[] = {
    {"addImageData", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_addImageData), METH_O, nullptr},
    {"comparisonFunction", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_comparisonFunction), METH_NOARGS, nullptr},
    {"comparisonMode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_comparisonMode), METH_NOARGS, nullptr},
    {"depth", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_depth), METH_NOARGS, nullptr},
    {"format", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_format), METH_NOARGS, nullptr},
    {"height", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_height), METH_NOARGS, nullptr},
    {"imageData", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_imageData), METH_NOARGS, nullptr},
    {"isAutoMipMapGenerationEnabled", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_isAutoMipMapGenerationEnabled), METH_NOARGS, nullptr},
    {"layers", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_layers), METH_NOARGS, nullptr},
    {"magnificationFilter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_magnificationFilter), METH_NOARGS, nullptr},
    {"maximumAnisotropy", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_maximumAnisotropy), METH_NOARGS, nullptr},
    {"minificationFilter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_minificationFilter), METH_NOARGS, nullptr},
    {"setAutoMipMapGenerationEnabled", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_setAutoMipMapGenerationEnabled), METH_O, nullptr},
    {"setComparisonFunction", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_setComparisonFunction), METH_O, nullptr},
    {"setComparisonMode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_setComparisonMode), METH_O, nullptr},
    {"setDepth", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_setDepth), METH_O, nullptr},
    {"setFormat", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_setFormat), METH_O, nullptr},
    {"setHeight", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_setHeight), METH_O, nullptr},
    {"setLayers", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_setLayers), METH_O, nullptr},
    {"setMagnificationFilter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_setMagnificationFilter), METH_O, nullptr},
    {"setMaximumAnisotropy", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_setMaximumAnisotropy), METH_O, nullptr},
    {"setMinificationFilter", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_setMinificationFilter), METH_O, nullptr},
    {"setTarget", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_setTarget), METH_O, nullptr},
    {"setWidth", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_setWidth), METH_O, nullptr},
    {"setWrapModeX", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_setWrapModeX), METH_O, nullptr},
    {"setWrapModeY", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_setWrapModeY), METH_O, nullptr},
    {"setWrapModeZ", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_setWrapModeZ), METH_O, nullptr},
    {"target", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_target), METH_NOARGS, nullptr},
    {"width", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_width), METH_NOARGS, nullptr},
    {"wrapModeX", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_wrapModeX), METH_NOARGS, nullptr},
    {"wrapModeY", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_wrapModeY), METH_NOARGS, nullptr},
    {"wrapModeZ", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QTextureDataFunc_wrapModeZ), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_Qt3DRender_QTextureData_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QTextureData_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QTextureData_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QTextureData_TypeF(void)
{
    return _Sbk_Qt3DRender_QTextureData_Type;
}

static PyType_Slot Sbk_Qt3DRender_QTextureData_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QTextureData_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QTextureData_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QTextureData_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QTextureData_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QTextureData_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QTextureData",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QTextureData_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextureData_PythonToCpp_QTextureData_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QTextureData_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextureData_PythonToCpp_QTextureData_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QTextureData_TypeF()))
        return QTextureData_PythonToCpp_QTextureData_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextureData_PTR_CppToPython_QTextureData(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_Qt3DRender_QTextureData_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QTextureData_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QTextureData(self)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.addImageData(self,imageData:PySide6.Qt3DRender.Qt3DRender.QTextureImageDataPtr)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.comparisonFunction(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.ComparisonFunction",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.comparisonMode(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.ComparisonMode",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.depth(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.format(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.TextureFormat",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.height(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.imageData(self)->QList[QSharedPointer[PySide6.Qt3DRender.Qt3DRender.QTextureImageData]]",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.isAutoMipMapGenerationEnabled(self)->bool",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.layers(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.magnificationFilter(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Filter",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.maximumAnisotropy(self)->float",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.minificationFilter(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Filter",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.setAutoMipMapGenerationEnabled(self,isAutoMipMapGenerationEnabled:bool)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.setComparisonFunction(self,comparisonFunction:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.ComparisonFunction)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.setComparisonMode(self,comparisonMode:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.ComparisonMode)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.setDepth(self,depth:int)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.setFormat(self,arg__1:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.TextureFormat)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.setHeight(self,height:int)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.setLayers(self,layers:int)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.setMagnificationFilter(self,filter:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Filter)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.setMaximumAnisotropy(self,maximumAnisotropy:float)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.setMinificationFilter(self,filter:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Filter)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.setTarget(self,target:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Target)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.setWidth(self,width:int)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.setWrapModeX(self,wrapModeX:PySide6.Qt3DRender.Qt3DRender.QTextureWrapMode.WrapMode)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.setWrapModeY(self,wrapModeY:PySide6.Qt3DRender.Qt3DRender.QTextureWrapMode.WrapMode)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.setWrapModeZ(self,wrapModeZ:PySide6.Qt3DRender.Qt3DRender.QTextureWrapMode.WrapMode)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.target(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Target",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.width(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.wrapModeX(self)->PySide6.Qt3DRender.Qt3DRender.QTextureWrapMode.WrapMode",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.wrapModeY(self)->PySide6.Qt3DRender.Qt3DRender.QTextureWrapMode.WrapMode",
    "PySide6.Qt3DRender.Qt3DRender.QTextureData.wrapModeZ(self)->PySide6.Qt3DRender.Qt3DRender.QTextureWrapMode.WrapMode",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QTextureData_SignatureByteSize = 464;
static constexpr uint8_t Qt3DRender_QTextureData_SignatureBytes[464] = {
    0x78, 0xda, 0xc5, 0x56, 0xc1, 0x6a, 0xc2, 0x40, 0x10, 0xbd, 0xf7, 0x4b, 0x5a, 0xd8, 0x0a, 0xa5,
    0xd0, 0x43, 0x0e, 0x05, 0xd1, 0xda, 0x16, 0x0c, 0xc4, 0x2a, 0x58, 0x15, 0x91, 0x35, 0x3b, 0xd1,
    0x85, 0x64, 0x37, 0x6c, 0x46, 0xd4, 0xbf, 0x6f, 0x12, 0x8d, 0x21, 0xa8, 0xd5, 0xd9, 0x80, 0x9e,
    0x32, 0x39, 0xcc, 0x7b, 0x6f, 0x76, 0xde, 0x3e, 0xd6, 0xdb, 0xf6, 0xa5, 0x80, 0xb7, 0x46, 0x0f,
    0x5f, 0xdb, 0x3f, 0xa0, 0x04, 0x98, 0x4a, 0x39, 0x80, 0x0d, 0xae, 0x0c, 0xb4, 0x39, 0xf2, 0xc7,
    0x04, 0xc2, 0xe0, 0xe9, 0xc1, 0xbb, 0xba, 0xa1, 0xc1, 0x85, 0xf8, 0x8e, 0xf8, 0xa2, 0xec, 0x66,
    0xb2, 0xf8, 0x75, 0xae, 0x83, 0x39, 0xb4, 0x7b, 0x68, 0x48, 0xd4, 0xbe, 0x8e, 0x62, 0x6e, 0x64,
    0xa2, 0x55, 0x67, 0xa5, 0x7c, 0x94, 0x5a, 0xed, 0xe4, 0x3f, 0xbf, 0x5f, 0x00, 0x69, 0xce, 0x13,
    0x34, 0xdc, 0xc7, 0x3d, 0x58, 0xa3, 0x75, 0x04, 0x64, 0x27, 0xc3, 0xd5, 0x02, 0x6a, 0x4b, 0xc8,
    0x40, 0x28, 0xf4, 0x02, 0x62, 0x5c, 0x16, 0xac, 0x52, 0x21, 0xa5, 0x37, 0xd0, 0x26, 0xe2, 0x68,
    0x29, 0x79, 0xff, 0xed, 0xe4, 0x18, 0x14, 0xd6, 0x25, 0xc8, 0xc5, 0x12, 0x2d, 0x25, 0xcb, 0x8a,
    0xd9, 0xd2, 0xfe, 0x5e, 0x57, 0x26, 0x38, 0xe9, 0xf5, 0x97, 0xdc, 0x80, 0xf0, 0x74, 0x0a, 0x07,
    0x66, 0x42, 0x74, 0xde, 0x74, 0x4a, 0x92, 0x90, 0x34, 0x57, 0xa8, 0x5d, 0x19, 0xbb, 0x3c, 0xfe,
    0x04, 0x05, 0x86, 0x67, 0x96, 0xf9, 0x50, 0x7c, 0x1e, 0x82, 0x28, 0x64, 0xcd, 0xb5, 0x0e, 0x29,
    0xa0, 0x21, 0xdf, 0x82, 0x49, 0x2c, 0x0f, 0x25, 0x9d, 0x43, 0xc9, 0x40, 0xfa, 0xb9, 0x90, 0x8e,
    0x0c, 0xd3, 0x23, 0xb0, 0x5c, 0xea, 0xae, 0x99, 0xc6, 0xbd, 0x91, 0xd1, 0x2a, 0x6a, 0xaa, 0xd4,
    0xbc, 0x68, 0x74, 0xbc, 0x2d, 0x98, 0x83, 0x50, 0xd3, 0x7c, 0x11, 0xc9, 0xbb, 0x0d, 0x91, 0x00,
    0x5e, 0xda, 0x29, 0xfb, 0x77, 0xed, 0x4e, 0xb6, 0xef, 0x27, 0x22, 0x65, 0xeb, 0x74, 0x80, 0xb1,
    0xe3, 0x60, 0x73, 0x6a, 0x27, 0x9a, 0xbd, 0xb6, 0x43, 0xaa, 0xb1, 0x6a, 0xd2, 0x39, 0xb5, 0x22,
    0x8e, 0xaa, 0xa7, 0x7d, 0x88, 0x39, 0x96, 0x27, 0x9e, 0x93, 0x5e, 0x11, 0x2a, 0x46, 0xa7, 0x8c,
    0x3b, 0xc6, 0xcd, 0x62, 0x36, 0x7b, 0x71, 0xea, 0x64, 0x1e, 0x95, 0xfe, 0xab, 0xcc, 0x3d, 0xb6,
    0xcb, 0x40, 0x9b, 0x21, 0xba, 0x65, 0x50, 0xb0, 0x5d, 0x68, 0xd8, 0xa0, 0xb8, 0x67, 0x12, 0x83,
    0x05, 0x79, 0xed, 0x58, 0xdd, 0x38, 0xba, 0x88, 0x53, 0xd1, 0xc1, 0x8e, 0x12, 0xc5, 0xc9, 0xa3,
    0x84, 0x8c, 0x2e, 0xef, 0x3f, 0xe1, 0x20, 0xb5, 0x19, 0xec, 0x57, 0x8e, 0x79, 0x4d, 0x76, 0x5c,
    0xde, 0x45, 0xe5, 0x1d, 0x4a, 0x51, 0xdc, 0x96, 0x75, 0x56, 0xda, 0x58, 0x64, 0x68, 0x78, 0x9c,
    0xdd, 0xd4, 0xdf, 0x3d, 0x4e, 0xf1, 0x7b, 0xe5, 0xb3, 0xae, 0x68, 0x6f, 0x14, 0x85, 0x2d, 0xff,
    0xa8, 0xca, 0x3f, 0xba, 0x35, 0xff, 0xb8, 0xca, 0x3f, 0xbe, 0x09, 0x3f, 0x96, 0xc6, 0xb1, 0x78,
    0x99, 0xe5, 0xcd, 0x14, 0xba, 0xf5, 0xc1, 0x2f, 0xf4, 0xc7, 0xc7, 0xba, 0xe2, 0x93, 0xcb, 0x6a,
    0xcf, 0x9d, 0x8f, 0x0d, 0xe7, 0xe8, 0x0e, 0x9c, 0xe3, 0xba, 0x9c, 0x7f, 0x89, 0x69, 0xe2, 0xbb
};
#endif

PyTypeObject *init_Qt3DRender_QTextureData(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QTextureData_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_Qt3DRender_QTextureData_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QTextureData",
        "Qt3DRender::QTextureData*",
        &Sbk_Qt3DRender_QTextureData_spec,
        &Shiboken::callCppDestructor< ::Qt3DRender::QTextureData >,
        Sbk_Qt3DRender_QTextureData_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QTextureData_TypeF(); // references _Sbk_Qt3DRender_QTextureData_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QTextureData_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QTextureData_SignatureBytes, Qt3DRender_QTextureData_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QTextureData_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureData_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextureData_PythonToCpp_QTextureData_PTR,
        is_QTextureData_PythonToCpp_QTextureData_PTR_Convertible,
        QTextureData_PTR_CppToPython_QTextureData);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QTextureData");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QTextureData*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QTextureData&");
    Shiboken::Conversions::registerConverterAlias(converter, "QTextureData");
    Shiboken::Conversions::registerConverterAlias(converter, "QTextureData*");
    Shiboken::Conversions::registerConverterAlias(converter, "QTextureData&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QTextureData).name());

    qRegisterMetaType< ::Qt3DRender::QTextureData *>();

    return pyType;
}
