// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qtextureimagedatagenerator_wrapper.h"

// Argument includes
#include <Qt3DRender/qtextureimagedata.h>
#include <Qt3DRender/qtextureimagedatagenerator.h>
#include <qsharedpointer.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QTextureImageDataGeneratorWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QTextureImageDataGeneratorWrapper::QTextureImageDataGeneratorWrapper()
{
}

::qintptr QTextureImageDataGeneratorWrapper::id() const
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QTextureImageDataGenerator.id");
        return ::qintptr();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::qintptr();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "id";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QTextureImageDataGenerator.id");
        return ::qintptr();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTextureImageDataGenerator", funcName);
        return ::qintptr();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QTextureImageDataGenerator", funcName, "qintptr", Py_TYPE(pyResult)->tp_name);
        return ::qintptr();
    }
    ::qintptr cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSharedPointer<Qt3DRender::QTextureImageData> QTextureImageDataGeneratorWrapper::operator()()
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QTextureImageDataGenerator.__call__");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "__call__";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QTextureImageDataGenerator.__call__");
        return {};
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTextureImageDataGenerator", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_QTextureImageData_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QTextureImageDataGenerator", funcName, "QSharedPointer", Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSharedPointer<Qt3DRender::QTextureImageData> cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QTextureImageDataGeneratorWrapper::operator==(const ::Qt3DRender::QTextureImageDataGenerator & other) const
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QTextureImageDataGenerator.__eq__");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "__eq__";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QTextureImageDataGenerator.__eq__");
        return false;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureImageDataGenerator_IDX]), &other)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureImageDataGenerator_IDX]), &other)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTextureImageDataGenerator", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QTextureImageDataGenerator", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QTextureImageDataGeneratorWrapper::~QTextureImageDataGeneratorWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DRender_QTextureImageDataGenerator_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureImageDataGenerator_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("Qt3DRender::QTextureImageDataGenerator");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DRender::QTextureImageDataGenerator >()))
        return -1;

    QTextureImageDataGeneratorWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureImageDataGenerator_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QTextureImageDataGenerator()
        cptr = new QTextureImageDataGeneratorWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DRender::QTextureImageDataGenerator >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Qt3DRender_QTextureImageDataGeneratorFunc___call__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QTextureImageDataGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureImageDataGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // operator()()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QTextureImageDataGenerator.operator()");
            return {};
        }
        QSharedPointer<Qt3DRender::QTextureImageData> cppResult = cppSelf->operator()();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_QTextureImageData_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DRender_QTextureImageDataGenerator_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QTextureImageDataGenerator_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QTextureImageDataGenerator_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QTextureImageDataGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureImageDataGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QTextureImageDataGeneratorWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

// Rich comparison
static PyObject * Sbk_Qt3DRender_QTextureImageDataGenerator_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::Qt3DRender::QTextureImageDataGenerator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureImageDataGenerator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureImageDataGenerator_IDX]), (pyArg)))) {
                // operator==(const Qt3DRender::QTextureImageDataGenerator &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::Qt3DRender::QTextureImageDataGenerator *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_Qt3DRender_QTextureImageDataGenerator_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QTextureImageDataGenerator_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QTextureImageDataGenerator_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QTextureImageDataGenerator_TypeF(void)
{
    return _Sbk_Qt3DRender_QTextureImageDataGenerator_Type;
}

static PyType_Slot Sbk_Qt3DRender_QTextureImageDataGenerator_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_call,        reinterpret_cast<void *>(&Sbk_Qt3DRender_QTextureImageDataGeneratorFunc___call__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QTextureImageDataGenerator_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QTextureImageDataGenerator_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QTextureImageDataGenerator_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_Qt3DRender_QTextureImageDataGenerator_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QTextureImageDataGenerator_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QTextureImageDataGenerator_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QTextureImageDataGenerator_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QTextureImageDataGenerator",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QTextureImageDataGenerator_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QTextureImageDataGenerator_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::Qt3DCore::QAbstractFunctor >())
        return dynamic_cast< ::Qt3DRender::QTextureImageDataGenerator *>(reinterpret_cast< ::Qt3DCore::QAbstractFunctor *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextureImageDataGenerator_PythonToCpp_QTextureImageDataGenerator_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QTextureImageDataGenerator_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextureImageDataGenerator_PythonToCpp_QTextureImageDataGenerator_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QTextureImageDataGenerator_TypeF()))
        return QTextureImageDataGenerator_PythonToCpp_QTextureImageDataGenerator_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextureImageDataGenerator_PTR_CppToPython_QTextureImageDataGenerator(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::Qt3DRender::QTextureImageDataGenerator *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_Qt3DRender_QTextureImageDataGenerator_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QTextureImageDataGenerator_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QTextureImageDataGenerator(self)",
    "PySide6.Qt3DRender.Qt3DRender.QTextureImageDataGenerator.__call__(self)->PySide6.Qt3DRender.Qt3DRender.QTextureImageDataPtr",
    "PySide6.Qt3DRender.Qt3DRender.QTextureImageDataGenerator.__eq__(self,other:PySide6.Qt3DRender.Qt3DRender.QTextureImageDataGenerator)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QTextureImageDataGenerator_SignatureByteSize = 105;
static constexpr uint8_t Qt3DRender_QTextureImageDataGenerator_SignatureBytes[105] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x31, 0x76, 0x09, 0x4a,
    0xcd, 0x4b, 0x49, 0x2d, 0x42, 0x61, 0x86, 0xa4, 0x56, 0x94, 0x94, 0x16, 0xa5, 0x7a, 0xe6, 0x26,
    0xa6, 0xa7, 0xba, 0x24, 0x96, 0x24, 0xba, 0xa7, 0xe6, 0xa5, 0x16, 0x25, 0x96, 0xe4, 0x17, 0x69,
    0x14, 0xa7, 0xe6, 0xa4, 0x69, 0x72, 0x05, 0x90, 0xa9, 0x5d, 0x2f, 0x3e, 0x3e, 0x39, 0x31, 0x27,
    0x27, 0x3e, 0x1e, 0x62, 0x8e, 0xae, 0x1d, 0x89, 0x06, 0x05, 0x94, 0x14, 0x51, 0x62, 0x77, 0x6a,
    0x21, 0xd4, 0x66, 0x9d, 0xfc, 0x92, 0x8c, 0xd4, 0x22, 0x2b, 0x72, 0x8d, 0x02, 0x3a, 0x3c, 0x29,
    0x3f, 0x3f, 0x87, 0x0b, 0x00, 0x9d, 0xd7, 0x75, 0x2b
};
#endif

PyTypeObject *init_Qt3DRender_QTextureImageDataGenerator(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureImageDataGenerator_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureImageDataGenerator_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QTextureImageDataGenerator_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAbstractFunctor_IDX]))));

    _Sbk_Qt3DRender_QTextureImageDataGenerator_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QTextureImageDataGenerator",
        "Qt3DRender::QTextureImageDataGenerator*",
        &Sbk_Qt3DRender_QTextureImageDataGenerator_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QTextureImageDataGenerator >,
        Sbk_Qt3DRender_QTextureImageDataGenerator_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QTextureImageDataGenerator_TypeF(); // references _Sbk_Qt3DRender_QTextureImageDataGenerator_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QTextureImageDataGenerator_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QTextureImageDataGenerator_SignatureBytes, Qt3DRender_QTextureImageDataGenerator_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QTextureImageDataGenerator_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureImageDataGenerator_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextureImageDataGenerator_PythonToCpp_QTextureImageDataGenerator_PTR,
        is_QTextureImageDataGenerator_PythonToCpp_QTextureImageDataGenerator_PTR_Convertible,
        QTextureImageDataGenerator_PTR_CppToPython_QTextureImageDataGenerator);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QTextureImageDataGenerator");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QTextureImageDataGenerator*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QTextureImageDataGenerator&");
    Shiboken::Conversions::registerConverterAlias(converter, "QTextureImageDataGenerator");
    Shiboken::Conversions::registerConverterAlias(converter, "QTextureImageDataGenerator*");
    Shiboken::Conversions::registerConverterAlias(converter, "QTextureImageDataGenerator&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QTextureImageDataGenerator).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QTextureImageDataGeneratorWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QTextureImageDataGenerator_TypeF(), &Sbk_Qt3DRender_QTextureImageDataGenerator_typeDiscovery);

    qRegisterMetaType< ::Qt3DRender::QTextureImageDataGenerator *>();

    return pyType;
}
