// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qbluetoothdevicediscoveryagent_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtBluetooth/qbluetoothdevicediscoveryagent.h>
#include <QtBluetooth/qbluetoothdeviceinfo.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QBluetoothDeviceDiscoveryAgentWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QBluetoothDeviceDiscoveryAgentWrapper::QBluetoothDeviceDiscoveryAgentWrapper(::QObject * parent) : QBluetoothDeviceDiscoveryAgent(parent)
{
}

QBluetoothDeviceDiscoveryAgentWrapper::QBluetoothDeviceDiscoveryAgentWrapper(const ::QBluetoothAddress & deviceAdapter, ::QObject * parent) : QBluetoothDeviceDiscoveryAgent(deviceAdapter, parent)
{
}

void QBluetoothDeviceDiscoveryAgentWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothDeviceDiscoveryAgent", funcName);
        return;
    }
}

void QBluetoothDeviceDiscoveryAgentWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothDeviceDiscoveryAgent", funcName);
        return;
    }
}

void QBluetoothDeviceDiscoveryAgentWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothDeviceDiscoveryAgent", funcName);
        return;
    }
}

void QBluetoothDeviceDiscoveryAgentWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothDeviceDiscoveryAgent", funcName);
        return;
    }
}

bool QBluetoothDeviceDiscoveryAgentWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothDeviceDiscoveryAgent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QBluetoothDeviceDiscoveryAgent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QBluetoothDeviceDiscoveryAgentWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothDeviceDiscoveryAgent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QBluetoothDeviceDiscoveryAgent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QBluetoothDeviceDiscoveryAgentWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothDeviceDiscoveryAgent", funcName);
        return;
    }
}

const QMetaObject *QBluetoothDeviceDiscoveryAgentWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QBluetoothDeviceDiscoveryAgent::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QBluetoothDeviceDiscoveryAgentWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QBluetoothDeviceDiscoveryAgent::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QBluetoothDeviceDiscoveryAgentWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QBluetoothDeviceDiscoveryAgentWrapper *>(this));
    return QBluetoothDeviceDiscoveryAgent::qt_metacast(_clname);
}

QBluetoothDeviceDiscoveryAgentWrapper::~QBluetoothDeviceDiscoveryAgentWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBluetoothDeviceDiscoveryAgent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBluetoothDeviceDiscoveryAgent >()))
        return -1;

    QBluetoothDeviceDiscoveryAgentWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QBluetoothDeviceDiscoveryAgent", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBluetoothDeviceDiscoveryAgent::QBluetoothDeviceDiscoveryAgent(QObject*=)
    // 1: QBluetoothDeviceDiscoveryAgent::QBluetoothDeviceDiscoveryAgent(QBluetoothAddress,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QBluetoothDeviceDiscoveryAgent(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QBluetoothDeviceDiscoveryAgent(QBluetoothAddress,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QBluetoothDeviceDiscoveryAgent(QBluetoothAddress,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QBluetoothDeviceDiscoveryAgent(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QBluetoothDeviceDiscoveryAgent(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothDeviceDiscoveryAgent(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QBluetoothDeviceDiscoveryAgentWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QBluetoothDeviceDiscoveryAgentWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QBluetoothDeviceDiscoveryAgent(const QBluetoothAddress &deviceAdapter, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBluetoothAddress cppArg0_local;
            ::QBluetoothAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothDeviceDiscoveryAgent(QBluetoothAddress,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QBluetoothDeviceDiscoveryAgentWrapper(*cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QBluetoothDeviceDiscoveryAgentWrapper(*cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QBluetoothDeviceDiscoveryAgent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QBluetoothDeviceDiscoveryAgentFunc_discoveredDevices(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // discoveredDevices()const
        QList<QBluetoothDeviceInfo> cppResult = const_cast<const ::QBluetoothDeviceDiscoveryAgent *>(cppSelf)->discoveredDevices();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothDeviceInfo_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceDiscoveryAgentFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QBluetoothDeviceDiscoveryAgent::Error cppResult = const_cast<const ::QBluetoothDeviceDiscoveryAgent *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_Error_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceDiscoveryAgentFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QBluetoothDeviceDiscoveryAgent *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceDiscoveryAgentFunc_isActive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isActive()const
        bool cppResult = const_cast<const ::QBluetoothDeviceDiscoveryAgent *>(cppSelf)->isActive();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceDiscoveryAgentFunc_lowEnergyDiscoveryTimeout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lowEnergyDiscoveryTimeout()const
        int cppResult = const_cast<const ::QBluetoothDeviceDiscoveryAgent *>(cppSelf)->lowEnergyDiscoveryTimeout();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceDiscoveryAgentFunc_setLowEnergyDiscoveryTimeout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothDeviceDiscoveryAgent::setLowEnergyDiscoveryTimeout(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLowEnergyDiscoveryTimeout(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLowEnergyDiscoveryTimeout", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLowEnergyDiscoveryTimeout(int)
            cppSelf->setLowEnergyDiscoveryTimeout(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothDeviceDiscoveryAgentFunc_start(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "start", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBluetoothDeviceDiscoveryAgent::start()
    // 1: QBluetoothDeviceDiscoveryAgent::start(QFlags<QBluetoothDeviceDiscoveryAgent::DiscoveryMethod>)
    if (numArgs == 0) {
        overloadId = 0; // start()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 1; // start(QFlags<QBluetoothDeviceDiscoveryAgent::DiscoveryMethod>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // start()
        {

            // start()
            cppSelf->start();
            break;
        }
        case 1: // start(QFlags<QBluetoothDeviceDiscoveryAgent::DiscoveryMethod> method)
        {
            ::QFlags<QBluetoothDeviceDiscoveryAgent::DiscoveryMethod> cppArg0 = QFlags<QBluetoothDeviceDiscoveryAgent::DiscoveryMethod>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // start(QFlags<QBluetoothDeviceDiscoveryAgent::DiscoveryMethod>)
                cppSelf->start(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothDeviceDiscoveryAgentFunc_stop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stop()
        cppSelf->stop();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothDeviceDiscoveryAgentFunc_supportedDiscoveryMethods(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedDiscoveryMethods()
        QFlags<QBluetoothDeviceDiscoveryAgent::DiscoveryMethod> cppResult = ::QBluetoothDeviceDiscoveryAgent::supportedDiscoveryMethods();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QBluetoothDeviceDiscoveryAgent_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QBluetoothDeviceDiscoveryAgent_EnumFlagInfo[] = {
    "DiscoveryMethod:Flag:DiscoveryMethods",
    "Error:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBluetoothDeviceDiscoveryAgent_methods[] = {
    {"discoveredDevices", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceDiscoveryAgentFunc_discoveredDevices), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceDiscoveryAgentFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceDiscoveryAgentFunc_errorString), METH_NOARGS, nullptr},
    {"isActive", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceDiscoveryAgentFunc_isActive), METH_NOARGS, nullptr},
    {"lowEnergyDiscoveryTimeout", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceDiscoveryAgentFunc_lowEnergyDiscoveryTimeout), METH_NOARGS, nullptr},
    {"setLowEnergyDiscoveryTimeout", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceDiscoveryAgentFunc_setLowEnergyDiscoveryTimeout), METH_O, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceDiscoveryAgentFunc_start), METH_VARARGS, nullptr},
    {"stop", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceDiscoveryAgentFunc_stop), METH_NOARGS, nullptr},
    {"supportedDiscoveryMethods", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceDiscoveryAgentFunc_supportedDiscoveryMethods), METH_NOARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QBluetoothDeviceDiscoveryAgent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QBluetoothDeviceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QBluetoothDeviceDiscoveryAgentWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QBluetoothDeviceDiscoveryAgent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBluetoothDeviceDiscoveryAgent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBluetoothDeviceDiscoveryAgent_Type = nullptr;
static PyTypeObject *Sbk_QBluetoothDeviceDiscoveryAgent_TypeF(void)
{
    return _Sbk_QBluetoothDeviceDiscoveryAgent_Type;
}

static PyType_Slot Sbk_QBluetoothDeviceDiscoveryAgent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QBluetoothDeviceDiscoveryAgent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBluetoothDeviceDiscoveryAgent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBluetoothDeviceDiscoveryAgent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBluetoothDeviceDiscoveryAgent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBluetoothDeviceDiscoveryAgent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBluetoothDeviceDiscoveryAgent_spec = {
    "2:PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBluetoothDeviceDiscoveryAgent_slots
};

} //extern "C"

static void *Sbk_QBluetoothDeviceDiscoveryAgent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QBluetoothDeviceDiscoveryAgent *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QBluetoothDeviceDiscoveryAgent_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceDiscoveryAgent::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceDiscoveryAgent::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBluetoothDeviceDiscoveryAgent_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_Error_IDX])))
        return Enum_PythonToCpp_QBluetoothDeviceDiscoveryAgent_Error;
    return {};
}

static PyObject *QBluetoothDeviceDiscoveryAgent_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBluetoothDeviceDiscoveryAgent::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBluetoothDeviceDiscoveryAgent::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_Error_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceDiscoveryAgent::DiscoveryMethod>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceDiscoveryAgent::DiscoveryMethod *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod_IDX])))
        return Enum_PythonToCpp_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod;
    return {};
}

static PyObject *QBluetoothDeviceDiscoveryAgent_DiscoveryMethod_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBluetoothDeviceDiscoveryAgent::DiscoveryMethod>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBluetoothDeviceDiscoveryAgent::DiscoveryMethod *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QBluetoothDeviceDiscoveryAgent::DiscoveryMethod>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QBluetoothDeviceDiscoveryAgent::DiscoveryMethod> *>(cppOut) = value;

}

static PyObject *QBluetoothDeviceDiscoveryAgent_DiscoveryMethod_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QBluetoothDeviceDiscoveryAgent::DiscoveryMethod> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBluetoothDeviceDiscoveryAgent_PythonToCpp_QBluetoothDeviceDiscoveryAgent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBluetoothDeviceDiscoveryAgent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBluetoothDeviceDiscoveryAgent_PythonToCpp_QBluetoothDeviceDiscoveryAgent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBluetoothDeviceDiscoveryAgent_TypeF()))
        return QBluetoothDeviceDiscoveryAgent_PythonToCpp_QBluetoothDeviceDiscoveryAgent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBluetoothDeviceDiscoveryAgent_PTR_CppToPython_QBluetoothDeviceDiscoveryAgent(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QBluetoothDeviceDiscoveryAgent *>(const_cast<void *>(cppIn)), Sbk_QBluetoothDeviceDiscoveryAgent_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBluetoothDeviceDiscoveryAgent_SignatureStrings[] = {
    "1:PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent(self,parent:PySide6.QtCore.QObject=nullptr)",
    "0:PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent(self,deviceAdapter:PySide6.QtBluetooth.QBluetoothAddress,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.discoveredDevices(self)->QList[PySide6.QtBluetooth.QBluetoothDeviceInfo]",
    "PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.error(self)->PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.Error",
    "PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.errorString(self)->QString",
    "PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.isActive(self)->bool",
    "PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.lowEnergyDiscoveryTimeout(self)->int",
    "PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.setLowEnergyDiscoveryTimeout(self,msTimeout:int)",
    "1:PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.start(self)",
    "0:PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.start(self,method:PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.DiscoveryMethod)",
    "PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.stop(self)",
    "PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.supportedDiscoveryMethods()->PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.DiscoveryMethod",
    nullptr}; // Sentinel
#else
static constexpr size_t QBluetoothDeviceDiscoveryAgent_SignatureByteSize = 264;
static constexpr uint8_t QBluetoothDeviceDiscoveryAgent_SignatureBytes[264] = {
    0x78, 0xda, 0x9d, 0x93, 0x41, 0x4f, 0x83, 0x40, 0x10, 0x85, 0xef, 0xfc, 0x92, 0x92, 0x20, 0xb1,
    0x17, 0x0f, 0x24, 0x9a, 0xa0, 0xed, 0xc1, 0xa4, 0x46, 0x49, 0xbd, 0x19, 0x0f, 0x94, 0x9d, 0xd2,
    0x35, 0xcb, 0x0e, 0x99, 0x19, 0x30, 0xfc, 0x7b, 0x91, 0x02, 0xa9, 0x1e, 0xb4, 0x9d, 0xdb, 0xcc,
    0x4e, 0xde, 0xf7, 0xde, 0x24, 0x3b, 0xcb, 0xe4, 0xa5, 0xdb, 0x5a, 0x03, 0x37, 0x71, 0x26, 0xf7,
    0xae, 0x01, 0x41, 0x94, 0x43, 0x9c, 0xcd, 0xe5, 0x0a, 0x5a, 0x5b, 0xc0, 0xca, 0x72, 0x81, 0x2d,
    0x50, 0x97, 0x96, 0xe0, 0x65, 0xc1, 0xe0, 0xf6, 0x51, 0x9d, 0x53, 0x5f, 0x9f, 0xc8, 0x1f, 0x90,
    0x20, 0xce, 0x9e, 0x77, 0x1f, 0x50, 0xc8, 0xad, 0x6f, 0x9c, 0xab, 0x85, 0xc2, 0xe0, 0x5a, 0x6d,
    0x60, 0x86, 0x49, 0x6a, 0xf2, 0x5a, 0x80, 0xfe, 0xa1, 0xa4, 0xc6, 0x10, 0x30, 0x9f, 0x1b, 0xea,
    0xf2, 0x48, 0xb1, 0x19, 0x5b, 0x30, 0xc7, 0x31, 0x0f, 0x21, 0xc3, 0xab, 0xbb, 0x6c, 0x63, 0x59,
    0xde, 0xce, 0x21, 0x3e, 0xfa, 0x3d, 0xbe, 0x6b, 0xbc, 0x81, 0x08, 0x69, 0xf2, 0x53, 0xe8, 0xd7,
    0xdf, 0x7a, 0xb5, 0xf1, 0x56, 0xc8, 0xfa, 0x72, 0x5e, 0xf7, 0xd8, 0x6a, 0x68, 0x96, 0xd3, 0x42,
    0x6c, 0x0b, 0x13, 0x6a, 0x87, 0xe8, 0x34, 0x1c, 0x87, 0x9f, 0x6b, 0x0f, 0x54, 0x76, 0xf3, 0xfb,
    0xab, 0xad, 0x00, 0x1b, 0x99, 0xc0, 0xd6, 0x8b, 0x86, 0xcb, 0x20, 0x9b, 0x3f, 0xd1, 0x51, 0xc5,
    0x63, 0x9b, 0xf4, 0x16, 0x61, 0xb0, 0x4c, 0x34, 0x2e, 0x92, 0xd3, 0x98, 0x54, 0x75, 0x1c, 0x27,
    0x80, 0xa8, 0x02, 0x39, 0xa0, 0xd1, 0x40, 0xe6, 0xf6, 0x69, 0x40, 0xa8, 0x4e, 0x82, 0x05, 0xeb,
    0x71, 0x11, 0x8d, 0xba, 0xa9, 0x6b, 0x24, 0xe9, 0xef, 0xe9, 0x67, 0x14, 0x5e, 0xe8, 0x3e, 0xf9,
    0x2f, 0x4c, 0xf0, 0x05, 0x93, 0x5c, 0xd4, 0xe3
};
#endif

PyTypeObject *init_QBluetoothDeviceDiscoveryAgent(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX].type;

    Shiboken::AutoDecRef Sbk_QBluetoothDeviceDiscoveryAgent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QBluetoothDeviceDiscoveryAgent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBluetoothDeviceDiscoveryAgent",
        "QBluetoothDeviceDiscoveryAgent*",
        &Sbk_QBluetoothDeviceDiscoveryAgent_spec,
        &Shiboken::callCppDestructor< QBluetoothDeviceDiscoveryAgent >,
        Sbk_QBluetoothDeviceDiscoveryAgent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QBluetoothDeviceDiscoveryAgent_TypeF(); // references _Sbk_QBluetoothDeviceDiscoveryAgent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBluetoothDeviceDiscoveryAgent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBluetoothDeviceDiscoveryAgent_SignatureBytes, QBluetoothDeviceDiscoveryAgent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBluetoothDeviceDiscoveryAgent_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBluetoothDeviceDiscoveryAgent_PythonToCpp_QBluetoothDeviceDiscoveryAgent_PTR,
        is_QBluetoothDeviceDiscoveryAgent_PythonToCpp_QBluetoothDeviceDiscoveryAgent_PTR_Convertible,
        QBluetoothDeviceDiscoveryAgent_PTR_CppToPython_QBluetoothDeviceDiscoveryAgent);

    Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceDiscoveryAgent");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceDiscoveryAgent*");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceDiscoveryAgent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBluetoothDeviceDiscoveryAgent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QBluetoothDeviceDiscoveryAgentWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QBluetoothDeviceDiscoveryAgent_TypeF(), &Sbk_QBluetoothDeviceDiscoveryAgent_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QBluetoothDeviceDiscoveryAgent_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "InputOutputError",
        "PoweredOffError",
        "InvalidBluetoothAdapterError",
        "UnsupportedPlatformError",
        "UnsupportedDiscoveryMethod",
        "LocationServiceTurnedOffError",
        "MissingPermissionsError",
        "UnknownError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QBluetoothDeviceDiscoveryAgent::Error::NoError),                       //  0x00  0
        uint8_t(QBluetoothDeviceDiscoveryAgent::Error::InputOutputError),              //  0x01  1
        uint8_t(QBluetoothDeviceDiscoveryAgent::Error::PoweredOffError),               //  0x02  2
        uint8_t(QBluetoothDeviceDiscoveryAgent::Error::InvalidBluetoothAdapterError),  //  0x03  3
        uint8_t(QBluetoothDeviceDiscoveryAgent::Error::UnsupportedPlatformError),      //  0x04  4
        uint8_t(QBluetoothDeviceDiscoveryAgent::Error::UnsupportedDiscoveryMethod),    //  0x05  5
        uint8_t(QBluetoothDeviceDiscoveryAgent::Error::LocationServiceTurnedOffError), //  0x06  6
        uint8_t(QBluetoothDeviceDiscoveryAgent::Error::MissingPermissionsError),       //  0x07  7
        uint8_t(QBluetoothDeviceDiscoveryAgent::Error::UnknownError)                   //  0x64  100
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceDiscoveryAgent_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_Error_IDX].type = EType;
    // Register converter for enum 'QBluetoothDeviceDiscoveryAgent::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceDiscoveryAgent_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBluetoothDeviceDiscoveryAgent_Error,
            is_Enum_PythonToCpp_QBluetoothDeviceDiscoveryAgent_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceDiscoveryAgent::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    // Initialization of enum 'DiscoveryMethod'.
    const char *DiscoveryMethod_Initializer[] = {
        "NoMethod",
        "ClassicMethod",
        "LowEnergyMethod",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DiscoveryMethod_InitializerValues[] = {
        uint8_t(QBluetoothDeviceDiscoveryAgent::DiscoveryMethod::NoMethod),       //  0x00  0
        uint8_t(QBluetoothDeviceDiscoveryAgent::DiscoveryMethod::ClassicMethod),  //  0x01  1
        uint8_t(QBluetoothDeviceDiscoveryAgent::DiscoveryMethod::LowEnergyMethod) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceDiscoveryAgent_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.DiscoveryMethod",
        DiscoveryMethod_Initializer, DiscoveryMethod_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod_IDX].type =
        EType;
    // Register converter for enum 'QBluetoothDeviceDiscoveryAgent::DiscoveryMethod'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceDiscoveryAgent_DiscoveryMethod_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod,
            is_Enum_PythonToCpp_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceDiscoveryAgent::DiscoveryMethod");
        Shiboken::Conversions::registerConverterAlias(converter, "DiscoveryMethod");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceDiscoveryAgent_DiscoveryMethod_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod,
            is_Enum_PythonToCpp_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod_Convertible);
        // Register converter for flag 'QFlags<QBluetoothDeviceDiscoveryAgent::DiscoveryMethod>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QBluetoothDeviceDiscoveryAgent::DiscoveryMethod>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QBluetoothDeviceDiscoveryAgent::DiscoveryMethods");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'DiscoveryMethod' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QBluetoothDeviceDiscoveryAgent::staticMetaObject);
    qRegisterMetaType< ::QBluetoothDeviceDiscoveryAgent::Error >("QBluetoothDeviceDiscoveryAgent::Error");
    qRegisterMetaType< ::QBluetoothDeviceDiscoveryAgent::DiscoveryMethod >("QBluetoothDeviceDiscoveryAgent::DiscoveryMethod");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QBluetoothDeviceDiscoveryAgent::staticMetaObject, sizeof(QBluetoothDeviceDiscoveryAgentWrapper));

    return pyType;
}
