// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qbluetoothhostinfo_wrapper.h"

// Argument includes
#include <QString>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtBluetooth/qbluetoothhostinfo.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBluetoothHostInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBluetoothHostInfo >()))
        return -1;

    ::QBluetoothHostInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QBluetoothHostInfo", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBluetoothHostInfo::QBluetoothHostInfo()
    // 1: QBluetoothHostInfo::QBluetoothHostInfo(QBluetoothHostInfo)
    if (numArgs == 0) {
        overloadId = 0; // QBluetoothHostInfo()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QBluetoothHostInfo(QBluetoothHostInfo)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QBluetoothHostInfo()
        {

            // QBluetoothHostInfo()
            cptr = new ::QBluetoothHostInfo();
            break;
        }
        case 1: // QBluetoothHostInfo(const QBluetoothHostInfo &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBluetoothHostInfo cppArg0_local;
            ::QBluetoothHostInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothHostInfo(QBluetoothHostInfo)
                cptr = new ::QBluetoothHostInfo(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QBluetoothHostInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QBluetoothHostInfoFunc_address(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // address()const
        QBluetoothAddress cppResult = const_cast<const ::QBluetoothHostInfo *>(cppSelf)->address();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothHostInfoFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QBluetoothHostInfo *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothHostInfoFunc_setAddress(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothHostInfo::setAddress(QBluetoothAddress)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), (pyArg)))) {
        overloadId = 0; // setAddress(QBluetoothAddress)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAddress", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBluetoothAddress cppArg0_local;
        ::QBluetoothAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setAddress(QBluetoothAddress)
            cppSelf->setAddress(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothHostInfoFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothHostInfo::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QString)
            cppSelf->setName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothHostInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QBluetoothHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QBluetoothHostInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBluetoothHostInfo_methods[] = {
    {"address", reinterpret_cast<PyCFunction>(Sbk_QBluetoothHostInfoFunc_address), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QBluetoothHostInfoFunc_name), METH_NOARGS, nullptr},
    {"setAddress", reinterpret_cast<PyCFunction>(Sbk_QBluetoothHostInfoFunc_setAddress), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QBluetoothHostInfoFunc_setName), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QBluetoothHostInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QBluetoothHostInfo_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QBluetoothHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]), (pyArg)))) {
                // operator!=(const QBluetoothHostInfo &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QBluetoothHostInfo cppArg0_local;
                ::QBluetoothHostInfo *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]), (pyArg)))) {
                // operator==(const QBluetoothHostInfo &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QBluetoothHostInfo cppArg0_local;
                ::QBluetoothHostInfo *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QBluetoothHostInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBluetoothHostInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBluetoothHostInfo_Type = nullptr;
static PyTypeObject *Sbk_QBluetoothHostInfo_TypeF(void)
{
    return _Sbk_QBluetoothHostInfo_Type;
}

static PyType_Slot Sbk_QBluetoothHostInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBluetoothHostInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBluetoothHostInfo_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QBluetoothHostInfo_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBluetoothHostInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBluetoothHostInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBluetoothHostInfo_spec = {
    "2:PySide6.QtBluetooth.QBluetoothHostInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBluetoothHostInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBluetoothHostInfo_PythonToCpp_QBluetoothHostInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBluetoothHostInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBluetoothHostInfo_PythonToCpp_QBluetoothHostInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBluetoothHostInfo_TypeF()))
        return QBluetoothHostInfo_PythonToCpp_QBluetoothHostInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBluetoothHostInfo_PTR_CppToPython_QBluetoothHostInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QBluetoothHostInfo_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QBluetoothHostInfo_COPY_CppToPython_QBluetoothHostInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QBluetoothHostInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QBluetoothHostInfo_TypeF(), new ::QBluetoothHostInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QBluetoothHostInfo_PythonToCpp_QBluetoothHostInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QBluetoothHostInfo *>(cppOut) = *reinterpret_cast< ::QBluetoothHostInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QBluetoothHostInfo_PythonToCpp_QBluetoothHostInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QBluetoothHostInfo_TypeF()))
        return QBluetoothHostInfo_PythonToCpp_QBluetoothHostInfo_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBluetoothHostInfo_SignatureStrings[] = {
    "1:PySide6.QtBluetooth.QBluetoothHostInfo(self)",
    "0:PySide6.QtBluetooth.QBluetoothHostInfo(self,other:PySide6.QtBluetooth.QBluetoothHostInfo)",
    "PySide6.QtBluetooth.QBluetoothHostInfo.address(self)->PySide6.QtBluetooth.QBluetoothAddress",
    "PySide6.QtBluetooth.QBluetoothHostInfo.name(self)->QString",
    "PySide6.QtBluetooth.QBluetoothHostInfo.setAddress(self,address:PySide6.QtBluetooth.QBluetoothAddress)",
    "PySide6.QtBluetooth.QBluetoothHostInfo.setName(self,name:QString)",
    "PySide6.QtBluetooth.QBluetoothHostInfo.__copy__(self)->typing.Self",
    "PySide6.QtBluetooth.QBluetoothHostInfo.__ne__(self,b:PySide6.QtBluetooth.QBluetoothHostInfo)->bool",
    "PySide6.QtBluetooth.QBluetoothHostInfo.__eq__(self,b:PySide6.QtBluetooth.QBluetoothHostInfo)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QBluetoothHostInfo_SignatureByteSize = 170;
static constexpr uint8_t QBluetoothHostInfo_SignatureBytes[170] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xca,
    0x29, 0x4d, 0x2d, 0xc9, 0xcf, 0x2f, 0xc9, 0xd0, 0x0b, 0x84, 0x33, 0x3d, 0xf2, 0x8b, 0x4b, 0x3c,
    0xf3, 0xd2, 0xf2, 0x35, 0x8a, 0x53, 0x73, 0xd2, 0x34, 0xb9, 0x0c, 0x48, 0x51, 0xae, 0x03, 0x14,
    0x48, 0x2d, 0x22, 0x52, 0x87, 0x26, 0x17, 0x71, 0xea, 0xf4, 0x12, 0x53, 0x52, 0x8a, 0x52, 0x8b,
    0x8b, 0x21, 0x0e, 0xd2, 0xb5, 0xc3, 0xaf, 0xcb, 0x11, 0xa2, 0x98, 0x58, 0xb3, 0xf3, 0x12, 0x73,
    0x53, 0x61, 0x06, 0x07, 0x06, 0x97, 0x14, 0x65, 0xe6, 0xa5, 0x13, 0xab, 0xb5, 0x38, 0xb5, 0xc4,
    0x11, 0xc9, 0x65, 0x3a, 0x50, 0x67, 0x5a, 0x11, 0xe5, 0x3e, 0x4d, 0x12, 0x6c, 0xf1, 0x83, 0xb9,
    0x51, 0x07, 0xe4, 0x5a, 0x2b, 0xa8, 0x33, 0x89, 0x36, 0x21, 0x3e, 0x3e, 0x39, 0xbf, 0xa0, 0x32,
    0x3e, 0x1e, 0xe6, 0xcd, 0x92, 0xca, 0x02, 0xa0, 0x76, 0xbd, 0x60, 0x20, 0x8f, 0x78, 0x23, 0xf2,
    0x52, 0xa1, 0x06, 0xe8, 0x24, 0x11, 0x1b, 0xbd, 0xba, 0x76, 0x49, 0xf9, 0xf9, 0x39, 0xc4, 0x5b,
    0x91, 0x5a, 0x48, 0xae, 0x15, 0x00, 0x09, 0xb4, 0x0b, 0x2f
};
#endif

PyTypeObject *init_QBluetoothHostInfo(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QBluetoothHostInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QBluetoothHostInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBluetoothHostInfo",
        "QBluetoothHostInfo",
        &Sbk_QBluetoothHostInfo_spec,
        &Shiboken::callCppDestructor< ::QBluetoothHostInfo >,
        Sbk_QBluetoothHostInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QBluetoothHostInfo_TypeF(); // references _Sbk_QBluetoothHostInfo_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBluetoothHostInfo_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBluetoothHostInfo_SignatureBytes, QBluetoothHostInfo_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBluetoothHostInfo_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBluetoothHostInfo_PythonToCpp_QBluetoothHostInfo_PTR,
        is_QBluetoothHostInfo_PythonToCpp_QBluetoothHostInfo_PTR_Convertible,
        QBluetoothHostInfo_PTR_CppToPython_QBluetoothHostInfo,
        QBluetoothHostInfo_COPY_CppToPython_QBluetoothHostInfo);

    Shiboken::Conversions::registerConverterName(converter, "QBluetoothHostInfo");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothHostInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothHostInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBluetoothHostInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QBluetoothHostInfo_PythonToCpp_QBluetoothHostInfo_COPY,
        is_QBluetoothHostInfo_PythonToCpp_QBluetoothHostInfo_COPY_Convertible);

    qRegisterMetaType< ::QBluetoothHostInfo >("QBluetoothHostInfo");

    return pyType;
}
