// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qbluetoothlocaldevice_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtBluetooth/qbluetoothhostinfo.h>
#include <QtBluetooth/qbluetoothlocaldevice.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QBluetoothLocalDeviceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QBluetoothLocalDeviceWrapper::QBluetoothLocalDeviceWrapper(::QObject * parent) : QBluetoothLocalDevice(parent)
{
}

QBluetoothLocalDeviceWrapper::QBluetoothLocalDeviceWrapper(const ::QBluetoothAddress & address, ::QObject * parent) : QBluetoothLocalDevice(address, parent)
{
}

void QBluetoothLocalDeviceWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothLocalDevice", funcName);
        return;
    }
}

void QBluetoothLocalDeviceWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothLocalDevice", funcName);
        return;
    }
}

void QBluetoothLocalDeviceWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothLocalDevice", funcName);
        return;
    }
}

void QBluetoothLocalDeviceWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothLocalDevice", funcName);
        return;
    }
}

bool QBluetoothLocalDeviceWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothLocalDevice", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QBluetoothLocalDevice", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QBluetoothLocalDeviceWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothLocalDevice", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QBluetoothLocalDevice", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QBluetoothLocalDeviceWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothLocalDevice", funcName);
        return;
    }
}

const QMetaObject *QBluetoothLocalDeviceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QBluetoothLocalDevice::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QBluetoothLocalDeviceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QBluetoothLocalDevice::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QBluetoothLocalDeviceWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QBluetoothLocalDeviceWrapper *>(this));
    return QBluetoothLocalDevice::qt_metacast(_clname);
}

QBluetoothLocalDeviceWrapper::~QBluetoothLocalDeviceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBluetoothLocalDevice_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBluetoothLocalDevice >()))
        return -1;

    QBluetoothLocalDeviceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QBluetoothLocalDevice", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBluetoothLocalDevice::QBluetoothLocalDevice(QObject*=)
    // 1: QBluetoothLocalDevice::QBluetoothLocalDevice(QBluetoothAddress,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QBluetoothLocalDevice(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QBluetoothLocalDevice(QBluetoothAddress,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QBluetoothLocalDevice(QBluetoothAddress,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QBluetoothLocalDevice(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QBluetoothLocalDevice(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothLocalDevice(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QBluetoothLocalDeviceWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QBluetoothLocalDeviceWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QBluetoothLocalDevice(const QBluetoothAddress &address, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBluetoothAddress cppArg0_local;
            ::QBluetoothAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothLocalDevice(QBluetoothAddress,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QBluetoothLocalDeviceWrapper(*cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QBluetoothLocalDeviceWrapper(*cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QBluetoothLocalDevice >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QBluetoothLocalDeviceFunc_address(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothLocalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // address()const
        QBluetoothAddress cppResult = const_cast<const ::QBluetoothLocalDevice *>(cppSelf)->address();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothLocalDeviceFunc_allDevices(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // allDevices()
        QList<QBluetoothHostInfo> cppResult = ::QBluetoothLocalDevice::allDevices();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothHostInfo_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothLocalDeviceFunc_connectedDevices(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothLocalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // connectedDevices()const
        QList<QBluetoothAddress> cppResult = const_cast<const ::QBluetoothLocalDevice *>(cppSelf)->connectedDevices();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothAddress_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothLocalDeviceFunc_hostMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothLocalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hostMode()const
        QBluetoothLocalDevice::HostMode cppResult = const_cast<const ::QBluetoothLocalDevice *>(cppSelf)->hostMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_HostMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothLocalDeviceFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothLocalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QBluetoothLocalDevice *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothLocalDeviceFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothLocalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QBluetoothLocalDevice *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothLocalDeviceFunc_pairingStatus(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothLocalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothLocalDevice::pairingStatus(QBluetoothAddress)const->QBluetoothLocalDevice::Pairing
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), (pyArg)))) {
        overloadId = 0; // pairingStatus(QBluetoothAddress)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "pairingStatus", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBluetoothAddress cppArg0_local;
        ::QBluetoothAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // pairingStatus(QBluetoothAddress)const
            QBluetoothLocalDevice::Pairing cppResult = const_cast<const ::QBluetoothLocalDevice *>(cppSelf)->pairingStatus(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_Pairing_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothLocalDeviceFunc_powerOn(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothLocalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // powerOn()
        cppSelf->powerOn();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothLocalDeviceFunc_requestPairing(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothLocalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "requestPairing", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBluetoothLocalDevice::requestPairing(QBluetoothAddress,QBluetoothLocalDevice::Pairing)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_Pairing_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // requestPairing(QBluetoothAddress,QBluetoothLocalDevice::Pairing)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "requestPairing", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QBluetoothAddress cppArg0_local;
        ::QBluetoothAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QBluetoothLocalDevice::Pairing cppArg1{QBluetoothLocalDevice::Unpaired};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // requestPairing(QBluetoothAddress,QBluetoothLocalDevice::Pairing)
            cppSelf->requestPairing(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothLocalDeviceFunc_setHostMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothLocalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothLocalDevice::setHostMode(QBluetoothLocalDevice::HostMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_HostMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setHostMode(QBluetoothLocalDevice::HostMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHostMode", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]);

    // Call function/method
    {
        ::QBluetoothLocalDevice::HostMode cppArg0{QBluetoothLocalDevice::HostPoweredOff};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHostMode(QBluetoothLocalDevice::HostMode)
            cppSelf->setHostMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QBluetoothLocalDevice_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QBluetoothLocalDevice_EnumFlagInfo[] = {
    "Error:Enum",
    "HostMode:Enum",
    "Pairing:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBluetoothLocalDevice_methods[] = {
    {"address", reinterpret_cast<PyCFunction>(Sbk_QBluetoothLocalDeviceFunc_address), METH_NOARGS, nullptr},
    {"allDevices", reinterpret_cast<PyCFunction>(Sbk_QBluetoothLocalDeviceFunc_allDevices), METH_NOARGS|METH_STATIC, nullptr},
    {"connectedDevices", reinterpret_cast<PyCFunction>(Sbk_QBluetoothLocalDeviceFunc_connectedDevices), METH_NOARGS, nullptr},
    {"hostMode", reinterpret_cast<PyCFunction>(Sbk_QBluetoothLocalDeviceFunc_hostMode), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QBluetoothLocalDeviceFunc_isValid), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QBluetoothLocalDeviceFunc_name), METH_NOARGS, nullptr},
    {"pairingStatus", reinterpret_cast<PyCFunction>(Sbk_QBluetoothLocalDeviceFunc_pairingStatus), METH_O, nullptr},
    {"powerOn", reinterpret_cast<PyCFunction>(Sbk_QBluetoothLocalDeviceFunc_powerOn), METH_NOARGS, nullptr},
    {"requestPairing", reinterpret_cast<PyCFunction>(Sbk_QBluetoothLocalDeviceFunc_requestPairing), METH_VARARGS, nullptr},
    {"setHostMode", reinterpret_cast<PyCFunction>(Sbk_QBluetoothLocalDeviceFunc_setHostMode), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QBluetoothLocalDevice_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QBluetoothLocalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QBluetoothLocalDeviceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QBluetoothLocalDevice_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBluetoothLocalDevice_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBluetoothLocalDevice_Type = nullptr;
static PyTypeObject *Sbk_QBluetoothLocalDevice_TypeF(void)
{
    return _Sbk_QBluetoothLocalDevice_Type;
}

static PyType_Slot Sbk_QBluetoothLocalDevice_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QBluetoothLocalDevice_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBluetoothLocalDevice_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBluetoothLocalDevice_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBluetoothLocalDevice_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBluetoothLocalDevice_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBluetoothLocalDevice_spec = {
    "2:PySide6.QtBluetooth.QBluetoothLocalDevice",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBluetoothLocalDevice_slots
};

} //extern "C"

static void *Sbk_QBluetoothLocalDevice_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QBluetoothLocalDevice *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QBluetoothLocalDevice_Pairing(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothLocalDevice::Pairing>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothLocalDevice::Pairing *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBluetoothLocalDevice_Pairing_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_Pairing_IDX])))
        return Enum_PythonToCpp_QBluetoothLocalDevice_Pairing;
    return {};
}

static PyObject *QBluetoothLocalDevice_Pairing_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBluetoothLocalDevice::Pairing>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBluetoothLocalDevice::Pairing *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_Pairing_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QBluetoothLocalDevice_HostMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothLocalDevice::HostMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothLocalDevice::HostMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBluetoothLocalDevice_HostMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_HostMode_IDX])))
        return Enum_PythonToCpp_QBluetoothLocalDevice_HostMode;
    return {};
}

static PyObject *QBluetoothLocalDevice_HostMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBluetoothLocalDevice::HostMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBluetoothLocalDevice::HostMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_HostMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QBluetoothLocalDevice_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothLocalDevice::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothLocalDevice::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBluetoothLocalDevice_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_Error_IDX])))
        return Enum_PythonToCpp_QBluetoothLocalDevice_Error;
    return {};
}

static PyObject *QBluetoothLocalDevice_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBluetoothLocalDevice::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBluetoothLocalDevice::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_Error_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBluetoothLocalDevice_PythonToCpp_QBluetoothLocalDevice_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBluetoothLocalDevice_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBluetoothLocalDevice_PythonToCpp_QBluetoothLocalDevice_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBluetoothLocalDevice_TypeF()))
        return QBluetoothLocalDevice_PythonToCpp_QBluetoothLocalDevice_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBluetoothLocalDevice_PTR_CppToPython_QBluetoothLocalDevice(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QBluetoothLocalDevice *>(const_cast<void *>(cppIn)), Sbk_QBluetoothLocalDevice_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBluetoothLocalDevice_SignatureStrings[] = {
    "1:PySide6.QtBluetooth.QBluetoothLocalDevice(self,parent:PySide6.QtCore.QObject=nullptr)",
    "0:PySide6.QtBluetooth.QBluetoothLocalDevice(self,address:PySide6.QtBluetooth.QBluetoothAddress,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtBluetooth.QBluetoothLocalDevice.address(self)->PySide6.QtBluetooth.QBluetoothAddress",
    "PySide6.QtBluetooth.QBluetoothLocalDevice.allDevices()->QList[PySide6.QtBluetooth.QBluetoothHostInfo]",
    "PySide6.QtBluetooth.QBluetoothLocalDevice.connectedDevices(self)->QList[PySide6.QtBluetooth.QBluetoothAddress]",
    "PySide6.QtBluetooth.QBluetoothLocalDevice.hostMode(self)->PySide6.QtBluetooth.QBluetoothLocalDevice.HostMode",
    "PySide6.QtBluetooth.QBluetoothLocalDevice.isValid(self)->bool",
    "PySide6.QtBluetooth.QBluetoothLocalDevice.name(self)->QString",
    "PySide6.QtBluetooth.QBluetoothLocalDevice.pairingStatus(self,address:PySide6.QtBluetooth.QBluetoothAddress)->PySide6.QtBluetooth.QBluetoothLocalDevice.Pairing",
    "PySide6.QtBluetooth.QBluetoothLocalDevice.powerOn(self)",
    "PySide6.QtBluetooth.QBluetoothLocalDevice.requestPairing(self,address:PySide6.QtBluetooth.QBluetoothAddress,pairing:PySide6.QtBluetooth.QBluetoothLocalDevice.Pairing)",
    "PySide6.QtBluetooth.QBluetoothLocalDevice.setHostMode(self,mode:PySide6.QtBluetooth.QBluetoothLocalDevice.HostMode)",
    nullptr}; // Sentinel
#else
static constexpr size_t QBluetoothLocalDevice_SignatureByteSize = 257;
static constexpr uint8_t QBluetoothLocalDevice_SignatureBytes[257] = {
    0x78, 0xda, 0x9d, 0x93, 0xb1, 0x6e, 0xc2, 0x30, 0x10, 0x86, 0x77, 0x9e, 0x84, 0x48, 0x10, 0x95,
    0x85, 0x21, 0x52, 0x2b, 0xb5, 0x65, 0x48, 0x25, 0x10, 0x58, 0x91, 0xba, 0x54, 0x1d, 0x4c, 0x7c,
    0x80, 0x2b, 0xe3, 0x4b, 0x7d, 0x17, 0xaa, 0xbe, 0x7d, 0x53, 0x62, 0x50, 0xa6, 0xd6, 0xc7, 0x76,
    0x43, 0xbe, 0xfb, 0xfe, 0xdf, 0xba, 0xcc, 0x8a, 0xcd, 0x77, 0x65, 0x0d, 0xcc, 0x73, 0xc5, 0x4f,
    0xae, 0x05, 0x46, 0xe4, 0x43, 0xae, 0xae, 0xe3, 0x12, 0x6b, 0xed, 0x16, 0x70, 0xb2, 0x35, 0x8c,
    0x09, 0xdc, 0x6e, 0xd2, 0xe8, 0x00, 0x9e, 0x07, 0xd4, 0x33, 0x06, 0xc8, 0xd5, 0x7a, 0xfb, 0x01,
    0x35, 0xdf, 0xfb, 0xd6, 0xb9, 0x86, 0x43, 0x36, 0xba, 0x93, 0xee, 0xd5, 0xc6, 0x04, 0x20, 0xfa,
    0x07, 0x7b, 0xec, 0xbf, 0x4a, 0x4d, 0x91, 0x9c, 0x21, 0x8f, 0xfa, 0x73, 0x96, 0x6c, 0xfa, 0x90,
    0x94, 0x42, 0xb2, 0xde, 0xc5, 0x89, 0xc6, 0xdd, 0x76, 0xb5, 0xb4, 0xc4, 0x6f, 0x7f, 0xd3, 0x25,
    0x12, 0xbf, 0xf8, 0x1d, 0xbe, 0x0b, 0x2c, 0x35, 0x7a, 0xdf, 0xf5, 0x07, 0x73, 0x71, 0xc5, 0x36,
    0x29, 0xbe, 0xd8, 0x49, 0xa2, 0x3b, 0x74, 0x11, 0x57, 0x68, 0x20, 0xed, 0xd1, 0x86, 0x64, 0x19,
    0x49, 0x81, 0xcc, 0xd2, 0xab, 0x76, 0xd6, 0x5c, 0x5c, 0x5b, 0x44, 0x27, 0xa0, 0xbd, 0x3e, 0x5e,
    0x63, 0xaa, 0x8a, 0x83, 0xf5, 0x7b, 0x01, 0xdd, 0x68, 0xfb, 0x4b, 0x54, 0xac, 0xb9, 0xa5, 0x1b,
    0xce, 0x55, 0xf4, 0x36, 0x9b, 0x5e, 0x26, 0x89, 0x87, 0x5f, 0x10, 0xd6, 0xbe, 0xef, 0x27, 0xe0,
    0x02, 0x7c, 0xb6, 0x40, 0x1c, 0x85, 0xb7, 0xfd, 0x86, 0x67, 0xb4, 0x10, 0xb7, 0x93, 0xc4, 0x24,
    0xe0, 0x72, 0x78, 0x69, 0x93, 0x63, 0x37, 0x15, 0xf2, 0x63, 0xcb, 0x46, 0x3f, 0x20, 0xf6, 0xd4,
    0xad
};
#endif

PyTypeObject *init_QBluetoothLocalDevice(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX].type;

    Shiboken::AutoDecRef Sbk_QBluetoothLocalDevice_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QBluetoothLocalDevice_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBluetoothLocalDevice",
        "QBluetoothLocalDevice*",
        &Sbk_QBluetoothLocalDevice_spec,
        &Shiboken::callCppDestructor< QBluetoothLocalDevice >,
        Sbk_QBluetoothLocalDevice_Type_bases.object(),
        0);
    auto *pyType = Sbk_QBluetoothLocalDevice_TypeF(); // references _Sbk_QBluetoothLocalDevice_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBluetoothLocalDevice_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBluetoothLocalDevice_SignatureBytes, QBluetoothLocalDevice_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBluetoothLocalDevice_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBluetoothLocalDevice_PythonToCpp_QBluetoothLocalDevice_PTR,
        is_QBluetoothLocalDevice_PythonToCpp_QBluetoothLocalDevice_PTR_Convertible,
        QBluetoothLocalDevice_PTR_CppToPython_QBluetoothLocalDevice);

    Shiboken::Conversions::registerConverterName(converter, "QBluetoothLocalDevice");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothLocalDevice*");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothLocalDevice&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBluetoothLocalDevice).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QBluetoothLocalDeviceWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QBluetoothLocalDevice_TypeF(), &Sbk_QBluetoothLocalDevice_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QBluetoothLocalDevice_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Pairing'.
    const char *Pairing_Initializer[] = {
        "Unpaired",
        "Paired",
        "AuthorizedPaired",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Pairing_InitializerValues[] = {
        uint8_t(QBluetoothLocalDevice::Pairing::Unpaired),        //  0x00  0
        uint8_t(QBluetoothLocalDevice::Pairing::Paired),          //  0x01  1
        uint8_t(QBluetoothLocalDevice::Pairing::AuthorizedPaired) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothLocalDevice_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothLocalDevice.Pairing",
        Pairing_Initializer, Pairing_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_Pairing_IDX].type = EType;
    // Register converter for enum 'QBluetoothLocalDevice::Pairing'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothLocalDevice_Pairing_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBluetoothLocalDevice_Pairing,
            is_Enum_PythonToCpp_QBluetoothLocalDevice_Pairing_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothLocalDevice::Pairing");
        Shiboken::Conversions::registerConverterAlias(converter, "Pairing");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Pairing' enum.

    // Initialization of enum 'HostMode'.
    const char *HostMode_Initializer[] = {
        "HostPoweredOff",
        "HostConnectable",
        "HostDiscoverable",
        "HostDiscoverableLimitedInquiry",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t HostMode_InitializerValues[] = {
        uint8_t(QBluetoothLocalDevice::HostMode::HostPoweredOff),                //  0x00  0
        uint8_t(QBluetoothLocalDevice::HostMode::HostConnectable),               //  0x01  1
        uint8_t(QBluetoothLocalDevice::HostMode::HostDiscoverable),              //  0x02  2
        uint8_t(QBluetoothLocalDevice::HostMode::HostDiscoverableLimitedInquiry) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothLocalDevice_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothLocalDevice.HostMode",
        HostMode_Initializer, HostMode_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_HostMode_IDX].type = EType;
    // Register converter for enum 'QBluetoothLocalDevice::HostMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothLocalDevice_HostMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBluetoothLocalDevice_HostMode,
            is_Enum_PythonToCpp_QBluetoothLocalDevice_HostMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothLocalDevice::HostMode");
        Shiboken::Conversions::registerConverterAlias(converter, "HostMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'HostMode' enum.

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "PairingError",
        "MissingPermissionsError",
        "UnknownError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QBluetoothLocalDevice::Error::NoError),                 //  0x00  0
        uint8_t(QBluetoothLocalDevice::Error::PairingError),            //  0x01  1
        uint8_t(QBluetoothLocalDevice::Error::MissingPermissionsError), //  0x02  2
        uint8_t(QBluetoothLocalDevice::Error::UnknownError)             //  0x64  100
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothLocalDevice_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothLocalDevice.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_Error_IDX].type = EType;
    // Register converter for enum 'QBluetoothLocalDevice::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothLocalDevice_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBluetoothLocalDevice_Error,
            is_Enum_PythonToCpp_QBluetoothLocalDevice_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothLocalDevice::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    PySide::Signal::registerSignals(pyType, &::QBluetoothLocalDevice::staticMetaObject);
    qRegisterMetaType< ::QBluetoothLocalDevice::Pairing >("QBluetoothLocalDevice::Pairing");
    qRegisterMetaType< ::QBluetoothLocalDevice::HostMode >("QBluetoothLocalDevice::HostMode");
    qRegisterMetaType< ::QBluetoothLocalDevice::Error >("QBluetoothLocalDevice::Error");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QBluetoothLocalDevice::staticMetaObject, sizeof(QBluetoothLocalDeviceWrapper));

    return pyType;
}
