// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qbluetoothservicediscoveryagent_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtBluetooth/qbluetoothservicediscoveryagent.h>
#include <QtBluetooth/qbluetoothserviceinfo.h>
#include <QtBluetooth/qbluetoothuuid.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QBluetoothServiceDiscoveryAgentWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QBluetoothServiceDiscoveryAgentWrapper::QBluetoothServiceDiscoveryAgentWrapper(::QObject * parent) : QBluetoothServiceDiscoveryAgent(parent)
{
}

QBluetoothServiceDiscoveryAgentWrapper::QBluetoothServiceDiscoveryAgentWrapper(const ::QBluetoothAddress & deviceAdapter, ::QObject * parent) : QBluetoothServiceDiscoveryAgent(deviceAdapter, parent)
{
}

void QBluetoothServiceDiscoveryAgentWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothServiceDiscoveryAgent", funcName);
        return;
    }
}

void QBluetoothServiceDiscoveryAgentWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothServiceDiscoveryAgent", funcName);
        return;
    }
}

void QBluetoothServiceDiscoveryAgentWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothServiceDiscoveryAgent", funcName);
        return;
    }
}

void QBluetoothServiceDiscoveryAgentWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothServiceDiscoveryAgent", funcName);
        return;
    }
}

bool QBluetoothServiceDiscoveryAgentWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothServiceDiscoveryAgent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QBluetoothServiceDiscoveryAgent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QBluetoothServiceDiscoveryAgentWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothServiceDiscoveryAgent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QBluetoothServiceDiscoveryAgent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QBluetoothServiceDiscoveryAgentWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBluetoothServiceDiscoveryAgent", funcName);
        return;
    }
}

const QMetaObject *QBluetoothServiceDiscoveryAgentWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QBluetoothServiceDiscoveryAgent::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QBluetoothServiceDiscoveryAgentWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QBluetoothServiceDiscoveryAgent::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QBluetoothServiceDiscoveryAgentWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QBluetoothServiceDiscoveryAgentWrapper *>(this));
    return QBluetoothServiceDiscoveryAgent::qt_metacast(_clname);
}

QBluetoothServiceDiscoveryAgentWrapper::~QBluetoothServiceDiscoveryAgentWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBluetoothServiceDiscoveryAgent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBluetoothServiceDiscoveryAgent >()))
        return -1;

    QBluetoothServiceDiscoveryAgentWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QBluetoothServiceDiscoveryAgent", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBluetoothServiceDiscoveryAgent::QBluetoothServiceDiscoveryAgent(QObject*=)
    // 1: QBluetoothServiceDiscoveryAgent::QBluetoothServiceDiscoveryAgent(QBluetoothAddress,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QBluetoothServiceDiscoveryAgent(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QBluetoothServiceDiscoveryAgent(QBluetoothAddress,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QBluetoothServiceDiscoveryAgent(QBluetoothAddress,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QBluetoothServiceDiscoveryAgent(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QBluetoothServiceDiscoveryAgent(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothServiceDiscoveryAgent(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QBluetoothServiceDiscoveryAgentWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QBluetoothServiceDiscoveryAgentWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QBluetoothServiceDiscoveryAgent(const QBluetoothAddress &deviceAdapter, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBluetoothAddress cppArg0_local;
            ::QBluetoothAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothServiceDiscoveryAgent(QBluetoothAddress,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QBluetoothServiceDiscoveryAgentWrapper(*cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QBluetoothServiceDiscoveryAgentWrapper(*cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QBluetoothServiceDiscoveryAgent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QBluetoothServiceDiscoveryAgentFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceDiscoveryAgentFunc_discoveredServices(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // discoveredServices()const
        QList<QBluetoothServiceInfo> cppResult = const_cast<const ::QBluetoothServiceDiscoveryAgent *>(cppSelf)->discoveredServices();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothServiceInfo_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceDiscoveryAgentFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QBluetoothServiceDiscoveryAgent::Error cppResult = const_cast<const ::QBluetoothServiceDiscoveryAgent *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_Error_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceDiscoveryAgentFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QBluetoothServiceDiscoveryAgent *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceDiscoveryAgentFunc_isActive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isActive()const
        bool cppResult = const_cast<const ::QBluetoothServiceDiscoveryAgent *>(cppSelf)->isActive();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceDiscoveryAgentFunc_remoteAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // remoteAddress()const
        QBluetoothAddress cppResult = const_cast<const ::QBluetoothServiceDiscoveryAgent *>(cppSelf)->remoteAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceDiscoveryAgentFunc_setRemoteAddress(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothServiceDiscoveryAgent::setRemoteAddress(QBluetoothAddress)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), (pyArg)))) {
        overloadId = 0; // setRemoteAddress(QBluetoothAddress)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRemoteAddress", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBluetoothAddress cppArg0_local;
        ::QBluetoothAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRemoteAddress(QBluetoothAddress)
            bool cppResult = cppSelf->setRemoteAddress(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceDiscoveryAgentFunc_setUuidFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothServiceDiscoveryAgent::setUuidFilter(QBluetoothUuid)
    // 1: QBluetoothServiceDiscoveryAgent::setUuidFilter(QList<QBluetoothUuid>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArg)))) {
        overloadId = 0; // setUuidFilter(QBluetoothUuid)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothUuid_IDX], (pyArg)))) {
        overloadId = 1; // setUuidFilter(QList<QBluetoothUuid>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUuidFilter", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setUuidFilter(const QBluetoothUuid &uuid)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QBluetoothUuid cppArg0_local;
            ::QBluetoothUuid *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUuidFilter(QBluetoothUuid)
                cppSelf->setUuidFilter(*cppArg0);
            }
            break;
        }
        case 1: // setUuidFilter(const QList<QBluetoothUuid> &uuids)
        {
            ::QList<QBluetoothUuid> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUuidFilter(QList<QBluetoothUuid>)
                cppSelf->setUuidFilter(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceDiscoveryAgentFunc_start(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);

    if (PyArg_ParseTuple(args, "|O:start", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBluetoothServiceDiscoveryAgent::start(QBluetoothServiceDiscoveryAgent::DiscoveryMode=)
    if (numArgs == 0) {
        overloadId = 0; // start(QBluetoothServiceDiscoveryAgent::DiscoveryMode)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_DiscoveryMode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // start(QBluetoothServiceDiscoveryAgent::DiscoveryMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_DiscoveryMode_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);
            }
        }
        ::QBluetoothServiceDiscoveryAgent::DiscoveryMode cppArg0(QBluetoothServiceDiscoveryAgent::DiscoveryMode::MinimalDiscovery);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // start(QBluetoothServiceDiscoveryAgent::DiscoveryMode)
            cppSelf->start(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceDiscoveryAgentFunc_stop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stop()
        cppSelf->stop();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceDiscoveryAgentFunc_uuidFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // uuidFilter()const
        QList<QBluetoothUuid> cppResult = const_cast<const ::QBluetoothServiceDiscoveryAgent *>(cppSelf)->uuidFilter();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothUuid_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QBluetoothServiceDiscoveryAgent_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QBluetoothServiceDiscoveryAgent_EnumFlagInfo[] = {
    "DiscoveryMode:Enum",
    "Error:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBluetoothServiceDiscoveryAgent_methods[] = {
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceDiscoveryAgentFunc_clear), METH_NOARGS, nullptr},
    {"discoveredServices", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceDiscoveryAgentFunc_discoveredServices), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceDiscoveryAgentFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceDiscoveryAgentFunc_errorString), METH_NOARGS, nullptr},
    {"isActive", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceDiscoveryAgentFunc_isActive), METH_NOARGS, nullptr},
    {"remoteAddress", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceDiscoveryAgentFunc_remoteAddress), METH_NOARGS, nullptr},
    {"setRemoteAddress", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceDiscoveryAgentFunc_setRemoteAddress), METH_O, nullptr},
    {"setUuidFilter", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceDiscoveryAgentFunc_setUuidFilter), METH_O, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceDiscoveryAgentFunc_start), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"stop", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceDiscoveryAgentFunc_stop), METH_NOARGS, nullptr},
    {"uuidFilter", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceDiscoveryAgentFunc_uuidFilter), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QBluetoothServiceDiscoveryAgent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QBluetoothServiceDiscoveryAgent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QBluetoothServiceDiscoveryAgentWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QBluetoothServiceDiscoveryAgent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBluetoothServiceDiscoveryAgent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBluetoothServiceDiscoveryAgent_Type = nullptr;
static PyTypeObject *Sbk_QBluetoothServiceDiscoveryAgent_TypeF(void)
{
    return _Sbk_QBluetoothServiceDiscoveryAgent_Type;
}

static PyType_Slot Sbk_QBluetoothServiceDiscoveryAgent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QBluetoothServiceDiscoveryAgent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBluetoothServiceDiscoveryAgent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBluetoothServiceDiscoveryAgent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBluetoothServiceDiscoveryAgent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBluetoothServiceDiscoveryAgent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBluetoothServiceDiscoveryAgent_spec = {
    "2:PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBluetoothServiceDiscoveryAgent_slots
};

} //extern "C"

static void *Sbk_QBluetoothServiceDiscoveryAgent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QBluetoothServiceDiscoveryAgent *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QBluetoothServiceDiscoveryAgent_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothServiceDiscoveryAgent::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothServiceDiscoveryAgent::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBluetoothServiceDiscoveryAgent_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_Error_IDX])))
        return Enum_PythonToCpp_QBluetoothServiceDiscoveryAgent_Error;
    return {};
}

static PyObject *QBluetoothServiceDiscoveryAgent_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBluetoothServiceDiscoveryAgent::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBluetoothServiceDiscoveryAgent::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_Error_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QBluetoothServiceDiscoveryAgent_DiscoveryMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothServiceDiscoveryAgent::DiscoveryMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothServiceDiscoveryAgent::DiscoveryMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBluetoothServiceDiscoveryAgent_DiscoveryMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_DiscoveryMode_IDX])))
        return Enum_PythonToCpp_QBluetoothServiceDiscoveryAgent_DiscoveryMode;
    return {};
}

static PyObject *QBluetoothServiceDiscoveryAgent_DiscoveryMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBluetoothServiceDiscoveryAgent::DiscoveryMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBluetoothServiceDiscoveryAgent::DiscoveryMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_DiscoveryMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBluetoothServiceDiscoveryAgent_PythonToCpp_QBluetoothServiceDiscoveryAgent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBluetoothServiceDiscoveryAgent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBluetoothServiceDiscoveryAgent_PythonToCpp_QBluetoothServiceDiscoveryAgent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBluetoothServiceDiscoveryAgent_TypeF()))
        return QBluetoothServiceDiscoveryAgent_PythonToCpp_QBluetoothServiceDiscoveryAgent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBluetoothServiceDiscoveryAgent_PTR_CppToPython_QBluetoothServiceDiscoveryAgent(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QBluetoothServiceDiscoveryAgent *>(const_cast<void *>(cppIn)), Sbk_QBluetoothServiceDiscoveryAgent_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBluetoothServiceDiscoveryAgent_SignatureStrings[] = {
    "1:PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent(self,parent:PySide6.QtCore.QObject=nullptr)",
    "0:PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent(self,deviceAdapter:PySide6.QtBluetooth.QBluetoothAddress,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.clear(self)",
    "PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.discoveredServices(self)->QList[PySide6.QtBluetooth.QBluetoothServiceInfo]",
    "PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.error(self)->PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.Error",
    "PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.errorString(self)->QString",
    "PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.isActive(self)->bool",
    "PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.remoteAddress(self)->PySide6.QtBluetooth.QBluetoothAddress",
    "PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.setRemoteAddress(self,address:PySide6.QtBluetooth.QBluetoothAddress)->bool",
    "1:PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.setUuidFilter(self,uuid:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid])",
    "0:PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.setUuidFilter(self,uuids:QList[PySide6.QtBluetooth.QBluetoothUuid])",
    "PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.start(self,mode:PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.DiscoveryMode=QBluetoothServiceDiscoveryAgent.DiscoveryMode.MinimalDiscovery)",
    "PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.stop(self)",
    "PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.uuidFilter(self)->QList[PySide6.QtBluetooth.QBluetoothUuid]",
    nullptr}; // Sentinel
#else
static constexpr size_t QBluetoothServiceDiscoveryAgent_SignatureByteSize = 349;
static constexpr uint8_t QBluetoothServiceDiscoveryAgent_SignatureBytes[349] = {
    0x78, 0xda, 0xa5, 0x54, 0x4b, 0x4b, 0x03, 0x31, 0x10, 0xbe, 0xfb, 0x2b, 0x3c, 0x2a, 0xd4, 0xc5,
    0x5e, 0x3c, 0x2c, 0x54, 0x58, 0x5b, 0x05, 0xc1, 0x62, 0xd7, 0xda, 0x93, 0xf4, 0x90, 0x26, 0xd3,
    0x36, 0x92, 0xee, 0x84, 0xc9, 0x6c, 0x61, 0xff, 0xbd, 0xd9, 0x6e, 0xba, 0xf8, 0x40, 0x1a, 0xe3,
    0x2d, 0x93, 0xe4, 0x7b, 0xcc, 0x64, 0x32, 0xc3, 0x7c, 0xd6, 0xcc, 0xb5, 0x82, 0x9b, 0xac, 0xe4,
    0x3b, 0x53, 0x03, 0x23, 0xf2, 0x36, 0x2b, 0xfb, 0xe5, 0x1c, 0x68, 0xaf, 0x25, 0x4c, 0xb4, 0x93,
    0xb8, 0x07, 0x6a, 0x8a, 0x0d, 0x54, 0x7c, 0xe1, 0xc0, 0xac, 0x07, 0x56, 0x90, 0x5f, 0x7f, 0xc2,
    0x8f, 0x91, 0x20, 0x2b, 0x9f, 0x57, 0xef, 0x20, 0x79, 0x54, 0xd5, 0xc6, 0x58, 0xa6, 0xcb, 0xb3,
    0xeb, 0x74, 0x05, 0x05, 0xed, 0x49, 0xa1, 0x84, 0x65, 0xa0, 0x13, 0x34, 0x85, 0x52, 0x04, 0xce,
    0xc5, 0xba, 0x4a, 0xf0, 0x94, 0x49, 0x03, 0x82, 0x0e, 0xce, 0xd2, 0xf0, 0x2a, 0x84, 0xa0, 0xc2,
    0xb9, 0xeb, 0xc8, 0xae, 0x6e, 0xcb, 0x27, 0xed, 0xf8, 0x2d, 0x8a, 0xf3, 0xb1, 0x5a, 0xe3, 0x32,
    0x49, 0x1e, 0x88, 0x90, 0x8e, 0x8a, 0x29, 0x04, 0xf7, 0x2d, 0x41, 0xba, 0xf4, 0x9c, 0x49, 0x57,
    0x9b, 0x3e, 0xe5, 0x2e, 0x4c, 0xa2, 0xd3, 0xae, 0x90, 0xac, 0xf7, 0x70, 0xe4, 0x5a, 0x21, 0x9a,
    0x24, 0x22, 0x82, 0x1d, 0x32, 0x84, 0xd6, 0x89, 0x2b, 0x4d, 0xb8, 0x9c, 0x24, 0xe7, 0x80, 0x5f,
    0x7e, 0x28, 0x0e, 0x44, 0x17, 0xc4, 0xf5, 0xf7, 0x31, 0xdb, 0x61, 0x9e, 0x68, 0x60, 0x51, 0x6b,
    0xf5, 0xa0, 0x8d, 0xff, 0x50, 0x9d, 0x7a, 0xed, 0xe3, 0x9c, 0x1b, 0xeb, 0xdf, 0x22, 0x5b, 0x54,
    0x1a, 0xab, 0x13, 0x6d, 0xd8, 0xe2, 0x07, 0xe7, 0xa7, 0xef, 0x64, 0xe3, 0xad, 0x20, 0x21, 0xbd,
    0x8e, 0x6f, 0x6d, 0x2d, 0x5f, 0x1b, 0x0b, 0x51, 0xb0, 0x09, 0x38, 0x49, 0xda, 0x32, 0x52, 0x34,
    0x64, 0x46, 0xc8, 0x28, 0xd1, 0x44, 0x5b, 0x0b, 0xc5, 0x19, 0x1b, 0xe1, 0xdc, 0x77, 0x50, 0x37,
    0x2e, 0xda, 0xdd, 0x65, 0xe2, 0xec, 0xfa, 0xad, 0xca, 0x2e, 0x8f, 0xf9, 0xe6, 0x41, 0x39, 0x49,
    0x97, 0x05, 0x85, 0xc9, 0xb9, 0x43, 0x05, 0x49, 0xde, 0xfb, 0x70, 0xea, 0x19, 0x46, 0x7f, 0xba,
    0x9d, 0x4d, 0x75, 0xa5, 0x77, 0xc2, 0xf4, 0x9b, 0xa9, 0x59, 0xa0, 0xfd, 0xc7, 0x90, 0xad, 0xbf,
    0x56, 0x3e, 0x72, 0xb8, 0x1e, 0xaa, 0x7e, 0xf6, 0x01, 0x06, 0x85, 0xa9, 0x23
};
#endif

PyTypeObject *init_QBluetoothServiceDiscoveryAgent(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX].type;

    Shiboken::AutoDecRef Sbk_QBluetoothServiceDiscoveryAgent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QBluetoothServiceDiscoveryAgent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBluetoothServiceDiscoveryAgent",
        "QBluetoothServiceDiscoveryAgent*",
        &Sbk_QBluetoothServiceDiscoveryAgent_spec,
        &Shiboken::callCppDestructor< QBluetoothServiceDiscoveryAgent >,
        Sbk_QBluetoothServiceDiscoveryAgent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QBluetoothServiceDiscoveryAgent_TypeF(); // references _Sbk_QBluetoothServiceDiscoveryAgent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBluetoothServiceDiscoveryAgent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBluetoothServiceDiscoveryAgent_SignatureBytes, QBluetoothServiceDiscoveryAgent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBluetoothServiceDiscoveryAgent_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBluetoothServiceDiscoveryAgent_PythonToCpp_QBluetoothServiceDiscoveryAgent_PTR,
        is_QBluetoothServiceDiscoveryAgent_PythonToCpp_QBluetoothServiceDiscoveryAgent_PTR_Convertible,
        QBluetoothServiceDiscoveryAgent_PTR_CppToPython_QBluetoothServiceDiscoveryAgent);

    Shiboken::Conversions::registerConverterName(converter, "QBluetoothServiceDiscoveryAgent");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothServiceDiscoveryAgent*");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothServiceDiscoveryAgent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBluetoothServiceDiscoveryAgent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QBluetoothServiceDiscoveryAgentWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QBluetoothServiceDiscoveryAgent_TypeF(), &Sbk_QBluetoothServiceDiscoveryAgent_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QBluetoothServiceDiscoveryAgent_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "InputOutputError",
        "PoweredOffError",
        "InvalidBluetoothAdapterError",
        "MissingPermissionsError",
        "UnknownError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QBluetoothServiceDiscoveryAgent::Error::NoError),                      //  0x00  0
        uint8_t(QBluetoothServiceDiscoveryAgent::Error::InputOutputError),             //  0x01  1
        uint8_t(QBluetoothServiceDiscoveryAgent::Error::PoweredOffError),              //  0x02  2
        uint8_t(QBluetoothServiceDiscoveryAgent::Error::InvalidBluetoothAdapterError), //  0x03  3
        uint8_t(QBluetoothServiceDiscoveryAgent::Error::MissingPermissionsError),      //  0x07  7
        uint8_t(QBluetoothServiceDiscoveryAgent::Error::UnknownError)                  //  0x64  100
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothServiceDiscoveryAgent_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_Error_IDX].type = EType;
    // Register converter for enum 'QBluetoothServiceDiscoveryAgent::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothServiceDiscoveryAgent_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBluetoothServiceDiscoveryAgent_Error,
            is_Enum_PythonToCpp_QBluetoothServiceDiscoveryAgent_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothServiceDiscoveryAgent::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    // Initialization of enum 'DiscoveryMode'.
    const char *DiscoveryMode_Initializer[] = {
        "MinimalDiscovery",
        "FullDiscovery",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DiscoveryMode_InitializerValues[] = {
        uint8_t(QBluetoothServiceDiscoveryAgent::DiscoveryMode::MinimalDiscovery), //  0x00  0
        uint8_t(QBluetoothServiceDiscoveryAgent::DiscoveryMode::FullDiscovery)     //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothServiceDiscoveryAgent_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.DiscoveryMode",
        DiscoveryMode_Initializer, DiscoveryMode_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_DiscoveryMode_IDX].type = EType;
    // Register converter for enum 'QBluetoothServiceDiscoveryAgent::DiscoveryMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothServiceDiscoveryAgent_DiscoveryMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBluetoothServiceDiscoveryAgent_DiscoveryMode,
            is_Enum_PythonToCpp_QBluetoothServiceDiscoveryAgent_DiscoveryMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothServiceDiscoveryAgent::DiscoveryMode");
        Shiboken::Conversions::registerConverterAlias(converter, "DiscoveryMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DiscoveryMode' enum.

    PySide::Signal::registerSignals(pyType, &::QBluetoothServiceDiscoveryAgent::staticMetaObject);
    qRegisterMetaType< ::QBluetoothServiceDiscoveryAgent::Error >("QBluetoothServiceDiscoveryAgent::Error");
    qRegisterMetaType< ::QBluetoothServiceDiscoveryAgent::DiscoveryMode >("QBluetoothServiceDiscoveryAgent::DiscoveryMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QBluetoothServiceDiscoveryAgent::staticMetaObject, sizeof(QBluetoothServiceDiscoveryAgentWrapper));

    return pyType;
}
