// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qbluetoothserviceinfo_sequence_wrapper.h"

// Argument includes
#include <QList>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBluetoothServiceInfo_Sequence_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBluetoothServiceInfo::Sequence >()))
        return -1;

    ::QBluetoothServiceInfo::Sequence *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Sequence", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Sequence::Sequence()
    // 1: Sequence::Sequence(QBluetoothServiceInfo::Sequence)
    // 2: Sequence::Sequence(QList<QVariant>)
    if (numArgs == 0) {
        overloadId = 0; // Sequence()
    } else if (numArgs == 1
        && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), pyArgs[0])
            && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], (pyArgs[0])))) {
        overloadId = 2; // Sequence(QList<QVariant>)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Sequence(QBluetoothServiceInfo::Sequence)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Sequence()
        {

            // Sequence()
            cptr = new ::QBluetoothServiceInfo::Sequence();
            break;
        }
        case 1: // Sequence(const QBluetoothServiceInfo::Sequence &Sequence)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBluetoothServiceInfo::Sequence cppArg0_local;
            ::QBluetoothServiceInfo::Sequence *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Sequence(QBluetoothServiceInfo::Sequence)
                cptr = new ::QBluetoothServiceInfo::Sequence(*cppArg0);
            }
            break;
        }
        case 2: // Sequence(const QList<QVariant> &list)
        {
            ::QList<QVariant> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Sequence(QList<QVariant>)
                cptr = new ::QBluetoothServiceInfo::Sequence(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QBluetoothServiceInfo::Sequence >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_append(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::append(QVariant)
    // 1: Sequence::append(QList<QVariant>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // append(QVariant)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], (pyArg)))) {
        overloadId = 1; // append(QList<QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "append", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // append(QVariant arg__1)
        {
            ::QVariant cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QVariant)
                cppSelf->append(cppArg0);
            }
            break;
        }
        case 1: // append(const QList<QVariant> &l)
        {
            ::QList<QVariant> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QList<QVariant>)
                cppSelf->append(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_at(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::at(qsizetype)const->const QVariant&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // at(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "at", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // at(qsizetype)const
            const QVariant & cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->at(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_back(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // back()
        QVariant & cppResult = cppSelf->back();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_capacity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // capacity()const
        qsizetype cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->capacity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_constData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // constData()const
        const QVariant * cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->constData();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_constFirst(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // constFirst()const
        const QVariant & cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->constFirst();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_constLast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // constLast()const
        const QVariant & cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->constLast();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        qsizetype cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()
        QVariant * cppResult = cppSelf->data();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_empty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // empty()const
        bool cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->empty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_first(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "first", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Sequence::first()->QVariant&
    // 1: Sequence::first(qsizetype)const->QList<QVariant>
    if (numArgs == 0) {
        overloadId = 0; // first()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        overloadId = 1; // first(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "first", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // first()
        {

            // first()
            QVariant & cppResult = cppSelf->first();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            break;
        }
        case 1: // first(qsizetype n) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // first(qsizetype)const
                QList<QVariant> cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->first(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_fromList(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static Sequence::fromList(QList<QVariant>)->QList<QVariant>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // fromList(QList<QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromList", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        ::QList<QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromList(QList<QVariant>)
            QList<QVariant> cppResult = ::QBluetoothServiceInfo::Sequence::fromList(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_fromVector(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static Sequence::fromVector(QList<QVariant>)->QList<QVariant>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // fromVector(QList<QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromVector", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        ::QList<QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromVector(QList<QVariant>)
            QList<QVariant> cppResult = ::QBluetoothServiceInfo::Sequence::fromVector(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_front(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // front()
        QVariant & cppResult = cppSelf->front();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_insert(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insert", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Sequence::insert(qsizetype,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // insert(qsizetype,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insert", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insert(qsizetype,QVariant)
            cppSelf->insert(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_isSharedWith(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::isSharedWith(QList<QVariant>)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // isSharedWith(QList<QVariant>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isSharedWith", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        ::QList<QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isSharedWith(QList<QVariant>)const
            bool cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->isSharedWith(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_last(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "last", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Sequence::last()->QVariant&
    // 1: Sequence::last(qsizetype)const->QList<QVariant>
    if (numArgs == 0) {
        overloadId = 0; // last()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        overloadId = 1; // last(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "last", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // last()
        {

            // last()
            QVariant & cppResult = cppSelf->last();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            break;
        }
        case 1: // last(qsizetype n) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // last(qsizetype)const
                QList<QVariant> cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->last(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // length()const
        qsizetype cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->length();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_maxSize(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxSize()
        qsizetype cppResult = ::QBluetoothServiceInfo::Sequence::maxSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_max_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // max_size()const
        qsizetype cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->max_size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_mid(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "mid", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    if (PyArg_ParseTuple(args, "|OO:mid", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Sequence::mid(qsizetype,qsizetype=)const->QList<QVariant>
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // mid(qsizetype,qsizetype)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 0; // mid(qsizetype,qsizetype)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mid", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_len = Shiboken::String::createStaticString("len");
            if (PyDict_Contains(kwds, key_len) != 0) {
                value = PyDict_GetItem(kwds, key_len);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_len);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "mid", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "mid", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_len);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "mid", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);
            }
        }
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = -1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mid(qsizetype,qsizetype)const
            QList<QVariant> cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->mid(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_move(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "move", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Sequence::move(qsizetype,qsizetype)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // move(qsizetype,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "move", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // move(qsizetype,qsizetype)
            cppSelf->move(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_pop_back(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pop_back()
        cppSelf->pop_back();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_pop_front(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pop_front()
        cppSelf->pop_front();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_prepend(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::prepend(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // prepend(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "prepend", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // prepend(QVariant)
            cppSelf->prepend(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_push_back(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::push_back(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // push_back(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "push_back", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // push_back(QVariant)
            cppSelf->push_back(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_push_front(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::push_front(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // push_front(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "push_front", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // push_front(QVariant)
            cppSelf->push_front(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_remove(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    if (PyArg_ParseTuple(args, "|OO:remove", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Sequence::remove(qsizetype,qsizetype=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // remove(qsizetype,qsizetype)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 0; // remove(qsizetype,qsizetype)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_n = Shiboken::String::createStaticString("n");
            if (PyDict_Contains(kwds, key_n) != 0) {
                value = PyDict_GetItem(kwds, key_n);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_n);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_n);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);
            }
        }
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = 1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // remove(qsizetype,qsizetype)
            cppSelf->remove(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_removeAll(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::removeAll(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // removeAll(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAll", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAll(QVariant)
            cppSelf->removeAll(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_removeAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::removeAt(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // removeAt(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAt", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAt(qsizetype)
            cppSelf->removeAt(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_removeFirst(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // removeFirst()
        cppSelf->removeFirst();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_removeLast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // removeLast()
        cppSelf->removeLast();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_removeOne(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::removeOne(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // removeOne(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeOne", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeOne(QVariant)
            cppSelf->removeOne(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_reserve(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::reserve(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // reserve(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "reserve", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // reserve(qsizetype)
            cppSelf->reserve(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_resize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::resize(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // resize(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resize", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resize(qsizetype)
            cppSelf->resize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_resizeForOverwrite(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::resizeForOverwrite(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // resizeForOverwrite(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resizeForOverwrite", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeForOverwrite(qsizetype)
            cppSelf->resizeForOverwrite(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_shrink_to_fit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shrink_to_fit()
        cppSelf->shrink_to_fit();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        qsizetype cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_sliced(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sliced", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Sequence::sliced(qsizetype)const->QList<QVariant>
    // 1: Sequence::sliced(qsizetype,qsizetype)const->QList<QVariant>
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // sliced(qsizetype)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 1; // sliced(qsizetype,qsizetype)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sliced", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // sliced(qsizetype pos) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sliced(qsizetype)const
                QList<QVariant> cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->sliced(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], &cppResult);
            }
            break;
        }
        case 1: // sliced(qsizetype pos, qsizetype n) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sliced(qsizetype,qsizetype)const
                QList<QVariant> cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->sliced(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_squeeze(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // squeeze()
        cppSelf->squeeze();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::swap(QList<QVariant>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // swap(QList<QVariant>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        ::QList<QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QList<QVariant>&)
            cppSelf->swap(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_swapItemsAt(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "swapItemsAt", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Sequence::swapItemsAt(qsizetype,qsizetype)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // swapItemsAt(qsizetype,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "swapItemsAt", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swapItemsAt(qsizetype,qsizetype)
            cppSelf->swapItemsAt(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_takeAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::takeAt(qsizetype)->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // takeAt(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "takeAt", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // takeAt(qsizetype)
            QVariant cppResult = cppSelf->takeAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_toList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toList()const
        QList<QVariant> cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->toList();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_toVector(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toVector()const
        QList<QVariant> cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->toVector();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc_value(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::value(qsizetype)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // value(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "value", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // value(qsizetype)const
            QVariant cppResult = const_cast<const ::QBluetoothServiceInfo::Sequence *>(cppSelf)->value(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_Sequence__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QBluetoothServiceInfo_Sequence_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBluetoothServiceInfo_Sequence_methods[] = {
    {"append", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_append), METH_O, nullptr},
    {"at", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_at), METH_O, nullptr},
    {"back", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_back), METH_NOARGS, nullptr},
    {"capacity", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_capacity), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_clear), METH_NOARGS, nullptr},
    {"constData", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_constData), METH_NOARGS, nullptr},
    {"constFirst", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_constFirst), METH_NOARGS, nullptr},
    {"constLast", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_constLast), METH_NOARGS, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_count), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_data), METH_NOARGS, nullptr},
    {"empty", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_empty), METH_NOARGS, nullptr},
    {"first", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_first), METH_VARARGS, nullptr},
    {"fromList", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_fromList), METH_O|METH_STATIC, nullptr},
    {"fromVector", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_fromVector), METH_O|METH_STATIC, nullptr},
    {"front", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_front), METH_NOARGS, nullptr},
    {"insert", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_insert), METH_VARARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_isEmpty), METH_NOARGS, nullptr},
    {"isSharedWith", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_isSharedWith), METH_O, nullptr},
    {"last", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_last), METH_VARARGS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_length), METH_NOARGS, nullptr},
    {"maxSize", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_maxSize), METH_NOARGS|METH_STATIC, nullptr},
    {"max_size", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_max_size), METH_NOARGS, nullptr},
    {"mid", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_mid), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"move", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_move), METH_VARARGS, nullptr},
    {"pop_back", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_pop_back), METH_NOARGS, nullptr},
    {"pop_front", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_pop_front), METH_NOARGS, nullptr},
    {"prepend", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_prepend), METH_O, nullptr},
    {"push_back", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_push_back), METH_O, nullptr},
    {"push_front", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_push_front), METH_O, nullptr},
    {"remove", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_remove), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"removeAll", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_removeAll), METH_O, nullptr},
    {"removeAt", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_removeAt), METH_O, nullptr},
    {"removeFirst", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_removeFirst), METH_NOARGS, nullptr},
    {"removeLast", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_removeLast), METH_NOARGS, nullptr},
    {"removeOne", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_removeOne), METH_O, nullptr},
    {"reserve", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_reserve), METH_O, nullptr},
    {"resize", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_resize), METH_O, nullptr},
    {"resizeForOverwrite", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_resizeForOverwrite), METH_O, nullptr},
    {"shrink_to_fit", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_shrink_to_fit), METH_NOARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_size), METH_NOARGS, nullptr},
    {"sliced", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_sliced), METH_VARARGS, nullptr},
    {"squeeze", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_squeeze), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_swap), METH_O, nullptr},
    {"swapItemsAt", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_swapItemsAt), METH_VARARGS, nullptr},
    {"takeAt", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_takeAt), METH_O, nullptr},
    {"toList", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_toList), METH_NOARGS, nullptr},
    {"toVector", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_toVector), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_SequenceFunc_value), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QBluetoothServiceInfo_Sequence__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc___add__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::operator+(QList<QVariant>)->QList<QVariant>
    // 1: Sequence::operator+(QList<QVariant>)const->QList<QVariant>
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], (pyArg)))) {
        overloadId = 1; // operator+(QList<QVariant>)const
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // operator+(QList<QVariant>)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // operator+(const QList<QVariant> &l)
        {
            ::QList<QVariant> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(QList<QVariant>)
                QList<QVariant> cppResult = (*cppSelf) + cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], &cppResult);
            }
            break;
        }
        case 1: // operator+(const QList<QVariant> &l) const
        {
            ::QList<QVariant> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(QList<QVariant>)const
                QList<QVariant> cppResult = (*cppSelf) + cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Sequence::operator+=(QList<QVariant>)->QList<QVariant>&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // operator+=(QList<QVariant>)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+=", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

    // Call function/method
    {
        ::QList<QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+=(QList<QVariant>)
            (*cppSelf) += cppArg0;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QBluetoothServiceInfo_SequenceFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: Sequence::operator<<(QList<QVariant>)->QList<QVariant>&
        if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], (pyArg)))) {
            overloadId = 0; // operator<<(QList<QVariant>)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]);

        // Call function/method
        {
            ::QList<QVariant> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QList<QVariant>)
                QList<QVariant> & cppResult = (*cppSelf) << cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

Py_ssize_t Sbk_QBluetoothServiceInfo_Sequence__len__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return cppSelf->size();
}
PyObject *Sbk_QBluetoothServiceInfo_Sequence__getitem__(PyObject *self, Py_ssize_t _i)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    const Py_ssize_t size = cppSelf->size();
    if (_i < 0 || _i >= size) {
        Shiboken::Errors::setIndexOutOfBounds(_i, 0, size);
        return nullptr;
    }
    QBluetoothServiceInfo::Sequence::const_iterator _item = cppSelf->begin();
    std::advance(_item, _i);
    return Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &*_item);
}
int Sbk_QBluetoothServiceInfo_Sequence__setitem__(PyObject *self, Py_ssize_t _i, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    const Py_ssize_t size = cppSelf->size();
    if (_i < 0 || _i >= size) {
        Shiboken::Errors::setIndexOutOfBounds(_i, 0, size);
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        Shiboken::Errors::setSequenceTypeError("QVariant");
        return -1;
    }
    ::QVariant cppValue;
    pythonToCpp(pyArg, &cppValue);
    QBluetoothServiceInfo::Sequence::iterator _item = cppSelf->begin();
    std::advance(_item, _i);
    *_item = cppValue;
    return {};
}
} // extern "C"

static int Sbk_QBluetoothServiceInfo_Sequence_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBluetoothServiceInfo_Sequence_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBluetoothServiceInfo_Sequence_Type = nullptr;
static PyTypeObject *Sbk_QBluetoothServiceInfo_Sequence_TypeF(void)
{
    return _Sbk_QBluetoothServiceInfo_Sequence_Type;
}

static PyType_Slot Sbk_QBluetoothServiceInfo_Sequence_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBluetoothServiceInfo_Sequence_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBluetoothServiceInfo_Sequence_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBluetoothServiceInfo_Sequence_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBluetoothServiceInfo_Sequence_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports sequence protocol
    {Py_sq_ass_item,    reinterpret_cast<void *>(Sbk_QBluetoothServiceInfo_Sequence__setitem__)},
    {Py_sq_length,      reinterpret_cast<void *>(Sbk_QBluetoothServiceInfo_Sequence__len__)},
    {Py_sq_item,        reinterpret_cast<void *>(Sbk_QBluetoothServiceInfo_Sequence__getitem__)},
    // type supports number protocol
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QBluetoothServiceInfo_SequenceFunc___iadd__)},
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QBluetoothServiceInfo_SequenceFunc___lshift__)},
    {Py_nb_add,         reinterpret_cast<void *>(Sbk_QBluetoothServiceInfo_SequenceFunc___add__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBluetoothServiceInfo_Sequence_spec = {
    "2:PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBluetoothServiceInfo_Sequence_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Sequence_PythonToCpp_Sequence_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBluetoothServiceInfo_Sequence_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Sequence_PythonToCpp_Sequence_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBluetoothServiceInfo_Sequence_TypeF()))
        return Sequence_PythonToCpp_Sequence_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Sequence_PTR_CppToPython_Sequence(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QBluetoothServiceInfo_Sequence_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *Sequence_COPY_CppToPython_Sequence(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QBluetoothServiceInfo::Sequence *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QBluetoothServiceInfo_Sequence_TypeF(), new ::QBluetoothServiceInfo::Sequence(*source), true, true);
}

// Python to C++ copy conversion.
static void Sequence_PythonToCpp_Sequence_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QBluetoothServiceInfo::Sequence *>(cppOut) = *reinterpret_cast< ::QBluetoothServiceInfo::Sequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Sequence_PythonToCpp_Sequence_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QBluetoothServiceInfo_Sequence_TypeF()))
        return Sequence_PythonToCpp_Sequence_COPY;
    return {};
}

// Implicit conversions.
static void _constQList_QVariant_REF_PythonToCpp_QBluetoothServiceInfo_Sequence(PyObject *pyIn, void *cppOut)
{
    ::QList<QVariant> cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QBluetoothServiceInfo::Sequence *>(cppOut) = ::QBluetoothServiceInfo::Sequence(cppIn);
}
static PythonToCppFunc is__constQList_QVariant_REF_PythonToCpp_QBluetoothServiceInfo_Sequence_Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyIn))
        return _constQList_QVariant_REF_PythonToCpp_QBluetoothServiceInfo_Sequence;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBluetoothServiceInfo_Sequence_SignatureStrings[] = {
    "2:PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence(self)",
    "1:PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence(self,Sequence:PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence)",
    "0:PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence(self,list:QList[QVariant])",
    "1:PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.append(self,arg__1:QVariant)",
    "0:PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.append(self,l:QList[QVariant])",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.at(self,i:qsizetype)->QVariant",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.back(self)->QVariant",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.capacity(self)->qsizetype",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.clear(self)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.constData(self)->QVariant*",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.constFirst(self)->QVariant",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.constLast(self)->QVariant",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.count(self)->qsizetype",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.data(self)->QVariant*",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.empty(self)->bool",
    "1:PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.first(self)->QVariant",
    "0:PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.first(self,n:qsizetype)->QList[QVariant]",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.fromList(list:QList[QVariant])->QList[QVariant]",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.fromVector(vector:QList[QVariant])->QList[QVariant]",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.front(self)->QVariant",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.insert(self,arg__1:qsizetype,arg__2:QVariant)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.isEmpty(self)->bool",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.isSharedWith(self,other:QList[QVariant])->bool",
    "1:PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.last(self)->QVariant",
    "0:PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.last(self,n:qsizetype)->QList[QVariant]",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.length(self)->qsizetype",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.maxSize()->qsizetype",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.max_size(self)->qsizetype",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.mid(self,pos:qsizetype,len:qsizetype=-1)->QList[QVariant]",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.move(self,from:qsizetype,to:qsizetype)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.pop_back(self)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.pop_front(self)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.prepend(self,arg__1:QVariant)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.push_back(self,arg__1:QVariant)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.push_front(self,arg__1:QVariant)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.remove(self,i:qsizetype,n:qsizetype=1)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.removeAll(self,arg__1:QVariant)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.removeAt(self,i:qsizetype)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.removeFirst(self)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.removeLast(self)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.removeOne(self,arg__1:QVariant)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.reserve(self,size:qsizetype)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.resize(self,size:qsizetype)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.resizeForOverwrite(self,size:qsizetype)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.shrink_to_fit(self)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.size(self)->qsizetype",
    "1:PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.sliced(self,pos:qsizetype)->QList[QVariant]",
    "0:PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.sliced(self,pos:qsizetype,n:qsizetype)->QList[QVariant]",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.squeeze(self)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.swap(self,other:QList[QVariant])",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.swapItemsAt(self,i:qsizetype,j:qsizetype)",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.takeAt(self,i:qsizetype)->QVariant",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.toList(self)->QList[QVariant]",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.toVector(self)->QList[QVariant]",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.value(self,i:qsizetype)->QVariant",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.__copy__(self)->typing.Self",
    "1:PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.__add__(self,l:QList[QVariant])->QList[QVariant]",
    "0:PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.__add__(self,l:QList[QVariant])->QList[QVariant]",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.__iadd__(self,l:QList[QVariant])->QList[QVariant]",
    "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence.__lshift__(self,l:QList[QVariant])->QList[QVariant]",
    nullptr}; // Sentinel
#else
static constexpr size_t QBluetoothServiceInfo_Sequence_SignatureByteSize = 579;
static constexpr uint8_t QBluetoothServiceInfo_Sequence_SignatureBytes[579] = {
    0x78, 0xda, 0xbd, 0x98, 0xdf, 0x6b, 0xdb, 0x30, 0x10, 0xc7, 0xdf, 0xfb, 0x97, 0x24, 0x23, 0x0d,
    0x49, 0x1f, 0xf6, 0x10, 0xe8, 0xa0, 0x65, 0x2b, 0x14, 0x0a, 0x5d, 0x30, 0x74, 0x0f, 0x63, 0x08,
    0xd5, 0x3e, 0xc7, 0x5a, 0x64, 0x49, 0x95, 0x2e, 0xee, 0xb2, 0xbf, 0x7e, 0x76, 0xfd, 0x33, 0xab,
    0x29, 0xf4, 0x7c, 0xdb, 0x4b, 0x1c, 0xdb, 0xd1, 0xe7, 0xee, 0xbe, 0xba, 0x3b, 0x1d, 0xb9, 0xd8,
    0x7c, 0x3d, 0x46, 0x2a, 0x81, 0x8f, 0xcb, 0x2d, 0x5e, 0xeb, 0x03, 0xa0, 0xb5, 0x98, 0x2d, 0xb7,
    0xdd, 0xd7, 0x08, 0x7c, 0xa1, 0x62, 0xb8, 0x35, 0xa9, 0x5d, 0x46, 0xf0, 0x74, 0x00, 0x13, 0xc3,
    0x2c, 0x80, 0x4e, 0xe7, 0x67, 0x6b, 0xea, 0xd2, 0x45, 0x7b, 0x47, 0x00, 0xcc, 0xcf, 0x56, 0x64,
    0xb3, 0x5a, 0x05, 0xdc, 0x6c, 0xef, 0xca, 0xcf, 0xef, 0xdb, 0x07, 0xe9, 0x95, 0x34, 0xf8, 0x83,
    0x16, 0xc6, 0x52, 0x3a, 0x07, 0x26, 0xa9, 0xb1, 0xd2, 0xef, 0x84, 0x58, 0x6f, 0x5a, 0x24, 0xcd,
    0xc3, 0x13, 0xa2, 0x7e, 0xed, 0x25, 0x85, 0x88, 0x35, 0x4d, 0x6d, 0x9e, 0x82, 0xfa, 0x0d, 0x78,
    0x74, 0x30, 0x3f, 0xff, 0xd4, 0x32, 0x29, 0xc4, 0x47, 0x19, 0xef, 0xeb, 0xcd, 0x9f, 0xc6, 0x89,
    0xa5, 0x93, 0xb1, 0xc2, 0x63, 0xcb, 0xea, 0xfc, 0x23, 0xc1, 0x34, 0x48, 0xdf, 0xa4, 0x24, 0x65,
    0xb9, 0x35, 0x01, 0x3f, 0x4b, 0x94, 0x7f, 0x07, 0xf6, 0x81, 0x4c, 0xbb, 0x51, 0x3e, 0x20, 0x8b,
    0x4e, 0x15, 0xed, 0x4e, 0x72, 0xc1, 0x0e, 0x06, 0x59, 0x14, 0x4f, 0xb8, 0xd4, 0x82, 0xdc, 0xf5,
    0x49, 0xf0, 0x68, 0xad, 0xa6, 0x15, 0x63, 0x3a, 0xaa, 0xf7, 0x6a, 0x1a, 0x6a, 0x61, 0x4e, 0xcb,
    0xe6, 0xb4, 0x20, 0x29, 0xd1, 0xa6, 0xde, 0xe6, 0x15, 0x65, 0x36, 0xda, 0x87, 0xd8, 0x4c, 0x3c,
    0x40, 0x8c, 0xd6, 0xcf, 0x8a, 0x97, 0xcb, 0x3f, 0x33, 0x63, 0x58, 0x72, 0x52, 0x99, 0x00, 0x1e,
    0x4f, 0xda, 0x68, 0x27, 0x7a, 0xfd, 0xe0, 0x62, 0xd0, 0x57, 0x29, 0x06, 0xc2, 0x97, 0x57, 0x39,
    0x46, 0xc2, 0x44, 0x99, 0xf4, 0x90, 0x7c, 0x53, 0x98, 0xd5, 0xde, 0x96, 0xbf, 0x84, 0x31, 0x75,
    0xe9, 0x59, 0xac, 0x25, 0x57, 0x12, 0x77, 0x24, 0xfe, 0x1c, 0xd6, 0x60, 0x76, 0x8d, 0x04, 0x53,
    0xbb, 0x48, 0x2e, 0x7f, 0x45, 0xe5, 0xf2, 0x19, 0x03, 0x47, 0x54, 0xeb, 0x79, 0x9c, 0x52, 0xcd,
    0x11, 0xec, 0x6c, 0x18, 0xa4, 0x62, 0x19, 0x76, 0x7f, 0x77, 0x79, 0xbe, 0xe6, 0x11, 0x33, 0xb7,
    0x45, 0x33, 0x99, 0x54, 0x75, 0x3b, 0x30, 0x87, 0x76, 0xb0, 0x6f, 0x14, 0xb2, 0xb3, 0x4e, 0xf4,
    0x87, 0x35, 0x95, 0x30, 0x28, 0x73, 0x12, 0xc2, 0xc3, 0x1b, 0x43, 0x12, 0x05, 0x78, 0x08, 0x59,
    0x1f, 0x16, 0x1f, 0xb2, 0x8f, 0x93, 0x85, 0xe9, 0xa1, 0xdf, 0xd8, 0xc1, 0xec, 0x35, 0x2c, 0xc6,
    0xcb, 0xf5, 0x04, 0xf2, 0x95, 0xd6, 0xdc, 0xce, 0x5e, 0x8d, 0x8c, 0x8a, 0x74, 0xda, 0x60, 0xfe,
    0xa1, 0x43, 0xfa, 0xb1, 0x87, 0xce, 0xb8, 0x37, 0xc0, 0xa9, 0x54, 0x79, 0x56, 0xb5, 0xfb, 0x5a,
    0xa9, 0x34, 0x59, 0xab, 0xae, 0x6b, 0xf1, 0xe1, 0x6e, 0xac, 0xbf, 0x2f, 0xc0, 0x3f, 0x7b, 0x85,
    0x7c, 0xe8, 0x90, 0x79, 0x65, 0xf6, 0x02, 0xad, 0x48, 0xd5, 0x84, 0x3d, 0x19, 0x6f, 0xd2, 0xa4,
    0xb3, 0x32, 0xe8, 0xf2, 0xd1, 0x58, 0xa7, 0x1e, 0x69, 0xcc, 0x2b, 0x56, 0x03, 0xfc, 0x47, 0x6a,
    0x28, 0xaf, 0xd0, 0x2a, 0x43, 0x02, 0x3c, 0x4b, 0xf7, 0xd6, 0x50, 0x42, 0x65, 0xde, 0x22, 0xe4,
    0x61, 0xa4, 0x33, 0x2c, 0x7e, 0x4e, 0xcc, 0x27, 0x94, 0xfb, 0xd1, 0x8e, 0x33, 0x6d, 0x96, 0x44,
    0xfb, 0x32, 0x5c, 0xb7, 0x13, 0xd4, 0xf4, 0x8d, 0x41, 0xdb, 0x8c, 0xd2, 0x7c, 0xc8, 0x42, 0x96,
    0xaf, 0xb9, 0x03, 0x17, 0x22, 0xb6, 0xee, 0x28, 0x44, 0xeb, 0x67, 0x89, 0x54, 0x66, 0x57, 0xbe,
    0xd7, 0x29, 0xad, 0xba, 0x84, 0x90, 0x49, 0xd2, 0xf0, 0x46, 0xfe, 0x8b, 0x60, 0x2a, 0xb1, 0x77,
    0x5b, 0x21, 0xd9, 0x50, 0xff, 0xc3, 0x88, 0x0e, 0x99, 0x4a, 0xf1, 0x3d, 0x66, 0xfe, 0x00, 0xc1,
    0x44, 0x40, 0x82
};
#endif

PyTypeObject *init_QBluetoothServiceInfo_Sequence(PyObject *enclosingClass)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX].type;

    Shiboken::AutoDecRef Sbk_QBluetoothServiceInfo_Sequence_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QBluetoothServiceInfo_Sequence_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Sequence",
        "QBluetoothServiceInfo::Sequence",
        &Sbk_QBluetoothServiceInfo_Sequence_spec,
        &Shiboken::callCppDestructor< ::QBluetoothServiceInfo::Sequence >,
        Sbk_QBluetoothServiceInfo_Sequence_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QBluetoothServiceInfo_Sequence_TypeF(); // references _Sbk_QBluetoothServiceInfo_Sequence_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBluetoothServiceInfo_Sequence_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBluetoothServiceInfo_Sequence_SignatureBytes, QBluetoothServiceInfo_Sequence_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBluetoothServiceInfo_Sequence_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Sequence_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Sequence_PythonToCpp_Sequence_PTR,
        is_Sequence_PythonToCpp_Sequence_PTR_Convertible,
        Sequence_PTR_CppToPython_Sequence,
        Sequence_COPY_CppToPython_Sequence);

    Shiboken::Conversions::registerConverterName(converter, "QBluetoothServiceInfo::Sequence");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothServiceInfo::Sequence*");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothServiceInfo::Sequence&");
    Shiboken::Conversions::registerConverterAlias(converter, "Sequence");
    Shiboken::Conversions::registerConverterAlias(converter, "Sequence*");
    Shiboken::Conversions::registerConverterAlias(converter, "Sequence&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBluetoothServiceInfo::Sequence).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Sequence_PythonToCpp_Sequence_COPY,
        is_Sequence_PythonToCpp_Sequence_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        _constQList_QVariant_REF_PythonToCpp_QBluetoothServiceInfo_Sequence,
        is__constQList_QVariant_REF_PythonToCpp_QBluetoothServiceInfo_Sequence_Convertible);

    qRegisterMetaType< ::QBluetoothServiceInfo::Sequence >("Sequence");
    qRegisterMetaType< ::QBluetoothServiceInfo::Sequence >("QBluetoothServiceInfo::Sequence");

    return pyType;
}
