// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qbluetoothuuid_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QString>
#include <QtBluetooth/qbluetoothuuid.h>
#include <qbytearray.h>
#include <qbytearrayview.h>
#include <qdatastream.h>
#include <qsysinfo.h>
#include <quuid.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBluetoothUuid_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBluetoothUuid >()))
        return -1;

    ::QBluetoothUuid *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QBluetoothUuid", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBluetoothUuid::QBluetoothUuid()
    // 1: QBluetoothUuid::QBluetoothUuid(QBluetoothUuid::CharacteristicType)
    // 2: QBluetoothUuid::QBluetoothUuid(QBluetoothUuid::DescriptorType)
    // 3: QBluetoothUuid::QBluetoothUuid(QBluetoothUuid::ProtocolUuid)
    // 4: QBluetoothUuid::QBluetoothUuid(QBluetoothUuid::ServiceClassUuid)
    // 5: QBluetoothUuid::QBluetoothUuid(QBluetoothUuid)
    // 6: QBluetoothUuid::QBluetoothUuid(QUuid)
    // 7: QBluetoothUuid::QBluetoothUuid(quint16)
    // 8: QBluetoothUuid::QBluetoothUuid(quint32)
    if (numArgs == 0) {
        overloadId = 0; // QBluetoothUuid()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_ServiceClassUuid_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 4; // QBluetoothUuid(QBluetoothUuid::ServiceClassUuid)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_ProtocolUuid_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 3; // QBluetoothUuid(QBluetoothUuid::ProtocolUuid)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_DescriptorType_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 2; // QBluetoothUuid(QBluetoothUuid::DescriptorType)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_CharacteristicType_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // QBluetoothUuid(QBluetoothUuid::CharacteristicType)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArgs[0])))) {
        overloadId = 5; // QBluetoothUuid(QBluetoothUuid)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArgs[0])))) {
        overloadId = 6; // QBluetoothUuid(QUuid)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[0])))) {
        overloadId = 7; // QBluetoothUuid(quint16)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[0])))) {
        overloadId = 8; // QBluetoothUuid(quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QBluetoothUuid()
        {

            // QBluetoothUuid()
            cptr = new ::QBluetoothUuid();
            break;
        }
        case 1: // QBluetoothUuid(QBluetoothUuid::CharacteristicType uuid)
        {
            ::QBluetoothUuid::CharacteristicType cppArg0 = static_cast< ::QBluetoothUuid::CharacteristicType>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothUuid(QBluetoothUuid::CharacteristicType)
                cptr = new ::QBluetoothUuid(cppArg0);
            }
            break;
        }
        case 2: // QBluetoothUuid(QBluetoothUuid::DescriptorType uuid)
        {
            ::QBluetoothUuid::DescriptorType cppArg0{QBluetoothUuid::DescriptorType::UnknownDescriptorType};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothUuid(QBluetoothUuid::DescriptorType)
                cptr = new ::QBluetoothUuid(cppArg0);
            }
            break;
        }
        case 3: // QBluetoothUuid(QBluetoothUuid::ProtocolUuid uuid)
        {
            ::QBluetoothUuid::ProtocolUuid cppArg0 = static_cast< ::QBluetoothUuid::ProtocolUuid>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothUuid(QBluetoothUuid::ProtocolUuid)
                cptr = new ::QBluetoothUuid(cppArg0);
            }
            break;
        }
        case 4: // QBluetoothUuid(QBluetoothUuid::ServiceClassUuid uuid)
        {
            ::QBluetoothUuid::ServiceClassUuid cppArg0 = static_cast< ::QBluetoothUuid::ServiceClassUuid>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothUuid(QBluetoothUuid::ServiceClassUuid)
                cptr = new ::QBluetoothUuid(cppArg0);
            }
            break;
        }
        case 5: // QBluetoothUuid(const QBluetoothUuid &uuid)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBluetoothUuid cppArg0_local;
            ::QBluetoothUuid *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothUuid(QBluetoothUuid)
                cptr = new ::QBluetoothUuid(*cppArg0);
            }
            break;
        }
        case 6: // QBluetoothUuid(const QUuid &uuid)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUuid cppArg0_local;
            ::QUuid *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothUuid(QUuid)
                cptr = new ::QBluetoothUuid(*cppArg0);
            }
            break;
        }
        case 7: // QBluetoothUuid(quint16 uuid)
        {
            quint16 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothUuid(quint16)
                cptr = new ::QBluetoothUuid(cppArg0);
            }
            break;
        }
        case 8: // QBluetoothUuid(quint32 uuid)
        {
            quint32 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothUuid(quint32)
                cptr = new ::QBluetoothUuid(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QBluetoothUuid >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QBluetoothUuidFunc_characteristicToString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QBluetoothUuid::characteristicToString(QBluetoothUuid::CharacteristicType)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_CharacteristicType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // characteristicToString(QBluetoothUuid::CharacteristicType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "characteristicToString", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]);

    // Call function/method
    {
        ::QBluetoothUuid::CharacteristicType cppArg0 = static_cast< ::QBluetoothUuid::CharacteristicType>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // characteristicToString(QBluetoothUuid::CharacteristicType)
            QString cppResult = ::QBluetoothUuid::characteristicToString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothUuidFunc_descriptorToString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QBluetoothUuid::descriptorToString(QBluetoothUuid::DescriptorType)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_DescriptorType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // descriptorToString(QBluetoothUuid::DescriptorType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "descriptorToString", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]);

    // Call function/method
    {
        ::QBluetoothUuid::DescriptorType cppArg0{QBluetoothUuid::DescriptorType::UnknownDescriptorType};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // descriptorToString(QBluetoothUuid::DescriptorType)
            QString cppResult = ::QBluetoothUuid::descriptorToString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothUuidFunc_minimumSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumSize()const
        int cppResult = const_cast<const ::QBluetoothUuid *>(cppSelf)->minimumSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothUuidFunc_protocolToString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QBluetoothUuid::protocolToString(QBluetoothUuid::ProtocolUuid)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_ProtocolUuid_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // protocolToString(QBluetoothUuid::ProtocolUuid)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "protocolToString", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]);

    // Call function/method
    {
        ::QBluetoothUuid::ProtocolUuid cppArg0 = static_cast< ::QBluetoothUuid::ProtocolUuid>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // protocolToString(QBluetoothUuid::ProtocolUuid)
            QString cppResult = ::QBluetoothUuid::protocolToString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothUuidFunc_serviceClassToString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QBluetoothUuid::serviceClassToString(QBluetoothUuid::ServiceClassUuid)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_ServiceClassUuid_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // serviceClassToString(QBluetoothUuid::ServiceClassUuid)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "serviceClassToString", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]);

    // Call function/method
    {
        ::QBluetoothUuid::ServiceClassUuid cppArg0 = static_cast< ::QBluetoothUuid::ServiceClassUuid>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // serviceClassToString(QBluetoothUuid::ServiceClassUuid)
            QString cppResult = ::QBluetoothUuid::serviceClassToString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothUuidFunc_toUInt16(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        bool* removed_cppArg0 = nullptr;
        SBK_UNUSED(removed_cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // toUInt16(bool*)const
            // Begin code injection
            // TEMPLATE - fix_bool* - START
            bool ok_;
            quint16 retval_ = cppSelf->toUInt16(&ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothUuidFunc_toUInt32(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        bool* removed_cppArg0 = nullptr;
        SBK_UNUSED(removed_cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // toUInt32(bool*)const
            // Begin code injection
            // TEMPLATE - fix_bool* - START
            bool ok_;
            quint32 retval_ = cppSelf->toUInt32(&ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothUuid__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QBluetoothUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QBluetoothUuid_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QBluetoothUuid_EnumFlagInfo[] = {
    "CharacteristicType:Enum",
    "DescriptorType:Enum",
    "ProtocolUuid:Enum",
    "ServiceClassUuid:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBluetoothUuid_methods[] = {
    {"characteristicToString", reinterpret_cast<PyCFunction>(Sbk_QBluetoothUuidFunc_characteristicToString), METH_O|METH_STATIC, nullptr},
    {"descriptorToString", reinterpret_cast<PyCFunction>(Sbk_QBluetoothUuidFunc_descriptorToString), METH_O|METH_STATIC, nullptr},
    {"minimumSize", reinterpret_cast<PyCFunction>(Sbk_QBluetoothUuidFunc_minimumSize), METH_NOARGS, nullptr},
    {"protocolToString", reinterpret_cast<PyCFunction>(Sbk_QBluetoothUuidFunc_protocolToString), METH_O|METH_STATIC, nullptr},
    {"serviceClassToString", reinterpret_cast<PyCFunction>(Sbk_QBluetoothUuidFunc_serviceClassToString), METH_O|METH_STATIC, nullptr},
    {"toUInt16", reinterpret_cast<PyCFunction>(Sbk_QBluetoothUuidFunc_toUInt16), METH_NOARGS, nullptr},
    {"toUInt32", reinterpret_cast<PyCFunction>(Sbk_QBluetoothUuidFunc_toUInt32), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QBluetoothUuid__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QBluetoothUuid___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QBluetoothUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

static PyObject *Sbk_QBluetoothUuidFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QBluetoothUuid::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QBluetoothUuid)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QBluetoothUuid) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothUuidFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QBluetoothUuid::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QBluetoothUuid&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QBluetoothUuid&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QBluetoothUuid_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QBluetoothUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArg)))) {
                // operator!=(const QBluetoothUuid &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QBluetoothUuid cppArg0_local;
                ::QBluetoothUuid *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArg)))) {
                // operator==(const QBluetoothUuid &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QBluetoothUuid cppArg0_local;
                ::QBluetoothUuid *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QBluetoothUuid_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBluetoothUuid_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBluetoothUuid_Type = nullptr;
static PyTypeObject *Sbk_QBluetoothUuid_TypeF(void)
{
    return _Sbk_QBluetoothUuid_Type;
}

static PyType_Slot Sbk_QBluetoothUuid_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBluetoothUuid_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBluetoothUuid_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QBluetoothUuid_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBluetoothUuid_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBluetoothUuid_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QBluetoothUuid___nb_bool)},
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QBluetoothUuidFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QBluetoothUuidFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBluetoothUuid_spec = {
    "2:PySide6.QtBluetooth.QBluetoothUuid",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBluetoothUuid_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QBluetoothUuid_ProtocolUuid(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothUuid::ProtocolUuid>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothUuid::ProtocolUuid *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBluetoothUuid_ProtocolUuid_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_ProtocolUuid_IDX])))
        return Enum_PythonToCpp_QBluetoothUuid_ProtocolUuid;
    return {};
}

static PyObject *QBluetoothUuid_ProtocolUuid_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBluetoothUuid::ProtocolUuid>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBluetoothUuid::ProtocolUuid *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_ProtocolUuid_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QBluetoothUuid_ServiceClassUuid(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothUuid::ServiceClassUuid>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothUuid::ServiceClassUuid *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBluetoothUuid_ServiceClassUuid_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_ServiceClassUuid_IDX])))
        return Enum_PythonToCpp_QBluetoothUuid_ServiceClassUuid;
    return {};
}

static PyObject *QBluetoothUuid_ServiceClassUuid_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBluetoothUuid::ServiceClassUuid>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBluetoothUuid::ServiceClassUuid *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_ServiceClassUuid_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QBluetoothUuid_CharacteristicType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothUuid::CharacteristicType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothUuid::CharacteristicType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBluetoothUuid_CharacteristicType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_CharacteristicType_IDX])))
        return Enum_PythonToCpp_QBluetoothUuid_CharacteristicType;
    return {};
}

static PyObject *QBluetoothUuid_CharacteristicType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBluetoothUuid::CharacteristicType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBluetoothUuid::CharacteristicType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_CharacteristicType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QBluetoothUuid_DescriptorType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothUuid::DescriptorType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothUuid::DescriptorType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBluetoothUuid_DescriptorType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_DescriptorType_IDX])))
        return Enum_PythonToCpp_QBluetoothUuid_DescriptorType;
    return {};
}

static PyObject *QBluetoothUuid_DescriptorType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBluetoothUuid::DescriptorType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBluetoothUuid::DescriptorType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_DescriptorType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBluetoothUuid_PythonToCpp_QBluetoothUuid_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBluetoothUuid_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBluetoothUuid_PythonToCpp_QBluetoothUuid_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBluetoothUuid_TypeF()))
        return QBluetoothUuid_PythonToCpp_QBluetoothUuid_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBluetoothUuid_PTR_CppToPython_QBluetoothUuid(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QBluetoothUuid_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QBluetoothUuid_COPY_CppToPython_QBluetoothUuid(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QBluetoothUuid *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QBluetoothUuid_TypeF(), new ::QBluetoothUuid(*source), true, true);
}

// Python to C++ copy conversion.
static void QBluetoothUuid_PythonToCpp_QBluetoothUuid_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QBluetoothUuid *>(cppOut) = *reinterpret_cast< ::QBluetoothUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QBluetoothUuid_PythonToCpp_QBluetoothUuid_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QBluetoothUuid_TypeF()))
        return QBluetoothUuid_PythonToCpp_QBluetoothUuid_COPY;
    return {};
}

// Implicit conversions.
static void QBluetoothUuid_CharacteristicType_PythonToCpp_QBluetoothUuid(PyObject *pyIn, void *cppOut)
{
    ::QBluetoothUuid::CharacteristicType cppIn = static_cast< ::QBluetoothUuid::CharacteristicType>(0);
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_CharacteristicType_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QBluetoothUuid *>(cppOut) = ::QBluetoothUuid(cppIn);
}
static PythonToCppFunc is_QBluetoothUuid_CharacteristicType_PythonToCpp_QBluetoothUuid_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_CharacteristicType_IDX]), pyIn))
        return QBluetoothUuid_CharacteristicType_PythonToCpp_QBluetoothUuid;
    return {};
}

static void QBluetoothUuid_DescriptorType_PythonToCpp_QBluetoothUuid(PyObject *pyIn, void *cppOut)
{
    ::QBluetoothUuid::DescriptorType cppIn{QBluetoothUuid::DescriptorType::UnknownDescriptorType};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_DescriptorType_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QBluetoothUuid *>(cppOut) = ::QBluetoothUuid(cppIn);
}
static PythonToCppFunc is_QBluetoothUuid_DescriptorType_PythonToCpp_QBluetoothUuid_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_DescriptorType_IDX]), pyIn))
        return QBluetoothUuid_DescriptorType_PythonToCpp_QBluetoothUuid;
    return {};
}

static void QBluetoothUuid_ProtocolUuid_PythonToCpp_QBluetoothUuid(PyObject *pyIn, void *cppOut)
{
    ::QBluetoothUuid::ProtocolUuid cppIn = static_cast< ::QBluetoothUuid::ProtocolUuid>(0);
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_ProtocolUuid_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QBluetoothUuid *>(cppOut) = ::QBluetoothUuid(cppIn);
}
static PythonToCppFunc is_QBluetoothUuid_ProtocolUuid_PythonToCpp_QBluetoothUuid_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_ProtocolUuid_IDX]), pyIn))
        return QBluetoothUuid_ProtocolUuid_PythonToCpp_QBluetoothUuid;
    return {};
}

static void QBluetoothUuid_ServiceClassUuid_PythonToCpp_QBluetoothUuid(PyObject *pyIn, void *cppOut)
{
    ::QBluetoothUuid::ServiceClassUuid cppIn = static_cast< ::QBluetoothUuid::ServiceClassUuid>(0);
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_ServiceClassUuid_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QBluetoothUuid *>(cppOut) = ::QBluetoothUuid(cppIn);
}
static PythonToCppFunc is_QBluetoothUuid_ServiceClassUuid_PythonToCpp_QBluetoothUuid_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_ServiceClassUuid_IDX]), pyIn))
        return QBluetoothUuid_ServiceClassUuid_PythonToCpp_QBluetoothUuid;
    return {};
}

static void PySide6_QtCore_constQUuidREF_PythonToCpp_QBluetoothUuid(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QBluetoothUuid *>(cppOut) = ::QBluetoothUuid( *reinterpret_cast< ::QUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_PySide6_QtCore_constQUuidREF_PythonToCpp_QBluetoothUuid_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), pyIn))
        return PySide6_QtCore_constQUuidREF_PythonToCpp_QBluetoothUuid;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBluetoothUuid_SignatureStrings[] = {
    "8:PySide6.QtBluetooth.QBluetoothUuid(self)",
    "7:PySide6.QtBluetooth.QBluetoothUuid(self,uuid:PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType)",
    "6:PySide6.QtBluetooth.QBluetoothUuid(self,uuid:PySide6.QtBluetooth.QBluetoothUuid.DescriptorType)",
    "5:PySide6.QtBluetooth.QBluetoothUuid(self,uuid:PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid)",
    "4:PySide6.QtBluetooth.QBluetoothUuid(self,uuid:PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid)",
    "3:PySide6.QtBluetooth.QBluetoothUuid(self,uuid:PySide6.QtBluetooth.QBluetoothUuid)",
    "2:PySide6.QtBluetooth.QBluetoothUuid(self,uuid:PySide6.QtCore.QUuid)",
    "1:PySide6.QtBluetooth.QBluetoothUuid(self,uuid:quint16)",
    "0:PySide6.QtBluetooth.QBluetoothUuid(self,uuid:quint32)",
    "PySide6.QtBluetooth.QBluetoothUuid.characteristicToString(uuid:PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType)->QString",
    "PySide6.QtBluetooth.QBluetoothUuid.descriptorToString(uuid:PySide6.QtBluetooth.QBluetoothUuid.DescriptorType)->QString",
    "PySide6.QtBluetooth.QBluetoothUuid.minimumSize(self)->int",
    "PySide6.QtBluetooth.QBluetoothUuid.protocolToString(uuid:PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid)->QString",
    "PySide6.QtBluetooth.QBluetoothUuid.serviceClassToString(uuid:PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid)->QString",
    "PySide6.QtBluetooth.QBluetoothUuid.toUInt16(self)->Tuple[int, bool]",
    "PySide6.QtBluetooth.QBluetoothUuid.toUInt32(self)->Tuple[int, bool]",
    "PySide6.QtBluetooth.QBluetoothUuid.__copy__(self)->typing.Self",
    "PySide6.QtBluetooth.QBluetoothUuid.__lshift__(self,s:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtBluetooth.QBluetoothUuid.__rshift__(self,s:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtBluetooth.QBluetoothUuid.__ne__(self,b:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid])->bool",
    "PySide6.QtBluetooth.QBluetoothUuid.__eq__(self,b:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QBluetoothUuid_SignatureByteSize = 355;
static constexpr uint8_t QBluetoothUuid_SignatureBytes[355] = {
    0x78, 0xda, 0xed, 0x94, 0xbd, 0x6e, 0xc2, 0x30, 0x14, 0x85, 0xf7, 0x3c, 0x05, 0x23, 0x91, 0x42,
    0x54, 0xa0, 0xa5, 0x15, 0x03, 0x43, 0xc3, 0xd2, 0x8d, 0x28, 0x30, 0x21, 0x14, 0x05, 0xe7, 0x52,
    0xae, 0xe4, 0xc4, 0xc1, 0xbe, 0xa9, 0x94, 0x3e, 0x7d, 0x8d, 0x02, 0xe5, 0x4f, 0x55, 0xed, 0x10,
    0x75, 0xea, 0x66, 0x2b, 0x3e, 0xe7, 0xb3, 0x8f, 0xce, 0xcd, 0xcb, 0x78, 0x56, 0x45, 0x98, 0xc2,
    0xc8, 0x0f, 0xe9, 0x95, 0x97, 0x40, 0x42, 0xd0, 0xd6, 0x0f, 0xbf, 0x97, 0x8b, 0x12, 0xd3, 0xae,
    0x02, 0xbe, 0x71, 0x9d, 0x67, 0xd3, 0xa3, 0x5e, 0xa9, 0x57, 0x06, 0x87, 0xfd, 0x60, 0x9b, 0xc8,
    0x84, 0x11, 0x48, 0x54, 0x84, 0x6c, 0x5e, 0x15, 0xe0, 0x3a, 0xa3, 0xd6, 0x29, 0x53, 0x50, 0x4c,
    0x62, 0x41, 0x42, 0xd6, 0x84, 0xa7, 0xd6, 0x09, 0x33, 0x29, 0x48, 0x30, 0xc1, 0xf7, 0x1b, 0xd7,
    0x79, 0x6c, 0xdd, 0x3f, 0x02, 0xf9, 0x81, 0x0c, 0x02, 0x9e, 0x28, 0x55, 0x33, 0x86, 0x6d, 0x33,
    0x5c, 0x67, 0xd0, 0xd4, 0x32, 0x10, 0x12, 0xfc, 0xb0, 0x36, 0xe9, 0xdb, 0x99, 0xec, 0x4a, 0xcc,
    0xa9, 0x3f, 0x72, 0x9d, 0x87, 0x06, 0xba, 0xe1, 0xc0, 0x75, 0x0c, 0xc2, 0x63, 0x97, 0x25, 0x13,
    0x11, 0x49, 0xcc, 0xdf, 0xbb, 0x77, 0x74, 0xb4, 0x37, 0x09, 0x6b, 0x13, 0x13, 0x7c, 0x7a, 0x6a,
    0x9f, 0x2d, 0xfa, 0xaa, 0xb8, 0x56, 0xd8, 0x0c, 0x73, 0xcc, 0xca, 0x2c, 0xc2, 0x4f, 0xa8, 0xc7,
    0xb7, 0x37, 0xd1, 0x91, 0x99, 0x28, 0x8b, 0x43, 0x99, 0xad, 0xaf, 0x7b, 0x31, 0x05, 0x56, 0x97,
    0x55, 0x67, 0xfd, 0xb6, 0xc6, 0xde, 0x0c, 0x87, 0x15, 0x9a, 0xc4, 0xe2, 0x6d, 0x5f, 0xc1, 0x63,
    0x48, 0xf3, 0xb2, 0xe0, 0xb0, 0xd4, 0x51, 0x79, 0x9d, 0xb5, 0x10, 0x7c, 0x65, 0xee, 0x31, 0x1c,
    0xdc, 0xe3, 0x11, 0xc7, 0x4c, 0x14, 0x55, 0x1c, 0x1f, 0x3d, 0xa8, 0x2a, 0xf4, 0x0b, 0xf4, 0xe3,
    0xf8, 0xc6, 0x4c, 0xce, 0xd5, 0x16, 0x37, 0x74, 0x30, 0xf0, 0xd4, 0xcd, 0x7c, 0x4e, 0x13, 0x4a,
    0x74, 0x2c, 0x90, 0x64, 0xda, 0xfd, 0xe7, 0x8f, 0x66, 0x30, 0xf9, 0x97, 0xb0, 0x1c, 0x8e, 0xa0,
    0xf5, 0xf8, 0x10, 0xcb, 0x22, 0x47, 0x91, 0x2f, 0x7f, 0x57, 0x7b, 0x9d, 0x46, 0x13, 0x6e, 0x24,
    0xbb, 0x9c, 0x4e, 0x23, 0xc9, 0xf9, 0x84, 0x18, 0x09, 0xae, 0xbb, 0x7d, 0x2e, 0x3a, 0xfd, 0x76,
    0x57, 0x3a, 0xe4, 0x7d, 0xd1, 0xcc, 0xe2, 0x84, 0xdd, 0x7f, 0x9c, 0x66, 0x71, 0x7e, 0x01, 0x6a,
    0x56, 0x5d, 0x87
};
#endif

PyTypeObject *init_QBluetoothUuid(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX].type;

    Shiboken::AutoDecRef Sbk_QBluetoothUuid_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]))));

    _Sbk_QBluetoothUuid_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBluetoothUuid",
        "QBluetoothUuid",
        &Sbk_QBluetoothUuid_spec,
        &Shiboken::callCppDestructor< ::QBluetoothUuid >,
        Sbk_QBluetoothUuid_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QBluetoothUuid_TypeF(); // references _Sbk_QBluetoothUuid_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBluetoothUuid_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBluetoothUuid_SignatureBytes, QBluetoothUuid_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBluetoothUuid_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBluetoothUuid_PythonToCpp_QBluetoothUuid_PTR,
        is_QBluetoothUuid_PythonToCpp_QBluetoothUuid_PTR_Convertible,
        QBluetoothUuid_PTR_CppToPython_QBluetoothUuid,
        QBluetoothUuid_COPY_CppToPython_QBluetoothUuid);

    Shiboken::Conversions::registerConverterName(converter, "QBluetoothUuid");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothUuid*");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothUuid&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBluetoothUuid).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QBluetoothUuid_PythonToCpp_QBluetoothUuid_COPY,
        is_QBluetoothUuid_PythonToCpp_QBluetoothUuid_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QBluetoothUuid_CharacteristicType_PythonToCpp_QBluetoothUuid,
        is_QBluetoothUuid_CharacteristicType_PythonToCpp_QBluetoothUuid_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QBluetoothUuid_DescriptorType_PythonToCpp_QBluetoothUuid,
        is_QBluetoothUuid_DescriptorType_PythonToCpp_QBluetoothUuid_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QBluetoothUuid_ProtocolUuid_PythonToCpp_QBluetoothUuid,
        is_QBluetoothUuid_ProtocolUuid_PythonToCpp_QBluetoothUuid_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QBluetoothUuid_ServiceClassUuid_PythonToCpp_QBluetoothUuid,
        is_QBluetoothUuid_ServiceClassUuid_PythonToCpp_QBluetoothUuid_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_constQUuidREF_PythonToCpp_QBluetoothUuid,
        is_PySide6_QtCore_constQUuidREF_PythonToCpp_QBluetoothUuid_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QBluetoothUuid_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ProtocolUuid'.
    const char *ProtocolUuid_Initializer[] = {
        "Sdp",
        "Udp",
        "Rfcomm",
        "Tcp",
        "TcsBin",
        "TcsAt",
        "Att",
        "Obex",
        "Ip",
        "Ftp",
        "Http",
        "Wsp",
        "Bnep",
        "Upnp",
        "Hidp",
        "HardcopyControlChannel",
        "HardcopyDataChannel",
        "HardcopyNotification",
        "Avctp",
        "Avdtp",
        "Cmtp",
        "UdiCPlain",
        "McapControlChannel",
        "McapDataChannel",
        "L2cap",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t ProtocolUuid_InitializerValues[] = {
        int16_t(QBluetoothUuid::ProtocolUuid::Sdp),                    //  0x0001  1
        int16_t(QBluetoothUuid::ProtocolUuid::Udp),                    //  0x0002  2
        int16_t(QBluetoothUuid::ProtocolUuid::Rfcomm),                 //  0x0003  3
        int16_t(QBluetoothUuid::ProtocolUuid::Tcp),                    //  0x0004  4
        int16_t(QBluetoothUuid::ProtocolUuid::TcsBin),                 //  0x0005  5
        int16_t(QBluetoothUuid::ProtocolUuid::TcsAt),                  //  0x0006  6
        int16_t(QBluetoothUuid::ProtocolUuid::Att),                    //  0x0007  7
        int16_t(QBluetoothUuid::ProtocolUuid::Obex),                   //  0x0008  8
        int16_t(QBluetoothUuid::ProtocolUuid::Ip),                     //  0x0009  9
        int16_t(QBluetoothUuid::ProtocolUuid::Ftp),                    //  0x000a  10
        int16_t(QBluetoothUuid::ProtocolUuid::Http),                   //  0x000c  12
        int16_t(QBluetoothUuid::ProtocolUuid::Wsp),                    //  0x000e  14
        int16_t(QBluetoothUuid::ProtocolUuid::Bnep),                   //  0x000f  15
        int16_t(QBluetoothUuid::ProtocolUuid::Upnp),                   //  0x0010  16
        int16_t(QBluetoothUuid::ProtocolUuid::Hidp),                   //  0x0011  17
        int16_t(QBluetoothUuid::ProtocolUuid::HardcopyControlChannel), //  0x0012  18
        int16_t(QBluetoothUuid::ProtocolUuid::HardcopyDataChannel),    //  0x0014  20
        int16_t(QBluetoothUuid::ProtocolUuid::HardcopyNotification),   //  0x0016  22
        int16_t(QBluetoothUuid::ProtocolUuid::Avctp),                  //  0x0017  23
        int16_t(QBluetoothUuid::ProtocolUuid::Avdtp),                  //  0x0019  25
        int16_t(QBluetoothUuid::ProtocolUuid::Cmtp),                   //  0x001b  27
        int16_t(QBluetoothUuid::ProtocolUuid::UdiCPlain),              //  0x001d  29
        int16_t(QBluetoothUuid::ProtocolUuid::McapControlChannel),     //  0x001e  30
        int16_t(QBluetoothUuid::ProtocolUuid::McapDataChannel),        //  0x001f  31
        int16_t(QBluetoothUuid::ProtocolUuid::L2cap)                   //  0x0100  256
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothUuid_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid",
        ProtocolUuid_Initializer, ProtocolUuid_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_ProtocolUuid_IDX].type = EType;
    // Register converter for enum 'QBluetoothUuid::ProtocolUuid'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothUuid_ProtocolUuid_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBluetoothUuid_ProtocolUuid,
            is_Enum_PythonToCpp_QBluetoothUuid_ProtocolUuid_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothUuid::ProtocolUuid");
        Shiboken::Conversions::registerConverterAlias(converter, "ProtocolUuid");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ProtocolUuid' enum.

    // Initialization of enum 'ServiceClassUuid'.
    const char *ServiceClassUuid_Initializer[] = {
        "ServiceDiscoveryServer",
        "BrowseGroupDescriptor",
        "PublicBrowseGroup",
        "SerialPort",
        "LANAccessUsingPPP",
        "DialupNetworking",
        "IrMCSync",
        "ObexObjectPush",
        "OBEXFileTransfer",
        "IrMCSyncCommand",
        "Headset",
        "AudioSource",
        "AudioSink",
        "AV_RemoteControlTarget",
        "AdvancedAudioDistribution",
        "AV_RemoteControl",
        "AV_RemoteControlController",
        "HeadsetAG",
        "PANU",
        "NAP",
        "GN",
        "DirectPrinting",
        "ReferencePrinting",
        "BasicImage",
        "ImagingResponder",
        "ImagingAutomaticArchive",
        "ImagingReferenceObjects",
        "Handsfree",
        "HandsfreeAudioGateway",
        "DirectPrintingReferenceObjectsService",
        "ReflectedUI",
        "BasicPrinting",
        "PrintingStatus",
        "HumanInterfaceDeviceService",
        "HardcopyCableReplacement",
        "HCRPrint",
        "HCRScan",
        "SIMAccess",
        "PhonebookAccessPCE",
        "PhonebookAccessPSE",
        "PhonebookAccess",
        "HeadsetHS",
        "MessageAccessServer",
        "MessageNotificationServer",
        "MessageAccessProfile",
        "GNSS",
        "GNSSServer",
        "Display3D",
        "Glasses3D",
        "Synchronization3D",
        "MPSProfile",
        "MPSService",
        "PnPInformation",
        "GenericNetworking",
        "GenericFileTransfer",
        "GenericAudio",
        "GenericTelephony",
        "VideoSource",
        "VideoSink",
        "VideoDistribution",
        "HDP",
        "HDPSource",
        "HDPSink",
        "GenericAccess",
        "GenericAttribute",
        "ImmediateAlert",
        "LinkLoss",
        "TxPower",
        "CurrentTimeService",
        "ReferenceTimeUpdateService",
        "NextDSTChangeService",
        "Glucose",
        "HealthThermometer",
        "DeviceInformation",
        "HeartRate",
        "PhoneAlertStatusService",
        "BatteryService",
        "BloodPressure",
        "AlertNotificationService",
        "HumanInterfaceDevice",
        "ScanParameters",
        "RunningSpeedAndCadence",
        "CyclingSpeedAndCadence",
        "CyclingPower",
        "LocationAndNavigation",
        "EnvironmentalSensing",
        "BodyComposition",
        "UserData",
        "WeightScale",
        "BondManagement",
        "ContinuousGlucoseMonitoring",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t ServiceClassUuid_InitializerValues[] = {
        int16_t(QBluetoothUuid::ServiceClassUuid::ServiceDiscoveryServer),                //  0x1000  4096
        int16_t(QBluetoothUuid::ServiceClassUuid::BrowseGroupDescriptor),                 //  0x1001  4097
        int16_t(QBluetoothUuid::ServiceClassUuid::PublicBrowseGroup),                     //  0x1002  4098
        int16_t(QBluetoothUuid::ServiceClassUuid::SerialPort),                            //  0x1101  4353
        int16_t(QBluetoothUuid::ServiceClassUuid::LANAccessUsingPPP),                     //  0x1102  4354
        int16_t(QBluetoothUuid::ServiceClassUuid::DialupNetworking),                      //  0x1103  4355
        int16_t(QBluetoothUuid::ServiceClassUuid::IrMCSync),                              //  0x1104  4356
        int16_t(QBluetoothUuid::ServiceClassUuid::ObexObjectPush),                        //  0x1105  4357
        int16_t(QBluetoothUuid::ServiceClassUuid::OBEXFileTransfer),                      //  0x1106  4358
        int16_t(QBluetoothUuid::ServiceClassUuid::IrMCSyncCommand),                       //  0x1107  4359
        int16_t(QBluetoothUuid::ServiceClassUuid::Headset),                               //  0x1108  4360
        int16_t(QBluetoothUuid::ServiceClassUuid::AudioSource),                           //  0x110a  4362
        int16_t(QBluetoothUuid::ServiceClassUuid::AudioSink),                             //  0x110b  4363
        int16_t(QBluetoothUuid::ServiceClassUuid::AV_RemoteControlTarget),                //  0x110c  4364
        int16_t(QBluetoothUuid::ServiceClassUuid::AdvancedAudioDistribution),             //  0x110d  4365
        int16_t(QBluetoothUuid::ServiceClassUuid::AV_RemoteControl),                      //  0x110e  4366
        int16_t(QBluetoothUuid::ServiceClassUuid::AV_RemoteControlController),            //  0x110f  4367
        int16_t(QBluetoothUuid::ServiceClassUuid::HeadsetAG),                             //  0x1112  4370
        int16_t(QBluetoothUuid::ServiceClassUuid::PANU),                                  //  0x1115  4373
        int16_t(QBluetoothUuid::ServiceClassUuid::NAP),                                   //  0x1116  4374
        int16_t(QBluetoothUuid::ServiceClassUuid::GN),                                    //  0x1117  4375
        int16_t(QBluetoothUuid::ServiceClassUuid::DirectPrinting),                        //  0x1118  4376
        int16_t(QBluetoothUuid::ServiceClassUuid::ReferencePrinting),                     //  0x1119  4377
        int16_t(QBluetoothUuid::ServiceClassUuid::BasicImage),                            //  0x111a  4378
        int16_t(QBluetoothUuid::ServiceClassUuid::ImagingResponder),                      //  0x111b  4379
        int16_t(QBluetoothUuid::ServiceClassUuid::ImagingAutomaticArchive),               //  0x111c  4380
        int16_t(QBluetoothUuid::ServiceClassUuid::ImagingReferenceObjects),               //  0x111d  4381
        int16_t(QBluetoothUuid::ServiceClassUuid::Handsfree),                             //  0x111e  4382
        int16_t(QBluetoothUuid::ServiceClassUuid::HandsfreeAudioGateway),                 //  0x111f  4383
        int16_t(QBluetoothUuid::ServiceClassUuid::DirectPrintingReferenceObjectsService), //  0x1120  4384
        int16_t(QBluetoothUuid::ServiceClassUuid::ReflectedUI),                           //  0x1121  4385
        int16_t(QBluetoothUuid::ServiceClassUuid::BasicPrinting),                         //  0x1122  4386
        int16_t(QBluetoothUuid::ServiceClassUuid::PrintingStatus),                        //  0x1123  4387
        int16_t(QBluetoothUuid::ServiceClassUuid::HumanInterfaceDeviceService),           //  0x1124  4388
        int16_t(QBluetoothUuid::ServiceClassUuid::HardcopyCableReplacement),              //  0x1125  4389
        int16_t(QBluetoothUuid::ServiceClassUuid::HCRPrint),                              //  0x1126  4390
        int16_t(QBluetoothUuid::ServiceClassUuid::HCRScan),                               //  0x1127  4391
        int16_t(QBluetoothUuid::ServiceClassUuid::SIMAccess),                             //  0x112d  4397
        int16_t(QBluetoothUuid::ServiceClassUuid::PhonebookAccessPCE),                    //  0x112e  4398
        int16_t(QBluetoothUuid::ServiceClassUuid::PhonebookAccessPSE),                    //  0x112f  4399
        int16_t(QBluetoothUuid::ServiceClassUuid::PhonebookAccess),                       //  0x1130  4400
        int16_t(QBluetoothUuid::ServiceClassUuid::HeadsetHS),                             //  0x1131  4401
        int16_t(QBluetoothUuid::ServiceClassUuid::MessageAccessServer),                   //  0x1132  4402
        int16_t(QBluetoothUuid::ServiceClassUuid::MessageNotificationServer),             //  0x1133  4403
        int16_t(QBluetoothUuid::ServiceClassUuid::MessageAccessProfile),                  //  0x1134  4404
        int16_t(QBluetoothUuid::ServiceClassUuid::GNSS),                                  //  0x1135  4405
        int16_t(QBluetoothUuid::ServiceClassUuid::GNSSServer),                            //  0x1136  4406
        int16_t(QBluetoothUuid::ServiceClassUuid::Display3D),                             //  0x1137  4407
        int16_t(QBluetoothUuid::ServiceClassUuid::Glasses3D),                             //  0x1138  4408
        int16_t(QBluetoothUuid::ServiceClassUuid::Synchronization3D),                     //  0x1139  4409
        int16_t(QBluetoothUuid::ServiceClassUuid::MPSProfile),                            //  0x113a  4410
        int16_t(QBluetoothUuid::ServiceClassUuid::MPSService),                            //  0x113b  4411
        int16_t(QBluetoothUuid::ServiceClassUuid::PnPInformation),                        //  0x1200  4608
        int16_t(QBluetoothUuid::ServiceClassUuid::GenericNetworking),                     //  0x1201  4609
        int16_t(QBluetoothUuid::ServiceClassUuid::GenericFileTransfer),                   //  0x1202  4610
        int16_t(QBluetoothUuid::ServiceClassUuid::GenericAudio),                          //  0x1203  4611
        int16_t(QBluetoothUuid::ServiceClassUuid::GenericTelephony),                      //  0x1204  4612
        int16_t(QBluetoothUuid::ServiceClassUuid::VideoSource),                           //  0x1303  4867
        int16_t(QBluetoothUuid::ServiceClassUuid::VideoSink),                             //  0x1304  4868
        int16_t(QBluetoothUuid::ServiceClassUuid::VideoDistribution),                     //  0x1305  4869
        int16_t(QBluetoothUuid::ServiceClassUuid::HDP),                                   //  0x1400  5120
        int16_t(QBluetoothUuid::ServiceClassUuid::HDPSource),                             //  0x1401  5121
        int16_t(QBluetoothUuid::ServiceClassUuid::HDPSink),                               //  0x1402  5122
        int16_t(QBluetoothUuid::ServiceClassUuid::GenericAccess),                         //  0x1800  6144
        int16_t(QBluetoothUuid::ServiceClassUuid::GenericAttribute),                      //  0x1801  6145
        int16_t(QBluetoothUuid::ServiceClassUuid::ImmediateAlert),                        //  0x1802  6146
        int16_t(QBluetoothUuid::ServiceClassUuid::LinkLoss),                              //  0x1803  6147
        int16_t(QBluetoothUuid::ServiceClassUuid::TxPower),                               //  0x1804  6148
        int16_t(QBluetoothUuid::ServiceClassUuid::CurrentTimeService),                    //  0x1805  6149
        int16_t(QBluetoothUuid::ServiceClassUuid::ReferenceTimeUpdateService),            //  0x1806  6150
        int16_t(QBluetoothUuid::ServiceClassUuid::NextDSTChangeService),                  //  0x1807  6151
        int16_t(QBluetoothUuid::ServiceClassUuid::Glucose),                               //  0x1808  6152
        int16_t(QBluetoothUuid::ServiceClassUuid::HealthThermometer),                     //  0x1809  6153
        int16_t(QBluetoothUuid::ServiceClassUuid::DeviceInformation),                     //  0x180a  6154
        int16_t(QBluetoothUuid::ServiceClassUuid::HeartRate),                             //  0x180d  6157
        int16_t(QBluetoothUuid::ServiceClassUuid::PhoneAlertStatusService),               //  0x180e  6158
        int16_t(QBluetoothUuid::ServiceClassUuid::BatteryService),                        //  0x180f  6159
        int16_t(QBluetoothUuid::ServiceClassUuid::BloodPressure),                         //  0x1810  6160
        int16_t(QBluetoothUuid::ServiceClassUuid::AlertNotificationService),              //  0x1811  6161
        int16_t(QBluetoothUuid::ServiceClassUuid::HumanInterfaceDevice),                  //  0x1812  6162
        int16_t(QBluetoothUuid::ServiceClassUuid::ScanParameters),                        //  0x1813  6163
        int16_t(QBluetoothUuid::ServiceClassUuid::RunningSpeedAndCadence),                //  0x1814  6164
        int16_t(QBluetoothUuid::ServiceClassUuid::CyclingSpeedAndCadence),                //  0x1816  6166
        int16_t(QBluetoothUuid::ServiceClassUuid::CyclingPower),                          //  0x1818  6168
        int16_t(QBluetoothUuid::ServiceClassUuid::LocationAndNavigation),                 //  0x1819  6169
        int16_t(QBluetoothUuid::ServiceClassUuid::EnvironmentalSensing),                  //  0x181a  6170
        int16_t(QBluetoothUuid::ServiceClassUuid::BodyComposition),                       //  0x181b  6171
        int16_t(QBluetoothUuid::ServiceClassUuid::UserData),                              //  0x181c  6172
        int16_t(QBluetoothUuid::ServiceClassUuid::WeightScale),                           //  0x181d  6173
        int16_t(QBluetoothUuid::ServiceClassUuid::BondManagement),                        //  0x181e  6174
        int16_t(QBluetoothUuid::ServiceClassUuid::ContinuousGlucoseMonitoring)            //  0x181f  6175
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothUuid_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid",
        ServiceClassUuid_Initializer, ServiceClassUuid_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_ServiceClassUuid_IDX].type = EType;
    // Register converter for enum 'QBluetoothUuid::ServiceClassUuid'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothUuid_ServiceClassUuid_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBluetoothUuid_ServiceClassUuid,
            is_Enum_PythonToCpp_QBluetoothUuid_ServiceClassUuid_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothUuid::ServiceClassUuid");
        Shiboken::Conversions::registerConverterAlias(converter, "ServiceClassUuid");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ServiceClassUuid' enum.

    // Initialization of enum 'CharacteristicType'.
    const char *CharacteristicType_Initializer[] = {
        "DeviceName",
        "Appearance",
        "PeripheralPrivacyFlag",
        "ReconnectionAddress",
        "PeripheralPreferredConnectionParameters",
        "ServiceChanged",
        "AlertLevel",
        "TxPowerLevel",
        "DateTime",
        "DayOfWeek",
        "DayDateTime",
        "ExactTime256",
        "DSTOffset",
        "TimeZone",
        "LocalTimeInformation",
        "TimeWithDST",
        "TimeAccuracy",
        "TimeSource",
        "ReferenceTimeInformation",
        "TimeUpdateControlPoint",
        "TimeUpdateState",
        "GlucoseMeasurement",
        "BatteryLevel",
        "TemperatureMeasurement",
        "TemperatureType",
        "IntermediateTemperature",
        "MeasurementInterval",
        "BootKeyboardInputReport",
        "SystemID",
        "ModelNumberString",
        "SerialNumberString",
        "FirmwareRevisionString",
        "HardwareRevisionString",
        "SoftwareRevisionString",
        "ManufacturerNameString",
        "IEEE1107320601RegulatoryCertificationDataList",
        "CurrentTime",
        "MagneticDeclination",
        "ScanRefresh",
        "BootKeyboardOutputReport",
        "BootMouseInputReport",
        "GlucoseMeasurementContext",
        "BloodPressureMeasurement",
        "IntermediateCuffPressure",
        "HeartRateMeasurement",
        "BodySensorLocation",
        "HeartRateControlPoint",
        "AlertStatus",
        "RingerControlPoint",
        "RingerSetting",
        "AlertCategoryIDBitMask",
        "AlertCategoryID",
        "AlertNotificationControlPoint",
        "UnreadAlertStatus",
        "NewAlert",
        "SupportedNewAlertCategory",
        "SupportedUnreadAlertCategory",
        "BloodPressureFeature",
        "HIDInformation",
        "ReportMap",
        "HIDControlPoint",
        "Report",
        "ProtocolMode",
        "ScanIntervalWindow",
        "PnPID",
        "GlucoseFeature",
        "RecordAccessControlPoint",
        "RSCMeasurement",
        "RSCFeature",
        "SCControlPoint",
        "CSCMeasurement",
        "CSCFeature",
        "SensorLocation",
        "CyclingPowerMeasurement",
        "CyclingPowerVector",
        "CyclingPowerFeature",
        "CyclingPowerControlPoint",
        "LocationAndSpeed",
        "Navigation",
        "PositionQuality",
        "LNFeature",
        "LNControlPoint",
        "Elevation",
        "Pressure",
        "Temperature",
        "Humidity",
        "TrueWindSpeed",
        "TrueWindDirection",
        "ApparentWindSpeed",
        "ApparentWindDirection",
        "GustFactor",
        "PollenConcentration",
        "UVIndex",
        "Irradiance",
        "Rainfall",
        "WindChill",
        "HeatIndex",
        "DewPoint",
        "DescriptorValueChanged",
        "AerobicHeartRateLowerLimit",
        "AerobicThreshold",
        "Age",
        "AnaerobicHeartRateLowerLimit",
        "AnaerobicHeartRateUpperLimit",
        "AnaerobicThreshold",
        "AerobicHeartRateUpperLimit",
        "DateOfBirth",
        "DateOfThresholdAssessment",
        "EmailAddress",
        "FatBurnHeartRateLowerLimit",
        "FatBurnHeartRateUpperLimit",
        "FirstName",
        "FiveZoneHeartRateLimits",
        "Gender",
        "HeartRateMax",
        "Height",
        "HipCircumference",
        "LastName",
        "MaximumRecommendedHeartRate",
        "RestingHeartRate",
        "SportTypeForAerobicAnaerobicThresholds",
        "ThreeZoneHeartRateLimits",
        "TwoZoneHeartRateLimits",
        "VO2Max",
        "WaistCircumference",
        "Weight",
        "DatabaseChangeIncrement",
        "UserIndex",
        "BodyCompositionFeature",
        "BodyCompositionMeasurement",
        "WeightMeasurement",
        "WeightScaleFeature",
        "UserControlPoint",
        "MagneticFluxDensity2D",
        "MagneticFluxDensity3D",
        "Language",
        "BarometricPressureTrend",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t CharacteristicType_InitializerValues[] = {
        int16_t(QBluetoothUuid::CharacteristicType::DeviceName),                                    //  0x2a00  10752
        int16_t(QBluetoothUuid::CharacteristicType::Appearance),                                    //  0x2a01  10753
        int16_t(QBluetoothUuid::CharacteristicType::PeripheralPrivacyFlag),                         //  0x2a02  10754
        int16_t(QBluetoothUuid::CharacteristicType::ReconnectionAddress),                           //  0x2a03  10755
        int16_t(QBluetoothUuid::CharacteristicType::PeripheralPreferredConnectionParameters),       //  0x2a04  10756
        int16_t(QBluetoothUuid::CharacteristicType::ServiceChanged),                                //  0x2a05  10757
        int16_t(QBluetoothUuid::CharacteristicType::AlertLevel),                                    //  0x2a06  10758
        int16_t(QBluetoothUuid::CharacteristicType::TxPowerLevel),                                  //  0x2a07  10759
        int16_t(QBluetoothUuid::CharacteristicType::DateTime),                                      //  0x2a08  10760
        int16_t(QBluetoothUuid::CharacteristicType::DayOfWeek),                                     //  0x2a09  10761
        int16_t(QBluetoothUuid::CharacteristicType::DayDateTime),                                   //  0x2a0a  10762
        int16_t(QBluetoothUuid::CharacteristicType::ExactTime256),                                  //  0x2a0c  10764
        int16_t(QBluetoothUuid::CharacteristicType::DSTOffset),                                     //  0x2a0d  10765
        int16_t(QBluetoothUuid::CharacteristicType::TimeZone),                                      //  0x2a0e  10766
        int16_t(QBluetoothUuid::CharacteristicType::LocalTimeInformation),                          //  0x2a0f  10767
        int16_t(QBluetoothUuid::CharacteristicType::TimeWithDST),                                   //  0x2a11  10769
        int16_t(QBluetoothUuid::CharacteristicType::TimeAccuracy),                                  //  0x2a12  10770
        int16_t(QBluetoothUuid::CharacteristicType::TimeSource),                                    //  0x2a13  10771
        int16_t(QBluetoothUuid::CharacteristicType::ReferenceTimeInformation),                      //  0x2a14  10772
        int16_t(QBluetoothUuid::CharacteristicType::TimeUpdateControlPoint),                        //  0x2a16  10774
        int16_t(QBluetoothUuid::CharacteristicType::TimeUpdateState),                               //  0x2a17  10775
        int16_t(QBluetoothUuid::CharacteristicType::GlucoseMeasurement),                            //  0x2a18  10776
        int16_t(QBluetoothUuid::CharacteristicType::BatteryLevel),                                  //  0x2a19  10777
        int16_t(QBluetoothUuid::CharacteristicType::TemperatureMeasurement),                        //  0x2a1c  10780
        int16_t(QBluetoothUuid::CharacteristicType::TemperatureType),                               //  0x2a1d  10781
        int16_t(QBluetoothUuid::CharacteristicType::IntermediateTemperature),                       //  0x2a1e  10782
        int16_t(QBluetoothUuid::CharacteristicType::MeasurementInterval),                           //  0x2a21  10785
        int16_t(QBluetoothUuid::CharacteristicType::BootKeyboardInputReport),                       //  0x2a22  10786
        int16_t(QBluetoothUuid::CharacteristicType::SystemID),                                      //  0x2a23  10787
        int16_t(QBluetoothUuid::CharacteristicType::ModelNumberString),                             //  0x2a24  10788
        int16_t(QBluetoothUuid::CharacteristicType::SerialNumberString),                            //  0x2a25  10789
        int16_t(QBluetoothUuid::CharacteristicType::FirmwareRevisionString),                        //  0x2a26  10790
        int16_t(QBluetoothUuid::CharacteristicType::HardwareRevisionString),                        //  0x2a27  10791
        int16_t(QBluetoothUuid::CharacteristicType::SoftwareRevisionString),                        //  0x2a28  10792
        int16_t(QBluetoothUuid::CharacteristicType::ManufacturerNameString),                        //  0x2a29  10793
        int16_t(QBluetoothUuid::CharacteristicType::IEEE1107320601RegulatoryCertificationDataList), //  0x2a2a  10794
        int16_t(QBluetoothUuid::CharacteristicType::CurrentTime),                                   //  0x2a2b  10795
        int16_t(QBluetoothUuid::CharacteristicType::MagneticDeclination),                           //  0x2a2c  10796
        int16_t(QBluetoothUuid::CharacteristicType::ScanRefresh),                                   //  0x2a31  10801
        int16_t(QBluetoothUuid::CharacteristicType::BootKeyboardOutputReport),                      //  0x2a32  10802
        int16_t(QBluetoothUuid::CharacteristicType::BootMouseInputReport),                          //  0x2a33  10803
        int16_t(QBluetoothUuid::CharacteristicType::GlucoseMeasurementContext),                     //  0x2a34  10804
        int16_t(QBluetoothUuid::CharacteristicType::BloodPressureMeasurement),                      //  0x2a35  10805
        int16_t(QBluetoothUuid::CharacteristicType::IntermediateCuffPressure),                      //  0x2a36  10806
        int16_t(QBluetoothUuid::CharacteristicType::HeartRateMeasurement),                          //  0x2a37  10807
        int16_t(QBluetoothUuid::CharacteristicType::BodySensorLocation),                            //  0x2a38  10808
        int16_t(QBluetoothUuid::CharacteristicType::HeartRateControlPoint),                         //  0x2a39  10809
        int16_t(QBluetoothUuid::CharacteristicType::AlertStatus),                                   //  0x2a3f  10815
        int16_t(QBluetoothUuid::CharacteristicType::RingerControlPoint),                            //  0x2a40  10816
        int16_t(QBluetoothUuid::CharacteristicType::RingerSetting),                                 //  0x2a41  10817
        int16_t(QBluetoothUuid::CharacteristicType::AlertCategoryIDBitMask),                        //  0x2a42  10818
        int16_t(QBluetoothUuid::CharacteristicType::AlertCategoryID),                               //  0x2a43  10819
        int16_t(QBluetoothUuid::CharacteristicType::AlertNotificationControlPoint),                 //  0x2a44  10820
        int16_t(QBluetoothUuid::CharacteristicType::UnreadAlertStatus),                             //  0x2a45  10821
        int16_t(QBluetoothUuid::CharacteristicType::NewAlert),                                      //  0x2a46  10822
        int16_t(QBluetoothUuid::CharacteristicType::SupportedNewAlertCategory),                     //  0x2a47  10823
        int16_t(QBluetoothUuid::CharacteristicType::SupportedUnreadAlertCategory),                  //  0x2a48  10824
        int16_t(QBluetoothUuid::CharacteristicType::BloodPressureFeature),                          //  0x2a49  10825
        int16_t(QBluetoothUuid::CharacteristicType::HIDInformation),                                //  0x2a4a  10826
        int16_t(QBluetoothUuid::CharacteristicType::ReportMap),                                     //  0x2a4b  10827
        int16_t(QBluetoothUuid::CharacteristicType::HIDControlPoint),                               //  0x2a4c  10828
        int16_t(QBluetoothUuid::CharacteristicType::Report),                                        //  0x2a4d  10829
        int16_t(QBluetoothUuid::CharacteristicType::ProtocolMode),                                  //  0x2a4e  10830
        int16_t(QBluetoothUuid::CharacteristicType::ScanIntervalWindow),                            //  0x2a4f  10831
        int16_t(QBluetoothUuid::CharacteristicType::PnPID),                                         //  0x2a50  10832
        int16_t(QBluetoothUuid::CharacteristicType::GlucoseFeature),                                //  0x2a51  10833
        int16_t(QBluetoothUuid::CharacteristicType::RecordAccessControlPoint),                      //  0x2a52  10834
        int16_t(QBluetoothUuid::CharacteristicType::RSCMeasurement),                                //  0x2a53  10835
        int16_t(QBluetoothUuid::CharacteristicType::RSCFeature),                                    //  0x2a54  10836
        int16_t(QBluetoothUuid::CharacteristicType::SCControlPoint),                                //  0x2a55  10837
        int16_t(QBluetoothUuid::CharacteristicType::CSCMeasurement),                                //  0x2a5b  10843
        int16_t(QBluetoothUuid::CharacteristicType::CSCFeature),                                    //  0x2a5c  10844
        int16_t(QBluetoothUuid::CharacteristicType::SensorLocation),                                //  0x2a5d  10845
        int16_t(QBluetoothUuid::CharacteristicType::CyclingPowerMeasurement),                       //  0x2a63  10851
        int16_t(QBluetoothUuid::CharacteristicType::CyclingPowerVector),                            //  0x2a64  10852
        int16_t(QBluetoothUuid::CharacteristicType::CyclingPowerFeature),                           //  0x2a65  10853
        int16_t(QBluetoothUuid::CharacteristicType::CyclingPowerControlPoint),                      //  0x2a66  10854
        int16_t(QBluetoothUuid::CharacteristicType::LocationAndSpeed),                              //  0x2a67  10855
        int16_t(QBluetoothUuid::CharacteristicType::Navigation),                                    //  0x2a68  10856
        int16_t(QBluetoothUuid::CharacteristicType::PositionQuality),                               //  0x2a69  10857
        int16_t(QBluetoothUuid::CharacteristicType::LNFeature),                                     //  0x2a6a  10858
        int16_t(QBluetoothUuid::CharacteristicType::LNControlPoint),                                //  0x2a6b  10859
        int16_t(QBluetoothUuid::CharacteristicType::Elevation),                                     //  0x2a6c  10860
        int16_t(QBluetoothUuid::CharacteristicType::Pressure),                                      //  0x2a6d  10861
        int16_t(QBluetoothUuid::CharacteristicType::Temperature),                                   //  0x2a6e  10862
        int16_t(QBluetoothUuid::CharacteristicType::Humidity),                                      //  0x2a6f  10863
        int16_t(QBluetoothUuid::CharacteristicType::TrueWindSpeed),                                 //  0x2a70  10864
        int16_t(QBluetoothUuid::CharacteristicType::TrueWindDirection),                             //  0x2a71  10865
        int16_t(QBluetoothUuid::CharacteristicType::ApparentWindSpeed),                             //  0x2a72  10866
        int16_t(QBluetoothUuid::CharacteristicType::ApparentWindDirection),                         //  0x2a73  10867
        int16_t(QBluetoothUuid::CharacteristicType::GustFactor),                                    //  0x2a74  10868
        int16_t(QBluetoothUuid::CharacteristicType::PollenConcentration),                           //  0x2a75  10869
        int16_t(QBluetoothUuid::CharacteristicType::UVIndex),                                       //  0x2a76  10870
        int16_t(QBluetoothUuid::CharacteristicType::Irradiance),                                    //  0x2a77  10871
        int16_t(QBluetoothUuid::CharacteristicType::Rainfall),                                      //  0x2a78  10872
        int16_t(QBluetoothUuid::CharacteristicType::WindChill),                                     //  0x2a79  10873
        int16_t(QBluetoothUuid::CharacteristicType::HeatIndex),                                     //  0x2a7a  10874
        int16_t(QBluetoothUuid::CharacteristicType::DewPoint),                                      //  0x2a7b  10875
        int16_t(QBluetoothUuid::CharacteristicType::DescriptorValueChanged),                        //  0x2a7d  10877
        int16_t(QBluetoothUuid::CharacteristicType::AerobicHeartRateLowerLimit),                    //  0x2a7e  10878
        int16_t(QBluetoothUuid::CharacteristicType::AerobicThreshold),                              //  0x2a7f  10879
        int16_t(QBluetoothUuid::CharacteristicType::Age),                                           //  0x2a80  10880
        int16_t(QBluetoothUuid::CharacteristicType::AnaerobicHeartRateLowerLimit),                  //  0x2a81  10881
        int16_t(QBluetoothUuid::CharacteristicType::AnaerobicHeartRateUpperLimit),                  //  0x2a82  10882
        int16_t(QBluetoothUuid::CharacteristicType::AnaerobicThreshold),                            //  0x2a83  10883
        int16_t(QBluetoothUuid::CharacteristicType::AerobicHeartRateUpperLimit),                    //  0x2a84  10884
        int16_t(QBluetoothUuid::CharacteristicType::DateOfBirth),                                   //  0x2a85  10885
        int16_t(QBluetoothUuid::CharacteristicType::DateOfThresholdAssessment),                     //  0x2a86  10886
        int16_t(QBluetoothUuid::CharacteristicType::EmailAddress),                                  //  0x2a87  10887
        int16_t(QBluetoothUuid::CharacteristicType::FatBurnHeartRateLowerLimit),                    //  0x2a88  10888
        int16_t(QBluetoothUuid::CharacteristicType::FatBurnHeartRateUpperLimit),                    //  0x2a89  10889
        int16_t(QBluetoothUuid::CharacteristicType::FirstName),                                     //  0x2a8a  10890
        int16_t(QBluetoothUuid::CharacteristicType::FiveZoneHeartRateLimits),                       //  0x2a8b  10891
        int16_t(QBluetoothUuid::CharacteristicType::Gender),                                        //  0x2a8c  10892
        int16_t(QBluetoothUuid::CharacteristicType::HeartRateMax),                                  //  0x2a8d  10893
        int16_t(QBluetoothUuid::CharacteristicType::Height),                                        //  0x2a8e  10894
        int16_t(QBluetoothUuid::CharacteristicType::HipCircumference),                              //  0x2a8f  10895
        int16_t(QBluetoothUuid::CharacteristicType::LastName),                                      //  0x2a90  10896
        int16_t(QBluetoothUuid::CharacteristicType::MaximumRecommendedHeartRate),                   //  0x2a91  10897
        int16_t(QBluetoothUuid::CharacteristicType::RestingHeartRate),                              //  0x2a92  10898
        int16_t(QBluetoothUuid::CharacteristicType::SportTypeForAerobicAnaerobicThresholds),        //  0x2a93  10899
        int16_t(QBluetoothUuid::CharacteristicType::ThreeZoneHeartRateLimits),                      //  0x2a94  10900
        int16_t(QBluetoothUuid::CharacteristicType::TwoZoneHeartRateLimits),                        //  0x2a95  10901
        int16_t(QBluetoothUuid::CharacteristicType::VO2Max),                                        //  0x2a96  10902
        int16_t(QBluetoothUuid::CharacteristicType::WaistCircumference),                            //  0x2a97  10903
        int16_t(QBluetoothUuid::CharacteristicType::Weight),                                        //  0x2a98  10904
        int16_t(QBluetoothUuid::CharacteristicType::DatabaseChangeIncrement),                       //  0x2a99  10905
        int16_t(QBluetoothUuid::CharacteristicType::UserIndex),                                     //  0x2a9a  10906
        int16_t(QBluetoothUuid::CharacteristicType::BodyCompositionFeature),                        //  0x2a9b  10907
        int16_t(QBluetoothUuid::CharacteristicType::BodyCompositionMeasurement),                    //  0x2a9c  10908
        int16_t(QBluetoothUuid::CharacteristicType::WeightMeasurement),                             //  0x2a9d  10909
        int16_t(QBluetoothUuid::CharacteristicType::WeightScaleFeature),                            //  0x2a9e  10910
        int16_t(QBluetoothUuid::CharacteristicType::UserControlPoint),                              //  0x2a9f  10911
        int16_t(QBluetoothUuid::CharacteristicType::MagneticFluxDensity2D),                         //  0x2aa0  10912
        int16_t(QBluetoothUuid::CharacteristicType::MagneticFluxDensity3D),                         //  0x2aa1  10913
        int16_t(QBluetoothUuid::CharacteristicType::Language),                                      //  0x2aa2  10914
        int16_t(QBluetoothUuid::CharacteristicType::BarometricPressureTrend)                        //  0x2aa3  10915
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothUuid_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType",
        CharacteristicType_Initializer, CharacteristicType_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_CharacteristicType_IDX].type = EType;
    // Register converter for enum 'QBluetoothUuid::CharacteristicType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothUuid_CharacteristicType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBluetoothUuid_CharacteristicType,
            is_Enum_PythonToCpp_QBluetoothUuid_CharacteristicType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothUuid::CharacteristicType");
        Shiboken::Conversions::registerConverterAlias(converter, "CharacteristicType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CharacteristicType' enum.

    // Initialization of enum 'DescriptorType'.
    const char *DescriptorType_Initializer[] = {
        "UnknownDescriptorType",
        "CharacteristicExtendedProperties",
        "CharacteristicUserDescription",
        "ClientCharacteristicConfiguration",
        "ServerCharacteristicConfiguration",
        "CharacteristicPresentationFormat",
        "CharacteristicAggregateFormat",
        "ValidRange",
        "ExternalReportReference",
        "ReportReference",
        "EnvironmentalSensingConfiguration",
        "EnvironmentalSensingMeasurement",
        "EnvironmentalSensingTriggerSetting",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t DescriptorType_InitializerValues[] = {
        int16_t(QBluetoothUuid::DescriptorType::UnknownDescriptorType),             //  0x0000  0
        int16_t(QBluetoothUuid::DescriptorType::CharacteristicExtendedProperties),  //  0x2900  10496
        int16_t(QBluetoothUuid::DescriptorType::CharacteristicUserDescription),     //  0x2901  10497
        int16_t(QBluetoothUuid::DescriptorType::ClientCharacteristicConfiguration), //  0x2902  10498
        int16_t(QBluetoothUuid::DescriptorType::ServerCharacteristicConfiguration), //  0x2903  10499
        int16_t(QBluetoothUuid::DescriptorType::CharacteristicPresentationFormat),  //  0x2904  10500
        int16_t(QBluetoothUuid::DescriptorType::CharacteristicAggregateFormat),     //  0x2905  10501
        int16_t(QBluetoothUuid::DescriptorType::ValidRange),                        //  0x2906  10502
        int16_t(QBluetoothUuid::DescriptorType::ExternalReportReference),           //  0x2907  10503
        int16_t(QBluetoothUuid::DescriptorType::ReportReference),                   //  0x2908  10504
        int16_t(QBluetoothUuid::DescriptorType::EnvironmentalSensingConfiguration), //  0x290b  10507
        int16_t(QBluetoothUuid::DescriptorType::EnvironmentalSensingMeasurement),   //  0x290c  10508
        int16_t(QBluetoothUuid::DescriptorType::EnvironmentalSensingTriggerSetting) //  0x290d  10509
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothUuid_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothUuid.DescriptorType",
        DescriptorType_Initializer, DescriptorType_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_DescriptorType_IDX].type = EType;
    // Register converter for enum 'QBluetoothUuid::DescriptorType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothUuid_DescriptorType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBluetoothUuid_DescriptorType,
            is_Enum_PythonToCpp_QBluetoothUuid_DescriptorType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothUuid::DescriptorType");
        Shiboken::Conversions::registerConverterAlias(converter, "DescriptorType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DescriptorType' enum.

    qRegisterMetaType< ::QBluetoothUuid >("QBluetoothUuid");
    qRegisterMetaType< ::QBluetoothUuid::ProtocolUuid >("QBluetoothUuid::ProtocolUuid");
    qRegisterMetaType< ::QBluetoothUuid::ServiceClassUuid >("QBluetoothUuid::ServiceClassUuid");
    qRegisterMetaType< ::QBluetoothUuid::CharacteristicType >("QBluetoothUuid::CharacteristicType");
    qRegisterMetaType< ::QBluetoothUuid::DescriptorType >("QBluetoothUuid::DescriptorType");

    return pyType;
}
