// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qlowenergyadvertisingdata_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtBluetooth/qbluetoothuuid.h>
#include <QtBluetooth/qlowenergyadvertisingdata.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLowEnergyAdvertisingData_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLowEnergyAdvertisingData >()))
        return -1;

    ::QLowEnergyAdvertisingData *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QLowEnergyAdvertisingData", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLowEnergyAdvertisingData::QLowEnergyAdvertisingData()
    // 1: QLowEnergyAdvertisingData::QLowEnergyAdvertisingData(QLowEnergyAdvertisingData)
    if (numArgs == 0) {
        overloadId = 0; // QLowEnergyAdvertisingData()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QLowEnergyAdvertisingData(QLowEnergyAdvertisingData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QLowEnergyAdvertisingData()
        {

            // QLowEnergyAdvertisingData()
            cptr = new ::QLowEnergyAdvertisingData();
            break;
        }
        case 1: // QLowEnergyAdvertisingData(const QLowEnergyAdvertisingData &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QLowEnergyAdvertisingData cppArg0_local;
            ::QLowEnergyAdvertisingData *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLowEnergyAdvertisingData(QLowEnergyAdvertisingData)
                cptr = new ::QLowEnergyAdvertisingData(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QLowEnergyAdvertisingData >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QLowEnergyAdvertisingDataFunc_discoverability(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // discoverability()const
        QLowEnergyAdvertisingData::Discoverability cppResult = const_cast<const ::QLowEnergyAdvertisingData *>(cppSelf)->discoverability();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_Discoverability_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyAdvertisingDataFunc_includePowerLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // includePowerLevel()const
        bool cppResult = const_cast<const ::QLowEnergyAdvertisingData *>(cppSelf)->includePowerLevel();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyAdvertisingDataFunc_invalidManufacturerId(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invalidManufacturerId()
        quint16 cppResult = ::QLowEnergyAdvertisingData::invalidManufacturerId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyAdvertisingDataFunc_localName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localName()const
        QString cppResult = const_cast<const ::QLowEnergyAdvertisingData *>(cppSelf)->localName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyAdvertisingDataFunc_manufacturerData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // manufacturerData()const
        QByteArray cppResult = const_cast<const ::QLowEnergyAdvertisingData *>(cppSelf)->manufacturerData();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyAdvertisingDataFunc_manufacturerId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // manufacturerId()const
        quint16 cppResult = const_cast<const ::QLowEnergyAdvertisingData *>(cppSelf)->manufacturerId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyAdvertisingDataFunc_rawData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rawData()const
        QByteArray cppResult = const_cast<const ::QLowEnergyAdvertisingData *>(cppSelf)->rawData();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyAdvertisingDataFunc_services(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // services()const
        QList<QBluetoothUuid> cppResult = const_cast<const ::QLowEnergyAdvertisingData *>(cppSelf)->services();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothUuid_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyAdvertisingDataFunc_setDiscoverability(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyAdvertisingData::setDiscoverability(QLowEnergyAdvertisingData::Discoverability)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_Discoverability_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDiscoverability(QLowEnergyAdvertisingData::Discoverability)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDiscoverability", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]);

    // Call function/method
    {
        ::QLowEnergyAdvertisingData::Discoverability cppArg0{QLowEnergyAdvertisingData::DiscoverabilityNone};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDiscoverability(QLowEnergyAdvertisingData::Discoverability)
            cppSelf->setDiscoverability(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyAdvertisingDataFunc_setIncludePowerLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyAdvertisingData::setIncludePowerLevel(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setIncludePowerLevel(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIncludePowerLevel", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIncludePowerLevel(bool)
            cppSelf->setIncludePowerLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyAdvertisingDataFunc_setLocalName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyAdvertisingData::setLocalName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setLocalName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLocalName", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocalName(QString)
            cppSelf->setLocalName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyAdvertisingDataFunc_setManufacturerData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setManufacturerData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLowEnergyAdvertisingData::setManufacturerData(quint16,QByteArray)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setManufacturerData(quint16,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setManufacturerData", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]);

    // Call function/method
    {
        quint16 cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setManufacturerData(quint16,QByteArray)
            cppSelf->setManufacturerData(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyAdvertisingDataFunc_setRawData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyAdvertisingData::setRawData(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setRawData(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRawData", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRawData(QByteArray)
            cppSelf->setRawData(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyAdvertisingDataFunc_setServices(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyAdvertisingData::setServices(QList<QBluetoothUuid>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothUuid_IDX], (pyArg)))) {
        overloadId = 0; // setServices(QList<QBluetoothUuid>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setServices", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]);

    // Call function/method
    {
        ::QList<QBluetoothUuid> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setServices(QList<QBluetoothUuid>)
            cppSelf->setServices(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyAdvertisingDataFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyAdvertisingData::swap(QLowEnergyAdvertisingData&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QLowEnergyAdvertisingData&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLowEnergyAdvertisingData cppArg0_local;
        ::QLowEnergyAdvertisingData *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QLowEnergyAdvertisingData&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyAdvertisingData__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QLowEnergyAdvertisingData_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QLowEnergyAdvertisingData_EnumFlagInfo[] = {
    "Discoverability:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLowEnergyAdvertisingData_methods[] = {
    {"discoverability", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingDataFunc_discoverability), METH_NOARGS, nullptr},
    {"includePowerLevel", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingDataFunc_includePowerLevel), METH_NOARGS, nullptr},
    {"invalidManufacturerId", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingDataFunc_invalidManufacturerId), METH_NOARGS|METH_STATIC, nullptr},
    {"localName", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingDataFunc_localName), METH_NOARGS, nullptr},
    {"manufacturerData", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingDataFunc_manufacturerData), METH_NOARGS, nullptr},
    {"manufacturerId", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingDataFunc_manufacturerId), METH_NOARGS, nullptr},
    {"rawData", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingDataFunc_rawData), METH_NOARGS, nullptr},
    {"services", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingDataFunc_services), METH_NOARGS, nullptr},
    {"setDiscoverability", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingDataFunc_setDiscoverability), METH_O, nullptr},
    {"setIncludePowerLevel", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingDataFunc_setIncludePowerLevel), METH_O, nullptr},
    {"setLocalName", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingDataFunc_setLocalName), METH_O, nullptr},
    {"setManufacturerData", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingDataFunc_setManufacturerData), METH_VARARGS, nullptr},
    {"setRawData", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingDataFunc_setRawData), METH_O, nullptr},
    {"setServices", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingDataFunc_setServices), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingDataFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyAdvertisingData__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QLowEnergyAdvertisingData_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), (pyArg)))) {
                // operator!=(const QLowEnergyAdvertisingData &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyAdvertisingData cppArg0_local;
                ::QLowEnergyAdvertisingData *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), (pyArg)))) {
                // operator==(const QLowEnergyAdvertisingData &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyAdvertisingData cppArg0_local;
                ::QLowEnergyAdvertisingData *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QLowEnergyAdvertisingData_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLowEnergyAdvertisingData_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLowEnergyAdvertisingData_Type = nullptr;
static PyTypeObject *Sbk_QLowEnergyAdvertisingData_TypeF(void)
{
    return _Sbk_QLowEnergyAdvertisingData_Type;
}

static PyType_Slot Sbk_QLowEnergyAdvertisingData_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLowEnergyAdvertisingData_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLowEnergyAdvertisingData_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QLowEnergyAdvertisingData_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLowEnergyAdvertisingData_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLowEnergyAdvertisingData_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLowEnergyAdvertisingData_spec = {
    "2:PySide6.QtBluetooth.QLowEnergyAdvertisingData",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLowEnergyAdvertisingData_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QLowEnergyAdvertisingData_Discoverability(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLowEnergyAdvertisingData::Discoverability>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLowEnergyAdvertisingData::Discoverability *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLowEnergyAdvertisingData_Discoverability_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_Discoverability_IDX])))
        return Enum_PythonToCpp_QLowEnergyAdvertisingData_Discoverability;
    return {};
}

static PyObject *QLowEnergyAdvertisingData_Discoverability_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLowEnergyAdvertisingData::Discoverability>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLowEnergyAdvertisingData::Discoverability *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_Discoverability_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLowEnergyAdvertisingData_PythonToCpp_QLowEnergyAdvertisingData_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLowEnergyAdvertisingData_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLowEnergyAdvertisingData_PythonToCpp_QLowEnergyAdvertisingData_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyAdvertisingData_TypeF()))
        return QLowEnergyAdvertisingData_PythonToCpp_QLowEnergyAdvertisingData_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLowEnergyAdvertisingData_PTR_CppToPython_QLowEnergyAdvertisingData(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QLowEnergyAdvertisingData_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QLowEnergyAdvertisingData_COPY_CppToPython_QLowEnergyAdvertisingData(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QLowEnergyAdvertisingData *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QLowEnergyAdvertisingData_TypeF(), new ::QLowEnergyAdvertisingData(*source), true, true);
}

// Python to C++ copy conversion.
static void QLowEnergyAdvertisingData_PythonToCpp_QLowEnergyAdvertisingData_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QLowEnergyAdvertisingData *>(cppOut) = *reinterpret_cast< ::QLowEnergyAdvertisingData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QLowEnergyAdvertisingData_PythonToCpp_QLowEnergyAdvertisingData_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyAdvertisingData_TypeF()))
        return QLowEnergyAdvertisingData_PythonToCpp_QLowEnergyAdvertisingData_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QLowEnergyAdvertisingData_SignatureStrings[] = {
    "1:PySide6.QtBluetooth.QLowEnergyAdvertisingData(self)",
    "0:PySide6.QtBluetooth.QLowEnergyAdvertisingData(self,other:PySide6.QtBluetooth.QLowEnergyAdvertisingData)",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.discoverability(self)->PySide6.QtBluetooth.QLowEnergyAdvertisingData.Discoverability",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.includePowerLevel(self)->bool",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.invalidManufacturerId()->quint16",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.localName(self)->QString",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.manufacturerData(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.manufacturerId(self)->quint16",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.rawData(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.services(self)->QList[PySide6.QtBluetooth.QBluetoothUuid]",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.setDiscoverability(self,mode:PySide6.QtBluetooth.QLowEnergyAdvertisingData.Discoverability)",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.setIncludePowerLevel(self,doInclude:bool)",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.setLocalName(self,name:QString)",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.setManufacturerData(self,id:quint16,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.setRawData(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.setServices(self,services:QList[PySide6.QtBluetooth.QBluetoothUuid])",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.swap(self,other:PySide6.QtBluetooth.QLowEnergyAdvertisingData)",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.__copy__(self)->typing.Self",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.__ne__(self,b:PySide6.QtBluetooth.QLowEnergyAdvertisingData)->bool",
    "PySide6.QtBluetooth.QLowEnergyAdvertisingData.__eq__(self,b:PySide6.QtBluetooth.QLowEnergyAdvertisingData)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QLowEnergyAdvertisingData_SignatureByteSize = 355;
static constexpr uint8_t QLowEnergyAdvertisingData_SignatureBytes[355] = {
    0x78, 0xda, 0xbd, 0x94, 0x4f, 0x6b, 0xc2, 0x30, 0x18, 0x87, 0xef, 0x7e, 0x8a, 0x1d, 0x75, 0x64,
    0x65, 0x5e, 0x3c, 0xe4, 0x30, 0xd0, 0x75, 0x07, 0xa1, 0x0e, 0xbb, 0xe2, 0x49, 0xa4, 0xc4, 0xe4,
    0x55, 0x5f, 0x88, 0x89, 0xa6, 0x69, 0x4b, 0xbf, 0xfd, 0x32, 0xd6, 0xba, 0x0a, 0x1d, 0x2c, 0x95,
    0x79, 0x4b, 0xf3, 0xe7, 0x79, 0x7f, 0x79, 0x79, 0x9a, 0x31, 0x5d, 0x56, 0x09, 0x0a, 0x98, 0x04,
    0xb1, 0x9d, 0xc9, 0x1c, 0xac, 0xd6, 0xf6, 0x10, 0xc4, 0x91, 0x2e, 0xdf, 0x14, 0x98, 0x7d, 0x35,
    0x15, 0x05, 0x18, 0x8b, 0x19, 0xaa, 0x7d, 0xc8, 0x2c, 0x1b, 0x66, 0x20, 0x77, 0xa3, 0xc1, 0x73,
    0x8f, 0x53, 0xc4, 0x6d, 0x01, 0xe3, 0x77, 0x70, 0x34, 0xf0, 0xda, 0x1e, 0x08, 0xcc, 0xb8, 0x76,
    0x53, 0x6c, 0x8b, 0x12, 0x6d, 0xf5, 0x9d, 0xf6, 0xe9, 0xc5, 0x0f, 0x12, 0x5e, 0x43, 0x3c, 0x23,
    0xa0, 0xe2, 0x32, 0x17, 0xb0, 0xd4, 0x25, 0x98, 0x08, 0x0a, 0x90, 0x4d, 0x88, 0xad, 0xd6, 0xd2,
    0x9b, 0x55, 0x30, 0x89, 0x62, 0xc1, 0x54, 0xbe, 0x63, 0xdc, 0xe6, 0x06, 0xcc, 0x5c, 0x0c, 0x1d,
    0xeb, 0x9c, 0xa3, 0xb2, 0xe3, 0x89, 0x27, 0x4e, 0x6a, 0xce, 0xe4, 0x3b, 0x3b, 0x42, 0x13, 0x29,
    0x4e, 0xac, 0x71, 0x8b, 0x9e, 0x98, 0x63, 0x2b, 0xce, 0x8f, 0x13, 0xed, 0x2e, 0xbf, 0x6a, 0x03,
    0x41, 0x3c, 0xab, 0x2c, 0x4c, 0x8d, 0x61, 0xd5, 0x0d, 0x7c, 0x77, 0xdd, 0x9a, 0xde, 0xef, 0xca,
    0x86, 0x95, 0xff, 0x11, 0x31, 0x03, 0x53, 0x20, 0x87, 0xec, 0xd2, 0xc8, 0x08, 0x33, 0xbb, 0xee,
    0x64, 0x5c, 0x86, 0xab, 0x1c, 0xc5, 0xc6, 0xbb, 0x8e, 0x0d, 0x3b, 0x94, 0x26, 0x47, 0x2d, 0x80,
    0xde, 0x64, 0xf5, 0xc8, 0x3f, 0xc9, 0xbc, 0xd3, 0x6c, 0x22, 0x74, 0xbd, 0x40, 0xbf, 0x0c, 0xef,
    0xc1, 0x8d, 0xae, 0xb4, 0x24, 0xca, 0x8d, 0x68, 0x6d, 0x66, 0x0f, 0xda, 0xa2, 0xcb, 0x4e, 0x82,
    0x82, 0xd6, 0x02, 0x11, 0xe1, 0x26, 0xa9, 0xad, 0x4e, 0xee, 0x4c, 0xb0, 0x52, 0xa8, 0xd5, 0xfa,
    0x57, 0x2b, 0xc8, 0x03, 0x3f, 0x30, 0xf3, 0xb8, 0xe9, 0x11, 0xe3, 0xa3, 0x25, 0xde, 0x9d, 0x4a,
    0x26, 0x6d, 0x29, 0x49, 0xa3, 0x28, 0xfd, 0xb3, 0x9b, 0xde, 0x25, 0x4b, 0x76, 0xba, 0xdb, 0xcb,
    0x9e, 0xa6, 0x5c, 0x9f, 0xaa, 0x34, 0x6d, 0xfe, 0xb8, 0xba, 0x9b, 0x89, 0xfb, 0xf2, 0x26, 0x29,
    0xa8, 0x39, 0x64, 0xeb, 0x19, 0xba, 0xd7, 0x2b, 0x9e, 0xa6, 0x70, 0xbe, 0xb1, 0xe0, 0x27, 0xf4,
    0xd6, 0xd9, 0x6c
};
#endif

PyTypeObject *init_QLowEnergyAdvertisingData(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX].type;

    Shiboken::AutoDecRef Sbk_QLowEnergyAdvertisingData_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QLowEnergyAdvertisingData_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLowEnergyAdvertisingData",
        "QLowEnergyAdvertisingData",
        &Sbk_QLowEnergyAdvertisingData_spec,
        &Shiboken::callCppDestructor< ::QLowEnergyAdvertisingData >,
        Sbk_QLowEnergyAdvertisingData_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QLowEnergyAdvertisingData_TypeF(); // references _Sbk_QLowEnergyAdvertisingData_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QLowEnergyAdvertisingData_SignatureStrings);
#else
    InitSignatureBytes(pyType, QLowEnergyAdvertisingData_SignatureBytes, QLowEnergyAdvertisingData_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLowEnergyAdvertisingData_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLowEnergyAdvertisingData_PythonToCpp_QLowEnergyAdvertisingData_PTR,
        is_QLowEnergyAdvertisingData_PythonToCpp_QLowEnergyAdvertisingData_PTR_Convertible,
        QLowEnergyAdvertisingData_PTR_CppToPython_QLowEnergyAdvertisingData,
        QLowEnergyAdvertisingData_COPY_CppToPython_QLowEnergyAdvertisingData);

    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyAdvertisingData");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyAdvertisingData*");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyAdvertisingData&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLowEnergyAdvertisingData).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLowEnergyAdvertisingData_PythonToCpp_QLowEnergyAdvertisingData_COPY,
        is_QLowEnergyAdvertisingData_PythonToCpp_QLowEnergyAdvertisingData_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QLowEnergyAdvertisingData_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Discoverability'.
    const char *Discoverability_Initializer[] = {
        "DiscoverabilityNone",
        "DiscoverabilityLimited",
        "DiscoverabilityGeneral",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Discoverability_InitializerValues[] = {
        uint8_t(QLowEnergyAdvertisingData::Discoverability::DiscoverabilityNone),    //  0x00  0
        uint8_t(QLowEnergyAdvertisingData::Discoverability::DiscoverabilityLimited), //  0x01  1
        uint8_t(QLowEnergyAdvertisingData::Discoverability::DiscoverabilityGeneral)  //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLowEnergyAdvertisingData_TypeF(),
        "2:PySide6.QtBluetooth.QLowEnergyAdvertisingData.Discoverability",
        Discoverability_Initializer, Discoverability_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_Discoverability_IDX].type = EType;
    // Register converter for enum 'QLowEnergyAdvertisingData::Discoverability'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLowEnergyAdvertisingData_Discoverability_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLowEnergyAdvertisingData_Discoverability,
            is_Enum_PythonToCpp_QLowEnergyAdvertisingData_Discoverability_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLowEnergyAdvertisingData::Discoverability");
        Shiboken::Conversions::registerConverterAlias(converter, "Discoverability");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Discoverability' enum.

    qRegisterMetaType< ::QLowEnergyAdvertisingData >("QLowEnergyAdvertisingData");
    qRegisterMetaType< ::QLowEnergyAdvertisingData::Discoverability >("QLowEnergyAdvertisingData::Discoverability");

    return pyType;
}
