// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qlowenergycharacteristicdata_wrapper.h"

// Argument includes
#include <QList>
#include <QtBluetooth/qbluetoothuuid.h>
#include <QtBluetooth/qlowenergycharacteristicdata.h>
#include <QtBluetooth/qlowenergydescriptordata.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLowEnergyCharacteristicData_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLowEnergyCharacteristicData >()))
        return -1;

    ::QLowEnergyCharacteristicData *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QLowEnergyCharacteristicData", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLowEnergyCharacteristicData::QLowEnergyCharacteristicData()
    // 1: QLowEnergyCharacteristicData::QLowEnergyCharacteristicData(QLowEnergyCharacteristicData)
    if (numArgs == 0) {
        overloadId = 0; // QLowEnergyCharacteristicData()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QLowEnergyCharacteristicData(QLowEnergyCharacteristicData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QLowEnergyCharacteristicData()
        {

            // QLowEnergyCharacteristicData()
            cptr = new ::QLowEnergyCharacteristicData();
            break;
        }
        case 1: // QLowEnergyCharacteristicData(const QLowEnergyCharacteristicData &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QLowEnergyCharacteristicData cppArg0_local;
            ::QLowEnergyCharacteristicData *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLowEnergyCharacteristicData(QLowEnergyCharacteristicData)
                cptr = new ::QLowEnergyCharacteristicData(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QLowEnergyCharacteristicData >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_addDescriptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyCharacteristicData::addDescriptor(QLowEnergyDescriptorData)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), (pyArg)))) {
        overloadId = 0; // addDescriptor(QLowEnergyDescriptorData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addDescriptor", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLowEnergyDescriptorData cppArg0_local;
        ::QLowEnergyDescriptorData *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // addDescriptor(QLowEnergyDescriptorData)
            cppSelf->addDescriptor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_descriptors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // descriptors()const
        QList<QLowEnergyDescriptorData> cppResult = const_cast<const ::QLowEnergyCharacteristicData *>(cppSelf)->descriptors();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyDescriptorData_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QLowEnergyCharacteristicData *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_maximumValueLength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumValueLength()const
        int cppResult = const_cast<const ::QLowEnergyCharacteristicData *>(cppSelf)->maximumValueLength();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_minimumValueLength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumValueLength()const
        int cppResult = const_cast<const ::QLowEnergyCharacteristicData *>(cppSelf)->minimumValueLength();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_properties(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // properties()const
        QFlags<QLowEnergyCharacteristic::PropertyType> cppResult = const_cast<const ::QLowEnergyCharacteristicData *>(cppSelf)->properties();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QLowEnergyCharacteristic_PropertyType_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_readConstraints(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readConstraints()const
        QFlags<QBluetooth::AttAccessConstraint> cppResult = const_cast<const ::QLowEnergyCharacteristicData *>(cppSelf)->readConstraints();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetooth_AttAccessConstraint_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_setDescriptors(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyCharacteristicData::setDescriptors(QList<QLowEnergyDescriptorData>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyDescriptorData_IDX], (pyArg)))) {
        overloadId = 0; // setDescriptors(QList<QLowEnergyDescriptorData>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDescriptors", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]);

    // Call function/method
    {
        ::QList<QLowEnergyDescriptorData> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDescriptors(QList<QLowEnergyDescriptorData>)
            cppSelf->setDescriptors(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_setProperties(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyCharacteristicData::setProperties(QFlags<QLowEnergyCharacteristic::PropertyType>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QLowEnergyCharacteristic_PropertyType_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setProperties(QFlags<QLowEnergyCharacteristic::PropertyType>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProperties", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]);

    // Call function/method
    {
        ::QFlags<QLowEnergyCharacteristic::PropertyType> cppArg0 = QFlags<QLowEnergyCharacteristic::PropertyType>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProperties(QFlags<QLowEnergyCharacteristic::PropertyType>)
            cppSelf->setProperties(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_setReadConstraints(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyCharacteristicData::setReadConstraints(QFlags<QBluetooth::AttAccessConstraint>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetooth_AttAccessConstraint_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setReadConstraints(QFlags<QBluetooth::AttAccessConstraint>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReadConstraints", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]);

    // Call function/method
    {
        ::QFlags<QBluetooth::AttAccessConstraint> cppArg0 = QFlags<QBluetooth::AttAccessConstraint>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReadConstraints(QFlags<QBluetooth::AttAccessConstraint>)
            cppSelf->setReadConstraints(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_setUuid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyCharacteristicData::setUuid(QBluetoothUuid)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArg)))) {
        overloadId = 0; // setUuid(QBluetoothUuid)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUuid", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBluetoothUuid cppArg0_local;
        ::QBluetoothUuid *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUuid(QBluetoothUuid)
            cppSelf->setUuid(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_setValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyCharacteristicData::setValue(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setValue(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setValue", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setValue(QByteArray)
            cppSelf->setValue(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_setValueLength(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setValueLength", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLowEnergyCharacteristicData::setValueLength(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setValueLength(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setValueLength", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValueLength(int,int)
            cppSelf->setValueLength(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_setWriteConstraints(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyCharacteristicData::setWriteConstraints(QFlags<QBluetooth::AttAccessConstraint>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetooth_AttAccessConstraint_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setWriteConstraints(QFlags<QBluetooth::AttAccessConstraint>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWriteConstraints", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]);

    // Call function/method
    {
        ::QFlags<QBluetooth::AttAccessConstraint> cppArg0 = QFlags<QBluetooth::AttAccessConstraint>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWriteConstraints(QFlags<QBluetooth::AttAccessConstraint>)
            cppSelf->setWriteConstraints(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyCharacteristicData::swap(QLowEnergyCharacteristicData&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QLowEnergyCharacteristicData&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLowEnergyCharacteristicData cppArg0_local;
        ::QLowEnergyCharacteristicData *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QLowEnergyCharacteristicData&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_uuid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // uuid()const
        QBluetoothUuid cppResult = const_cast<const ::QLowEnergyCharacteristicData *>(cppSelf)->uuid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // value()const
        QByteArray cppResult = const_cast<const ::QLowEnergyCharacteristicData *>(cppSelf)->value();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicDataFunc_writeConstraints(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // writeConstraints()const
        QFlags<QBluetooth::AttAccessConstraint> cppResult = const_cast<const ::QLowEnergyCharacteristicData *>(cppSelf)->writeConstraints();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetooth_AttAccessConstraint_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicData__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QLowEnergyCharacteristicData_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLowEnergyCharacteristicData_methods[] = {
    {"addDescriptor", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_addDescriptor), METH_O, nullptr},
    {"descriptors", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_descriptors), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_isValid), METH_NOARGS, nullptr},
    {"maximumValueLength", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_maximumValueLength), METH_NOARGS, nullptr},
    {"minimumValueLength", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_minimumValueLength), METH_NOARGS, nullptr},
    {"properties", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_properties), METH_NOARGS, nullptr},
    {"readConstraints", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_readConstraints), METH_NOARGS, nullptr},
    {"setDescriptors", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_setDescriptors), METH_O, nullptr},
    {"setProperties", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_setProperties), METH_O, nullptr},
    {"setReadConstraints", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_setReadConstraints), METH_O, nullptr},
    {"setUuid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_setUuid), METH_O, nullptr},
    {"setValue", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_setValue), METH_O, nullptr},
    {"setValueLength", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_setValueLength), METH_VARARGS, nullptr},
    {"setWriteConstraints", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_setWriteConstraints), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_swap), METH_O, nullptr},
    {"uuid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_uuid), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_value), METH_NOARGS, nullptr},
    {"writeConstraints", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicDataFunc_writeConstraints), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicData__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QLowEnergyCharacteristicData_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), (pyArg)))) {
                // operator!=(const QLowEnergyCharacteristicData &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyCharacteristicData cppArg0_local;
                ::QLowEnergyCharacteristicData *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), (pyArg)))) {
                // operator==(const QLowEnergyCharacteristicData &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyCharacteristicData cppArg0_local;
                ::QLowEnergyCharacteristicData *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QLowEnergyCharacteristicData_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLowEnergyCharacteristicData_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLowEnergyCharacteristicData_Type = nullptr;
static PyTypeObject *Sbk_QLowEnergyCharacteristicData_TypeF(void)
{
    return _Sbk_QLowEnergyCharacteristicData_Type;
}

static PyType_Slot Sbk_QLowEnergyCharacteristicData_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLowEnergyCharacteristicData_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLowEnergyCharacteristicData_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QLowEnergyCharacteristicData_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLowEnergyCharacteristicData_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLowEnergyCharacteristicData_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLowEnergyCharacteristicData_spec = {
    "2:PySide6.QtBluetooth.QLowEnergyCharacteristicData",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLowEnergyCharacteristicData_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLowEnergyCharacteristicData_PythonToCpp_QLowEnergyCharacteristicData_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLowEnergyCharacteristicData_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLowEnergyCharacteristicData_PythonToCpp_QLowEnergyCharacteristicData_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyCharacteristicData_TypeF()))
        return QLowEnergyCharacteristicData_PythonToCpp_QLowEnergyCharacteristicData_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLowEnergyCharacteristicData_PTR_CppToPython_QLowEnergyCharacteristicData(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QLowEnergyCharacteristicData_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QLowEnergyCharacteristicData_COPY_CppToPython_QLowEnergyCharacteristicData(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QLowEnergyCharacteristicData *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QLowEnergyCharacteristicData_TypeF(), new ::QLowEnergyCharacteristicData(*source), true, true);
}

// Python to C++ copy conversion.
static void QLowEnergyCharacteristicData_PythonToCpp_QLowEnergyCharacteristicData_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QLowEnergyCharacteristicData *>(cppOut) = *reinterpret_cast< ::QLowEnergyCharacteristicData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QLowEnergyCharacteristicData_PythonToCpp_QLowEnergyCharacteristicData_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyCharacteristicData_TypeF()))
        return QLowEnergyCharacteristicData_PythonToCpp_QLowEnergyCharacteristicData_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QLowEnergyCharacteristicData_SignatureStrings[] = {
    "1:PySide6.QtBluetooth.QLowEnergyCharacteristicData(self)",
    "0:PySide6.QtBluetooth.QLowEnergyCharacteristicData(self,other:PySide6.QtBluetooth.QLowEnergyCharacteristicData)",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.addDescriptor(self,descriptor:PySide6.QtBluetooth.QLowEnergyDescriptorData)",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.descriptors(self)->QList[PySide6.QtBluetooth.QLowEnergyDescriptorData]",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.isValid(self)->bool",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.maximumValueLength(self)->int",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.minimumValueLength(self)->int",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.properties(self)->PySide6.QtBluetooth.QLowEnergyCharacteristic.PropertyType",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.readConstraints(self)->PySide6.QtBluetooth.QBluetooth.AttAccessConstraint",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.setDescriptors(self,descriptors:QList[PySide6.QtBluetooth.QLowEnergyDescriptorData])",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.setProperties(self,properties:PySide6.QtBluetooth.QLowEnergyCharacteristic.PropertyType)",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.setReadConstraints(self,constraints:PySide6.QtBluetooth.QBluetooth.AttAccessConstraint)",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.setUuid(self,uuid:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid])",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.setValue(self,value:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.setValueLength(self,minimum:int,maximum:int)",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.setWriteConstraints(self,constraints:PySide6.QtBluetooth.QBluetooth.AttAccessConstraint)",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.swap(self,other:PySide6.QtBluetooth.QLowEnergyCharacteristicData)",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.uuid(self)->PySide6.QtBluetooth.QBluetoothUuid",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.value(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.writeConstraints(self)->PySide6.QtBluetooth.QBluetooth.AttAccessConstraint",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.__copy__(self)->typing.Self",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.__ne__(self,b:PySide6.QtBluetooth.QLowEnergyCharacteristicData)->bool",
    "PySide6.QtBluetooth.QLowEnergyCharacteristicData.__eq__(self,b:PySide6.QtBluetooth.QLowEnergyCharacteristicData)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QLowEnergyCharacteristicData_SignatureByteSize = 426;
static constexpr uint8_t QLowEnergyCharacteristicData_SignatureBytes[426] = {
    0x78, 0xda, 0xcd, 0x56, 0x41, 0x4f, 0xc2, 0x30, 0x18, 0xbd, 0xf3, 0x2b, 0x38, 0x8a, 0xa9, 0x8b,
    0x5e, 0x3c, 0xec, 0x60, 0x82, 0xc3, 0x1b, 0x07, 0x26, 0xa2, 0x07, 0x62, 0x96, 0xd2, 0x7d, 0x42,
    0x93, 0xd1, 0xce, 0xf6, 0x1b, 0xd8, 0x7f, 0x6f, 0xe7, 0x06, 0x03, 0x82, 0x40, 0x8b, 0x21, 0xde,
    0xda, 0xae, 0xef, 0xbd, 0x2f, 0xdf, 0x7b, 0xfb, 0xb6, 0xbb, 0x70, 0x60, 0x86, 0x3c, 0x85, 0xfb,
    0x20, 0xc6, 0xc7, 0xac, 0x00, 0x94, 0x12, 0x67, 0x41, 0xdc, 0x97, 0xcb, 0x27, 0x01, 0x6a, 0x6a,
    0xa2, 0x19, 0x55, 0x94, 0x21, 0x28, 0xae, 0x91, 0xb3, 0x1e, 0x45, 0x7a, 0xa5, 0x21, 0xfb, 0xe8,
    0xb4, 0x6e, 0xfd, 0x80, 0xc4, 0xde, 0x02, 0xe5, 0x8c, 0xed, 0xb4, 0x5c, 0x11, 0x01, 0x4d, 0xd3,
    0x1e, 0x68, 0xa6, 0x78, 0x8e, 0x52, 0x55, 0xda, 0xe9, 0x7a, 0x7f, 0xa4, 0x80, 0x06, 0xe8, 0x29,
    0xde, 0x28, 0xe9, 0xaa, 0x5f, 0x37, 0x0f, 0x71, 0xdf, 0x3e, 0x1e, 0xbb, 0xe8, 0xbe, 0xbb, 0xeb,
    0x72, 0xfd, 0x4a, 0x33, 0x9e, 0xae, 0x34, 0x27, 0x52, 0x66, 0xee, 0x24, 0x73, 0xfa, 0xc5, 0xe7,
    0xc5, 0xdc, 0x32, 0x15, 0xd0, 0x07, 0x31, 0xc5, 0xd9, 0x8a, 0x8f, 0x0b, 0xf4, 0xa0, 0xe3, 0xe2,
    0x2f, 0xe9, 0x72, 0x25, 0x73, 0x50, 0xc8, 0x61, 0xdd, 0x59, 0x17, 0x8a, 0x60, 0x50, 0xc1, 0xcd,
    0x8b, 0xc9, 0xc1, 0x5d, 0x5c, 0x01, 0x4d, 0x23, 0x29, 0x34, 0x2a, 0x6a, 0x8b, 0x3f, 0x5c, 0x41,
    0xb3, 0xec, 0x22, 0x76, 0x19, 0x03, 0xad, 0x1b, 0xa8, 0xbb, 0xb4, 0x06, 0xec, 0xed, 0xa4, 0x6a,
    0x23, 0xd0, 0x3a, 0xf4, 0xc8, 0x57, 0xc7, 0xab, 0x8a, 0xc1, 0xb6, 0x01, 0xa4, 0x31, 0x24, 0xf4,
    0x76, 0xc2, 0xaf, 0x92, 0xe7, 0x3d, 0x6e, 0x10, 0xd6, 0x1c, 0x84, 0xee, 0xbe, 0xf8, 0x15, 0x32,
    0x2a, 0xea, 0x77, 0x8e, 0x14, 0x76, 0x15, 0xa2, 0xc9, 0xb9, 0x98, 0x06, 0x23, 0xc1, 0xa5, 0x18,
    0x1f, 0xae, 0xa1, 0x44, 0x92, 0xf6, 0xf1, 0x3b, 0xc1, 0xb6, 0x70, 0xd9, 0xb3, 0x93, 0x60, 0x8d,
    0xe3, 0x27, 0x43, 0xac, 0x2f, 0x28, 0x99, 0xcc, 0x4e, 0x2e, 0x6d, 0x08, 0x6a, 0xc1, 0x19, 0x44,
    0x19, 0xd5, 0x7a, 0x17, 0x14, 0x49, 0x05, 0x41, 0x5c, 0x9e, 0x7a, 0xa6, 0xed, 0x67, 0x6c, 0x54,
    0xbd, 0x5d, 0x94, 0xcb, 0xdf, 0x9a, 0x5b, 0x09, 0x3d, 0x1a, 0x84, 0xae, 0x52, 0xd4, 0x90, 0x36,
    0xb3, 0x74, 0xd7, 0xe7, 0x88, 0x6e, 0xcc, 0x2a, 0x52, 0xcf, 0xb0, 0xd0, 0x26, 0x84, 0xd4, 0xe3,
    0x31, 0xf4, 0x4e, 0xcb, 0x9b, 0xe2, 0x08, 0xff, 0x20, 0xb7, 0x4b, 0x9a, 0x5f, 0xf8, 0x9b, 0x5c,
    0x14, 0xcd, 0xb7, 0xe9, 0x78, 0xb0, 0xdc, 0xf9, 0x17, 0xeb, 0xb0, 0x6c, 0x09, 0xec, 0x64, 0xc3,
    0x9d, 0x77, 0xb9, 0xcf, 0xb1, 0x0b, 0xcd, 0xfd, 0x24, 0x61, 0x32, 0x37, 0x49, 0xb2, 0xd2, 0xac,
    0xf3, 0x3f, 0xb4, 0x3b, 0x1f, 0x32, 0x01, 0x35, 0x15, 0x99, 0xb8, 0x3b, 0xee, 0xfb, 0x47, 0x91,
    0x24, 0xf0, 0x79, 0xbe, 0xec, 0x37, 0x75, 0xda, 0x03, 0x2b
};
#endif

PyTypeObject *init_QLowEnergyCharacteristicData(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX].type;

    Shiboken::AutoDecRef Sbk_QLowEnergyCharacteristicData_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QLowEnergyCharacteristicData_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLowEnergyCharacteristicData",
        "QLowEnergyCharacteristicData",
        &Sbk_QLowEnergyCharacteristicData_spec,
        &Shiboken::callCppDestructor< ::QLowEnergyCharacteristicData >,
        Sbk_QLowEnergyCharacteristicData_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QLowEnergyCharacteristicData_TypeF(); // references _Sbk_QLowEnergyCharacteristicData_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QLowEnergyCharacteristicData_SignatureStrings);
#else
    InitSignatureBytes(pyType, QLowEnergyCharacteristicData_SignatureBytes, QLowEnergyCharacteristicData_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLowEnergyCharacteristicData_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLowEnergyCharacteristicData_PythonToCpp_QLowEnergyCharacteristicData_PTR,
        is_QLowEnergyCharacteristicData_PythonToCpp_QLowEnergyCharacteristicData_PTR_Convertible,
        QLowEnergyCharacteristicData_PTR_CppToPython_QLowEnergyCharacteristicData,
        QLowEnergyCharacteristicData_COPY_CppToPython_QLowEnergyCharacteristicData);

    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyCharacteristicData");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyCharacteristicData*");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyCharacteristicData&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLowEnergyCharacteristicData).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLowEnergyCharacteristicData_PythonToCpp_QLowEnergyCharacteristicData_COPY,
        is_QLowEnergyCharacteristicData_PythonToCpp_QLowEnergyCharacteristicData_COPY_Convertible);

    qRegisterMetaType< ::QLowEnergyCharacteristicData >("QLowEnergyCharacteristicData");

    return pyType;
}
