// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qlowenergyconnectionparameters_wrapper.h"

// Argument includes
#include <QtBluetooth/qlowenergyconnectionparameters.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLowEnergyConnectionParameters_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLowEnergyConnectionParameters >()))
        return -1;

    ::QLowEnergyConnectionParameters *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QLowEnergyConnectionParameters", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLowEnergyConnectionParameters::QLowEnergyConnectionParameters()
    // 1: QLowEnergyConnectionParameters::QLowEnergyConnectionParameters(QLowEnergyConnectionParameters)
    if (numArgs == 0) {
        overloadId = 0; // QLowEnergyConnectionParameters()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QLowEnergyConnectionParameters(QLowEnergyConnectionParameters)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QLowEnergyConnectionParameters()
        {

            // QLowEnergyConnectionParameters()
            cptr = new ::QLowEnergyConnectionParameters();
            break;
        }
        case 1: // QLowEnergyConnectionParameters(const QLowEnergyConnectionParameters &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QLowEnergyConnectionParameters cppArg0_local;
            ::QLowEnergyConnectionParameters *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLowEnergyConnectionParameters(QLowEnergyConnectionParameters)
                cptr = new ::QLowEnergyConnectionParameters(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QLowEnergyConnectionParameters >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_latency(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // latency()const
        int cppResult = const_cast<const ::QLowEnergyConnectionParameters *>(cppSelf)->latency();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_maximumInterval(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumInterval()const
        double cppResult = const_cast<const ::QLowEnergyConnectionParameters *>(cppSelf)->maximumInterval();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_minimumInterval(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumInterval()const
        double cppResult = const_cast<const ::QLowEnergyConnectionParameters *>(cppSelf)->minimumInterval();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_setIntervalRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setIntervalRange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLowEnergyConnectionParameters::setIntervalRange(double,double)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))) {
        overloadId = 0; // setIntervalRange(double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setIntervalRange", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIntervalRange(double,double)
            cppSelf->setIntervalRange(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_setLatency(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyConnectionParameters::setLatency(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLatency(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLatency", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLatency(int)
            cppSelf->setLatency(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_setSupervisionTimeout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyConnectionParameters::setSupervisionTimeout(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSupervisionTimeout(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSupervisionTimeout", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSupervisionTimeout(int)
            cppSelf->setSupervisionTimeout(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_supervisionTimeout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supervisionTimeout()const
        int cppResult = const_cast<const ::QLowEnergyConnectionParameters *>(cppSelf)->supervisionTimeout();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyConnectionParameters::swap(QLowEnergyConnectionParameters&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QLowEnergyConnectionParameters&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLowEnergyConnectionParameters cppArg0_local;
        ::QLowEnergyConnectionParameters *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QLowEnergyConnectionParameters&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyConnectionParameters__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QLowEnergyConnectionParameters_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLowEnergyConnectionParameters_methods[] = {
    {"latency", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_latency), METH_NOARGS, nullptr},
    {"maximumInterval", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_maximumInterval), METH_NOARGS, nullptr},
    {"minimumInterval", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_minimumInterval), METH_NOARGS, nullptr},
    {"setIntervalRange", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_setIntervalRange), METH_VARARGS, nullptr},
    {"setLatency", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_setLatency), METH_O, nullptr},
    {"setSupervisionTimeout", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_setSupervisionTimeout), METH_O, nullptr},
    {"supervisionTimeout", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_supervisionTimeout), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParameters__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QLowEnergyConnectionParameters_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), (pyArg)))) {
                // operator!=(const QLowEnergyConnectionParameters &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyConnectionParameters cppArg0_local;
                ::QLowEnergyConnectionParameters *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), (pyArg)))) {
                // operator==(const QLowEnergyConnectionParameters &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyConnectionParameters cppArg0_local;
                ::QLowEnergyConnectionParameters *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QLowEnergyConnectionParameters_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLowEnergyConnectionParameters_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLowEnergyConnectionParameters_Type = nullptr;
static PyTypeObject *Sbk_QLowEnergyConnectionParameters_TypeF(void)
{
    return _Sbk_QLowEnergyConnectionParameters_Type;
}

static PyType_Slot Sbk_QLowEnergyConnectionParameters_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLowEnergyConnectionParameters_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLowEnergyConnectionParameters_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QLowEnergyConnectionParameters_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLowEnergyConnectionParameters_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLowEnergyConnectionParameters_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLowEnergyConnectionParameters_spec = {
    "2:PySide6.QtBluetooth.QLowEnergyConnectionParameters",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLowEnergyConnectionParameters_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLowEnergyConnectionParameters_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyConnectionParameters_TypeF()))
        return QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLowEnergyConnectionParameters_PTR_CppToPython_QLowEnergyConnectionParameters(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QLowEnergyConnectionParameters_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QLowEnergyConnectionParameters_COPY_CppToPython_QLowEnergyConnectionParameters(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QLowEnergyConnectionParameters *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QLowEnergyConnectionParameters_TypeF(), new ::QLowEnergyConnectionParameters(*source), true, true);
}

// Python to C++ copy conversion.
static void QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QLowEnergyConnectionParameters *>(cppOut) = *reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyConnectionParameters_TypeF()))
        return QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QLowEnergyConnectionParameters_SignatureStrings[] = {
    "1:PySide6.QtBluetooth.QLowEnergyConnectionParameters(self)",
    "0:PySide6.QtBluetooth.QLowEnergyConnectionParameters(self,other:PySide6.QtBluetooth.QLowEnergyConnectionParameters)",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.latency(self)->int",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.maximumInterval(self)->double",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.minimumInterval(self)->double",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.setIntervalRange(self,minimum:double,maximum:double)",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.setLatency(self,latency:int)",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.setSupervisionTimeout(self,timeout:int)",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.supervisionTimeout(self)->int",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.swap(self,other:PySide6.QtBluetooth.QLowEnergyConnectionParameters)",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.__copy__(self)->typing.Self",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.__ne__(self,b:PySide6.QtBluetooth.QLowEnergyConnectionParameters)->bool",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.__eq__(self,b:PySide6.QtBluetooth.QLowEnergyConnectionParameters)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QLowEnergyConnectionParameters_SignatureByteSize = 230;
static constexpr uint8_t QLowEnergyConnectionParameters_SignatureBytes[230] = {
    0x78, 0xda, 0xc5, 0x92, 0x31, 0x6f, 0xc2, 0x30, 0x10, 0x85, 0x77, 0x7e, 0x49, 0x23, 0x85, 0x08,
    0x96, 0x0e, 0x19, 0x18, 0x5a, 0x31, 0x20, 0x31, 0x40, 0xc3, 0x1e, 0x39, 0xe1, 0x08, 0x96, 0xec,
    0xbb, 0x10, 0x9f, 0xa1, 0xfe, 0xf7, 0xb5, 0x64, 0x47, 0xea, 0xd0, 0xa5, 0x27, 0x24, 0xc6, 0x27,
    0xfb, 0x7d, 0xef, 0xee, 0xe9, 0xd6, 0xf5, 0x21, 0x34, 0xfa, 0x0c, 0xef, 0xd5, 0x91, 0x3f, 0x8c,
    0x07, 0x26, 0xe2, 0x6b, 0x75, 0xdc, 0xd3, 0x63, 0x8b, 0x30, 0x0d, 0xe1, 0x93, 0x10, 0xa1, 0x67,
    0x4d, 0x78, 0x50, 0x93, 0xb2, 0xc0, 0x30, 0xb9, 0x37, 0x07, 0xe6, 0x52, 0x2c, 0x56, 0x52, 0x6b,
    0x19, 0xff, 0xc1, 0x24, 0x70, 0x17, 0x8b, 0xff, 0x7b, 0x2a, 0xa3, 0x18, 0xb0, 0x0f, 0x69, 0xe8,
    0xe5, 0x46, 0x23, 0x4b, 0x28, 0x56, 0x7d, 0x6b, 0xeb, 0xed, 0x0e, 0xa3, 0xba, 0x2b, 0x33, 0xd3,
    0xce, 0xe4, 0x3b, 0x03, 0x22, 0xa0, 0xc6, 0xe7, 0x02, 0x1d, 0xf0, 0x0c, 0xfb, 0x52, 0x38, 0x40,
    0xaa, 0x3a, 0xc7, 0xd4, 0x89, 0x5b, 0xe6, 0x35, 0xb2, 0x2c, 0x84, 0x39, 0xfb, 0x5f, 0x95, 0x96,
    0xb9, 0xdf, 0x3a, 0x16, 0x2b, 0xe5, 0x35, 0x7e, 0x8c, 0x73, 0x6b, 0x17, 0x1f, 0x4e, 0xda, 0x02,
    0x79, 0x4e, 0x68, 0x4e, 0x42, 0x8e, 0xfe, 0x9b, 0x2b, 0xbf, 0x02, 0xf7, 0x50, 0xe3, 0x0b, 0x4e,
    0xb8, 0x6d, 0x7b, 0x1a, 0x43, 0xdb, 0xce, 0xd3, 0x73, 0x18, 0x35, 0x0e, 0x55, 0x13, 0x95, 0x0c,
    0x87, 0x90, 0x61, 0x65, 0x27, 0xd9, 0x61, 0xb9, 0xe9, 0x88, 0x8c, 0x2c, 0x1a, 0x6e, 0xcf, 0x88,
    0xfe, 0x01, 0x6e, 0x1d, 0xc9, 0x4e
};
#endif

PyTypeObject *init_QLowEnergyConnectionParameters(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX].type;

    Shiboken::AutoDecRef Sbk_QLowEnergyConnectionParameters_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QLowEnergyConnectionParameters_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLowEnergyConnectionParameters",
        "QLowEnergyConnectionParameters",
        &Sbk_QLowEnergyConnectionParameters_spec,
        &Shiboken::callCppDestructor< ::QLowEnergyConnectionParameters >,
        Sbk_QLowEnergyConnectionParameters_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QLowEnergyConnectionParameters_TypeF(); // references _Sbk_QLowEnergyConnectionParameters_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QLowEnergyConnectionParameters_SignatureStrings);
#else
    InitSignatureBytes(pyType, QLowEnergyConnectionParameters_SignatureBytes, QLowEnergyConnectionParameters_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLowEnergyConnectionParameters_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_PTR,
        is_QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_PTR_Convertible,
        QLowEnergyConnectionParameters_PTR_CppToPython_QLowEnergyConnectionParameters,
        QLowEnergyConnectionParameters_COPY_CppToPython_QLowEnergyConnectionParameters);

    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyConnectionParameters");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyConnectionParameters*");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyConnectionParameters&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLowEnergyConnectionParameters).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_COPY,
        is_QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_COPY_Convertible);

    qRegisterMetaType< ::QLowEnergyConnectionParameters >("QLowEnergyConnectionParameters");

    return pyType;
}
