// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qlowenergycontroller_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtBluetooth/qbluetoothdeviceinfo.h>
#include <QtBluetooth/qbluetoothuuid.h>
#include <QtBluetooth/qlowenergyadvertisingdata.h>
#include <QtBluetooth/qlowenergyadvertisingparameters.h>
#include <QtBluetooth/qlowenergyconnectionparameters.h>
#include <QtBluetooth/qlowenergycontroller.h>
#include <QtBluetooth/qlowenergyservice.h>
#include <QtBluetooth/qlowenergyservicedata.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QLowEnergyControllerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QLowEnergyControllerWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QLowEnergyController", funcName);
        return;
    }
}

void QLowEnergyControllerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QLowEnergyController", funcName);
        return;
    }
}

void QLowEnergyControllerWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QLowEnergyController", funcName);
        return;
    }
}

void QLowEnergyControllerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QLowEnergyController", funcName);
        return;
    }
}

bool QLowEnergyControllerWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QLowEnergyController", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QLowEnergyController", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QLowEnergyControllerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QLowEnergyController", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QLowEnergyController", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QLowEnergyControllerWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QLowEnergyController", funcName);
        return;
    }
}

const QMetaObject *QLowEnergyControllerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QLowEnergyController::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QLowEnergyControllerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QLowEnergyController::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QLowEnergyControllerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QLowEnergyControllerWrapper *>(this));
    return QLowEnergyController::qt_metacast(_clname);
}

QLowEnergyControllerWrapper::~QLowEnergyControllerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QLowEnergyControllerFunc_addService(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addService", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);

    if (PyArg_ParseTuple(args, "|OO:addService", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLowEnergyController::addService(QLowEnergyServiceData,QObject*=)->QLowEnergyService*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addService(QLowEnergyServiceData,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // addService(QLowEnergyServiceData,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addService", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "addService", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "addService", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "addService", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QLowEnergyServiceData cppArg0_local;
        ::QLowEnergyServiceData *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addService(QLowEnergyServiceData,QObject*)
            QLowEnergyService * cppResult = cppSelf->addService(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyControllerFunc_connectToDevice(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // connectToDevice()
        cppSelf->connectToDevice();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyControllerFunc_createCentral(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "createCentral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:createCentral", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QLowEnergyController::createCentral(QBluetoothDeviceInfo,QObject*=)->QLowEnergyController*
    // 1: static QLowEnergyController::createCentral(QBluetoothDeviceInfo,QBluetoothAddress,QObject*=)->QLowEnergyController*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // createCentral(QBluetoothDeviceInfo,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // createCentral(QBluetoothDeviceInfo,QBluetoothAddress,QObject*)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))) {
                overloadId = 1; // createCentral(QBluetoothDeviceInfo,QBluetoothAddress,QObject*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // createCentral(QBluetoothDeviceInfo,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createCentral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // createCentral(const QBluetoothDeviceInfo &remoteDevice, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "createCentral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "createCentral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "createCentral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QBluetoothDeviceInfo cppArg0_local;
            ::QBluetoothDeviceInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // createCentral(QBluetoothDeviceInfo,QObject*)
                QLowEnergyController * cppResult = ::QLowEnergyController::createCentral(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), cppResult);
            }
            break;
        }
        case 1: // createCentral(const QBluetoothDeviceInfo &remoteDevice, const QBluetoothAddress &localDevice, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "createCentral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "createCentral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "createCentral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QBluetoothDeviceInfo cppArg0_local;
            ::QBluetoothDeviceInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QBluetoothAddress cppArg1_local;
            ::QBluetoothAddress *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // createCentral(QBluetoothDeviceInfo,QBluetoothAddress,QObject*)
                QLowEnergyController * cppResult = ::QLowEnergyController::createCentral(*cppArg0, *cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyControllerFunc_createPeripheral(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "createPeripheral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);

    if (PyArg_ParseTuple(args, "|OO:createPeripheral", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QLowEnergyController::createPeripheral(QObject*=)->QLowEnergyController*
    // 1: static QLowEnergyController::createPeripheral(QBluetoothAddress,QObject*=)->QLowEnergyController*
    if (numArgs == 0) {
        overloadId = 0; // createPeripheral(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // createPeripheral(QBluetoothAddress,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // createPeripheral(QBluetoothAddress,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // createPeripheral(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createPeripheral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // createPeripheral(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "createPeripheral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "createPeripheral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "createPeripheral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // createPeripheral(QObject*)
                QLowEnergyController * cppResult = ::QLowEnergyController::createPeripheral(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), cppResult);
            }
            break;
        }
        case 1: // createPeripheral(const QBluetoothAddress &localDevice, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "createPeripheral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "createPeripheral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "createPeripheral", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QBluetoothAddress cppArg0_local;
            ::QBluetoothAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // createPeripheral(QBluetoothAddress,QObject*)
                QLowEnergyController * cppResult = ::QLowEnergyController::createPeripheral(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyControllerFunc_createServiceObject(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "createServiceObject", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);

    if (PyArg_ParseTuple(args, "|OO:createServiceObject", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLowEnergyController::createServiceObject(QBluetoothUuid,QObject*=)->QLowEnergyService*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // createServiceObject(QBluetoothUuid,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // createServiceObject(QBluetoothUuid,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createServiceObject", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "createServiceObject", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "createServiceObject", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "createServiceObject", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QBluetoothUuid cppArg0_local;
        ::QBluetoothUuid *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createServiceObject(QBluetoothUuid,QObject*)
            QLowEnergyService * cppResult = cppSelf->createServiceObject(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyControllerFunc_disconnectFromDevice(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // disconnectFromDevice()
        cppSelf->disconnectFromDevice();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyControllerFunc_discoverServices(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // discoverServices()
        cppSelf->discoverServices();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyControllerFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QLowEnergyController::Error cppResult = const_cast<const ::QLowEnergyController *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_Error_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyControllerFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QLowEnergyController *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyControllerFunc_localAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localAddress()const
        QBluetoothAddress cppResult = const_cast<const ::QLowEnergyController *>(cppSelf)->localAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyControllerFunc_mtu(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mtu()const
        int cppResult = const_cast<const ::QLowEnergyController *>(cppSelf)->mtu();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyControllerFunc_readRssi(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readRssi()
        cppSelf->readRssi();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyControllerFunc_remoteAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // remoteAddress()const
        QBluetoothAddress cppResult = const_cast<const ::QLowEnergyController *>(cppSelf)->remoteAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyControllerFunc_remoteAddressType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // remoteAddressType()const
        QLowEnergyController::RemoteAddressType cppResult = const_cast<const ::QLowEnergyController *>(cppSelf)->remoteAddressType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_RemoteAddressType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyControllerFunc_remoteDeviceUuid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // remoteDeviceUuid()const
        QBluetoothUuid cppResult = const_cast<const ::QLowEnergyController *>(cppSelf)->remoteDeviceUuid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyControllerFunc_remoteName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // remoteName()const
        QString cppResult = const_cast<const ::QLowEnergyController *>(cppSelf)->remoteName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyControllerFunc_requestConnectionUpdate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyController::requestConnectionUpdate(QLowEnergyConnectionParameters)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), (pyArg)))) {
        overloadId = 0; // requestConnectionUpdate(QLowEnergyConnectionParameters)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "requestConnectionUpdate", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLowEnergyConnectionParameters cppArg0_local;
        ::QLowEnergyConnectionParameters *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // requestConnectionUpdate(QLowEnergyConnectionParameters)
            cppSelf->requestConnectionUpdate(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyControllerFunc_role(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // role()const
        QLowEnergyController::Role cppResult = const_cast<const ::QLowEnergyController *>(cppSelf)->role();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_Role_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyControllerFunc_services(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // services()const
        QList<QBluetoothUuid> cppResult = const_cast<const ::QLowEnergyController *>(cppSelf)->services();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothUuid_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyControllerFunc_setRemoteAddressType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyController::setRemoteAddressType(QLowEnergyController::RemoteAddressType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_RemoteAddressType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setRemoteAddressType(QLowEnergyController::RemoteAddressType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRemoteAddressType", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);

    // Call function/method
    {
        ::QLowEnergyController::RemoteAddressType cppArg0{QLowEnergyController::PublicAddress};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRemoteAddressType(QLowEnergyController::RemoteAddressType)
            cppSelf->setRemoteAddressType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyControllerFunc_startAdvertising(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "startAdvertising", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:startAdvertising", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLowEnergyController::startAdvertising(QLowEnergyAdvertisingParameters,QLowEnergyAdvertisingData,const QLowEnergyAdvertisingData&=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingParameters_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // startAdvertising(QLowEnergyAdvertisingParameters,QLowEnergyAdvertisingData,QLowEnergyAdvertisingData)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), (pyArgs[2])))) {
            overloadId = 0; // startAdvertising(QLowEnergyAdvertisingParameters,QLowEnergyAdvertisingData,QLowEnergyAdvertisingData)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "startAdvertising", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_scanResponseData = Shiboken::String::createStaticString("scanResponseData");
            if (PyDict_Contains(kwds, key_scanResponseData) != 0) {
                value = PyDict_GetItem(kwds, key_scanResponseData);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_scanResponseData);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "startAdvertising", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingData_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "startAdvertising", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_scanResponseData);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "startAdvertising", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QLowEnergyAdvertisingParameters cppArg0_local;
        ::QLowEnergyAdvertisingParameters *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QLowEnergyAdvertisingData cppArg1_local;
        ::QLowEnergyAdvertisingData *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QLowEnergyAdvertisingData cppArg2_local = QLowEnergyAdvertisingData();
        ::QLowEnergyAdvertisingData *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // startAdvertising(QLowEnergyAdvertisingParameters,QLowEnergyAdvertisingData,QLowEnergyAdvertisingData)
            cppSelf->startAdvertising(*cppArg0, *cppArg1, *cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyControllerFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QLowEnergyController::ControllerState cppResult = const_cast<const ::QLowEnergyController *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_ControllerState_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyControllerFunc_stopAdvertising(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stopAdvertising()
        cppSelf->stopAdvertising();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QLowEnergyController_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QLowEnergyController_EnumFlagInfo[] = {
    "ControllerState:Enum",
    "Error:Enum",
    "RemoteAddressType:Enum",
    "Role:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLowEnergyController_methods[] = {
    {"addService", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_addService), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"connectToDevice", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_connectToDevice), METH_NOARGS, nullptr},
    {"createCentral", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_createCentral), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"createPeripheral", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_createPeripheral), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"createServiceObject", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_createServiceObject), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"disconnectFromDevice", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_disconnectFromDevice), METH_NOARGS, nullptr},
    {"discoverServices", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_discoverServices), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_errorString), METH_NOARGS, nullptr},
    {"localAddress", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_localAddress), METH_NOARGS, nullptr},
    {"mtu", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_mtu), METH_NOARGS, nullptr},
    {"readRssi", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_readRssi), METH_NOARGS, nullptr},
    {"remoteAddress", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_remoteAddress), METH_NOARGS, nullptr},
    {"remoteAddressType", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_remoteAddressType), METH_NOARGS, nullptr},
    {"remoteDeviceUuid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_remoteDeviceUuid), METH_NOARGS, nullptr},
    {"remoteName", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_remoteName), METH_NOARGS, nullptr},
    {"requestConnectionUpdate", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_requestConnectionUpdate), METH_O, nullptr},
    {"role", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_role), METH_NOARGS, nullptr},
    {"services", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_services), METH_NOARGS, nullptr},
    {"setRemoteAddressType", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_setRemoteAddressType), METH_O, nullptr},
    {"startAdvertising", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_startAdvertising), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_state), METH_NOARGS, nullptr},
    {"stopAdvertising", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyControllerFunc_stopAdvertising), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QLowEnergyController_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QLowEnergyController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QLowEnergyControllerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QLowEnergyController_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLowEnergyController_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLowEnergyController_Type = nullptr;
static PyTypeObject *Sbk_QLowEnergyController_TypeF(void)
{
    return _Sbk_QLowEnergyController_Type;
}

static PyType_Slot Sbk_QLowEnergyController_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QLowEnergyController_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLowEnergyController_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLowEnergyController_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLowEnergyController_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLowEnergyController_spec = {
    "2:PySide6.QtBluetooth.QLowEnergyController",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLowEnergyController_slots
};

} //extern "C"

static void *Sbk_QLowEnergyController_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QLowEnergyController *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QLowEnergyController_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLowEnergyController::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLowEnergyController::Error *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLowEnergyController_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_Error_IDX])))
        return Enum_PythonToCpp_QLowEnergyController_Error;
    return {};
}

static PyObject *QLowEnergyController_Error_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLowEnergyController::Error>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLowEnergyController::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_Error_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QLowEnergyController_ControllerState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLowEnergyController::ControllerState>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLowEnergyController::ControllerState *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLowEnergyController_ControllerState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_ControllerState_IDX])))
        return Enum_PythonToCpp_QLowEnergyController_ControllerState;
    return {};
}

static PyObject *QLowEnergyController_ControllerState_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLowEnergyController::ControllerState>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLowEnergyController::ControllerState *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_ControllerState_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QLowEnergyController_RemoteAddressType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLowEnergyController::RemoteAddressType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLowEnergyController::RemoteAddressType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLowEnergyController_RemoteAddressType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_RemoteAddressType_IDX])))
        return Enum_PythonToCpp_QLowEnergyController_RemoteAddressType;
    return {};
}

static PyObject *QLowEnergyController_RemoteAddressType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLowEnergyController::RemoteAddressType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLowEnergyController::RemoteAddressType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_RemoteAddressType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QLowEnergyController_Role(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLowEnergyController::Role>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLowEnergyController::Role *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLowEnergyController_Role_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_Role_IDX])))
        return Enum_PythonToCpp_QLowEnergyController_Role;
    return {};
}

static PyObject *QLowEnergyController_Role_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLowEnergyController::Role>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLowEnergyController::Role *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_Role_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLowEnergyController_PythonToCpp_QLowEnergyController_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLowEnergyController_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLowEnergyController_PythonToCpp_QLowEnergyController_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyController_TypeF()))
        return QLowEnergyController_PythonToCpp_QLowEnergyController_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLowEnergyController_PTR_CppToPython_QLowEnergyController(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QLowEnergyController *>(const_cast<void *>(cppIn)), Sbk_QLowEnergyController_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QLowEnergyController_SignatureStrings[] = {
    "PySide6.QtBluetooth.QLowEnergyController.addService(self,service:PySide6.QtBluetooth.QLowEnergyServiceData,parent:PySide6.QtCore.QObject=nullptr)->PySide6.QtBluetooth.QLowEnergyService",
    "PySide6.QtBluetooth.QLowEnergyController.connectToDevice(self)",
    "1:PySide6.QtBluetooth.QLowEnergyController.createCentral(remoteDevice:PySide6.QtBluetooth.QBluetoothDeviceInfo,parent:PySide6.QtCore.QObject=nullptr)->PySide6.QtBluetooth.QLowEnergyController",
    "0:PySide6.QtBluetooth.QLowEnergyController.createCentral(remoteDevice:PySide6.QtBluetooth.QBluetoothDeviceInfo,localDevice:PySide6.QtBluetooth.QBluetoothAddress,parent:PySide6.QtCore.QObject=nullptr)->PySide6.QtBluetooth.QLowEnergyController",
    "1:PySide6.QtBluetooth.QLowEnergyController.createPeripheral(parent:PySide6.QtCore.QObject=nullptr)->PySide6.QtBluetooth.QLowEnergyController",
    "0:PySide6.QtBluetooth.QLowEnergyController.createPeripheral(localDevice:PySide6.QtBluetooth.QBluetoothAddress,parent:PySide6.QtCore.QObject=nullptr)->PySide6.QtBluetooth.QLowEnergyController",
    "PySide6.QtBluetooth.QLowEnergyController.createServiceObject(self,service:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid],parent:PySide6.QtCore.QObject=nullptr)->PySide6.QtBluetooth.QLowEnergyService",
    "PySide6.QtBluetooth.QLowEnergyController.disconnectFromDevice(self)",
    "PySide6.QtBluetooth.QLowEnergyController.discoverServices(self)",
    "PySide6.QtBluetooth.QLowEnergyController.error(self)->PySide6.QtBluetooth.QLowEnergyController.Error",
    "PySide6.QtBluetooth.QLowEnergyController.errorString(self)->QString",
    "PySide6.QtBluetooth.QLowEnergyController.localAddress(self)->PySide6.QtBluetooth.QBluetoothAddress",
    "PySide6.QtBluetooth.QLowEnergyController.mtu(self)->int",
    "PySide6.QtBluetooth.QLowEnergyController.readRssi(self)",
    "PySide6.QtBluetooth.QLowEnergyController.remoteAddress(self)->PySide6.QtBluetooth.QBluetoothAddress",
    "PySide6.QtBluetooth.QLowEnergyController.remoteAddressType(self)->PySide6.QtBluetooth.QLowEnergyController.RemoteAddressType",
    "PySide6.QtBluetooth.QLowEnergyController.remoteDeviceUuid(self)->PySide6.QtBluetooth.QBluetoothUuid",
    "PySide6.QtBluetooth.QLowEnergyController.remoteName(self)->QString",
    "PySide6.QtBluetooth.QLowEnergyController.requestConnectionUpdate(self,parameters:PySide6.QtBluetooth.QLowEnergyConnectionParameters)",
    "PySide6.QtBluetooth.QLowEnergyController.role(self)->PySide6.QtBluetooth.QLowEnergyController.Role",
    "PySide6.QtBluetooth.QLowEnergyController.services(self)->QList[PySide6.QtBluetooth.QBluetoothUuid]",
    "PySide6.QtBluetooth.QLowEnergyController.setRemoteAddressType(self,type:PySide6.QtBluetooth.QLowEnergyController.RemoteAddressType)",
    "PySide6.QtBluetooth.QLowEnergyController.startAdvertising(self,parameters:PySide6.QtBluetooth.QLowEnergyAdvertisingParameters,advertisingData:PySide6.QtBluetooth.QLowEnergyAdvertisingData,scanResponseData:PySide6.QtBluetooth.QLowEnergyAdvertisingData=QLowEnergyAdvertisingData())",
    "PySide6.QtBluetooth.QLowEnergyController.state(self)->PySide6.QtBluetooth.QLowEnergyController.ControllerState",
    "PySide6.QtBluetooth.QLowEnergyController.stopAdvertising(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QLowEnergyController_SignatureByteSize = 518;
static constexpr uint8_t QLowEnergyController_SignatureBytes[518] = {
    0x78, 0xda, 0xcd, 0x56, 0xcb, 0x6e, 0xdb, 0x30, 0x10, 0xbc, 0xfb, 0x2b, 0x72, 0xb4, 0x01, 0x55,
    0x48, 0x2f, 0x3d, 0x18, 0x48, 0x81, 0x54, 0x4e, 0x81, 0x02, 0x41, 0x23, 0xdb, 0xf1, 0xa9, 0xc8,
    0x81, 0x11, 0x37, 0x31, 0x0b, 0x9a, 0xab, 0xee, 0xae, 0x52, 0xf8, 0xef, 0x4b, 0x99, 0xf2, 0x13,
    0x89, 0x43, 0x1a, 0x69, 0xd3, 0x9b, 0x5e, 0x33, 0xb3, 0xcf, 0xa1, 0xca, 0xe5, 0xd4, 0x68, 0xf8,
    0x94, 0x8f, 0xe5, 0x8b, 0x6d, 0x40, 0x10, 0x65, 0x9e, 0x8f, 0xaf, 0xf1, 0xf7, 0x95, 0x03, 0x7a,
    0x5c, 0x16, 0xe8, 0x84, 0xd0, 0x5a, 0xa0, 0x5c, 0x69, 0x3d, 0x05, 0x7a, 0x32, 0x15, 0xf4, 0x19,
    0xec, 0x43, 0xc6, 0xe1, 0x66, 0x58, 0x1e, 0x25, 0xe8, 0x20, 0x23, 0x25, 0x2a, 0xab, 0x15, 0x81,
    0x93, 0x1d, 0x40, 0x81, 0x04, 0xf9, 0xf8, 0xe6, 0xfe, 0x27, 0x54, 0x72, 0xe1, 0x1a, 0x6b, 0x6b,
    0xa1, 0xc1, 0x87, 0xcf, 0x51, 0x8c, 0xbd, 0x32, 0x36, 0xf0, 0x0a, 0x9d, 0xf3, 0x02, 0xb7, 0x38,
    0x82, 0x4d, 0xf4, 0x83, 0xde, 0xc7, 0x61, 0x3c, 0x01, 0x81, 0x12, 0x28, 0x7c, 0xec, 0xa4, 0x6c,
    0x9f, 0x60, 0x81, 0x02, 0x81, 0xeb, 0x79, 0x8e, 0xcd, 0x65, 0xf8, 0xe8, 0x9b, 0x7b, 0xc0, 0x37,
    0xca, 0x7d, 0x1b, 0x54, 0xef, 0xfc, 0xdf, 0xc6, 0x6f, 0xb1, 0x52, 0x36, 0x0a, 0x74, 0xa9, 0x35,
    0x01, 0xf3, 0xdb, 0x67, 0x9c, 0xdc, 0xb1, 0x12, 0xc8, 0xd4, 0x73, 0x68, 0x93, 0x7e, 0xff, 0xf2,
    0xef, 0x04, 0xf3, 0x1f, 0xd4, 0x32, 0x31, 0xf8, 0x6e, 0xe7, 0x82, 0xde, 0xfe, 0xfa, 0xcb, 0xb2,
    0x36, 0xee, 0x31, 0x9f, 0x39, 0x83, 0xee, 0xc7, 0xf1, 0x6c, 0x66, 0x8d, 0xd1, 0xd9, 0xd9, 0xeb,
    0xdf, 0xe4, 0xc5, 0x5c, 0x91, 0xaa, 0xc4, 0x57, 0x8c, 0xc5, 0x54, 0xb7, 0xcb, 0x1a, 0xa2, 0x60,
    0x23, 0xe0, 0xca, 0x17, 0x59, 0x90, 0xa2, 0x21, 0x25, 0xa1, 0x60, 0x85, 0x36, 0x3a, 0xb4, 0xae,
    0x12, 0x85, 0x55, 0xcc, 0x87, 0xa0, 0xd0, 0x94, 0xf6, 0xe9, 0xdd, 0x7b, 0x79, 0x9d, 0x36, 0xdc,
    0xd9, 0xdd, 0x57, 0xc2, 0xc5, 0x9e, 0xe1, 0xa5, 0x71, 0x3c, 0x01, 0x75, 0xe2, 0x9c, 0x8a, 0x07,
    0x22, 0xa4, 0x00, 0x8a, 0x9f, 0xc8, 0xfc, 0xaa, 0x45, 0x25, 0x8a, 0x4c, 0x85, 0xfc, 0xec, 0xad,
    0xa5, 0xc6, 0xe1, 0x36, 0x9e, 0x63, 0xb5, 0x87, 0xdd, 0x8a, 0x1d, 0x8d, 0xf7, 0x70, 0x1f, 0xe3,
    0x25, 0x16, 0xd2, 0xac, 0x99, 0x8d, 0x93, 0x78, 0x9c, 0xdf, 0x3a, 0x3d, 0x61, 0x36, 0xa9, 0xb5,
    0x0f, 0xe6, 0xfe, 0x77, 0x73, 0xda, 0xd3, 0x68, 0x37, 0x2d, 0xb9, 0xd7, 0x93, 0x43, 0x86, 0x54,
    0xf1, 0x30, 0xd8, 0xed, 0xa6, 0xc5, 0xe5, 0xd8, 0x7e, 0x99, 0xaa, 0xf1, 0x5d, 0x2d, 0xe0, 0xe4,
    0xd1, 0x22, 0xf8, 0xd5, 0x00, 0xfb, 0xa5, 0x5f, 0xed, 0xa2, 0xb7, 0xc6, 0x59, 0xad, 0xbd, 0x8f,
    0x06, 0xeb, 0xf4, 0xde, 0xe0, 0xb9, 0xbd, 0xbd, 0xf1, 0xeb, 0x87, 0x48, 0x07, 0x2f, 0x37, 0x90,
    0x94, 0x61, 0x40, 0x7b, 0x42, 0x6f, 0x3c, 0x28, 0x5e, 0x82, 0xf7, 0x3c, 0xc2, 0x17, 0xea, 0xda,
    0x5b, 0x76, 0xc4, 0x31, 0x70, 0x97, 0x22, 0x21, 0x93, 0x67, 0x27, 0x2e, 0xf3, 0x47, 0x0f, 0x0c,
    0x4f, 0x1f, 0xba, 0x84, 0x4a, 0xb2, 0x28, 0x92, 0x4b, 0xed, 0x4d, 0x51, 0x0c, 0xaf, 0x2d, 0x27,
    0xbe, 0x8f, 0x3b, 0xc8, 0x6d, 0x23, 0x33, 0xb5, 0x7d, 0xda, 0xfe, 0x1e, 0xc7, 0x73, 0xac, 0x7e,
    0xa6, 0xb9, 0x52, 0x6e, 0x02, 0x5c, 0xa3, 0x63, 0x48, 0x87, 0x5f, 0xbc, 0xf8, 0xa6, 0x3f, 0x48,
    0xab, 0x8b, 0xa4, 0x8f, 0xd8, 0xf6, 0x72, 0xda, 0xe2, 0x53, 0xe4, 0xb0, 0x3e, 0xec, 0xc2, 0xa0,
    0xf7, 0x07, 0x97, 0x44, 0xcc, 0x3a
};
#endif

PyTypeObject *init_QLowEnergyController(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX].type;

    Shiboken::AutoDecRef Sbk_QLowEnergyController_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QLowEnergyController_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLowEnergyController",
        "QLowEnergyController*",
        &Sbk_QLowEnergyController_spec,
        &Shiboken::callCppDestructor< QLowEnergyController >,
        Sbk_QLowEnergyController_Type_bases.object(),
        0);
    auto *pyType = Sbk_QLowEnergyController_TypeF(); // references _Sbk_QLowEnergyController_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QLowEnergyController_SignatureStrings);
#else
    InitSignatureBytes(pyType, QLowEnergyController_SignatureBytes, QLowEnergyController_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLowEnergyController_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLowEnergyController_PythonToCpp_QLowEnergyController_PTR,
        is_QLowEnergyController_PythonToCpp_QLowEnergyController_PTR_Convertible,
        QLowEnergyController_PTR_CppToPython_QLowEnergyController);

    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyController");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyController*");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyController&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLowEnergyController).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QLowEnergyControllerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QLowEnergyController_TypeF(), &Sbk_QLowEnergyController_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QLowEnergyController_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "UnknownError",
        "UnknownRemoteDeviceError",
        "NetworkError",
        "InvalidBluetoothAdapterError",
        "ConnectionError",
        "AdvertisingError",
        "RemoteHostClosedError",
        "AuthorizationError",
        "MissingPermissionsError",
        "RssiReadError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QLowEnergyController::Error::NoError),                      //  0x00  0
        uint8_t(QLowEnergyController::Error::UnknownError),                 //  0x01  1
        uint8_t(QLowEnergyController::Error::UnknownRemoteDeviceError),     //  0x02  2
        uint8_t(QLowEnergyController::Error::NetworkError),                 //  0x03  3
        uint8_t(QLowEnergyController::Error::InvalidBluetoothAdapterError), //  0x04  4
        uint8_t(QLowEnergyController::Error::ConnectionError),              //  0x05  5
        uint8_t(QLowEnergyController::Error::AdvertisingError),             //  0x06  6
        uint8_t(QLowEnergyController::Error::RemoteHostClosedError),        //  0x07  7
        uint8_t(QLowEnergyController::Error::AuthorizationError),           //  0x08  8
        uint8_t(QLowEnergyController::Error::MissingPermissionsError),      //  0x09  9
        uint8_t(QLowEnergyController::Error::RssiReadError)                 //  0x0a  10
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLowEnergyController_TypeF(),
        "2:PySide6.QtBluetooth.QLowEnergyController.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_Error_IDX].type = EType;
    // Register converter for enum 'QLowEnergyController::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLowEnergyController_Error_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLowEnergyController_Error,
            is_Enum_PythonToCpp_QLowEnergyController_Error_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLowEnergyController::Error");
        Shiboken::Conversions::registerConverterAlias(converter, "Error");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Error' enum.

    // Initialization of enum 'ControllerState'.
    const char *ControllerState_Initializer[] = {
        "UnconnectedState",
        "ConnectingState",
        "ConnectedState",
        "DiscoveringState",
        "DiscoveredState",
        "ClosingState",
        "AdvertisingState",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ControllerState_InitializerValues[] = {
        uint8_t(QLowEnergyController::ControllerState::UnconnectedState), //  0x00  0
        uint8_t(QLowEnergyController::ControllerState::ConnectingState),  //  0x01  1
        uint8_t(QLowEnergyController::ControllerState::ConnectedState),   //  0x02  2
        uint8_t(QLowEnergyController::ControllerState::DiscoveringState), //  0x03  3
        uint8_t(QLowEnergyController::ControllerState::DiscoveredState),  //  0x04  4
        uint8_t(QLowEnergyController::ControllerState::ClosingState),     //  0x05  5
        uint8_t(QLowEnergyController::ControllerState::AdvertisingState)  //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLowEnergyController_TypeF(),
        "2:PySide6.QtBluetooth.QLowEnergyController.ControllerState",
        ControllerState_Initializer, ControllerState_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_ControllerState_IDX].type = EType;
    // Register converter for enum 'QLowEnergyController::ControllerState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLowEnergyController_ControllerState_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLowEnergyController_ControllerState,
            is_Enum_PythonToCpp_QLowEnergyController_ControllerState_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLowEnergyController::ControllerState");
        Shiboken::Conversions::registerConverterAlias(converter, "ControllerState");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ControllerState' enum.

    // Initialization of enum 'RemoteAddressType'.
    const char *RemoteAddressType_Initializer[] = {
        "PublicAddress",
        "RandomAddress",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RemoteAddressType_InitializerValues[] = {
        uint8_t(QLowEnergyController::RemoteAddressType::PublicAddress), //  0x00  0
        uint8_t(QLowEnergyController::RemoteAddressType::RandomAddress)  //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLowEnergyController_TypeF(),
        "2:PySide6.QtBluetooth.QLowEnergyController.RemoteAddressType",
        RemoteAddressType_Initializer, RemoteAddressType_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_RemoteAddressType_IDX].type = EType;
    // Register converter for enum 'QLowEnergyController::RemoteAddressType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLowEnergyController_RemoteAddressType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLowEnergyController_RemoteAddressType,
            is_Enum_PythonToCpp_QLowEnergyController_RemoteAddressType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLowEnergyController::RemoteAddressType");
        Shiboken::Conversions::registerConverterAlias(converter, "RemoteAddressType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'RemoteAddressType' enum.

    // Initialization of enum 'Role'.
    const char *Role_Initializer[] = {
        "CentralRole",
        "PeripheralRole",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Role_InitializerValues[] = {
        uint8_t(QLowEnergyController::Role::CentralRole),   //  0x00  0
        uint8_t(QLowEnergyController::Role::PeripheralRole) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLowEnergyController_TypeF(),
        "2:PySide6.QtBluetooth.QLowEnergyController.Role",
        Role_Initializer, Role_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_Role_IDX].type = EType;
    // Register converter for enum 'QLowEnergyController::Role'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLowEnergyController_Role_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLowEnergyController_Role,
            is_Enum_PythonToCpp_QLowEnergyController_Role_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLowEnergyController::Role");
        Shiboken::Conversions::registerConverterAlias(converter, "Role");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Role' enum.

    PySide::Signal::registerSignals(pyType, &::QLowEnergyController::staticMetaObject);
    qRegisterMetaType< ::QLowEnergyController::Error >("QLowEnergyController::Error");
    qRegisterMetaType< ::QLowEnergyController::ControllerState >("QLowEnergyController::ControllerState");
    qRegisterMetaType< ::QLowEnergyController::RemoteAddressType >("QLowEnergyController::RemoteAddressType");
    qRegisterMetaType< ::QLowEnergyController::Role >("QLowEnergyController::Role");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QLowEnergyController::staticMetaObject, sizeof(QLowEnergyControllerWrapper));

    return pyType;
}
