// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qlowenergydescriptor_wrapper.h"

// Argument includes
#include <QString>
#include <QtBluetooth/qbluetoothuuid.h>
#include <QtBluetooth/qlowenergydescriptor.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLowEnergyDescriptor_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLowEnergyDescriptor >()))
        return -1;

    ::QLowEnergyDescriptor *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QLowEnergyDescriptor", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLowEnergyDescriptor::QLowEnergyDescriptor()
    // 1: QLowEnergyDescriptor::QLowEnergyDescriptor(QLowEnergyDescriptor)
    if (numArgs == 0) {
        overloadId = 0; // QLowEnergyDescriptor()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QLowEnergyDescriptor(QLowEnergyDescriptor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QLowEnergyDescriptor()
        {

            // QLowEnergyDescriptor()
            cptr = new ::QLowEnergyDescriptor();
            break;
        }
        case 1: // QLowEnergyDescriptor(const QLowEnergyDescriptor &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QLowEnergyDescriptor cppArg0_local;
            ::QLowEnergyDescriptor *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLowEnergyDescriptor(QLowEnergyDescriptor)
                cptr = new ::QLowEnergyDescriptor(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QLowEnergyDescriptor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QLowEnergyDescriptorFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QLowEnergyDescriptor *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyDescriptorFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QLowEnergyDescriptor *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyDescriptorFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QBluetoothUuid::DescriptorType cppResult = const_cast<const ::QLowEnergyDescriptor *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_DescriptorType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyDescriptorFunc_uuid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // uuid()const
        QBluetoothUuid cppResult = const_cast<const ::QLowEnergyDescriptor *>(cppSelf)->uuid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyDescriptorFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // value()const
        QByteArray cppResult = const_cast<const ::QLowEnergyDescriptor *>(cppSelf)->value();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyDescriptor__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QLowEnergyDescriptor_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLowEnergyDescriptor_methods[] = {
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorFunc_isValid), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorFunc_name), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorFunc_type), METH_NOARGS, nullptr},
    {"uuid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorFunc_uuid), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorFunc_value), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptor__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QLowEnergyDescriptor_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), (pyArg)))) {
                // operator!=(const QLowEnergyDescriptor &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyDescriptor cppArg0_local;
                ::QLowEnergyDescriptor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), (pyArg)))) {
                // operator==(const QLowEnergyDescriptor &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyDescriptor cppArg0_local;
                ::QLowEnergyDescriptor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QLowEnergyDescriptor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLowEnergyDescriptor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLowEnergyDescriptor_Type = nullptr;
static PyTypeObject *Sbk_QLowEnergyDescriptor_TypeF(void)
{
    return _Sbk_QLowEnergyDescriptor_Type;
}

static PyType_Slot Sbk_QLowEnergyDescriptor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLowEnergyDescriptor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLowEnergyDescriptor_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QLowEnergyDescriptor_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLowEnergyDescriptor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLowEnergyDescriptor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLowEnergyDescriptor_spec = {
    "2:PySide6.QtBluetooth.QLowEnergyDescriptor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLowEnergyDescriptor_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLowEnergyDescriptor_PythonToCpp_QLowEnergyDescriptor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLowEnergyDescriptor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLowEnergyDescriptor_PythonToCpp_QLowEnergyDescriptor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyDescriptor_TypeF()))
        return QLowEnergyDescriptor_PythonToCpp_QLowEnergyDescriptor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLowEnergyDescriptor_PTR_CppToPython_QLowEnergyDescriptor(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QLowEnergyDescriptor_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QLowEnergyDescriptor_COPY_CppToPython_QLowEnergyDescriptor(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QLowEnergyDescriptor *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QLowEnergyDescriptor_TypeF(), new ::QLowEnergyDescriptor(*source), true, true);
}

// Python to C++ copy conversion.
static void QLowEnergyDescriptor_PythonToCpp_QLowEnergyDescriptor_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QLowEnergyDescriptor *>(cppOut) = *reinterpret_cast< ::QLowEnergyDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QLowEnergyDescriptor_PythonToCpp_QLowEnergyDescriptor_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyDescriptor_TypeF()))
        return QLowEnergyDescriptor_PythonToCpp_QLowEnergyDescriptor_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QLowEnergyDescriptor_SignatureStrings[] = {
    "1:PySide6.QtBluetooth.QLowEnergyDescriptor(self)",
    "0:PySide6.QtBluetooth.QLowEnergyDescriptor(self,other:PySide6.QtBluetooth.QLowEnergyDescriptor)",
    "PySide6.QtBluetooth.QLowEnergyDescriptor.isValid(self)->bool",
    "PySide6.QtBluetooth.QLowEnergyDescriptor.name(self)->QString",
    "PySide6.QtBluetooth.QLowEnergyDescriptor.type(self)->PySide6.QtBluetooth.QBluetoothUuid.DescriptorType",
    "PySide6.QtBluetooth.QLowEnergyDescriptor.uuid(self)->PySide6.QtBluetooth.QBluetoothUuid",
    "PySide6.QtBluetooth.QLowEnergyDescriptor.value(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtBluetooth.QLowEnergyDescriptor.__copy__(self)->typing.Self",
    "PySide6.QtBluetooth.QLowEnergyDescriptor.__ne__(self,b:PySide6.QtBluetooth.QLowEnergyDescriptor)->bool",
    "PySide6.QtBluetooth.QLowEnergyDescriptor.__eq__(self,b:PySide6.QtBluetooth.QLowEnergyDescriptor)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QLowEnergyDescriptor_SignatureByteSize = 192;
static constexpr uint8_t QLowEnergyDescriptor_SignatureBytes[192] = {
    0x78, 0xda, 0x9d, 0x92, 0x3d, 0x0f, 0xc2, 0x20, 0x10, 0x86, 0xf7, 0xfe, 0x12, 0x9b, 0x54, 0xa2,
    0x8b, 0x83, 0x83, 0x89, 0x5f, 0x9b, 0x83, 0x4d, 0xd5, 0x95, 0xd0, 0xf6, 0xac, 0x24, 0xc8, 0xd5,
    0x2b, 0x68, 0xf8, 0xf7, 0x92, 0x68, 0xdb, 0x41, 0x13, 0xa9, 0x1b, 0xe4, 0x78, 0x9e, 0xf7, 0x38,
    0x98, 0xce, 0xf7, 0x2e, 0x93, 0x25, 0xcc, 0x58, 0x6a, 0x56, 0xca, 0x82, 0x41, 0x34, 0x17, 0x96,
    0xee, 0xf0, 0xb1, 0xd5, 0x40, 0x95, 0xdb, 0x40, 0x53, 0x90, 0xac, 0x0d, 0xd2, 0xa8, 0x01, 0x75,
    0x8e, 0xa3, 0xc9, 0x30, 0x20, 0xf1, 0x55, 0xa0, 0x60, 0x26, 0x8e, 0x42, 0x4f, 0x32, 0xd9, 0x9c,
    0x84, 0x92, 0xe5, 0xab, 0xad, 0xf1, 0x22, 0x47, 0x54, 0xe1, 0xb0, 0x16, 0x57, 0x68, 0xc9, 0x34,
    0x33, 0x24, 0x75, 0x15, 0x0e, 0x1b, 0x57, 0x77, 0xf0, 0x57, 0xa8, 0x5b, 0x1e, 0xad, 0x2c, 0x59,
    0x4f, 0x1e, 0x3c, 0x18, 0x1e, 0x63, 0x6d, 0x7f, 0xbb, 0xdf, 0x31, 0xe1, 0xde, 0xbb, 0xf0, 0xf5,
    0x4f, 0xf1, 0x1a, 0x09, 0xbc, 0xd3, 0x19, 0x58, 0x12, 0x09, 0x17, 0xee, 0xe3, 0xbc, 0xc0, 0xda,
    0x71, 0xde, 0x2a, 0xfd, 0x78, 0xfc, 0x38, 0x59, 0xe6, 0x77, 0x43, 0x24, 0x1a, 0xde, 0x8a, 0x24,
    0x0f, 0xff, 0x2e, 0x43, 0xdf, 0x9d, 0x73, 0xb8, 0xfd, 0x1f, 0xf3, 0x04, 0xd0, 0x40, 0x2d, 0x1f
};
#endif

PyTypeObject *init_QLowEnergyDescriptor(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX].type;

    Shiboken::AutoDecRef Sbk_QLowEnergyDescriptor_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QLowEnergyDescriptor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLowEnergyDescriptor",
        "QLowEnergyDescriptor",
        &Sbk_QLowEnergyDescriptor_spec,
        &Shiboken::callCppDestructor< ::QLowEnergyDescriptor >,
        Sbk_QLowEnergyDescriptor_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QLowEnergyDescriptor_TypeF(); // references _Sbk_QLowEnergyDescriptor_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QLowEnergyDescriptor_SignatureStrings);
#else
    InitSignatureBytes(pyType, QLowEnergyDescriptor_SignatureBytes, QLowEnergyDescriptor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLowEnergyDescriptor_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLowEnergyDescriptor_PythonToCpp_QLowEnergyDescriptor_PTR,
        is_QLowEnergyDescriptor_PythonToCpp_QLowEnergyDescriptor_PTR_Convertible,
        QLowEnergyDescriptor_PTR_CppToPython_QLowEnergyDescriptor,
        QLowEnergyDescriptor_COPY_CppToPython_QLowEnergyDescriptor);

    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyDescriptor");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyDescriptor*");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyDescriptor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLowEnergyDescriptor).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLowEnergyDescriptor_PythonToCpp_QLowEnergyDescriptor_COPY,
        is_QLowEnergyDescriptor_PythonToCpp_QLowEnergyDescriptor_COPY_Convertible);

    qRegisterMetaType< ::QLowEnergyDescriptor >("QLowEnergyDescriptor");

    return pyType;
}
