// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qlowenergydescriptordata_wrapper.h"

// Argument includes
#include <QtBluetooth/qbluetoothuuid.h>
#include <QtBluetooth/qlowenergydescriptordata.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLowEnergyDescriptorData_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLowEnergyDescriptorData >()))
        return -1;

    ::QLowEnergyDescriptorData *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QLowEnergyDescriptorData", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLowEnergyDescriptorData::QLowEnergyDescriptorData()
    // 1: QLowEnergyDescriptorData::QLowEnergyDescriptorData(QBluetoothUuid,QByteArray)
    // 2: QLowEnergyDescriptorData::QLowEnergyDescriptorData(QLowEnergyDescriptorData)
    if (numArgs == 0) {
        overloadId = 0; // QLowEnergyDescriptorData()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QLowEnergyDescriptorData(QLowEnergyDescriptorData)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 1; // QLowEnergyDescriptorData(QBluetoothUuid,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QLowEnergyDescriptorData()
        {

            // QLowEnergyDescriptorData()
            cptr = new ::QLowEnergyDescriptorData();
            break;
        }
        case 1: // QLowEnergyDescriptorData(const QBluetoothUuid &uuid, const QByteArray &value)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBluetoothUuid cppArg0_local;
            ::QBluetoothUuid *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLowEnergyDescriptorData(QBluetoothUuid,QByteArray)
                cptr = new ::QLowEnergyDescriptorData(*cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // QLowEnergyDescriptorData(const QLowEnergyDescriptorData &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QLowEnergyDescriptorData cppArg0_local;
            ::QLowEnergyDescriptorData *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLowEnergyDescriptorData(QLowEnergyDescriptorData)
                cptr = new ::QLowEnergyDescriptorData(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QLowEnergyDescriptorData >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QLowEnergyDescriptorDataFunc_isReadable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptorData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isReadable()const
        bool cppResult = const_cast<const ::QLowEnergyDescriptorData *>(cppSelf)->isReadable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyDescriptorDataFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptorData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QLowEnergyDescriptorData *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyDescriptorDataFunc_isWritable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptorData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isWritable()const
        bool cppResult = const_cast<const ::QLowEnergyDescriptorData *>(cppSelf)->isWritable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyDescriptorDataFunc_readConstraints(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptorData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readConstraints()const
        QFlags<QBluetooth::AttAccessConstraint> cppResult = const_cast<const ::QLowEnergyDescriptorData *>(cppSelf)->readConstraints();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetooth_AttAccessConstraint_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyDescriptorDataFunc_setReadPermissions(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptorData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setReadPermissions", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setReadPermissions", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLowEnergyDescriptorData::setReadPermissions(bool,QFlags<QBluetooth::AttAccessConstraint>=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setReadPermissions(bool,QFlags<QBluetooth::AttAccessConstraint>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetooth_AttAccessConstraint_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // setReadPermissions(bool,QFlags<QBluetooth::AttAccessConstraint>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setReadPermissions", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_constraints = Shiboken::String::createStaticString("constraints");
            if (PyDict_Contains(kwds, key_constraints) != 0) {
                value = PyDict_GetItem(kwds, key_constraints);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_constraints);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setReadPermissions", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetooth_AttAccessConstraint_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setReadPermissions", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_constraints);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setReadPermissions", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);
            }
        }
        bool cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QBluetooth::AttAccessConstraint> cppArg1 = QBluetooth::AttAccessConstraints();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReadPermissions(bool,QFlags<QBluetooth::AttAccessConstraint>)
            cppSelf->setReadPermissions(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyDescriptorDataFunc_setUuid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptorData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyDescriptorData::setUuid(QBluetoothUuid)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArg)))) {
        overloadId = 0; // setUuid(QBluetoothUuid)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUuid", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBluetoothUuid cppArg0_local;
        ::QBluetoothUuid *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUuid(QBluetoothUuid)
            cppSelf->setUuid(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyDescriptorDataFunc_setValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptorData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyDescriptorData::setValue(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setValue(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setValue", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setValue(QByteArray)
            cppSelf->setValue(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyDescriptorDataFunc_setWritePermissions(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptorData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setWritePermissions", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setWritePermissions", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLowEnergyDescriptorData::setWritePermissions(bool,QFlags<QBluetooth::AttAccessConstraint>=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setWritePermissions(bool,QFlags<QBluetooth::AttAccessConstraint>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetooth_AttAccessConstraint_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // setWritePermissions(bool,QFlags<QBluetooth::AttAccessConstraint>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setWritePermissions", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_constraints = Shiboken::String::createStaticString("constraints");
            if (PyDict_Contains(kwds, key_constraints) != 0) {
                value = PyDict_GetItem(kwds, key_constraints);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_constraints);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setWritePermissions", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetooth_AttAccessConstraint_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setWritePermissions", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_constraints);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setWritePermissions", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);
            }
        }
        bool cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QBluetooth::AttAccessConstraint> cppArg1 = QBluetooth::AttAccessConstraints();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWritePermissions(bool,QFlags<QBluetooth::AttAccessConstraint>)
            cppSelf->setWritePermissions(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyDescriptorDataFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptorData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyDescriptorData::swap(QLowEnergyDescriptorData&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QLowEnergyDescriptorData&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLowEnergyDescriptorData cppArg0_local;
        ::QLowEnergyDescriptorData *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QLowEnergyDescriptorData&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyDescriptorDataFunc_uuid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptorData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // uuid()const
        QBluetoothUuid cppResult = const_cast<const ::QLowEnergyDescriptorData *>(cppSelf)->uuid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyDescriptorDataFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptorData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // value()const
        QByteArray cppResult = const_cast<const ::QLowEnergyDescriptorData *>(cppSelf)->value();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyDescriptorDataFunc_writeConstraints(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyDescriptorData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // writeConstraints()const
        QFlags<QBluetooth::AttAccessConstraint> cppResult = const_cast<const ::QLowEnergyDescriptorData *>(cppSelf)->writeConstraints();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetooth_AttAccessConstraint_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyDescriptorData__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyDescriptorData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QLowEnergyDescriptorData_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLowEnergyDescriptorData_methods[] = {
    {"isReadable", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorDataFunc_isReadable), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorDataFunc_isValid), METH_NOARGS, nullptr},
    {"isWritable", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorDataFunc_isWritable), METH_NOARGS, nullptr},
    {"readConstraints", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorDataFunc_readConstraints), METH_NOARGS, nullptr},
    {"setReadPermissions", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorDataFunc_setReadPermissions), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setUuid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorDataFunc_setUuid), METH_O, nullptr},
    {"setValue", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorDataFunc_setValue), METH_O, nullptr},
    {"setWritePermissions", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorDataFunc_setWritePermissions), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorDataFunc_swap), METH_O, nullptr},
    {"uuid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorDataFunc_uuid), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorDataFunc_value), METH_NOARGS, nullptr},
    {"writeConstraints", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorDataFunc_writeConstraints), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyDescriptorData__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QLowEnergyDescriptorData_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyDescriptorData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), (pyArg)))) {
                // operator!=(const QLowEnergyDescriptorData &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyDescriptorData cppArg0_local;
                ::QLowEnergyDescriptorData *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), (pyArg)))) {
                // operator==(const QLowEnergyDescriptorData &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyDescriptorData cppArg0_local;
                ::QLowEnergyDescriptorData *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QLowEnergyDescriptorData_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLowEnergyDescriptorData_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLowEnergyDescriptorData_Type = nullptr;
static PyTypeObject *Sbk_QLowEnergyDescriptorData_TypeF(void)
{
    return _Sbk_QLowEnergyDescriptorData_Type;
}

static PyType_Slot Sbk_QLowEnergyDescriptorData_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLowEnergyDescriptorData_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLowEnergyDescriptorData_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QLowEnergyDescriptorData_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLowEnergyDescriptorData_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLowEnergyDescriptorData_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLowEnergyDescriptorData_spec = {
    "2:PySide6.QtBluetooth.QLowEnergyDescriptorData",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLowEnergyDescriptorData_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLowEnergyDescriptorData_PythonToCpp_QLowEnergyDescriptorData_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLowEnergyDescriptorData_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLowEnergyDescriptorData_PythonToCpp_QLowEnergyDescriptorData_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyDescriptorData_TypeF()))
        return QLowEnergyDescriptorData_PythonToCpp_QLowEnergyDescriptorData_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLowEnergyDescriptorData_PTR_CppToPython_QLowEnergyDescriptorData(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QLowEnergyDescriptorData_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QLowEnergyDescriptorData_COPY_CppToPython_QLowEnergyDescriptorData(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QLowEnergyDescriptorData *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QLowEnergyDescriptorData_TypeF(), new ::QLowEnergyDescriptorData(*source), true, true);
}

// Python to C++ copy conversion.
static void QLowEnergyDescriptorData_PythonToCpp_QLowEnergyDescriptorData_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QLowEnergyDescriptorData *>(cppOut) = *reinterpret_cast< ::QLowEnergyDescriptorData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QLowEnergyDescriptorData_PythonToCpp_QLowEnergyDescriptorData_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyDescriptorData_TypeF()))
        return QLowEnergyDescriptorData_PythonToCpp_QLowEnergyDescriptorData_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QLowEnergyDescriptorData_SignatureStrings[] = {
    "2:PySide6.QtBluetooth.QLowEnergyDescriptorData(self)",
    "1:PySide6.QtBluetooth.QLowEnergyDescriptorData(self,uuid:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid],value:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "0:PySide6.QtBluetooth.QLowEnergyDescriptorData(self,other:PySide6.QtBluetooth.QLowEnergyDescriptorData)",
    "PySide6.QtBluetooth.QLowEnergyDescriptorData.isReadable(self)->bool",
    "PySide6.QtBluetooth.QLowEnergyDescriptorData.isValid(self)->bool",
    "PySide6.QtBluetooth.QLowEnergyDescriptorData.isWritable(self)->bool",
    "PySide6.QtBluetooth.QLowEnergyDescriptorData.readConstraints(self)->PySide6.QtBluetooth.QBluetooth.AttAccessConstraint",
    "PySide6.QtBluetooth.QLowEnergyDescriptorData.setReadPermissions(self,readable:bool,constraints:PySide6.QtBluetooth.QBluetooth.AttAccessConstraint=QBluetooth.AttAccessConstraints())",
    "PySide6.QtBluetooth.QLowEnergyDescriptorData.setUuid(self,uuid:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid])",
    "PySide6.QtBluetooth.QLowEnergyDescriptorData.setValue(self,value:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtBluetooth.QLowEnergyDescriptorData.setWritePermissions(self,writable:bool,constraints:PySide6.QtBluetooth.QBluetooth.AttAccessConstraint=QBluetooth.AttAccessConstraints())",
    "PySide6.QtBluetooth.QLowEnergyDescriptorData.swap(self,other:PySide6.QtBluetooth.QLowEnergyDescriptorData)",
    "PySide6.QtBluetooth.QLowEnergyDescriptorData.uuid(self)->PySide6.QtBluetooth.QBluetoothUuid",
    "PySide6.QtBluetooth.QLowEnergyDescriptorData.value(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtBluetooth.QLowEnergyDescriptorData.writeConstraints(self)->PySide6.QtBluetooth.QBluetooth.AttAccessConstraint",
    "PySide6.QtBluetooth.QLowEnergyDescriptorData.__copy__(self)->typing.Self",
    "PySide6.QtBluetooth.QLowEnergyDescriptorData.__ne__(self,b:PySide6.QtBluetooth.QLowEnergyDescriptorData)->bool",
    "PySide6.QtBluetooth.QLowEnergyDescriptorData.__eq__(self,b:PySide6.QtBluetooth.QLowEnergyDescriptorData)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QLowEnergyDescriptorData_SignatureByteSize = 376;
static constexpr uint8_t QLowEnergyDescriptorData_SignatureBytes[376] = {
    0x78, 0xda, 0xed, 0x54, 0x4d, 0x4f, 0xc2, 0x40, 0x10, 0xbd, 0xf3, 0x2b, 0x38, 0x52, 0x53, 0x37,
    0xea, 0xc1, 0x43, 0x13, 0x4d, 0xa0, 0x78, 0xf3, 0x00, 0x22, 0x78, 0x30, 0xa4, 0x59, 0xb6, 0x23,
    0x6c, 0xb2, 0xee, 0xd6, 0xd9, 0x29, 0xa4, 0xff, 0xde, 0x6e, 0x5a, 0x68, 0x44, 0x05, 0x16, 0x12,
    0xf5, 0xe0, 0xad, 0x1f, 0xf3, 0xde, 0xbc, 0x99, 0x79, 0x33, 0x57, 0xd1, 0xa0, 0x18, 0xc9, 0x14,
    0xae, 0xd9, 0x90, 0x7a, 0x2a, 0x07, 0x32, 0x86, 0x16, 0x6c, 0x78, 0x6f, 0x56, 0x77, 0x1a, 0x70,
    0x5e, 0xf4, 0xc1, 0x0a, 0x94, 0x19, 0x19, 0xec, 0x73, 0xe2, 0x1d, 0x0b, 0xea, 0x25, 0x68, 0x5d,
    0xfa, 0x83, 0xc2, 0x3c, 0x97, 0x69, 0x44, 0x45, 0x26, 0xf5, 0x9c, 0x8d, 0xb5, 0x34, 0xfa, 0xf9,
    0x4b, 0x8e, 0xcd, 0xe3, 0xb8, 0x8c, 0x0f, 0xdb, 0xfb, 0x63, 0x58, 0xbc, 0xe0, 0xc8, 0x05, 0x01,
    0x4a, 0x4b, 0x52, 0x3c, 0x16, 0x19, 0x1c, 0x04, 0x6b, 0x34, 0x1e, 0x0c, 0x19, 0xa0, 0x21, 0x23,
    0x8c, 0x3a, 0x58, 0xda, 0x08, 0x70, 0x29, 0x05, 0xc4, 0x8a, 0x5b, 0xbb, 0x0d, 0x8a, 0x0d, 0x02,
    0x1b, 0xba, 0xaf, 0xd3, 0x70, 0xc9, 0x4b, 0xd8, 0x77, 0xcd, 0xa9, 0x02, 0x7b, 0x05, 0x41, 0x17,
    0x91, 0x17, 0x61, 0x5b, 0x94, 0x05, 0x9f, 0x4d, 0x83, 0xd6, 0xc5, 0x11, 0x53, 0x28, 0x23, 0x00,
    0xbd, 0x70, 0x41, 0xcb, 0x27, 0x9a, 0x49, 0xfb, 0x00, 0x3c, 0xe5, 0x33, 0x05, 0x95, 0x57, 0xce,
    0x6f, 0x67, 0xc6, 0x28, 0x5f, 0x8e, 0x09, 0x57, 0x32, 0x3d, 0x85, 0xe0, 0x09, 0x25, 0x9d, 0x26,
    0x02, 0xcb, 0x32, 0x62, 0xa3, 0x2d, 0x21, 0x97, 0x9a, 0xec, 0x9a, 0x68, 0xf7, 0xd4, 0x59, 0x97,
    0xa8, 0x2b, 0x04, 0x58, 0xdb, 0x40, 0xfd, 0xd2, 0x5a, 0x20, 0xd7, 0xc0, 0x01, 0xe0, 0xab, 0xb4,
    0xb6, 0x74, 0x42, 0x95, 0x39, 0xc4, 0xba, 0xab, 0x91, 0xab, 0x24, 0x14, 0x8d, 0xb0, 0xc8, 0x5f,
    0xd1, 0xcd, 0xee, 0xdf, 0xb6, 0x13, 0x04, 0xde, 0xa2, 0x9d, 0x91, 0xff, 0x17, 0x7d, 0xcf, 0xa2,
    0xfb, 0xb7, 0x75, 0xe2, 0x2e, 0x43, 0xd5, 0xd7, 0xe3, 0x8e, 0x84, 0x6f, 0x42, 0xb7, 0x38, 0xf0,
    0xc9, 0x7d, 0xab, 0x7a, 0x9d, 0xfe, 0xa6, 0xfb, 0x56, 0x3c, 0xfb, 0xa1, 0xeb, 0x96, 0xe7, 0xcd,
    0x59, 0xda, 0x6f, 0x0b, 0x3f, 0xee, 0xe5, 0x66, 0xd4, 0x1f, 0xc8, 0xb7, 0x26, 0xeb, 0xc7, 0xe9,
    0xe6, 0x06, 0xbf, 0x70, 0xc5, 0x92, 0x44, 0x98, 0xac, 0x48, 0x92, 0x75, 0xbe, 0xda, 0xb5, 0xa3,
    0xf2, 0xcd, 0x97, 0x48, 0x43, 0x4d, 0x13, 0xce, 0xfc, 0x26, 0x7b, 0xcc, 0xd1, 0x4f, 0x12, 0x78,
    0x3b, 0x2d, 0xdd, 0x3b, 0x6d, 0x7f, 0x7a, 0x06
};
#endif

PyTypeObject *init_QLowEnergyDescriptorData(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX].type;

    Shiboken::AutoDecRef Sbk_QLowEnergyDescriptorData_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QLowEnergyDescriptorData_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLowEnergyDescriptorData",
        "QLowEnergyDescriptorData",
        &Sbk_QLowEnergyDescriptorData_spec,
        &Shiboken::callCppDestructor< ::QLowEnergyDescriptorData >,
        Sbk_QLowEnergyDescriptorData_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QLowEnergyDescriptorData_TypeF(); // references _Sbk_QLowEnergyDescriptorData_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QLowEnergyDescriptorData_SignatureStrings);
#else
    InitSignatureBytes(pyType, QLowEnergyDescriptorData_SignatureBytes, QLowEnergyDescriptorData_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLowEnergyDescriptorData_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLowEnergyDescriptorData_PythonToCpp_QLowEnergyDescriptorData_PTR,
        is_QLowEnergyDescriptorData_PythonToCpp_QLowEnergyDescriptorData_PTR_Convertible,
        QLowEnergyDescriptorData_PTR_CppToPython_QLowEnergyDescriptorData,
        QLowEnergyDescriptorData_COPY_CppToPython_QLowEnergyDescriptorData);

    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyDescriptorData");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyDescriptorData*");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyDescriptorData&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLowEnergyDescriptorData).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLowEnergyDescriptorData_PythonToCpp_QLowEnergyDescriptorData_COPY,
        is_QLowEnergyDescriptorData_PythonToCpp_QLowEnergyDescriptorData_COPY_Convertible);

    qRegisterMetaType< ::QLowEnergyDescriptorData >("QLowEnergyDescriptorData");

    return pyType;
}
