// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qlowenergyservice_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtBluetooth/qbluetoothuuid.h>
#include <QtBluetooth/qlowenergycharacteristic.h>
#include <QtBluetooth/qlowenergydescriptor.h>
#include <QtBluetooth/qlowenergyservice.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QLowEnergyServiceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QLowEnergyServiceWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QLowEnergyService", funcName);
        return;
    }
}

void QLowEnergyServiceWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QLowEnergyService", funcName);
        return;
    }
}

void QLowEnergyServiceWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QLowEnergyService", funcName);
        return;
    }
}

void QLowEnergyServiceWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QLowEnergyService", funcName);
        return;
    }
}

bool QLowEnergyServiceWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QLowEnergyService", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QLowEnergyService", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QLowEnergyServiceWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QLowEnergyService", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QLowEnergyService", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QLowEnergyServiceWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QLowEnergyService", funcName);
        return;
    }
}

const QMetaObject *QLowEnergyServiceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QLowEnergyService::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QLowEnergyServiceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QLowEnergyService::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QLowEnergyServiceWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QLowEnergyServiceWrapper *>(this));
    return QLowEnergyService::qt_metacast(_clname);
}

QLowEnergyServiceWrapper::~QLowEnergyServiceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QLowEnergyServiceFunc_characteristic(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyService *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyService::characteristic(QBluetoothUuid)const->QLowEnergyCharacteristic
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArg)))) {
        overloadId = 0; // characteristic(QBluetoothUuid)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "characteristic", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBluetoothUuid cppArg0_local;
        ::QBluetoothUuid *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // characteristic(QBluetoothUuid)const
            QLowEnergyCharacteristic cppResult = const_cast<const ::QLowEnergyService *>(cppSelf)->characteristic(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceFunc_characteristics(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyService *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // characteristics()const
        QList<QLowEnergyCharacteristic> cppResult = const_cast<const ::QLowEnergyService *>(cppSelf)->characteristics();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyCharacteristic_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyService *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyService::contains(QLowEnergyCharacteristic)const->bool
    // 1: QLowEnergyService::contains(QLowEnergyDescriptor)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), (pyArg)))) {
        overloadId = 1; // contains(QLowEnergyDescriptor)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), (pyArg)))) {
        overloadId = 0; // contains(QLowEnergyCharacteristic)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contains", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // contains(const QLowEnergyCharacteristic &characteristic) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QLowEnergyCharacteristic cppArg0_local;
            ::QLowEnergyCharacteristic *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // contains(QLowEnergyCharacteristic)const
                bool cppResult = const_cast<const ::QLowEnergyService *>(cppSelf)->contains(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // contains(const QLowEnergyDescriptor &descriptor) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QLowEnergyDescriptor cppArg0_local;
            ::QLowEnergyDescriptor *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // contains(QLowEnergyDescriptor)const
                bool cppResult = const_cast<const ::QLowEnergyService *>(cppSelf)->contains(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceFunc_discoverDetails(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyService *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "discoverDetails", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);

    if (PyArg_ParseTuple(args, "|O:discoverDetails", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLowEnergyService::discoverDetails(QLowEnergyService::DiscoveryMode=)
    if (numArgs == 0) {
        overloadId = 0; // discoverDetails(QLowEnergyService::DiscoveryMode)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_DiscoveryMode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // discoverDetails(QLowEnergyService::DiscoveryMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "discoverDetails", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "discoverDetails", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_DiscoveryMode_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "discoverDetails", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "discoverDetails", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);
            }
        }
        ::QLowEnergyService::DiscoveryMode cppArg0(QLowEnergyService::DiscoveryMode::FullDiscovery);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // discoverDetails(QLowEnergyService::DiscoveryMode)
            cppSelf->discoverDetails(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyService *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QLowEnergyService::ServiceError cppResult = const_cast<const ::QLowEnergyService *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_ServiceError_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceFunc_includedServices(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyService *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // includedServices()const
        QList<QBluetoothUuid> cppResult = const_cast<const ::QLowEnergyService *>(cppSelf)->includedServices();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothUuid_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceFunc_readCharacteristic(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyService *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyService::readCharacteristic(QLowEnergyCharacteristic)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), (pyArg)))) {
        overloadId = 0; // readCharacteristic(QLowEnergyCharacteristic)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "readCharacteristic", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLowEnergyCharacteristic cppArg0_local;
        ::QLowEnergyCharacteristic *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // readCharacteristic(QLowEnergyCharacteristic)
            cppSelf->readCharacteristic(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceFunc_readDescriptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyService *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyService::readDescriptor(QLowEnergyDescriptor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), (pyArg)))) {
        overloadId = 0; // readDescriptor(QLowEnergyDescriptor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "readDescriptor", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLowEnergyDescriptor cppArg0_local;
        ::QLowEnergyDescriptor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // readDescriptor(QLowEnergyDescriptor)
            cppSelf->readDescriptor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceFunc_serviceName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyService *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // serviceName()const
        QString cppResult = const_cast<const ::QLowEnergyService *>(cppSelf)->serviceName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceFunc_serviceUuid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyService *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // serviceUuid()const
        QBluetoothUuid cppResult = const_cast<const ::QLowEnergyService *>(cppSelf)->serviceUuid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyService *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QLowEnergyService::ServiceState cppResult = const_cast<const ::QLowEnergyService *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_ServiceState_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyService *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QFlags<QLowEnergyService::ServiceType> cppResult = const_cast<const ::QLowEnergyService *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QLowEnergyService_ServiceType_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceFunc_writeCharacteristic(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyService *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "writeCharacteristic", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:writeCharacteristic", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLowEnergyService::writeCharacteristic(QLowEnergyCharacteristic,QByteArray,QLowEnergyService::WriteMode=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // writeCharacteristic(QLowEnergyCharacteristic,QByteArray,QLowEnergyService::WriteMode)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_WriteMode_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 0; // writeCharacteristic(QLowEnergyCharacteristic,QByteArray,QLowEnergyService::WriteMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeCharacteristic", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "writeCharacteristic", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_WriteMode_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "writeCharacteristic", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "writeCharacteristic", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QLowEnergyCharacteristic cppArg0_local;
        ::QLowEnergyCharacteristic *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        ::QLowEnergyService::WriteMode cppArg2(QLowEnergyService::WriteMode::WriteWithResponse);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeCharacteristic(QLowEnergyCharacteristic,QByteArray,QLowEnergyService::WriteMode)
            cppSelf->writeCharacteristic(*cppArg0, *cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceFunc_writeDescriptor(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyService *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeDescriptor", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLowEnergyService::writeDescriptor(QLowEnergyDescriptor,QByteArray)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // writeDescriptor(QLowEnergyDescriptor,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeDescriptor", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QLowEnergyDescriptor cppArg0_local;
        ::QLowEnergyDescriptor *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // writeDescriptor(QLowEnergyDescriptor,QByteArray)
            cppSelf->writeDescriptor(*cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QLowEnergyService_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QLowEnergyService_EnumFlagInfo[] = {
    "DiscoveryMode:Enum",
    "ServiceError:Enum",
    "ServiceState:Enum",
    "ServiceType:Flag:ServiceTypes",
    "WriteMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLowEnergyService_methods[] = {
    {"characteristic", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceFunc_characteristic), METH_O, nullptr},
    {"characteristics", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceFunc_characteristics), METH_NOARGS, nullptr},
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceFunc_contains), METH_O, nullptr},
    {"discoverDetails", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceFunc_discoverDetails), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceFunc_error), METH_NOARGS, nullptr},
    {"includedServices", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceFunc_includedServices), METH_NOARGS, nullptr},
    {"readCharacteristic", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceFunc_readCharacteristic), METH_O, nullptr},
    {"readDescriptor", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceFunc_readDescriptor), METH_O, nullptr},
    {"serviceName", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceFunc_serviceName), METH_NOARGS, nullptr},
    {"serviceUuid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceFunc_serviceUuid), METH_NOARGS, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceFunc_state), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceFunc_type), METH_NOARGS, nullptr},
    {"writeCharacteristic", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceFunc_writeCharacteristic), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"writeDescriptor", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceFunc_writeDescriptor), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QLowEnergyService_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QLowEnergyService *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QLowEnergyServiceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QLowEnergyService_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLowEnergyService_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLowEnergyService_Type = nullptr;
static PyTypeObject *Sbk_QLowEnergyService_TypeF(void)
{
    return _Sbk_QLowEnergyService_Type;
}

static PyType_Slot Sbk_QLowEnergyService_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QLowEnergyService_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLowEnergyService_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLowEnergyService_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLowEnergyService_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLowEnergyService_spec = {
    "2:PySide6.QtBluetooth.QLowEnergyService",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLowEnergyService_slots
};

} //extern "C"

static void *Sbk_QLowEnergyService_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QLowEnergyService *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QLowEnergyService_ServiceType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLowEnergyService::ServiceType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLowEnergyService::ServiceType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLowEnergyService_ServiceType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_ServiceType_IDX])))
        return Enum_PythonToCpp_QLowEnergyService_ServiceType;
    return {};
}

static PyObject *QLowEnergyService_ServiceType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLowEnergyService::ServiceType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLowEnergyService::ServiceType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_ServiceType_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QLowEnergyService_ServiceType(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QLowEnergyService::ServiceType>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QLowEnergyService::ServiceType> *>(cppOut) = value;

}

static PyObject *QLowEnergyService_ServiceType_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QLowEnergyService::ServiceType> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_ServiceType_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QLowEnergyService_ServiceError(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLowEnergyService::ServiceError>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLowEnergyService::ServiceError *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLowEnergyService_ServiceError_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_ServiceError_IDX])))
        return Enum_PythonToCpp_QLowEnergyService_ServiceError;
    return {};
}

static PyObject *QLowEnergyService_ServiceError_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLowEnergyService::ServiceError>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLowEnergyService::ServiceError *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_ServiceError_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QLowEnergyService_ServiceState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLowEnergyService::ServiceState>(Shiboken::Enum::getValue(pyIn));
    switch (value) {
    case QLowEnergyService::ServiceState::DiscoveryRequired:
        Shiboken::Warnings::warnDeprecatedEnumValue("QLowEnergyService::ServiceState", "DiscoveryRequired");
        break;
    case QLowEnergyService::ServiceState::DiscoveringService:
        Shiboken::Warnings::warnDeprecatedEnumValue("QLowEnergyService::ServiceState", "DiscoveringService");
        break;
    case QLowEnergyService::ServiceState::ServiceDiscovered:
        Shiboken::Warnings::warnDeprecatedEnumValue("QLowEnergyService::ServiceState", "ServiceDiscovered");
        break;
    default:
        break;
    }
    *reinterpret_cast<::QLowEnergyService::ServiceState *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLowEnergyService_ServiceState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_ServiceState_IDX])))
        return Enum_PythonToCpp_QLowEnergyService_ServiceState;
    return {};
}

static PyObject *QLowEnergyService_ServiceState_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLowEnergyService::ServiceState>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLowEnergyService::ServiceState *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_ServiceState_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QLowEnergyService_DiscoveryMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLowEnergyService::DiscoveryMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLowEnergyService::DiscoveryMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLowEnergyService_DiscoveryMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_DiscoveryMode_IDX])))
        return Enum_PythonToCpp_QLowEnergyService_DiscoveryMode;
    return {};
}

static PyObject *QLowEnergyService_DiscoveryMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLowEnergyService::DiscoveryMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLowEnergyService::DiscoveryMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_DiscoveryMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QLowEnergyService_WriteMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLowEnergyService::WriteMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLowEnergyService::WriteMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLowEnergyService_WriteMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_WriteMode_IDX])))
        return Enum_PythonToCpp_QLowEnergyService_WriteMode;
    return {};
}

static PyObject *QLowEnergyService_WriteMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLowEnergyService::WriteMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLowEnergyService::WriteMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_WriteMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLowEnergyService_PythonToCpp_QLowEnergyService_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLowEnergyService_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLowEnergyService_PythonToCpp_QLowEnergyService_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyService_TypeF()))
        return QLowEnergyService_PythonToCpp_QLowEnergyService_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLowEnergyService_PTR_CppToPython_QLowEnergyService(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QLowEnergyService *>(const_cast<void *>(cppIn)), Sbk_QLowEnergyService_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QLowEnergyService_SignatureStrings[] = {
    "PySide6.QtBluetooth.QLowEnergyService.characteristic(self,uuid:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid])->PySide6.QtBluetooth.QLowEnergyCharacteristic",
    "PySide6.QtBluetooth.QLowEnergyService.characteristics(self)->QList[PySide6.QtBluetooth.QLowEnergyCharacteristic]",
    "1:PySide6.QtBluetooth.QLowEnergyService.contains(self,characteristic:PySide6.QtBluetooth.QLowEnergyCharacteristic)->bool",
    "0:PySide6.QtBluetooth.QLowEnergyService.contains(self,descriptor:PySide6.QtBluetooth.QLowEnergyDescriptor)->bool",
    "PySide6.QtBluetooth.QLowEnergyService.discoverDetails(self,mode:PySide6.QtBluetooth.QLowEnergyService.DiscoveryMode=QLowEnergyService.DiscoveryMode.FullDiscovery)",
    "PySide6.QtBluetooth.QLowEnergyService.error(self)->PySide6.QtBluetooth.QLowEnergyService.ServiceError",
    "PySide6.QtBluetooth.QLowEnergyService.includedServices(self)->QList[PySide6.QtBluetooth.QBluetoothUuid]",
    "PySide6.QtBluetooth.QLowEnergyService.readCharacteristic(self,characteristic:PySide6.QtBluetooth.QLowEnergyCharacteristic)",
    "PySide6.QtBluetooth.QLowEnergyService.readDescriptor(self,descriptor:PySide6.QtBluetooth.QLowEnergyDescriptor)",
    "PySide6.QtBluetooth.QLowEnergyService.serviceName(self)->QString",
    "PySide6.QtBluetooth.QLowEnergyService.serviceUuid(self)->PySide6.QtBluetooth.QBluetoothUuid",
    "PySide6.QtBluetooth.QLowEnergyService.state(self)->PySide6.QtBluetooth.QLowEnergyService.ServiceState",
    "PySide6.QtBluetooth.QLowEnergyService.type(self)->PySide6.QtBluetooth.QLowEnergyService.ServiceType",
    "PySide6.QtBluetooth.QLowEnergyService.writeCharacteristic(self,characteristic:PySide6.QtBluetooth.QLowEnergyCharacteristic,newValue:typing.Union[PySide6.QtCore.QByteArray, char*],mode:PySide6.QtBluetooth.QLowEnergyService.WriteMode=QLowEnergyService.WriteMode.WriteWithResponse)",
    "PySide6.QtBluetooth.QLowEnergyService.writeDescriptor(self,descriptor:PySide6.QtBluetooth.QLowEnergyDescriptor,newValue:typing.Union[PySide6.QtCore.QByteArray, char*])",
    nullptr}; // Sentinel
#else
static constexpr size_t QLowEnergyService_SignatureByteSize = 399;
static constexpr uint8_t QLowEnergyService_SignatureBytes[399] = {
    0x78, 0xda, 0xad, 0x95, 0xcf, 0x4f, 0x83, 0x30, 0x14, 0xc7, 0xef, 0xfb, 0x2b, 0x76, 0x14, 0x83,
    0x44, 0x2f, 0x1e, 0x96, 0x68, 0xe2, 0xd8, 0x3c, 0x4d, 0x03, 0xe2, 0xf4, 0xb0, 0x70, 0xa8, 0xed,
    0x73, 0x6b, 0xd2, 0xb5, 0xe4, 0xb5, 0x6c, 0xe1, 0xbf, 0xb7, 0x08, 0x63, 0xc1, 0xec, 0x47, 0xc1,
    0x9d, 0xda, 0xd2, 0x7e, 0xfb, 0x79, 0xbc, 0xf7, 0xe5, 0x11, 0x15, 0x09, 0x67, 0x70, 0x1f, 0xc4,
    0x66, 0x2c, 0x72, 0x30, 0x4a, 0x99, 0x55, 0x10, 0xcf, 0xd4, 0x76, 0x2a, 0x01, 0x97, 0x45, 0x02,
    0xb8, 0xe1, 0x14, 0x02, 0xba, 0x22, 0x48, 0xa8, 0x01, 0xe4, 0xda, 0x70, 0x7a, 0xa5, 0x41, 0x7c,
    0xfb, 0x79, 0xce, 0xd9, 0xc8, 0x14, 0x19, 0x97, 0xcb, 0x60, 0x2e, 0xb9, 0x92, 0x8b, 0xe8, 0xd0,
    0x5d, 0xcd, 0x74, 0x6e, 0xcf, 0xfb, 0xc3, 0xf3, 0x67, 0x82, 0xb0, 0x05, 0x7b, 0x2f, 0x32, 0x70,
    0x92, 0x4d, 0x40, 0x53, 0xe4, 0x99, 0x51, 0xe8, 0x2c, 0x89, 0x50, 0x19, 0x45, 0x95, 0x70, 0x0e,
    0xad, 0xce, 0x47, 0x28, 0x88, 0xd6, 0x7f, 0x45, 0xa1, 0x42, 0x08, 0xe2, 0xf2, 0x69, 0xea, 0xdd,
    0x3c, 0x46, 0x27, 0xf3, 0xda, 0x7e, 0xc5, 0x41, 0xd4, 0xa3, 0x08, 0xfa, 0xb7, 0x0a, 0x96, 0x14,
    0xcf, 0xec, 0x7a, 0xd1, 0x85, 0x97, 0x0e, 0xee, 0x46, 0x8e, 0x48, 0x25, 0x0d, 0xe1, 0xb2, 0x62,
    0xf9, 0xed, 0x00, 0x46, 0x5d, 0x90, 0x36, 0xce, 0x2f, 0xa5, 0xc4, 0xe0, 0xb6, 0x17, 0x98, 0x35,
    0xa5, 0x3d, 0x23, 0xdf, 0x7b, 0x60, 0x07, 0x74, 0xc3, 0x31, 0xae, 0xa9, 0xda, 0x00, 0x4e, 0xc0,
    0x52, 0x45, 0x4d, 0x5d, 0x2b, 0x06, 0x8e, 0xe1, 0x4e, 0x6a, 0x7d, 0xf1, 0x62, 0x35, 0x0f, 0x67,
    0xf6, 0x83, 0xe7, 0x5c, 0x88, 0xe6, 0x89, 0xe7, 0x18, 0x22, 0x20, 0x2a, 0xdc, 0xd5, 0xdc, 0x4d,
    0x52, 0x8f, 0xd3, 0x52, 0xe9, 0x48, 0xe1, 0x92, 0x8a, 0x9c, 0x01, 0xab, 0xd7, 0x2e, 0x26, 0x6b,
    0x7d, 0x21, 0xa9, 0x23, 0x07, 0x81, 0xb0, 0xf0, 0x40, 0x53, 0xf9, 0x8f, 0xc5, 0x3a, 0xa0, 0xf7,
    0x3e, 0xe9, 0x6f, 0x30, 0x47, 0x9c, 0xae, 0xc6, 0x57, 0xb2, 0x86, 0x26, 0x99, 0x89, 0x41, 0xdb,
    0x35, 0xbb, 0x5d, 0x50, 0x66, 0xf7, 0x64, 0xf9, 0x5b, 0x75, 0x70, 0xbd, 0xdb, 0x10, 0x03, 0xbd,
    0x4c, 0x95, 0x94, 0x4a, 0x47, 0x8a, 0xfd, 0x49, 0xf4, 0x83, 0x94, 0x8d, 0xdc, 0x91, 0xb1, 0x45,
    0x6e, 0xe0, 0xc2, 0x8e, 0xf2, 0x25, 0x6c, 0x3f, 0x88, 0x3d, 0x76, 0xec, 0x37, 0x57, 0xb5, 0xfc,
    0x71, 0x61, 0xe0, 0x09, 0x91, 0x14, 0xfe, 0xb0, 0x84, 0x5d, 0xa7, 0x5d, 0x3a, 0xc7, 0x67, 0x19,
    0xf7, 0x91, 0xae, 0xd1, 0xec, 0x55, 0xb3, 0x4f, 0x6e, 0x56, 0x6f, 0xa0, 0x33, 0x25, 0x35, 0x78,
    0x5d, 0xd2, 0x72, 0x01, 0xb7, 0xf7, 0x4d, 0x85, 0x37, 0xf8, 0x01, 0x96, 0xeb, 0x24, 0xfd
};
#endif

PyTypeObject *init_QLowEnergyService(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX].type;

    Shiboken::AutoDecRef Sbk_QLowEnergyService_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QLowEnergyService_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLowEnergyService",
        "QLowEnergyService*",
        &Sbk_QLowEnergyService_spec,
        &Shiboken::callCppDestructor< QLowEnergyService >,
        Sbk_QLowEnergyService_Type_bases.object(),
        0);
    auto *pyType = Sbk_QLowEnergyService_TypeF(); // references _Sbk_QLowEnergyService_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QLowEnergyService_SignatureStrings);
#else
    InitSignatureBytes(pyType, QLowEnergyService_SignatureBytes, QLowEnergyService_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLowEnergyService_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLowEnergyService_PythonToCpp_QLowEnergyService_PTR,
        is_QLowEnergyService_PythonToCpp_QLowEnergyService_PTR_Convertible,
        QLowEnergyService_PTR_CppToPython_QLowEnergyService);

    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyService");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyService*");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyService&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLowEnergyService).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QLowEnergyServiceWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QLowEnergyService_TypeF(), &Sbk_QLowEnergyService_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QLowEnergyService_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ServiceType'.
    const char *ServiceType_Initializer[] = {
        "PrimaryService",
        "IncludedService",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ServiceType_InitializerValues[] = {
        uint8_t(QLowEnergyService::ServiceType::PrimaryService), //  0x01  1
        uint8_t(QLowEnergyService::ServiceType::IncludedService) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLowEnergyService_TypeF(),
        "2:PySide6.QtBluetooth.QLowEnergyService.ServiceType",
        ServiceType_Initializer, ServiceType_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_ServiceType_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QLowEnergyService_ServiceType_IDX].type =
        EType;
    // Register converter for enum 'QLowEnergyService::ServiceType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLowEnergyService_ServiceType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLowEnergyService_ServiceType,
            is_Enum_PythonToCpp_QLowEnergyService_ServiceType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLowEnergyService::ServiceType");
        Shiboken::Conversions::registerConverterAlias(converter, "ServiceType");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QLowEnergyService_ServiceType_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QLowEnergyService_ServiceType,
            is_Enum_PythonToCpp_QLowEnergyService_ServiceType_Convertible);
        // Register converter for flag 'QFlags<QLowEnergyService::ServiceType>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QLowEnergyService::ServiceType>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QLowEnergyService::ServiceTypes");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'ServiceType' enum/flags.

    // Initialization of enum 'ServiceError'.
    const char *ServiceError_Initializer[] = {
        "NoError",
        "OperationError",
        "CharacteristicWriteError",
        "DescriptorWriteError",
        "UnknownError",
        "CharacteristicReadError",
        "DescriptorReadError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ServiceError_InitializerValues[] = {
        uint8_t(QLowEnergyService::ServiceError::NoError),                  //  0x00  0
        uint8_t(QLowEnergyService::ServiceError::OperationError),           //  0x01  1
        uint8_t(QLowEnergyService::ServiceError::CharacteristicWriteError), //  0x02  2
        uint8_t(QLowEnergyService::ServiceError::DescriptorWriteError),     //  0x03  3
        uint8_t(QLowEnergyService::ServiceError::UnknownError),             //  0x04  4
        uint8_t(QLowEnergyService::ServiceError::CharacteristicReadError),  //  0x05  5
        uint8_t(QLowEnergyService::ServiceError::DescriptorReadError)       //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLowEnergyService_TypeF(),
        "2:PySide6.QtBluetooth.QLowEnergyService.ServiceError",
        ServiceError_Initializer, ServiceError_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_ServiceError_IDX].type = EType;
    // Register converter for enum 'QLowEnergyService::ServiceError'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLowEnergyService_ServiceError_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLowEnergyService_ServiceError,
            is_Enum_PythonToCpp_QLowEnergyService_ServiceError_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLowEnergyService::ServiceError");
        Shiboken::Conversions::registerConverterAlias(converter, "ServiceError");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ServiceError' enum.

    // Initialization of enum 'ServiceState'.
    const char *ServiceState_Initializer[] = {
        "InvalidService",
        "RemoteService",
        "RemoteServiceDiscovering",
        "RemoteServiceDiscovered",
        "LocalService",
        "DiscoveryRequired",
        "DiscoveringService",
        "ServiceDiscovered",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ServiceState_InitializerValues[] = {
        uint8_t(QLowEnergyService::ServiceState::InvalidService),           //  0x00  0
        uint8_t(QLowEnergyService::ServiceState::RemoteService),            //  0x01  1
        uint8_t(QLowEnergyService::ServiceState::RemoteServiceDiscovering), //  0x02  2
        uint8_t(QLowEnergyService::ServiceState::RemoteServiceDiscovered),  //  0x03  3
        uint8_t(QLowEnergyService::ServiceState::LocalService),             //  0x04  4
        uint8_t(QLowEnergyService::ServiceState::DiscoveryRequired),        //  0x01  1
        uint8_t(QLowEnergyService::ServiceState::DiscoveringService),       //  0x02  2
        uint8_t(QLowEnergyService::ServiceState::ServiceDiscovered)         //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLowEnergyService_TypeF(),
        "2:PySide6.QtBluetooth.QLowEnergyService.ServiceState",
        ServiceState_Initializer, ServiceState_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_ServiceState_IDX].type = EType;
    // Register converter for enum 'QLowEnergyService::ServiceState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLowEnergyService_ServiceState_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLowEnergyService_ServiceState,
            is_Enum_PythonToCpp_QLowEnergyService_ServiceState_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLowEnergyService::ServiceState");
        Shiboken::Conversions::registerConverterAlias(converter, "ServiceState");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ServiceState' enum.

    // Initialization of enum 'DiscoveryMode'.
    const char *DiscoveryMode_Initializer[] = {
        "FullDiscovery",
        "SkipValueDiscovery",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DiscoveryMode_InitializerValues[] = {
        uint8_t(QLowEnergyService::DiscoveryMode::FullDiscovery),     //  0x00  0
        uint8_t(QLowEnergyService::DiscoveryMode::SkipValueDiscovery) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLowEnergyService_TypeF(),
        "2:PySide6.QtBluetooth.QLowEnergyService.DiscoveryMode",
        DiscoveryMode_Initializer, DiscoveryMode_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_DiscoveryMode_IDX].type = EType;
    // Register converter for enum 'QLowEnergyService::DiscoveryMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLowEnergyService_DiscoveryMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLowEnergyService_DiscoveryMode,
            is_Enum_PythonToCpp_QLowEnergyService_DiscoveryMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLowEnergyService::DiscoveryMode");
        Shiboken::Conversions::registerConverterAlias(converter, "DiscoveryMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DiscoveryMode' enum.

    // Initialization of enum 'WriteMode'.
    const char *WriteMode_Initializer[] = {
        "WriteWithResponse",
        "WriteWithoutResponse",
        "WriteSigned",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t WriteMode_InitializerValues[] = {
        uint8_t(QLowEnergyService::WriteMode::WriteWithResponse),    //  0x00  0
        uint8_t(QLowEnergyService::WriteMode::WriteWithoutResponse), //  0x01  1
        uint8_t(QLowEnergyService::WriteMode::WriteSigned)           //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLowEnergyService_TypeF(),
        "2:PySide6.QtBluetooth.QLowEnergyService.WriteMode",
        WriteMode_Initializer, WriteMode_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_WriteMode_IDX].type = EType;
    // Register converter for enum 'QLowEnergyService::WriteMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLowEnergyService_WriteMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLowEnergyService_WriteMode,
            is_Enum_PythonToCpp_QLowEnergyService_WriteMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLowEnergyService::WriteMode");
        Shiboken::Conversions::registerConverterAlias(converter, "WriteMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'WriteMode' enum.

    PySide::Signal::registerSignals(pyType, &::QLowEnergyService::staticMetaObject);
    qRegisterMetaType< ::QLowEnergyService::ServiceType >("QLowEnergyService::ServiceType");
    qRegisterMetaType< ::QLowEnergyService::ServiceError >("QLowEnergyService::ServiceError");
    qRegisterMetaType< ::QLowEnergyService::ServiceState >("QLowEnergyService::ServiceState");
    qRegisterMetaType< ::QLowEnergyService::DiscoveryMode >("QLowEnergyService::DiscoveryMode");
    qRegisterMetaType< ::QLowEnergyService::WriteMode >("QLowEnergyService::WriteMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QLowEnergyService::staticMetaObject, sizeof(QLowEnergyServiceWrapper));

    return pyType;
}
