// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qlowenergyservicedata_wrapper.h"

// Argument includes
#include <QList>
#include <QtBluetooth/qbluetoothuuid.h>
#include <QtBluetooth/qlowenergycharacteristicdata.h>
#include <QtBluetooth/qlowenergyservice.h>
#include <QtBluetooth/qlowenergyservicedata.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLowEnergyServiceData_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLowEnergyServiceData >()))
        return -1;

    ::QLowEnergyServiceData *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QLowEnergyServiceData", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLowEnergyServiceData::QLowEnergyServiceData()
    // 1: QLowEnergyServiceData::QLowEnergyServiceData(QLowEnergyServiceData)
    if (numArgs == 0) {
        overloadId = 0; // QLowEnergyServiceData()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QLowEnergyServiceData(QLowEnergyServiceData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QLowEnergyServiceData()
        {

            // QLowEnergyServiceData()
            cptr = new ::QLowEnergyServiceData();
            break;
        }
        case 1: // QLowEnergyServiceData(const QLowEnergyServiceData &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QLowEnergyServiceData cppArg0_local;
            ::QLowEnergyServiceData *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLowEnergyServiceData(QLowEnergyServiceData)
                cptr = new ::QLowEnergyServiceData(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QLowEnergyServiceData >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_addCharacteristic(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyServiceData::addCharacteristic(QLowEnergyCharacteristicData)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), (pyArg)))) {
        overloadId = 0; // addCharacteristic(QLowEnergyCharacteristicData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addCharacteristic", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLowEnergyCharacteristicData cppArg0_local;
        ::QLowEnergyCharacteristicData *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // addCharacteristic(QLowEnergyCharacteristicData)
            cppSelf->addCharacteristic(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_addIncludedService(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyServiceData::addIncludedService(QLowEnergyService*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), (pyArg)))) {
        overloadId = 0; // addIncludedService(QLowEnergyService*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addIncludedService", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLowEnergyService *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addIncludedService(QLowEnergyService*)
            cppSelf->addIncludedService(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_characteristics(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // characteristics()const
        QList<QLowEnergyCharacteristicData> cppResult = const_cast<const ::QLowEnergyServiceData *>(cppSelf)->characteristics();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyCharacteristicData_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_includedServices(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // includedServices()const
        QList<QLowEnergyService*> cppResult = const_cast<const ::QLowEnergyServiceData *>(cppSelf)->includedServices();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyServicePTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QLowEnergyServiceData *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_setCharacteristics(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyServiceData::setCharacteristics(QList<QLowEnergyCharacteristicData>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyCharacteristicData_IDX], (pyArg)))) {
        overloadId = 0; // setCharacteristics(QList<QLowEnergyCharacteristicData>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCharacteristics", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]);

    // Call function/method
    {
        ::QList<QLowEnergyCharacteristicData> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCharacteristics(QList<QLowEnergyCharacteristicData>)
            cppSelf->setCharacteristics(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_setIncludedServices(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyServiceData::setIncludedServices(QList<QLowEnergyService*>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyServicePTR_IDX], (pyArg)))) {
        overloadId = 0; // setIncludedServices(QList<QLowEnergyService*>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIncludedServices", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]);

    // Call function/method
    {
        ::QList<QLowEnergyService*> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIncludedServices(QList<QLowEnergyService*>)
            cppSelf->setIncludedServices(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_setType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyServiceData::setType(QLowEnergyServiceData::ServiceType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_ServiceType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setType(QLowEnergyServiceData::ServiceType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setType", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]);

    // Call function/method
    {
        ::QLowEnergyServiceData::ServiceType cppArg0 = static_cast< ::QLowEnergyServiceData::ServiceType>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setType(QLowEnergyServiceData::ServiceType)
            cppSelf->setType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_setUuid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyServiceData::setUuid(QBluetoothUuid)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArg)))) {
        overloadId = 0; // setUuid(QBluetoothUuid)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUuid", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBluetoothUuid cppArg0_local;
        ::QBluetoothUuid *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUuid(QBluetoothUuid)
            cppSelf->setUuid(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyServiceData::swap(QLowEnergyServiceData&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QLowEnergyServiceData&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLowEnergyServiceData cppArg0_local;
        ::QLowEnergyServiceData *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QLowEnergyServiceData&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QLowEnergyServiceData::ServiceType cppResult = const_cast<const ::QLowEnergyServiceData *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_ServiceType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_uuid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // uuid()const
        QBluetoothUuid cppResult = const_cast<const ::QLowEnergyServiceData *>(cppSelf)->uuid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceData__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QLowEnergyServiceData_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QLowEnergyServiceData_EnumFlagInfo[] = {
    "ServiceType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLowEnergyServiceData_methods[] = {
    {"addCharacteristic", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_addCharacteristic), METH_O, nullptr},
    {"addIncludedService", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_addIncludedService), METH_O, nullptr},
    {"characteristics", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_characteristics), METH_NOARGS, nullptr},
    {"includedServices", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_includedServices), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_isValid), METH_NOARGS, nullptr},
    {"setCharacteristics", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_setCharacteristics), METH_O, nullptr},
    {"setIncludedServices", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_setIncludedServices), METH_O, nullptr},
    {"setType", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_setType), METH_O, nullptr},
    {"setUuid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_setUuid), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_swap), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_type), METH_NOARGS, nullptr},
    {"uuid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_uuid), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceData__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QLowEnergyServiceData_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), (pyArg)))) {
                // operator!=(const QLowEnergyServiceData &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyServiceData cppArg0_local;
                ::QLowEnergyServiceData *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), (pyArg)))) {
                // operator==(const QLowEnergyServiceData &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyServiceData cppArg0_local;
                ::QLowEnergyServiceData *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QLowEnergyServiceData_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLowEnergyServiceData_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLowEnergyServiceData_Type = nullptr;
static PyTypeObject *Sbk_QLowEnergyServiceData_TypeF(void)
{
    return _Sbk_QLowEnergyServiceData_Type;
}

static PyType_Slot Sbk_QLowEnergyServiceData_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLowEnergyServiceData_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLowEnergyServiceData_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QLowEnergyServiceData_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLowEnergyServiceData_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLowEnergyServiceData_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLowEnergyServiceData_spec = {
    "2:PySide6.QtBluetooth.QLowEnergyServiceData",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLowEnergyServiceData_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QLowEnergyServiceData_ServiceType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLowEnergyServiceData::ServiceType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLowEnergyServiceData::ServiceType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLowEnergyServiceData_ServiceType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_ServiceType_IDX])))
        return Enum_PythonToCpp_QLowEnergyServiceData_ServiceType;
    return {};
}

static PyObject *QLowEnergyServiceData_ServiceType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLowEnergyServiceData::ServiceType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLowEnergyServiceData::ServiceType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_ServiceType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLowEnergyServiceData_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyServiceData_TypeF()))
        return QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLowEnergyServiceData_PTR_CppToPython_QLowEnergyServiceData(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QLowEnergyServiceData_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QLowEnergyServiceData_COPY_CppToPython_QLowEnergyServiceData(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QLowEnergyServiceData *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QLowEnergyServiceData_TypeF(), new ::QLowEnergyServiceData(*source), true, true);
}

// Python to C++ copy conversion.
static void QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QLowEnergyServiceData *>(cppOut) = *reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyServiceData_TypeF()))
        return QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QLowEnergyServiceData_SignatureStrings[] = {
    "1:PySide6.QtBluetooth.QLowEnergyServiceData(self)",
    "0:PySide6.QtBluetooth.QLowEnergyServiceData(self,other:PySide6.QtBluetooth.QLowEnergyServiceData)",
    "PySide6.QtBluetooth.QLowEnergyServiceData.addCharacteristic(self,characteristic:PySide6.QtBluetooth.QLowEnergyCharacteristicData)",
    "PySide6.QtBluetooth.QLowEnergyServiceData.addIncludedService(self,service:PySide6.QtBluetooth.QLowEnergyService)",
    "PySide6.QtBluetooth.QLowEnergyServiceData.characteristics(self)->QList[PySide6.QtBluetooth.QLowEnergyCharacteristicData]",
    "PySide6.QtBluetooth.QLowEnergyServiceData.includedServices(self)->QList[PySide6.QtBluetooth.QLowEnergyService]",
    "PySide6.QtBluetooth.QLowEnergyServiceData.isValid(self)->bool",
    "PySide6.QtBluetooth.QLowEnergyServiceData.setCharacteristics(self,characteristics:QList[PySide6.QtBluetooth.QLowEnergyCharacteristicData])",
    "PySide6.QtBluetooth.QLowEnergyServiceData.setIncludedServices(self,services:QList[PySide6.QtBluetooth.QLowEnergyService])",
    "PySide6.QtBluetooth.QLowEnergyServiceData.setType(self,type:PySide6.QtBluetooth.QLowEnergyServiceData.ServiceType)",
    "PySide6.QtBluetooth.QLowEnergyServiceData.setUuid(self,uuid:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid])",
    "PySide6.QtBluetooth.QLowEnergyServiceData.swap(self,other:PySide6.QtBluetooth.QLowEnergyServiceData)",
    "PySide6.QtBluetooth.QLowEnergyServiceData.type(self)->PySide6.QtBluetooth.QLowEnergyServiceData.ServiceType",
    "PySide6.QtBluetooth.QLowEnergyServiceData.uuid(self)->PySide6.QtBluetooth.QBluetoothUuid",
    "PySide6.QtBluetooth.QLowEnergyServiceData.__copy__(self)->typing.Self",
    "PySide6.QtBluetooth.QLowEnergyServiceData.__ne__(self,b:PySide6.QtBluetooth.QLowEnergyServiceData)->bool",
    "PySide6.QtBluetooth.QLowEnergyServiceData.__eq__(self,b:PySide6.QtBluetooth.QLowEnergyServiceData)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QLowEnergyServiceData_SignatureByteSize = 335;
static constexpr uint8_t QLowEnergyServiceData_SignatureBytes[335] = {
    0x78, 0xda, 0xb5, 0x54, 0x3d, 0x4f, 0xc3, 0x30, 0x10, 0xdd, 0xfb, 0x2b, 0x18, 0x89, 0x14, 0x2c,
    0x58, 0x18, 0x32, 0x30, 0x90, 0x32, 0x54, 0xea, 0xd0, 0x28, 0x94, 0x05, 0x21, 0xcb, 0x75, 0x8e,
    0xd6, 0x92, 0x15, 0x07, 0x7f, 0x50, 0xe5, 0xdf, 0xe3, 0x28, 0x0e, 0x28, 0x55, 0xa4, 0xf8, 0x82,
    0xba, 0xdd, 0xd9, 0x7e, 0xf7, 0xee, 0xde, 0xdd, 0xf9, 0x21, 0xdb, 0xb5, 0xa5, 0xa8, 0xe0, 0x91,
    0x14, 0xf6, 0x59, 0x3a, 0xb0, 0x4a, 0xd9, 0x13, 0x29, 0xb6, 0xea, 0xfc, 0x52, 0x83, 0x3e, 0xb6,
    0x25, 0xe8, 0x6f, 0xc1, 0x61, 0xcd, 0x2c, 0xbb, 0x35, 0x20, 0x3f, 0x93, 0xd5, 0x3d, 0x12, 0x91,
    0xfa, 0x6b, 0xd0, 0xf1, 0xa0, 0x64, 0x15, 0xfd, 0x94, 0xb0, 0xaa, 0xca, 0x4f, 0x4c, 0x33, 0x6e,
    0x41, 0x0b, 0x63, 0x05, 0xef, 0x19, 0xf9, 0xe8, 0x6c, 0x86, 0x7a, 0x1c, 0x60, 0x41, 0x06, 0x9b,
    0x9a, 0x4b, 0x57, 0x41, 0x15, 0x8e, 0xfb, 0x14, 0x4c, 0xef, 0xc4, 0x95, 0x8d, 0x21, 0x1c, 0xd7,
    0x66, 0xfa, 0xa6, 0xdc, 0x3d, 0x15, 0x5b, 0xef, 0xbf, 0x63, 0x2b, 0xfd, 0x40, 0x10, 0x8b, 0x71,
    0x99, 0x28, 0xe6, 0x80, 0x41, 0xd1, 0x99, 0x37, 0x26, 0x45, 0x35, 0xb0, 0x1c, 0x94, 0x92, 0x08,
    0xb4, 0x01, 0x9b, 0x4f, 0x08, 0x75, 0x31, 0x19, 0x26, 0x5b, 0x28, 0x5b, 0x82, 0x4b, 0x65, 0x33,
    0x25, 0xdd, 0x30, 0x22, 0x71, 0x49, 0x0c, 0x0a, 0x22, 0x99, 0x5f, 0xdb, 0x26, 0x0c, 0xa4, 0xf5,
    0x56, 0xfc, 0x12, 0x92, 0x60, 0x77, 0x78, 0x24, 0xe5, 0xde, 0x85, 0xae, 0xa5, 0xce, 0x5b, 0x99,
    0xe7, 0x15, 0xf5, 0x91, 0xec, 0x6b, 0xa1, 0xea, 0xe9, 0x1a, 0x7f, 0xcd, 0x0e, 0x99, 0xde, 0xcc,
    0xbf, 0x21, 0xe3, 0x8e, 0x74, 0x39, 0x46, 0xc1, 0xd6, 0x60, 0xb8, 0x16, 0x8d, 0x55, 0x3a, 0x1a,
    0xb2, 0xd3, 0xca, 0x2a, 0xae, 0x64, 0x74, 0x6a, 0x41, 0x8c, 0x5c, 0x32, 0x63, 0x2e, 0x41, 0xb9,
    0xd2, 0x40, 0x8a, 0xee, 0x14, 0xd7, 0xc6, 0x33, 0x6b, 0xae, 0xfe, 0x93, 0xda, 0x61, 0x50, 0xfc,
    0xae, 0x2d, 0x9a, 0x12, 0x04, 0x97, 0x73, 0x7f, 0x7b, 0x3d, 0x2f, 0x29, 0x22, 0x30, 0xa5, 0x5c,
    0x35, 0x2d, 0xa5, 0x43, 0xf0, 0x30, 0x7b, 0xa5, 0xf7, 0x50, 0x51, 0x6a, 0x08, 0x31, 0xd2, 0x03,
    0x42, 0x6d, 0xf4, 0x27, 0x45, 0x29, 0x7c, 0xfd, 0x83, 0xe8, 0x07, 0xd5, 0x1f, 0xe1, 0x9a
};
#endif

PyTypeObject *init_QLowEnergyServiceData(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX].type;

    Shiboken::AutoDecRef Sbk_QLowEnergyServiceData_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QLowEnergyServiceData_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLowEnergyServiceData",
        "QLowEnergyServiceData",
        &Sbk_QLowEnergyServiceData_spec,
        &Shiboken::callCppDestructor< ::QLowEnergyServiceData >,
        Sbk_QLowEnergyServiceData_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QLowEnergyServiceData_TypeF(); // references _Sbk_QLowEnergyServiceData_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QLowEnergyServiceData_SignatureStrings);
#else
    InitSignatureBytes(pyType, QLowEnergyServiceData_SignatureBytes, QLowEnergyServiceData_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLowEnergyServiceData_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_PTR,
        is_QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_PTR_Convertible,
        QLowEnergyServiceData_PTR_CppToPython_QLowEnergyServiceData,
        QLowEnergyServiceData_COPY_CppToPython_QLowEnergyServiceData);

    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyServiceData");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyServiceData*");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyServiceData&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLowEnergyServiceData).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_COPY,
        is_QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QLowEnergyServiceData_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ServiceType'.
    const char *ServiceType_Initializer[] = {
        "ServiceTypePrimary",
        "ServiceTypeSecondary",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t ServiceType_InitializerValues[] = {
        uint16_t(QLowEnergyServiceData::ServiceType::ServiceTypePrimary),  //  0x2800  10240
        uint16_t(QLowEnergyServiceData::ServiceType::ServiceTypeSecondary) //  0x2801  10241
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLowEnergyServiceData_TypeF(),
        "2:PySide6.QtBluetooth.QLowEnergyServiceData.ServiceType",
        ServiceType_Initializer, ServiceType_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_ServiceType_IDX].type = EType;
    // Register converter for enum 'QLowEnergyServiceData::ServiceType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLowEnergyServiceData_ServiceType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLowEnergyServiceData_ServiceType,
            is_Enum_PythonToCpp_QLowEnergyServiceData_ServiceType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLowEnergyServiceData::ServiceType");
        Shiboken::Conversions::registerConverterAlias(converter, "ServiceType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ServiceType' enum.

    qRegisterMetaType< ::QLowEnergyServiceData >("QLowEnergyServiceData");
    qRegisterMetaType< ::QLowEnergyServiceData::ServiceType >("QLowEnergyServiceData::ServiceType");

    return pyType;
}
