// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtconcurrent_python.h"

// main header
#include "qfuturevoid_wrapper.h"

// Argument includes
#include <QString>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFutureVoid_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFutureVoid >()))
        return -1;

    ::QFutureVoid *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QFutureVoid", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QFutureVoid::QFutureVoid()
    // 1: QFutureVoid::QFutureVoid(QFutureVoid)
    if (numArgs == 0) {
        overloadId = 0; // QFutureVoid()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QFutureVoid(QFutureVoid)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QFutureVoid()
        {

            // QFutureVoid()
            cptr = new ::QFutureVoid();
            break;
        }
        case 1: // QFutureVoid(const QFutureVoid &QFutureVoid)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QFutureVoid cppArg0_local;
            ::QFutureVoid *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QFutureVoid(QFutureVoid)
                cptr = new ::QFutureVoid(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QFutureVoid >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QFutureVoidFunc_cancel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cancel()
        cppSelf->cancel();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureVoidFunc_isCanceled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isCanceled()const
        bool cppResult = const_cast<const ::QFutureVoid *>(cppSelf)->isCanceled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureVoidFunc_isFinished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFinished()const
        bool cppResult = const_cast<const ::QFutureVoid *>(cppSelf)->isFinished();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureVoidFunc_isPaused(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QFutureVoid", "isPaused() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // isPaused()const
        bool cppResult = const_cast<const ::QFutureVoid *>(cppSelf)->isPaused();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureVoidFunc_isRunning(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRunning()const
        bool cppResult = const_cast<const ::QFutureVoid *>(cppSelf)->isRunning();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureVoidFunc_isStarted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isStarted()const
        bool cppResult = const_cast<const ::QFutureVoid *>(cppSelf)->isStarted();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureVoidFunc_isSuspended(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSuspended()const
        bool cppResult = const_cast<const ::QFutureVoid *>(cppSelf)->isSuspended();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureVoidFunc_isSuspending(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSuspending()const
        bool cppResult = const_cast<const ::QFutureVoid *>(cppSelf)->isSuspending();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureVoidFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QFutureVoid *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureVoidFunc_pause(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QFutureVoid", "pause()");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // pause()
        cppSelf->pause();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureVoidFunc_progressMaximum(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // progressMaximum()const
        int cppResult = const_cast<const ::QFutureVoid *>(cppSelf)->progressMaximum();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureVoidFunc_progressMinimum(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // progressMinimum()const
        int cppResult = const_cast<const ::QFutureVoid *>(cppSelf)->progressMinimum();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureVoidFunc_progressText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // progressText()const
        QString cppResult = const_cast<const ::QFutureVoid *>(cppSelf)->progressText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureVoidFunc_progressValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // progressValue()const
        int cppResult = const_cast<const ::QFutureVoid *>(cppSelf)->progressValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureVoidFunc_resultCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resultCount()const
        int cppResult = const_cast<const ::QFutureVoid *>(cppSelf)->resultCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureVoidFunc_resume(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resume()
        cppSelf->resume();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureVoidFunc_setPaused(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureVoid::setPaused(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setPaused(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPaused", errInfo, SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QFutureVoid", "setPaused(bool paused)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPaused(bool)
            cppSelf->setPaused(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureVoidFunc_setSuspended(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureVoid::setSuspended(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSuspended(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSuspended", errInfo, SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSuspended(bool)
            cppSelf->setSuspended(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureVoidFunc_suspend(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // suspend()
        cppSelf->suspend();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureVoidFunc_togglePaused(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QFutureVoid", "togglePaused()");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // togglePaused()
        cppSelf->togglePaused();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureVoidFunc_toggleSuspended(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toggleSuspended()
        cppSelf->toggleSuspended();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureVoidFunc_waitForFinished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // waitForFinished()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        cppSelf->waitForFinished();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureVoid__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QFutureVoid_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFutureVoid_methods[] = {
    {"cancel", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_cancel), METH_NOARGS, nullptr},
    {"isCanceled", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_isCanceled), METH_NOARGS, nullptr},
    {"isFinished", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_isFinished), METH_NOARGS, nullptr},
    {"isPaused", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_isPaused), METH_NOARGS, nullptr},
    {"isRunning", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_isRunning), METH_NOARGS, nullptr},
    {"isStarted", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_isStarted), METH_NOARGS, nullptr},
    {"isSuspended", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_isSuspended), METH_NOARGS, nullptr},
    {"isSuspending", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_isSuspending), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_isValid), METH_NOARGS, nullptr},
    {"pause", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_pause), METH_NOARGS, nullptr},
    {"progressMaximum", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_progressMaximum), METH_NOARGS, nullptr},
    {"progressMinimum", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_progressMinimum), METH_NOARGS, nullptr},
    {"progressText", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_progressText), METH_NOARGS, nullptr},
    {"progressValue", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_progressValue), METH_NOARGS, nullptr},
    {"resultCount", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_resultCount), METH_NOARGS, nullptr},
    {"resume", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_resume), METH_NOARGS, nullptr},
    {"setPaused", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_setPaused), METH_O, nullptr},
    {"setSuspended", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_setSuspended), METH_O, nullptr},
    {"suspend", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_suspend), METH_NOARGS, nullptr},
    {"togglePaused", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_togglePaused), METH_NOARGS, nullptr},
    {"toggleSuspended", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_toggleSuspended), METH_NOARGS, nullptr},
    {"waitForFinished", reinterpret_cast<PyCFunction>(Sbk_QFutureVoidFunc_waitForFinished), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QFutureVoid__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QFutureVoid_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFutureVoid_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFutureVoid_Type = nullptr;
static PyTypeObject *Sbk_QFutureVoid_TypeF(void)
{
    return _Sbk_QFutureVoid_Type;
}

static PyType_Slot Sbk_QFutureVoid_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFutureVoid_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFutureVoid_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFutureVoid_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFutureVoid_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFutureVoid_spec = {
    "2:PySide6.QtConcurrent.QFutureVoid",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFutureVoid_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFutureVoid_PythonToCpp_QFutureVoid_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFutureVoid_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFutureVoid_PythonToCpp_QFutureVoid_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFutureVoid_TypeF()))
        return QFutureVoid_PythonToCpp_QFutureVoid_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFutureVoid_PTR_CppToPython_QFutureVoid(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QFutureVoid_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QFutureVoid_COPY_CppToPython_QFutureVoid(const void *cppIn)
{
    auto *source = reinterpret_cast<const QFutureVoid *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QFutureVoid_TypeF(), new ::QFutureVoid(*source), true, true);
}

// Python to C++ copy conversion.
static void QFutureVoid_PythonToCpp_QFutureVoid_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<QFutureVoid *>(cppOut) = *reinterpret_cast< ::QFutureVoid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QFutureVoid_PythonToCpp_QFutureVoid_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QFutureVoid_TypeF()))
        return QFutureVoid_PythonToCpp_QFutureVoid_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFutureVoid_SignatureStrings[] = {
    "1:PySide6.QtConcurrent.QFutureVoid(self)",
    "0:PySide6.QtConcurrent.QFutureVoid(self,QFutureVoid:PySide6.QtConcurrent.QFutureVoid)",
    "PySide6.QtConcurrent.QFutureVoid.cancel(self)",
    "PySide6.QtConcurrent.QFutureVoid.isCanceled(self)->bool",
    "PySide6.QtConcurrent.QFutureVoid.isFinished(self)->bool",
    "PySide6.QtConcurrent.QFutureVoid.isPaused(self)->bool",
    "PySide6.QtConcurrent.QFutureVoid.isRunning(self)->bool",
    "PySide6.QtConcurrent.QFutureVoid.isStarted(self)->bool",
    "PySide6.QtConcurrent.QFutureVoid.isSuspended(self)->bool",
    "PySide6.QtConcurrent.QFutureVoid.isSuspending(self)->bool",
    "PySide6.QtConcurrent.QFutureVoid.isValid(self)->bool",
    "PySide6.QtConcurrent.QFutureVoid.pause(self)",
    "PySide6.QtConcurrent.QFutureVoid.progressMaximum(self)->int",
    "PySide6.QtConcurrent.QFutureVoid.progressMinimum(self)->int",
    "PySide6.QtConcurrent.QFutureVoid.progressText(self)->QString",
    "PySide6.QtConcurrent.QFutureVoid.progressValue(self)->int",
    "PySide6.QtConcurrent.QFutureVoid.resultCount(self)->int",
    "PySide6.QtConcurrent.QFutureVoid.resume(self)",
    "PySide6.QtConcurrent.QFutureVoid.setPaused(self,paused:bool)",
    "PySide6.QtConcurrent.QFutureVoid.setSuspended(self,suspend:bool)",
    "PySide6.QtConcurrent.QFutureVoid.suspend(self)",
    "PySide6.QtConcurrent.QFutureVoid.togglePaused(self)",
    "PySide6.QtConcurrent.QFutureVoid.toggleSuspended(self)",
    "PySide6.QtConcurrent.QFutureVoid.waitForFinished(self)",
    "PySide6.QtConcurrent.QFutureVoid.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QFutureVoid_SignatureByteSize = 263;
static constexpr uint8_t QFutureVoid_SignatureBytes[263] = {
    0x78, 0xda, 0x9d, 0x94, 0x4d, 0x6f, 0xc3, 0x20, 0x0c, 0x86, 0xef, 0xf9, 0x25, 0xab, 0x94, 0x45,
    0xdb, 0xa5, 0x87, 0x1e, 0x76, 0xa9, 0x94, 0xdb, 0xa4, 0xa6, 0x4c, 0xbd, 0x46, 0x2c, 0xf1, 0x32,
    0x24, 0x62, 0x10, 0xd8, 0x6a, 0xf3, 0xef, 0x47, 0x3f, 0x22, 0xa5, 0xbb, 0x00, 0x39, 0x1a, 0xde,
    0x07, 0x5b, 0x7e, 0x6d, 0xde, 0x77, 0x87, 0x49, 0xa8, 0x1e, 0xb6, 0x55, 0x43, 0x7b, 0x83, 0x1d,
    0x3b, 0x07, 0x48, 0x55, 0x53, 0x33, 0xb1, 0x83, 0x93, 0x51, 0xfd, 0x8b, 0x07, 0xfd, 0xb3, 0x29,
    0xde, 0xd2, 0x84, 0xe5, 0xe2, 0x20, 0x4a, 0x6c, 0x8a, 0x98, 0xa2, 0xea, 0x24, 0x76, 0xa0, 0x1f,
    0x35, 0x44, 0xd5, 0xca, 0xef, 0x6f, 0x7a, 0x78, 0x54, 0xfd, 0xfa, 0xf1, 0x6d, 0x8c, 0x4e, 0xe1,
    0x6a, 0x85, 0xca, 0xff, 0xe6, 0x73, 0x07, 0xc9, 0x3e, 0x9f, 0x3a, 0x32, 0xa2, 0xc2, 0x21, 0x17,
    0x13, 0x24, 0x1d, 0xe5, 0x67, 0x13, 0xec, 0x2d, 0x60, 0xbf, 0x1a, 0x5c, 0x51, 0xe9, 0x49, 0x6a,
    0x95, 0x99, 0xce, 0x5e, 0x3b, 0x99, 0x6a, 0xb4, 0x75, 0x66, 0x70, 0xe0, 0xfd, 0xa7, 0xbc, 0xa8,
    0x91, 0xc7, 0x39, 0x93, 0x42, 0xca, 0x60, 0x83, 0xe5, 0x6b, 0xd9, 0x2f, 0xb8, 0xd0, 0x0c, 0x36,
    0x82, 0x5c, 0x68, 0x51, 0x3a, 0x1c, 0x9a, 0xc3, 0x90, 0x95, 0x36, 0x50, 0xac, 0xc3, 0x25, 0x23,
    0x65, 0x73, 0x63, 0x72, 0x53, 0x3d, 0xd0, 0x62, 0x9c, 0xcb, 0x9b, 0x21, 0xfd, 0xee, 0xea, 0x5e,
    0x1a, 0xfc, 0x3c, 0x67, 0xa5, 0xbf, 0x87, 0xc9, 0x0f, 0xdc, 0xe5, 0xa9, 0xc5, 0x92, 0x19, 0x06,
    0x0d, 0xcb, 0xf5, 0x4b, 0x65, 0xfe, 0xad, 0x43, 0x1c, 0x3b, 0x4b, 0x45, 0xb5, 0x71, 0xcf, 0x5f,
    0x44, 0x1c, 0x6b, 0xdb, 0xce, 0xd8, 0xa9, 0x6d, 0x67, 0xc7, 0x68, 0xb2, 0x61, 0x4c, 0x2a, 0x11,
    0xa2, 0xe2, 0x0f, 0xf9, 0x04, 0x03, 0x2c
};
#endif

PyTypeObject *init_QFutureVoid(PyObject *module)
{
    if (SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX].type != nullptr)
        return SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX].type;

    Shiboken::AutoDecRef Sbk_QFutureVoid_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QFutureVoid_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFutureVoid",
        "QFutureVoid",
        &Sbk_QFutureVoid_spec,
        &Shiboken::callCppDestructor< ::QFutureVoid >,
        Sbk_QFutureVoid_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QFutureVoid_TypeF(); // references _Sbk_QFutureVoid_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFutureVoid_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFutureVoid_SignatureBytes, QFutureVoid_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFutureVoid_PropertyStrings);
    SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureVoid_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFutureVoid_PythonToCpp_QFutureVoid_PTR,
        is_QFutureVoid_PythonToCpp_QFutureVoid_PTR_Convertible,
        QFutureVoid_PTR_CppToPython_QFutureVoid,
        QFutureVoid_COPY_CppToPython_QFutureVoid);

    Shiboken::Conversions::registerConverterName(converter, "QFutureVoid");
    Shiboken::Conversions::registerConverterName(converter, "QFutureVoid*");
    Shiboken::Conversions::registerConverterName(converter, "QFutureVoid&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFutureVoid).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QFutureVoid_PythonToCpp_QFutureVoid_COPY,
        is_QFutureVoid_PythonToCpp_QFutureVoid_COPY_Convertible);

    qRegisterMetaType< ::QFutureVoid >("QFutureVoid");

    return pyType;
}
