// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qabstractnativeeventfilter_wrapper.h"

// Argument includes
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstractNativeEventFilterWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstractNativeEventFilterWrapper::QAbstractNativeEventFilterWrapper()
{
}

bool QAbstractNativeEventFilterWrapper::nativeEventFilter(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractNativeEventFilter.nativeEventFilter");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "nativeEventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractNativeEventFilter.nativeEventFilter");
        return false;
    }

    SBK_UNUSED(result)
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &eventType),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), message)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractNativeEventFilter", funcName);
        return false;
    }
    // Begin code injection
    // TEMPLATE - return_native_eventfilter_conversion - START
    bool cppResult = false;
    if (PySequence_Check(pyResult.object()) && (PySequence_Size(pyResult.object()) == 2)) {
        Shiboken::AutoDecRef pyItem(PySequence_GetItem(pyResult.object(), 0));
        Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyItem, &(cppResult));
        if (result) {
            Shiboken::AutoDecRef pyResultItem(PySequence_GetItem(pyResult, 1));
            Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<long>(), pyResultItem, (result));
        }
    }
    // TEMPLATE - return_native_eventfilter_conversion - END
    // End of code injection


    return cppResult;
}

QAbstractNativeEventFilterWrapper::~QAbstractNativeEventFilterWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractNativeEventFilter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractNativeEventFilter_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QAbstractNativeEventFilter");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAbstractNativeEventFilter >()))
        return -1;

    QAbstractNativeEventFilterWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QAbstractNativeEventFilter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QAbstractNativeEventFilter()
        cptr = new QAbstractNativeEventFilterWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAbstractNativeEventFilter >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAbstractNativeEventFilterFunc_nativeEventFilter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractNativeEventFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractNativeEventFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "nativeEventFilter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractNativeEventFilter::nativeEventFilter(QByteArray,void*,qintptr*)->PyObject
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
        overloadId = 0; // nativeEventFilter(QByteArray,void*,qintptr*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "nativeEventFilter", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QAbstractNativeEventFilter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        void* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // nativeEventFilter(QByteArray,void*,qintptr*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractNativeEventFilter.nativeEventFilter");
                return {};
            }
            // Begin code injection
            // TEMPLATE - return_native_eventfilter_conversion_variables - START
            qintptr resultVar{0};
            qintptr *result_out = &resultVar;
            // TEMPLATE - return_native_eventfilter_conversion_variables - END
            // End of code injection

            bool cppResult = cppSelf->nativeEventFilter(*cppArg0, cppArg1, result_out);
            // Begin code injection
            // TEMPLATE - return_native_eventfilter - START
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<long>(), &*result_out));
            // TEMPLATE - return_native_eventfilter - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAbstractNativeEventFilter_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractNativeEventFilter_methods[] = {
    {"nativeEventFilter", reinterpret_cast<PyCFunction>(Sbk_QAbstractNativeEventFilterFunc_nativeEventFilter), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractNativeEventFilter_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstractNativeEventFilter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractNativeEventFilter_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractNativeEventFilterWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractNativeEventFilter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractNativeEventFilter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractNativeEventFilter_Type = nullptr;
static PyTypeObject *Sbk_QAbstractNativeEventFilter_TypeF(void)
{
    return _Sbk_QAbstractNativeEventFilter_Type;
}

static PyType_Slot Sbk_QAbstractNativeEventFilter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractNativeEventFilter_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractNativeEventFilter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractNativeEventFilter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractNativeEventFilter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractNativeEventFilter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractNativeEventFilter_spec = {
    "2:PySide6.QtCore.QAbstractNativeEventFilter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractNativeEventFilter_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractNativeEventFilter_PythonToCpp_QAbstractNativeEventFilter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractNativeEventFilter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractNativeEventFilter_PythonToCpp_QAbstractNativeEventFilter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractNativeEventFilter_TypeF()))
        return QAbstractNativeEventFilter_PythonToCpp_QAbstractNativeEventFilter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractNativeEventFilter_PTR_CppToPython_QAbstractNativeEventFilter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QAbstractNativeEventFilter *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QAbstractNativeEventFilter_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstractNativeEventFilter_SignatureStrings[] = {
    "PySide6.QtCore.QAbstractNativeEventFilter(self)",
    "PySide6.QtCore.QAbstractNativeEventFilter.nativeEventFilter(self,eventType:typing.Union[PySide6.QtCore.QByteArray, char*],message:void)->PyObject",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstractNativeEventFilter_SignatureByteSize = 130;
static constexpr uint8_t QAbstractNativeEventFilter_SignatureBytes[130] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce, 0x2f, 0x4a,
    0xd5, 0x0b, 0x74, 0x4c, 0x2a, 0x2e, 0x29, 0x4a, 0x4c, 0x2e, 0xf1, 0x4b, 0x2c, 0xc9, 0x2c, 0x4b,
    0x75, 0x2d, 0x4b, 0xcd, 0x2b, 0x71, 0xcb, 0xcc, 0x29, 0x49, 0x2d, 0xd2, 0x28, 0x4e, 0xcd, 0x49,
    0xd3, 0xe4, 0x0a, 0x20, 0x56, 0xbd, 0x5e, 0x1e, 0x56, 0x13, 0x74, 0x52, 0x41, 0x02, 0x21, 0x95,
    0x05, 0xa9, 0x56, 0x25, 0x95, 0x05, 0x99, 0x79, 0xe9, 0x7a, 0xa1, 0x79, 0x99, 0xf9, 0x79, 0xd1,
    0xe8, 0xe6, 0x3a, 0x55, 0x96, 0xa4, 0x3a, 0x16, 0x15, 0x25, 0x56, 0xea, 0x28, 0x24, 0x67, 0x24,
    0x16, 0x69, 0xc5, 0xea, 0xe4, 0xa6, 0x16, 0x17, 0x27, 0xa6, 0xa7, 0x5a, 0x95, 0xe5, 0x67, 0xa6,
    0x68, 0xea, 0xda, 0x05, 0x54, 0xfa, 0x27, 0x65, 0xa5, 0x26, 0x97, 0x70, 0x01, 0x00, 0x78, 0xd9,
    0x47, 0x8e
};
#endif

PyTypeObject *init_QAbstractNativeEventFilter(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QAbstractNativeEventFilter_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QAbstractNativeEventFilter_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractNativeEventFilter_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAbstractNativeEventFilter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractNativeEventFilter",
        "QAbstractNativeEventFilter*",
        &Sbk_QAbstractNativeEventFilter_spec,
        &Shiboken::callCppDestructor< QAbstractNativeEventFilter >,
        Sbk_QAbstractNativeEventFilter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAbstractNativeEventFilter_TypeF(); // references _Sbk_QAbstractNativeEventFilter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstractNativeEventFilter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstractNativeEventFilter_SignatureBytes, QAbstractNativeEventFilter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractNativeEventFilter_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QAbstractNativeEventFilter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractNativeEventFilter_PythonToCpp_QAbstractNativeEventFilter_PTR,
        is_QAbstractNativeEventFilter_PythonToCpp_QAbstractNativeEventFilter_PTR_Convertible,
        QAbstractNativeEventFilter_PTR_CppToPython_QAbstractNativeEventFilter);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractNativeEventFilter");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractNativeEventFilter*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractNativeEventFilter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractNativeEventFilter).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractNativeEventFilterWrapper).name());

    qRegisterMetaType< ::QAbstractNativeEventFilter *>();

    return pyType;
}
