// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qbasicmutex_wrapper.h"

// Argument includes
#include <qdeadlinetimer.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBasicMutex_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBasicMutex >()))
        return -1;

    ::QBasicMutex *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QBasicMutex_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QBasicMutex()
        cptr = new ::QBasicMutex();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QBasicMutex >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QBasicMutexFunc_lock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBasicMutex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBasicMutex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lock()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        cppSelf->lock();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBasicMutexFunc_tryLock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBasicMutex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBasicMutex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tryLock()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = cppSelf->tryLock();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBasicMutexFunc_try_lock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBasicMutex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBasicMutex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // try_lock()
        bool cppResult = cppSelf->try_lock();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBasicMutexFunc_unlock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBasicMutex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBasicMutex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unlock()
        cppSelf->unlock();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QBasicMutex_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBasicMutex_methods[] = {
    {"lock", reinterpret_cast<PyCFunction>(Sbk_QBasicMutexFunc_lock), METH_NOARGS, nullptr},
    {"tryLock", reinterpret_cast<PyCFunction>(Sbk_QBasicMutexFunc_tryLock), METH_NOARGS, nullptr},
    {"try_lock", reinterpret_cast<PyCFunction>(Sbk_QBasicMutexFunc_try_lock), METH_NOARGS, nullptr},
    {"unlock", reinterpret_cast<PyCFunction>(Sbk_QBasicMutexFunc_unlock), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QBasicMutex_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBasicMutex_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBasicMutex_Type = nullptr;
static PyTypeObject *Sbk_QBasicMutex_TypeF(void)
{
    return _Sbk_QBasicMutex_Type;
}

static PyType_Slot Sbk_QBasicMutex_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBasicMutex_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBasicMutex_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBasicMutex_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBasicMutex_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBasicMutex_spec = {
    "2:PySide6.QtCore.QBasicMutex",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBasicMutex_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBasicMutex_PythonToCpp_QBasicMutex_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBasicMutex_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBasicMutex_PythonToCpp_QBasicMutex_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBasicMutex_TypeF()))
        return QBasicMutex_PythonToCpp_QBasicMutex_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBasicMutex_PTR_CppToPython_QBasicMutex(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QBasicMutex_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBasicMutex_SignatureStrings[] = {
    "PySide6.QtCore.QBasicMutex(self)",
    "PySide6.QtCore.QBasicMutex.lock(self)",
    "PySide6.QtCore.QBasicMutex.tryLock(self)->bool",
    "PySide6.QtCore.QBasicMutex.try_lock(self)->bool",
    "PySide6.QtCore.QBasicMutex.unlock(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QBasicMutex_SignatureByteSize = 74;
static constexpr uint8_t QBasicMutex_SignatureBytes[74] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce, 0x2f, 0x4a,
    0xd5, 0x0b, 0x74, 0x4a, 0x2c, 0xce, 0x4c, 0xf6, 0x2d, 0x2d, 0x49, 0xad, 0xd0, 0x28, 0x4e, 0xcd,
    0x49, 0xd3, 0xe4, 0x0a, 0xc0, 0xa9, 0x40, 0x2f, 0x27, 0x3f, 0x39, 0x9b, 0xb0, 0xaa, 0x92, 0xa2,
    0x4a, 0x1f, 0xb8, 0x42, 0x5d, 0xbb, 0xa4, 0xfc, 0xfc, 0x1c, 0x02, 0xca, 0xe3, 0x73, 0x48, 0x50,
    0x5f, 0x9a, 0x87, 0xe4, 0x0c, 0x00, 0x61, 0x7e, 0x48, 0xc8
};
#endif

PyTypeObject *init_QBasicMutex(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QBasicMutex_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QBasicMutex_IDX].type;

    Shiboken::AutoDecRef Sbk_QBasicMutex_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QBasicMutex_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBasicMutex",
        "QBasicMutex*",
        &Sbk_QBasicMutex_spec,
        &Shiboken::callCppDestructor< ::QBasicMutex >,
        Sbk_QBasicMutex_Type_bases.object(),
        0);
    auto *pyType = Sbk_QBasicMutex_TypeF(); // references _Sbk_QBasicMutex_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBasicMutex_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBasicMutex_SignatureBytes, QBasicMutex_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBasicMutex_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QBasicMutex_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBasicMutex_PythonToCpp_QBasicMutex_PTR,
        is_QBasicMutex_PythonToCpp_QBasicMutex_PTR_Convertible,
        QBasicMutex_PTR_CppToPython_QBasicMutex);

    Shiboken::Conversions::registerConverterName(converter, "QBasicMutex");
    Shiboken::Conversions::registerConverterName(converter, "QBasicMutex*");
    Shiboken::Conversions::registerConverterName(converter, "QBasicMutex&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBasicMutex).name());

    qRegisterMetaType< ::QBasicMutex *>();

    return pyType;
}
