// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qbasictimer_wrapper.h"

// Argument includes
#include <qbasictimer.h>
#include <qnamespace.h>
#include <qobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBasicTimer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBasicTimer >()))
        return -1;

    ::QBasicTimer *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QBasicTimer_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QBasicTimer()
        cptr = new ::QBasicTimer();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QBasicTimer >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QBasicTimerFunc_id(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBasicTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBasicTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // id()const
        Qt::TimerId cppResult = const_cast<const ::QBasicTimer *>(cppSelf)->id();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerId_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBasicTimerFunc_isActive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBasicTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBasicTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isActive()const
        bool cppResult = const_cast<const ::QBasicTimer *>(cppSelf)->isActive();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBasicTimerFunc_start(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBasicTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBasicTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "start", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBasicTimer::start(int,QObject*)
    // 1: QBasicTimer::start(int,Qt::TimerType,QObject*)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))) {
            overloadId = 1; // start(int,Qt::TimerType,QObject*)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // start(int,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QBasicTimer_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // start(int msec, QObject *obj)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // start(int,QObject*)
                cppSelf->start(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // start(int msec, Qt::TimerType timerType, QObject *obj)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::TimerType cppArg1{Qt::PreciseTimer};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // start(int,Qt::TimerType,QObject*)
                cppSelf->start(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBasicTimerFunc_stop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBasicTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBasicTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stop()
        cppSelf->stop();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBasicTimerFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBasicTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBasicTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBasicTimer::swap(QBasicTimer&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBasicTimer_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QBasicTimer&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QBasicTimer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBasicTimer *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QBasicTimer&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBasicTimerFunc_timerId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBasicTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBasicTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // timerId()const
        int cppResult = const_cast<const ::QBasicTimer *>(cppSelf)->timerId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QBasicTimer_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBasicTimer_methods[] = {
    {"id", reinterpret_cast<PyCFunction>(Sbk_QBasicTimerFunc_id), METH_NOARGS, nullptr},
    {"isActive", reinterpret_cast<PyCFunction>(Sbk_QBasicTimerFunc_isActive), METH_NOARGS, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QBasicTimerFunc_start), METH_VARARGS, nullptr},
    {"stop", reinterpret_cast<PyCFunction>(Sbk_QBasicTimerFunc_stop), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QBasicTimerFunc_swap), METH_O, nullptr},
    {"timerId", reinterpret_cast<PyCFunction>(Sbk_QBasicTimerFunc_timerId), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QBasicTimer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBasicTimer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBasicTimer_Type = nullptr;
static PyTypeObject *Sbk_QBasicTimer_TypeF(void)
{
    return _Sbk_QBasicTimer_Type;
}

static PyType_Slot Sbk_QBasicTimer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBasicTimer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBasicTimer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBasicTimer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBasicTimer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBasicTimer_spec = {
    "2:PySide6.QtCore.QBasicTimer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBasicTimer_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBasicTimer_PythonToCpp_QBasicTimer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBasicTimer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBasicTimer_PythonToCpp_QBasicTimer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBasicTimer_TypeF()))
        return QBasicTimer_PythonToCpp_QBasicTimer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBasicTimer_PTR_CppToPython_QBasicTimer(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QBasicTimer_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBasicTimer_SignatureStrings[] = {
    "PySide6.QtCore.QBasicTimer(self)",
    "PySide6.QtCore.QBasicTimer.id(self)->PySide6.QtCore.Qt.TimerId",
    "PySide6.QtCore.QBasicTimer.isActive(self)->bool",
    "1:PySide6.QtCore.QBasicTimer.start(self,msec:int,obj:PySide6.QtCore.QObject)",
    "0:PySide6.QtCore.QBasicTimer.start(self,msec:int,timerType:PySide6.QtCore.Qt.TimerType,obj:PySide6.QtCore.QObject)",
    "PySide6.QtCore.QBasicTimer.stop(self)",
    "PySide6.QtCore.QBasicTimer.swap(self,other:PySide6.QtCore.QBasicTimer)",
    "PySide6.QtCore.QBasicTimer.timerId(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QBasicTimer_SignatureByteSize = 158;
static constexpr uint8_t QBasicTimer_SignatureBytes[158] = {
    0x78, 0xda, 0x95, 0x90, 0xc1, 0x0a, 0xc2, 0x30, 0x10, 0x44, 0xef, 0xf9, 0x12, 0x0b, 0x31, 0xe8,
    0xc5, 0x43, 0x0e, 0x82, 0x7a, 0xf2, 0x64, 0x8b, 0xfd, 0x81, 0x24, 0x5d, 0x31, 0xa5, 0xed, 0x96,
    0xec, 0xa2, 0xf4, 0xef, 0xb5, 0x0d, 0xbd, 0x28, 0x8d, 0x78, 0x9e, 0x37, 0x33, 0xcc, 0xe4, 0xc3,
    0xd5, 0x57, 0xb0, 0x53, 0x05, 0x9f, 0x30, 0x80, 0x2a, 0x8e, 0x86, 0xbc, 0x2b, 0x7d, 0x0b, 0x61,
    0x45, 0xd0, 0xdc, 0x32, 0x91, 0x2f, 0x02, 0xca, 0x57, 0x91, 0x59, 0xef, 0x3f, 0x21, 0x56, 0x13,
    0x71, 0xae, 0x92, 0x76, 0x3a, 0x38, 0xf6, 0x0f, 0x98, 0x43, 0x2c, 0x62, 0x23, 0xb6, 0x3a, 0xe1,
    0x20, 0x36, 0x81, 0x27, 0x5c, 0xb6, 0x04, 0x4e, 0xfb, 0x8e, 0x25, 0xda, 0xfa, 0xcb, 0x72, 0xb1,
    0x35, 0x38, 0xce, 0xc4, 0xe6, 0xdf, 0x30, 0x1e, 0x95, 0x72, 0xe8, 0x41, 0x2f, 0x2c, 0x1a, 0xb5,
    0x64, 0x65, 0xb2, 0x10, 0xfb, 0xdf, 0xa7, 0xd2, 0xd3, 0x44, 0x4a, 0x22, 0xdf, 0x21, 0x24, 0x16,
    0x24, 0x63, 0x38, 0xfe, 0x3f, 0x7f, 0xfb, 0x1e, 0x27, 0x5e, 0x51, 0xa5, 0xac, 0x7e
};
#endif

PyTypeObject *init_QBasicTimer(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QBasicTimer_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QBasicTimer_IDX].type;

    Shiboken::AutoDecRef Sbk_QBasicTimer_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QBasicTimer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBasicTimer",
        "QBasicTimer*",
        &Sbk_QBasicTimer_spec,
        &Shiboken::callCppDestructor< ::QBasicTimer >,
        Sbk_QBasicTimer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QBasicTimer_TypeF(); // references _Sbk_QBasicTimer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBasicTimer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBasicTimer_SignatureBytes, QBasicTimer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBasicTimer_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QBasicTimer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBasicTimer_PythonToCpp_QBasicTimer_PTR,
        is_QBasicTimer_PythonToCpp_QBasicTimer_PTR_Convertible,
        QBasicTimer_PTR_CppToPython_QBasicTimer);

    Shiboken::Conversions::registerConverterName(converter, "QBasicTimer");
    Shiboken::Conversions::registerConverterName(converter, "QBasicTimer*");
    Shiboken::Conversions::registerConverterName(converter, "QBasicTimer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBasicTimer).name());

    qRegisterMetaType< ::QBasicTimer *>();

    return pyType;
}
