// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qbluetoothpermission_wrapper.h"

// Argument includes
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpermissions.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBluetoothPermission_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBluetoothPermission >()))
        return -1;

    ::QBluetoothPermission *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QBluetoothPermission", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBluetoothPermission::QBluetoothPermission()
    // 1: QBluetoothPermission::QBluetoothPermission(QBluetoothPermission)
    if (numArgs == 0) {
        overloadId = 0; // QBluetoothPermission()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QBluetoothPermission(QBluetoothPermission)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QBluetoothPermission()
        {

            // QBluetoothPermission()
            cptr = new ::QBluetoothPermission();
            break;
        }
        case 1: // QBluetoothPermission(const QBluetoothPermission &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBluetoothPermission cppArg0_local;
            ::QBluetoothPermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothPermission(QBluetoothPermission)
                cptr = new ::QBluetoothPermission(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QBluetoothPermission >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QBluetoothPermissionFunc_communicationModes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // communicationModes()const
        QFlags<QBluetoothPermission::CommunicationMode> cppResult = const_cast<const ::QBluetoothPermission *>(cppSelf)->communicationModes();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QBluetoothPermission_CommunicationMode_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothPermissionFunc_setCommunicationModes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothPermission::setCommunicationModes(QFlags<QBluetoothPermission::CommunicationMode>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QBluetoothPermission_CommunicationMode_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setCommunicationModes(QFlags<QBluetoothPermission::CommunicationMode>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCommunicationModes", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX]);

    // Call function/method
    {
        ::QFlags<QBluetoothPermission::CommunicationMode> cppArg0 = QFlags<QBluetoothPermission::CommunicationMode>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCommunicationModes(QFlags<QBluetoothPermission::CommunicationMode>)
            cppSelf->setCommunicationModes(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothPermissionFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothPermission::swap(QBluetoothPermission&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QBluetoothPermission&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBluetoothPermission cppArg0_local;
        ::QBluetoothPermission *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QBluetoothPermission&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothPermission__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QBluetoothPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QBluetoothPermission_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QBluetoothPermission_EnumFlagInfo[] = {
    "CommunicationMode:Flag:CommunicationModes",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBluetoothPermission_methods[] = {
    {"communicationModes", reinterpret_cast<PyCFunction>(Sbk_QBluetoothPermissionFunc_communicationModes), METH_NOARGS, nullptr},
    {"setCommunicationModes", reinterpret_cast<PyCFunction>(Sbk_QBluetoothPermissionFunc_setCommunicationModes), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QBluetoothPermissionFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QBluetoothPermission__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QBluetoothPermission_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBluetoothPermission_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBluetoothPermission_Type = nullptr;
static PyTypeObject *Sbk_QBluetoothPermission_TypeF(void)
{
    return _Sbk_QBluetoothPermission_Type;
}

static PyType_Slot Sbk_QBluetoothPermission_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBluetoothPermission_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBluetoothPermission_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBluetoothPermission_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBluetoothPermission_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBluetoothPermission_spec = {
    "2:PySide6.QtCore.QBluetoothPermission",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBluetoothPermission_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QBluetoothPermission_CommunicationMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothPermission::CommunicationMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothPermission::CommunicationMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBluetoothPermission_CommunicationMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_CommunicationMode_IDX])))
        return Enum_PythonToCpp_QBluetoothPermission_CommunicationMode;
    return {};
}

static PyObject *QBluetoothPermission_CommunicationMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBluetoothPermission::CommunicationMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBluetoothPermission::CommunicationMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_CommunicationMode_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QBluetoothPermission_CommunicationMode(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QBluetoothPermission::CommunicationMode>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QBluetoothPermission::CommunicationMode> *>(cppOut) = value;

}

static PyObject *QBluetoothPermission_CommunicationMode_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QBluetoothPermission::CommunicationMode> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_CommunicationMode_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBluetoothPermission_PythonToCpp_QBluetoothPermission_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBluetoothPermission_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBluetoothPermission_PythonToCpp_QBluetoothPermission_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBluetoothPermission_TypeF()))
        return QBluetoothPermission_PythonToCpp_QBluetoothPermission_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBluetoothPermission_PTR_CppToPython_QBluetoothPermission(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QBluetoothPermission_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QBluetoothPermission_COPY_CppToPython_QBluetoothPermission(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QBluetoothPermission *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QBluetoothPermission_TypeF(), new ::QBluetoothPermission(*source), true, true);
}

// Python to C++ copy conversion.
static void QBluetoothPermission_PythonToCpp_QBluetoothPermission_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QBluetoothPermission *>(cppOut) = *reinterpret_cast< ::QBluetoothPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QBluetoothPermission_PythonToCpp_QBluetoothPermission_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QBluetoothPermission_TypeF()))
        return QBluetoothPermission_PythonToCpp_QBluetoothPermission_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBluetoothPermission_SignatureStrings[] = {
    "1:PySide6.QtCore.QBluetoothPermission(self)",
    "0:PySide6.QtCore.QBluetoothPermission(self,other:PySide6.QtCore.QBluetoothPermission)",
    "PySide6.QtCore.QBluetoothPermission.communicationModes(self)->PySide6.QtCore.QBluetoothPermission.CommunicationMode",
    "PySide6.QtCore.QBluetoothPermission.setCommunicationModes(self,modes:PySide6.QtCore.QBluetoothPermission.CommunicationMode)",
    "PySide6.QtCore.QBluetoothPermission.swap(self,other:PySide6.QtCore.QBluetoothPermission)",
    "PySide6.QtCore.QBluetoothPermission.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QBluetoothPermission_SignatureByteSize = 141;
static constexpr uint8_t QBluetoothPermission_SignatureBytes[141] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0x74, 0xca, 0x29, 0x4d, 0x2d, 0xc9, 0xcf, 0x2f, 0xc9, 0x08, 0x48, 0x2d,
    0xca, 0xcd, 0x2c, 0x2e, 0xce, 0xcc, 0xcf, 0xd3, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x20,
    0x5a, 0xad, 0x0e, 0x50, 0x28, 0xb5, 0x88, 0x18, 0xe5, 0x9a, 0x5c, 0x44, 0x28, 0xd2, 0x4b, 0xce,
    0xcf, 0xcd, 0x2d, 0xcd, 0xcb, 0x4c, 0x4e, 0x2c, 0x01, 0xf2, 0x7c, 0xf3, 0x53, 0x52, 0x8b, 0x21,
    0x4e, 0xd2, 0xb5, 0x23, 0x46, 0xb7, 0x33, 0xba, 0x6e, 0xa2, 0xec, 0x2c, 0x4e, 0x2d, 0x71, 0xc6,
    0x6e, 0xad, 0x4e, 0x2e, 0x88, 0x69, 0x45, 0x96, 0xd5, 0xc4, 0xf9, 0xb7, 0xb8, 0x3c, 0xb1, 0x80,
    0x26, 0x01, 0x19, 0x1f, 0x9f, 0x9c, 0x5f, 0x50, 0x19, 0x1f, 0x0f, 0x0b, 0xbe, 0x92, 0xca, 0x82,
    0xcc, 0xbc, 0x74, 0xbd, 0x60, 0x20, 0x8f, 0x0b, 0x00, 0x2d, 0x5a, 0xc3, 0x1b
};
#endif

PyTypeObject *init_QBluetoothPermission(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX].type;

    Shiboken::AutoDecRef Sbk_QBluetoothPermission_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QBluetoothPermission_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBluetoothPermission",
        "QBluetoothPermission",
        &Sbk_QBluetoothPermission_spec,
        &Shiboken::callCppDestructor< ::QBluetoothPermission >,
        Sbk_QBluetoothPermission_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QBluetoothPermission_TypeF(); // references _Sbk_QBluetoothPermission_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBluetoothPermission_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBluetoothPermission_SignatureBytes, QBluetoothPermission_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBluetoothPermission_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBluetoothPermission_PythonToCpp_QBluetoothPermission_PTR,
        is_QBluetoothPermission_PythonToCpp_QBluetoothPermission_PTR_Convertible,
        QBluetoothPermission_PTR_CppToPython_QBluetoothPermission,
        QBluetoothPermission_COPY_CppToPython_QBluetoothPermission);

    Shiboken::Conversions::registerConverterName(converter, "QBluetoothPermission");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothPermission*");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothPermission&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBluetoothPermission).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QBluetoothPermission_PythonToCpp_QBluetoothPermission_COPY,
        is_QBluetoothPermission_PythonToCpp_QBluetoothPermission_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QBluetoothPermission_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'CommunicationMode'.
    const char *CommunicationMode_Initializer[] = {
        "Access",
        "Advertise",
        "Default",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t CommunicationMode_InitializerValues[] = {
        uint8_t(QBluetoothPermission::CommunicationMode::Access),    //  0x01  1
        uint8_t(QBluetoothPermission::CommunicationMode::Advertise), //  0x02  2
        uint8_t(QBluetoothPermission::CommunicationMode::Default)    //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothPermission_TypeF(),
        "2:PySide6.QtCore.QBluetoothPermission.CommunicationMode",
        CommunicationMode_Initializer, CommunicationMode_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_CommunicationMode_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QBluetoothPermission_CommunicationMode_IDX].type =
        EType;
    // Register converter for enum 'QBluetoothPermission::CommunicationMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothPermission_CommunicationMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBluetoothPermission_CommunicationMode,
            is_Enum_PythonToCpp_QBluetoothPermission_CommunicationMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothPermission::CommunicationMode");
        Shiboken::Conversions::registerConverterAlias(converter, "CommunicationMode");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QBluetoothPermission_CommunicationMode_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QBluetoothPermission_CommunicationMode,
            is_Enum_PythonToCpp_QBluetoothPermission_CommunicationMode_Convertible);
        // Register converter for flag 'QFlags<QBluetoothPermission::CommunicationMode>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QBluetoothPermission::CommunicationMode>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QBluetoothPermission::CommunicationModes");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'CommunicationMode' enum/flags.

    qRegisterMetaType< ::QBluetoothPermission >("QBluetoothPermission");
    qRegisterMetaType< ::QBluetoothPermission::CommunicationMode >("QBluetoothPermission::CommunicationMode");

    return pyType;
}
