// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qcalendar_wrapper.h"

// inner classes
#include "qcalendar_systemid_wrapper.h"
#include "qcalendar_yearmonthday_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QString>
#include <QStringList>
#include <QStringView>
#include <qcalendar.h>
#include <qdatetime.h>
#include <qlocale.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCalendar_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCalendar >()))
        return -1;

    ::QCalendar *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QCalendar", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCalendar::QCalendar()
    // 1: QCalendar::QCalendar(QAnyStringView)
    // 2: QCalendar::QCalendar(QCalendar::System)
    // 3: QCalendar::QCalendar(QCalendar::SystemId)
    // 4: QCalendar::QCalendar(QCalendar)
    if (numArgs == 0) {
        overloadId = 0; // QCalendar()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[0])))) {
        overloadId = 4; // QCalendar(QCalendar)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_SystemId_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QCalendar(QCalendar::SystemId)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_System_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 2; // QCalendar(QCalendar::System)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // QCalendar(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QCalendar()
        {

            // QCalendar()
            cptr = new ::QCalendar();
            break;
        }
        case 1: // QCalendar(QAnyStringView name)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCalendar(QAnyStringView)
                cptr = new ::QCalendar(QAnyStringView(cppArg0));
            }
            break;
        }
        case 2: // QCalendar(QCalendar::System system)
        {
            ::QCalendar::System cppArg0{QCalendar::System::Gregorian};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCalendar(QCalendar::System)
                cptr = new ::QCalendar(cppArg0);
            }
            break;
        }
        case 3: // QCalendar(QCalendar::SystemId id)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QCalendar::SystemId *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCalendar(QCalendar::SystemId)
                cptr = new ::QCalendar(*cppArg0);
            }
            break;
        }
        case 4: // QCalendar(const QCalendar &QCalendar)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QCalendar cppArg0_local;
            ::QCalendar *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCalendar(QCalendar)
                cptr = new ::QCalendar(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCalendar >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCalendarFunc_availableCalendars(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // availableCalendars()
        QStringList cppResult = ::QCalendar::availableCalendars();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_dateFromParts(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments(args, "dateFromParts", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    if (PyArg_UnpackTuple(args, "dateFromParts", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendar::dateFromParts(QCalendar::YearMonthDay)const->QDate
    // 1: QCalendar::dateFromParts(int,int,int)const->QDate
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 1; // dateFromParts(int,int,int)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_YearMonthDay_IDX]), (pyArgs[0])))) {
        overloadId = 0; // dateFromParts(QCalendar::YearMonthDay)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dateFromParts", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // dateFromParts(const QCalendar::YearMonthDay &parts) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QCalendar::YearMonthDay cppArg0_local;
            ::QCalendar::YearMonthDay *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // dateFromParts(QCalendar::YearMonthDay)const
                QDate cppResult = const_cast<const ::QCalendar *>(cppSelf)->dateFromParts(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 1: // dateFromParts(int year, int month, int day) const
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // dateFromParts(int,int,int)const
                QDate cppResult = const_cast<const ::QCalendar *>(cppSelf)->dateFromParts(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_dateTimeToString(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "dateTimeToString", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendar::dateTimeToString(QStringView,QDateTime,QDate,QTime,QLocale)const->QString
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArgs[4])))) {
        overloadId = 0; // dateTimeToString(QStringView,QDateTime,QDate,QTime,QLocale)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dateTimeToString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDateTime cppArg1_local;
        ::QDateTime *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QDate cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QTime cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        if (!Shiboken::Object::isValid(pyArgs[4]))
            return {};
        ::QLocale cppArg4_local;
        ::QLocale *cppArg4 = &cppArg4_local;
        if (pythonToCpp[4].isValue())
            pythonToCpp[4](pyArgs[4], &cppArg4_local);
        else
            pythonToCpp[4](pyArgs[4], &cppArg4);


        if (Shiboken::Errors::occurred() == nullptr) {
            // dateTimeToString(QStringView,QDateTime,QDate,QTime,QLocale)const
            QString cppResult = const_cast<const ::QCalendar *>(cppSelf)->dateTimeToString(QStringView(cppArg0), *cppArg1, cppArg2, cppArg3, *cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_dayOfWeek(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendar::dayOfWeek(QDate)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // dayOfWeek(QDate)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dayOfWeek", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dayOfWeek(QDate)const
            int cppResult = const_cast<const ::QCalendar *>(cppSelf)->dayOfWeek(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_daysInMonth(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "daysInMonth", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    if (PyArg_ParseTuple(args, "|OO:daysInMonth", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendar::daysInMonth(int,int=)const->int
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // daysInMonth(int,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // daysInMonth(int,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "daysInMonth", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_year = Shiboken::String::createStaticString("year");
            if (PyDict_Contains(kwds, key_year) != 0) {
                value = PyDict_GetItem(kwds, key_year);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_year);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "daysInMonth", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "daysInMonth", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_year);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "daysInMonth", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = QCalendar::Unspecified;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // daysInMonth(int,int)const
            int cppResult = const_cast<const ::QCalendar *>(cppSelf)->daysInMonth(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_daysInYear(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendar::daysInYear(int)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // daysInYear(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "daysInYear", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // daysInYear(int)const
            int cppResult = const_cast<const ::QCalendar *>(cppSelf)->daysInYear(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_hasYearZero(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasYearZero()const
        bool cppResult = const_cast<const ::QCalendar *>(cppSelf)->hasYearZero();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_isDateValid(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "isDateValid", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendar::isDateValid(int,int,int)const->bool
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // isDateValid(int,int,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isDateValid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDateValid(int,int,int)const
            bool cppResult = const_cast<const ::QCalendar *>(cppSelf)->isDateValid(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_isGregorian(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isGregorian()const
        bool cppResult = const_cast<const ::QCalendar *>(cppSelf)->isGregorian();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_isLeapYear(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendar::isLeapYear(int)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // isLeapYear(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isLeapYear", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isLeapYear(int)const
            bool cppResult = const_cast<const ::QCalendar *>(cppSelf)->isLeapYear(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_isLunar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLunar()const
        bool cppResult = const_cast<const ::QCalendar *>(cppSelf)->isLunar();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_isLuniSolar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLuniSolar()const
        bool cppResult = const_cast<const ::QCalendar *>(cppSelf)->isLuniSolar();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_isProleptic(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isProleptic()const
        bool cppResult = const_cast<const ::QCalendar *>(cppSelf)->isProleptic();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_isSolar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSolar()const
        bool cppResult = const_cast<const ::QCalendar *>(cppSelf)->isSolar();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QCalendar *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_matchCenturyToWeekday(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "matchCenturyToWeekday", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendar::matchCenturyToWeekday(QCalendar::YearMonthDay,int)const->QDate
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_YearMonthDay_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // matchCenturyToWeekday(QCalendar::YearMonthDay,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "matchCenturyToWeekday", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QCalendar::YearMonthDay cppArg0_local;
        ::QCalendar::YearMonthDay *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // matchCenturyToWeekday(QCalendar::YearMonthDay,int)const
            QDate cppResult = const_cast<const ::QCalendar *>(cppSelf)->matchCenturyToWeekday(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_maximumDaysInMonth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumDaysInMonth()const
        int cppResult = const_cast<const ::QCalendar *>(cppSelf)->maximumDaysInMonth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_maximumMonthsInYear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumMonthsInYear()const
        int cppResult = const_cast<const ::QCalendar *>(cppSelf)->maximumMonthsInYear();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_minimumDaysInMonth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumDaysInMonth()const
        int cppResult = const_cast<const ::QCalendar *>(cppSelf)->minimumDaysInMonth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_monthName(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "monthName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:monthName", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendar::monthName(QLocale,int,int=,QLocale::FormatType=)const->QString
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // monthName(QLocale,int,int,QLocale::FormatType)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // monthName(QLocale,int,int,QLocale::FormatType)const
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[3])))) {
                overloadId = 0; // monthName(QLocale,int,int,QLocale::FormatType)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "monthName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_year = Shiboken::String::createStaticString("year");
            if (PyDict_Contains(kwds, key_year) != 0) {
                value = PyDict_GetItem(kwds, key_year);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_year);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "monthName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "monthName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_year);
            }
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "monthName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "monthName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "monthName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = QCalendar::Unspecified;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QLocale::FormatType cppArg3(QLocale::LongFormat);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // monthName(QLocale,int,int,QLocale::FormatType)const
            QString cppResult = const_cast<const ::QCalendar *>(cppSelf)->monthName(*cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_monthsInYear(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendar::monthsInYear(int)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // monthsInYear(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "monthsInYear", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // monthsInYear(int)const
            int cppResult = const_cast<const ::QCalendar *>(cppSelf)->monthsInYear(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QCalendar *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_partsFromDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendar::partsFromDate(QDate)const->QCalendar::YearMonthDay
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // partsFromDate(QDate)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "partsFromDate", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // partsFromDate(QDate)const
            QCalendar::YearMonthDay cppResult = const_cast<const ::QCalendar *>(cppSelf)->partsFromDate(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_YearMonthDay_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_standaloneMonthName(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "standaloneMonthName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:standaloneMonthName", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendar::standaloneMonthName(QLocale,int,int=,QLocale::FormatType=)const->QString
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // standaloneMonthName(QLocale,int,int,QLocale::FormatType)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // standaloneMonthName(QLocale,int,int,QLocale::FormatType)const
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[3])))) {
                overloadId = 0; // standaloneMonthName(QLocale,int,int,QLocale::FormatType)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "standaloneMonthName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_year = Shiboken::String::createStaticString("year");
            if (PyDict_Contains(kwds, key_year) != 0) {
                value = PyDict_GetItem(kwds, key_year);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_year);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "standaloneMonthName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "standaloneMonthName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_year);
            }
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "standaloneMonthName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "standaloneMonthName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "standaloneMonthName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = QCalendar::Unspecified;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QLocale::FormatType cppArg3(QLocale::LongFormat);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // standaloneMonthName(QLocale,int,int,QLocale::FormatType)const
            QString cppResult = const_cast<const ::QCalendar *>(cppSelf)->standaloneMonthName(*cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_standaloneWeekDayName(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "standaloneWeekDayName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:standaloneWeekDayName", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendar::standaloneWeekDayName(QLocale,int,QLocale::FormatType=)const->QString
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // standaloneWeekDayName(QLocale,int,QLocale::FormatType)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 0; // standaloneWeekDayName(QLocale,int,QLocale::FormatType)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "standaloneWeekDayName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "standaloneWeekDayName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "standaloneWeekDayName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "standaloneWeekDayName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QLocale::FormatType cppArg2(QLocale::LongFormat);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // standaloneWeekDayName(QLocale,int,QLocale::FormatType)const
            QString cppResult = const_cast<const ::QCalendar *>(cppSelf)->standaloneWeekDayName(*cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarFunc_weekDayName(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "weekDayName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:weekDayName", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendar::weekDayName(QLocale,int,QLocale::FormatType=)const->QString
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // weekDayName(QLocale,int,QLocale::FormatType)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 0; // weekDayName(QLocale,int,QLocale::FormatType)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "weekDayName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "weekDayName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "weekDayName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "weekDayName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QLocale::FormatType cppArg2(QLocale::LongFormat);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // weekDayName(QLocale,int,QLocale::FormatType)const
            QString cppResult = const_cast<const ::QCalendar *>(cppSelf)->weekDayName(*cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendar__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCalendar_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QCalendar_EnumFlagInfo[] = {
    "System:Enum",
    "Unspecified:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCalendar_methods[] = {
    {"availableCalendars", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_availableCalendars), METH_NOARGS|METH_STATIC, nullptr},
    {"dateFromParts", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_dateFromParts), METH_VARARGS, nullptr},
    {"dateTimeToString", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_dateTimeToString), METH_VARARGS, nullptr},
    {"dayOfWeek", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_dayOfWeek), METH_O, nullptr},
    {"daysInMonth", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_daysInMonth), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"daysInYear", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_daysInYear), METH_O, nullptr},
    {"hasYearZero", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_hasYearZero), METH_NOARGS, nullptr},
    {"isDateValid", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_isDateValid), METH_VARARGS, nullptr},
    {"isGregorian", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_isGregorian), METH_NOARGS, nullptr},
    {"isLeapYear", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_isLeapYear), METH_O, nullptr},
    {"isLunar", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_isLunar), METH_NOARGS, nullptr},
    {"isLuniSolar", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_isLuniSolar), METH_NOARGS, nullptr},
    {"isProleptic", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_isProleptic), METH_NOARGS, nullptr},
    {"isSolar", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_isSolar), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_isValid), METH_NOARGS, nullptr},
    {"matchCenturyToWeekday", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_matchCenturyToWeekday), METH_VARARGS, nullptr},
    {"maximumDaysInMonth", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_maximumDaysInMonth), METH_NOARGS, nullptr},
    {"maximumMonthsInYear", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_maximumMonthsInYear), METH_NOARGS, nullptr},
    {"minimumDaysInMonth", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_minimumDaysInMonth), METH_NOARGS, nullptr},
    {"monthName", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_monthName), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"monthsInYear", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_monthsInYear), METH_O, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_name), METH_NOARGS, nullptr},
    {"partsFromDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_partsFromDate), METH_O, nullptr},
    {"standaloneMonthName", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_standaloneMonthName), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"standaloneWeekDayName", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_standaloneWeekDayName), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"weekDayName", reinterpret_cast<PyCFunction>(Sbk_QCalendarFunc_weekDayName), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QCalendar__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QCalendar_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCalendar_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCalendar_Type = nullptr;
static PyTypeObject *Sbk_QCalendar_TypeF(void)
{
    return _Sbk_QCalendar_Type;
}

static PyType_Slot Sbk_QCalendar_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCalendar_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCalendar_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCalendar_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCalendar_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCalendar_spec = {
    "2:PySide6.QtCore.QCalendar",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCalendar_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QCalendar_System(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCalendar::System>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCalendar::System *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCalendar_System_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_System_IDX])))
        return Enum_PythonToCpp_QCalendar_System;
    return {};
}

static PyObject *QCalendar_System_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCalendar::System>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCalendar::System *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_System_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCalendar_PythonToCpp_QCalendar_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCalendar_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCalendar_PythonToCpp_QCalendar_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCalendar_TypeF()))
        return QCalendar_PythonToCpp_QCalendar_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCalendar_PTR_CppToPython_QCalendar(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QCalendar_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QCalendar_COPY_CppToPython_QCalendar(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QCalendar *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QCalendar_TypeF(), new ::QCalendar(*source), true, true);
}

// Python to C++ copy conversion.
static void QCalendar_PythonToCpp_QCalendar_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QCalendar *>(cppOut) = *reinterpret_cast< ::QCalendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QCalendar_PythonToCpp_QCalendar_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QCalendar_TypeF()))
        return QCalendar_PythonToCpp_QCalendar_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCalendar_SignatureStrings[] = {
    "4:PySide6.QtCore.QCalendar(self)",
    "3:PySide6.QtCore.QCalendar(self,name:QString)",
    "2:PySide6.QtCore.QCalendar(self,system:PySide6.QtCore.QCalendar.System)",
    "1:PySide6.QtCore.QCalendar(self,id:PySide6.QtCore.QCalendar.SystemId)",
    "0:PySide6.QtCore.QCalendar(self,QCalendar:PySide6.QtCore.QCalendar)",
    "PySide6.QtCore.QCalendar.availableCalendars()->QStringList",
    "1:PySide6.QtCore.QCalendar.dateFromParts(self,parts:typing.Union[PySide6.QtCore.QCalendar.YearMonthDay, int])->PySide6.QtCore.QDate",
    "0:PySide6.QtCore.QCalendar.dateFromParts(self,year:int,month:int,day:int)->PySide6.QtCore.QDate",
    "PySide6.QtCore.QCalendar.dateTimeToString(self,format:QString,datetime:PySide6.QtCore.QDateTime,dateOnly:PySide6.QtCore.QDate,timeOnly:PySide6.QtCore.QTime,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])->QString",
    "PySide6.QtCore.QCalendar.dayOfWeek(self,date:PySide6.QtCore.QDate)->int",
    "PySide6.QtCore.QCalendar.daysInMonth(self,month:int,year:int=QCalendar.Unspecified)->int",
    "PySide6.QtCore.QCalendar.daysInYear(self,year:int)->int",
    "PySide6.QtCore.QCalendar.hasYearZero(self)->bool",
    "PySide6.QtCore.QCalendar.isDateValid(self,year:int,month:int,day:int)->bool",
    "PySide6.QtCore.QCalendar.isGregorian(self)->bool",
    "PySide6.QtCore.QCalendar.isLeapYear(self,year:int)->bool",
    "PySide6.QtCore.QCalendar.isLunar(self)->bool",
    "PySide6.QtCore.QCalendar.isLuniSolar(self)->bool",
    "PySide6.QtCore.QCalendar.isProleptic(self)->bool",
    "PySide6.QtCore.QCalendar.isSolar(self)->bool",
    "PySide6.QtCore.QCalendar.isValid(self)->bool",
    "PySide6.QtCore.QCalendar.matchCenturyToWeekday(self,parts:typing.Union[PySide6.QtCore.QCalendar.YearMonthDay, int],dow:int)->PySide6.QtCore.QDate",
    "PySide6.QtCore.QCalendar.maximumDaysInMonth(self)->int",
    "PySide6.QtCore.QCalendar.maximumMonthsInYear(self)->int",
    "PySide6.QtCore.QCalendar.minimumDaysInMonth(self)->int",
    "PySide6.QtCore.QCalendar.monthName(self,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language],month:int,year:int=QCalendar.Unspecified,format:PySide6.QtCore.QLocale.FormatType=QLocale.LongFormat)->QString",
    "PySide6.QtCore.QCalendar.monthsInYear(self,year:int)->int",
    "PySide6.QtCore.QCalendar.name(self)->QString",
    "PySide6.QtCore.QCalendar.partsFromDate(self,date:PySide6.QtCore.QDate)->PySide6.QtCore.QCalendar.YearMonthDay",
    "PySide6.QtCore.QCalendar.standaloneMonthName(self,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language],month:int,year:int=QCalendar.Unspecified,format:PySide6.QtCore.QLocale.FormatType=QLocale.LongFormat)->QString",
    "PySide6.QtCore.QCalendar.standaloneWeekDayName(self,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language],day:int,format:PySide6.QtCore.QLocale.FormatType=QLocale.LongFormat)->QString",
    "PySide6.QtCore.QCalendar.weekDayName(self,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language],day:int,format:PySide6.QtCore.QLocale.FormatType=QLocale.LongFormat)->QString",
    "PySide6.QtCore.QCalendar.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QCalendar_SignatureByteSize = 538;
static constexpr uint8_t QCalendar_SignatureBytes[538] = {
    0x78, 0xda, 0xe5, 0x55, 0x5b, 0x6f, 0x9b, 0x30, 0x14, 0x7e, 0xe7, 0x57, 0xf4, 0xb1, 0x48, 0x14,
    0xed, 0xa6, 0x3d, 0x20, 0xb5, 0x2f, 0x89, 0x3a, 0x55, 0x4a, 0xd7, 0x44, 0xa4, 0x9b, 0xb6, 0xa9,
    0x8a, 0x4e, 0xe1, 0x84, 0x58, 0xf3, 0x05, 0xd9, 0xce, 0x3a, 0xff, 0xfb, 0xd9, 0x10, 0xca, 0x16,
    0x01, 0xf6, 0xaa, 0xf6, 0x65, 0x7b, 0x32, 0xb6, 0xbf, 0xef, 0x3b, 0x57, 0x1f, 0xde, 0x65, 0x4b,
    0x93, 0x93, 0x12, 0xdf, 0xa7, 0x2b, 0x3d, 0x13, 0x12, 0xd3, 0xd5, 0x0c, 0x28, 0xf2, 0x12, 0xe4,
    0xa9, 0x42, 0xba, 0x8d, 0xa3, 0xb7, 0xd3, 0x80, 0x84, 0x03, 0xc3, 0x6c, 0x95, 0x6b, 0x49, 0x78,
    0x15, 0x47, 0x6f, 0x3c, 0x68, 0x65, 0x94, 0x46, 0x36, 0x0a, 0x4a, 0xf3, 0xe6, 0x3e, 0x8e, 0x5e,
    0x7b, 0x74, 0x48, 0xe9, 0xd3, 0xb8, 0x2a, 0xe3, 0xe8, 0x95, 0x47, 0xe5, 0x71, 0x3b, 0x8a, 0x8b,
    0xa3, 0x51, 0x33, 0xf0, 0x03, 0x08, 0x85, 0x7b, 0x8a, 0xdd, 0x89, 0x3a, 0x8d, 0xcf, 0x2e, 0x0e,
    0x99, 0x58, 0x10, 0xa5, 0x27, 0x82, 0x48, 0x4b, 0xd0, 0x78, 0x29, 0x05, 0x5b, 0x82, 0xd4, 0xaa,
    0x75, 0xa6, 0x76, 0x9f, 0x99, 0x36, 0xb5, 0xa5, 0xa7, 0xb7, 0x9c, 0x08, 0xfe, 0x6d, 0x94, 0xfe,
    0x05, 0x41, 0x5e, 0x0b, 0xae, 0x77, 0x73, 0x30, 0xc9, 0x09, 0xe1, 0xfa, 0xce, 0x9a, 0x3e, 0x46,
    0xcf, 0xad, 0x8d, 0x89, 0x14, 0x0c, 0xf9, 0x60, 0xac, 0x6e, 0x66, 0xe5, 0x12, 0xe6, 0xc4, 0x9b,
    0xaf, 0x12, 0x8c, 0x5b, 0xc7, 0xf4, 0x27, 0xd5, 0xd7, 0x84, 0xe1, 0x5a, 0xb4, 0x19, 0x69, 0x0d,
    0x6c, 0x85, 0x64, 0xa0, 0xbb, 0x7e, 0x49, 0x1c, 0x48, 0x5b, 0x50, 0x36, 0xa4, 0xed, 0xd8, 0x0d,
    0xe2, 0x86, 0x53, 0x33, 0x88, 0x48, 0x1c, 0x77, 0xf0, 0xb6, 0xe1, 0x52, 0x51, 0x58, 0x6f, 0xa6,
    0x53, 0xba, 0x68, 0x30, 0xc9, 0xc9, 0xf0, 0x79, 0xba, 0x00, 0x5e, 0xed, 0xa1, 0xc2, 0xbb, 0xbe,
    0xb4, 0x53, 0x21, 0x9b, 0x9b, 0xed, 0x67, 0xc4, 0xef, 0x6d, 0xac, 0xce, 0xf5, 0x41, 0xb7, 0xad,
    0x96, 0xcd, 0xe8, 0xa4, 0x8e, 0xba, 0xe2, 0x4d, 0x7d, 0x5b, 0xa5, 0xbe, 0x1a, 0x5d, 0x81, 0xce,
    0x7b, 0xf4, 0x2d, 0x57, 0x35, 0x16, 0x64, 0x4b, 0xb0, 0x0c, 0x13, 0x76, 0xcd, 0xf3, 0x67, 0xb9,
    0x7d, 0xbc, 0x1d, 0x28, 0x47, 0xfa, 0x8a, 0x52, 0xb4, 0x53, 0xe1, 0xec, 0xe2, 0x5e, 0x08, 0x3a,
    0x4e, 0x20, 0xca, 0xc5, 0xf9, 0x09, 0x28, 0x29, 0x03, 0x1a, 0xcb, 0xa7, 0xf5, 0x41, 0x62, 0x25,
    0x24, 0x01, 0x1e, 0x6a, 0x7c, 0x81, 0x50, 0x0f, 0x46, 0xe9, 0x25, 0xee, 0x79, 0x37, 0xf8, 0x82,
    0xc0, 0x24, 0x17, 0x34, 0x9c, 0xb0, 0x94, 0x82, 0x62, 0xad, 0x49, 0x11, 0x4a, 0xf8, 0x2b, 0xf5,
    0x3e, 0xdb, 0x5e, 0xb0, 0x7d, 0x82, 0xc5, 0x6e, 0x86, 0x5c, 0xef, 0xa5, 0x59, 0x0b, 0xd7, 0xb1,
    0xb6, 0x18, 0xcf, 0x31, 0x85, 0x92, 0x52, 0x3c, 0x3c, 0x69, 0x5a, 0x30, 0xf8, 0x49, 0xd8, 0x9e,
    0xcd, 0x8f, 0x3a, 0xdf, 0xd7, 0x98, 0x07, 0x5a, 0x43, 0xf8, 0xbd, 0xb3, 0xbd, 0x3c, 0xc2, 0x9f,
    0x64, 0xce, 0x21, 0x3f, 0xda, 0x1f, 0x5e, 0x9b, 0xab, 0xe7, 0x9c, 0x2f, 0xc1, 0x6f, 0xbc, 0x1b,
    0xa1, 0x23, 0x82, 0x97, 0xcd, 0xed, 0xda, 0xd4, 0x78, 0xfe, 0x68, 0x43, 0xf0, 0xaa, 0x3d, 0x0e,
    0x19, 0x62, 0xec, 0x38, 0x97, 0xc1, 0x53, 0x82, 0x77, 0x89, 0x09, 0x31, 0xd3, 0xf4, 0x99, 0xfb,
    0xfb, 0xb8, 0xbe, 0xf0, 0xcf, 0xcb, 0xa0, 0x1e, 0x1c, 0xb7, 0xa6, 0x34, 0xd8, 0x95, 0x0a, 0x8e,
    0xd7, 0xff, 0x41, 0x09, 0xfb, 0x68, 0xdd, 0xd3, 0xb6, 0x89, 0x79, 0xa1, 0x78, 0x0f, 0x13, 0xfc,
    0xa5, 0xc3, 0x79, 0xf8, 0x17, 0x82, 0xd8, 0x6c, 0x0a, 0x51, 0x9b, 0xcd, 0xa6, 0x7b, 0x20, 0x07,
    0xe7, 0x73, 0xbb, 0x8b, 0x7e, 0x01, 0x71, 0xf6, 0x1d, 0x2d
};
#endif

PyTypeObject *init_QCalendar(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX].type;

    Shiboken::AutoDecRef Sbk_QCalendar_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCalendar_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCalendar",
        "QCalendar",
        &Sbk_QCalendar_spec,
        &Shiboken::callCppDestructor< ::QCalendar >,
        Sbk_QCalendar_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QCalendar_TypeF(); // references _Sbk_QCalendar_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCalendar_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCalendar_SignatureBytes, QCalendar_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCalendar_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCalendar_PythonToCpp_QCalendar_PTR,
        is_QCalendar_PythonToCpp_QCalendar_PTR_Convertible,
        QCalendar_PTR_CppToPython_QCalendar,
        QCalendar_COPY_CppToPython_QCalendar);

    Shiboken::Conversions::registerConverterName(converter, "QCalendar");
    Shiboken::Conversions::registerConverterName(converter, "QCalendar*");
    Shiboken::Conversions::registerConverterName(converter, "QCalendar&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCalendar).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QCalendar_PythonToCpp_QCalendar_COPY,
        is_QCalendar_PythonToCpp_QCalendar_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCalendar_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of anonymous enum identified by enum value 'Unspecified'.
    // "int32_t" used instead of "int"
    constexpr int32_t Unspecified_InitializerValues[] = {
        int32_t(QCalendar::Unspecified) // -0x80000000 -2147483648
        };
    tpDict.reset(PepType_GetDict(reinterpret_cast<PyTypeObject *>(Sbk_QCalendar_TypeF())));
    PyDict_SetItemString(tpDict.object(), "Unspecified",
        PyLong_FromLongLong(Unspecified_InitializerValues[0]));
    // End of 'Unspecified' enum.

    // Initialization of enum 'System'.
    const char *System_Initializer[] = {
        "Gregorian",
        "Julian",
        "Milankovic",
        "Jalali",
        "IslamicCivil",
        "Last",
        "User",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t System_InitializerValues[] = {
        int8_t(QCalendar::System::Gregorian),    //  0x00  0
        int8_t(QCalendar::System::Julian),       //  0x08  8
        int8_t(QCalendar::System::Milankovic),   //  0x09  9
        int8_t(QCalendar::System::Jalali),       //  0x0a  10
        int8_t(QCalendar::System::IslamicCivil), //  0x0b  11
        int8_t(QCalendar::System::Last),         //  0x0b  11
        int8_t(QCalendar::System::User)          // -0x01 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCalendar_TypeF(),
        "2:PySide6.QtCore.QCalendar.System",
        System_Initializer, System_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_System_IDX].type = EType;
    // Register converter for enum 'QCalendar::System'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCalendar_System_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCalendar_System,
            is_Enum_PythonToCpp_QCalendar_System_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCalendar::System");
        Shiboken::Conversions::registerConverterAlias(converter, "System");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'System' enum.

    qRegisterMetaType< ::QCalendar >("QCalendar");
    qRegisterMetaType< ::QCalendar::System >("QCalendar::System");

    return pyType;
}
