// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qcborarray_wrapper.h"

// Argument includes
#include <QList>
#include <QStringList>
#include <qcborarray.h>
#include <qcborvalue.h>
#include <qjsonarray.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCborArray_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCborArray >()))
        return -1;

    ::QCborArray *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QCborArray", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCborArray::QCborArray()
    // 1: QCborArray::QCborArray(QCborArray)
    if (numArgs == 0) {
        overloadId = 0; // QCborArray()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QCborArray(QCborArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QCborArray()
        {

            // QCborArray()
            cptr = new ::QCborArray();
            break;
        }
        case 1: // QCborArray(const QCborArray &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QCborArray cppArg0_local;
            ::QCborArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborArray(QCborArray)
                cptr = new ::QCborArray(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCborArray >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCborArrayFunc_append(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborArray::append(QCborValue)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
        overloadId = 0; // append(QCborValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCborValue cppArg0_local;
        ::QCborValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // append(QCborValue)
            cppSelf->append(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborArrayFunc_at(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborArray::at(qsizetype)const->QCborValue
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // at(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "at", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // at(qsizetype)const
            QCborValue cppResult = const_cast<const ::QCborArray *>(cppSelf)->at(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborArrayFunc_compare(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborArray::compare(QCborArray)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), (pyArg)))) {
        overloadId = 0; // compare(QCborArray)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "compare", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCborArray cppArg0_local;
        ::QCborArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // compare(QCborArray)const
            int cppResult = const_cast<const ::QCborArray *>(cppSelf)->compare(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborArray::contains(QCborValue)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
        overloadId = 0; // contains(QCborValue)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contains", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCborValue cppArg0_local;
        ::QCborValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // contains(QCborValue)const
            bool cppResult = const_cast<const ::QCborArray *>(cppSelf)->contains(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_empty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // empty()const
        bool cppResult = const_cast<const ::QCborArray *>(cppSelf)->empty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_first(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // first()const
        QCborValue cppResult = const_cast<const ::QCborArray *>(cppSelf)->first();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_fromJsonArray(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCborArray::fromJsonArray(QJsonArray)->QCborArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), (pyArg)))) {
        overloadId = 0; // fromJsonArray(QJsonArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromJsonArray", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJsonArray cppArg0_local;
        ::QJsonArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // fromJsonArray(QJsonArray)
            QCborArray cppResult = ::QCborArray::fromJsonArray(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_fromStringList(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCborArray::fromStringList(QStringList)->QCborArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // fromStringList(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromStringList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromStringList(QStringList)
            QCborArray cppResult = ::QCborArray::fromStringList(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_fromVariantList(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCborArray::fromVariantList(QList<QVariant>)->QCborArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // fromVariantList(QList<QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromVariantList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        ::QList<QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromVariantList(QList<QVariant>)
            QCborArray cppResult = ::QCborArray::fromVariantList(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_insert(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insert", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborArray::insert(qsizetype,QCborValue)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insert(qsizetype,QCborValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insert", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QCborValue cppArg1_local;
        ::QCborValue *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // insert(qsizetype,QCborValue)
            cppSelf->insert(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborArrayFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QCborArray *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_last(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // last()const
        QCborValue cppResult = const_cast<const ::QCborArray *>(cppSelf)->last();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_pop_back(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pop_back()
        cppSelf->pop_back();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborArrayFunc_pop_front(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pop_front()
        cppSelf->pop_front();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborArrayFunc_prepend(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborArray::prepend(QCborValue)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
        overloadId = 0; // prepend(QCborValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "prepend", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCborValue cppArg0_local;
        ::QCborValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // prepend(QCborValue)
            cppSelf->prepend(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborArrayFunc_push_back(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborArray::push_back(QCborValue)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
        overloadId = 0; // push_back(QCborValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "push_back", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCborValue cppArg0_local;
        ::QCborValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // push_back(QCborValue)
            cppSelf->push_back(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborArrayFunc_push_front(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborArray::push_front(QCborValue)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
        overloadId = 0; // push_front(QCborValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "push_front", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCborValue cppArg0_local;
        ::QCborValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // push_front(QCborValue)
            cppSelf->push_front(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborArrayFunc_removeAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborArray::removeAt(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // removeAt(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAt(qsizetype)
            cppSelf->removeAt(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborArrayFunc_removeFirst(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // removeFirst()
        cppSelf->removeFirst();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborArrayFunc_removeLast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // removeLast()
        cppSelf->removeLast();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborArrayFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        qsizetype cppResult = const_cast<const ::QCborArray *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborArray::swap(QCborArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QCborArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCborArray cppArg0_local;
        ::QCborArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QCborArray&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborArrayFunc_takeAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborArray::takeAt(qsizetype)->QCborValue
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // takeAt(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "takeAt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // takeAt(qsizetype)
            QCborValue cppResult = cppSelf->takeAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_takeFirst(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // takeFirst()
        QCborValue cppResult = cppSelf->takeFirst();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_takeLast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // takeLast()
        QCborValue cppResult = cppSelf->takeLast();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_toCborValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toCborValue()const
        QCborValue cppResult = const_cast<const ::QCborArray *>(cppSelf)->toCborValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_toJsonArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toJsonArray()const
        QJsonArray cppResult = const_cast<const ::QCborArray *>(cppSelf)->toJsonArray();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc_toVariantList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toVariantList()const
        QList<QVariant> cppResult = const_cast<const ::QCborArray *>(cppSelf)->toVariantList();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArray__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCborArray_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCborArray_methods[] = {
    {"append", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_append), METH_O, nullptr},
    {"at", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_at), METH_O, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_clear), METH_NOARGS, nullptr},
    {"compare", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_compare), METH_O, nullptr},
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_contains), METH_O, nullptr},
    {"empty", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_empty), METH_NOARGS, nullptr},
    {"first", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_first), METH_NOARGS, nullptr},
    {"fromJsonArray", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_fromJsonArray), METH_O|METH_STATIC, nullptr},
    {"fromStringList", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_fromStringList), METH_O|METH_STATIC, nullptr},
    {"fromVariantList", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_fromVariantList), METH_O|METH_STATIC, nullptr},
    {"insert", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_insert), METH_VARARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_isEmpty), METH_NOARGS, nullptr},
    {"last", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_last), METH_NOARGS, nullptr},
    {"pop_back", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_pop_back), METH_NOARGS, nullptr},
    {"pop_front", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_pop_front), METH_NOARGS, nullptr},
    {"prepend", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_prepend), METH_O, nullptr},
    {"push_back", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_push_back), METH_O, nullptr},
    {"push_front", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_push_front), METH_O, nullptr},
    {"removeAt", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_removeAt), METH_O, nullptr},
    {"removeFirst", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_removeFirst), METH_NOARGS, nullptr},
    {"removeLast", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_removeLast), METH_NOARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_size), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_swap), METH_O, nullptr},
    {"takeAt", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_takeAt), METH_O, nullptr},
    {"takeFirst", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_takeFirst), METH_NOARGS, nullptr},
    {"takeLast", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_takeLast), METH_NOARGS, nullptr},
    {"toCborValue", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_toCborValue), METH_NOARGS, nullptr},
    {"toJsonArray", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_toJsonArray), METH_NOARGS, nullptr},
    {"toVariantList", reinterpret_cast<PyCFunction>(Sbk_QCborArrayFunc_toVariantList), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QCborArray__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QCborArrayFunc___add__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborArray::operator+(QCborValue)const->QCborArray
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
        overloadId = 0; // operator+(QCborValue)const
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCborValue cppArg0_local;
        ::QCborValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+(QCborValue)const
            QCborArray cppResult = (*cppSelf) + (*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborArrayFunc___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborArray::operator+=(QCborValue)->QCborArray&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
        overloadId = 0; // operator+=(QCborValue)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+=", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCborValue cppArg0_local;
        ::QCborValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+=(QCborValue)
            (*cppSelf) += (*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QCborArrayFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QCborArray::operator<<(QCborValue)->QCborArray&
        if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QCborValue)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QCborValue cppArg0_local;
            ::QCborValue *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QCborValue)
                QCborArray & cppResult = (*cppSelf) << (*cppArg0);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QCborArray_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), (pyArg)))) {
                // operator!=(const QCborArray &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborArray cppArg0_local;
                ::QCborArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
                // operator!=(const QCborValue &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborValue cppArg0_local;
                ::QCborValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), (pyArg)))) {
                // operator<(const QCborArray &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborArray cppArg0_local;
                ::QCborArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
                // operator<(const QCborValue &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborValue cppArg0_local;
                ::QCborValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), (pyArg)))) {
                // operator<=(const QCborArray &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborArray cppArg0_local;
                ::QCborArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
                // operator<=(const QCborValue &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborValue cppArg0_local;
                ::QCborValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), (pyArg)))) {
                // operator==(const QCborArray &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborArray cppArg0_local;
                ::QCborArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
                // operator==(const QCborValue &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborValue cppArg0_local;
                ::QCborValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), (pyArg)))) {
                // operator>(const QCborArray &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborArray cppArg0_local;
                ::QCborArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
                // operator>(const QCborValue &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborValue cppArg0_local;
                ::QCborValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), (pyArg)))) {
                // operator>=(const QCborArray &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborArray cppArg0_local;
                ::QCborArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
                // operator>=(const QCborValue &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborValue cppArg0_local;
                ::QCborValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QCborArray_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QCborArray_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCborArray_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QCborArray__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCborArray_Type = nullptr;
static PyTypeObject *Sbk_QCborArray_TypeF(void)
{
    return _Sbk_QCborArray_Type;
}

static PyType_Slot Sbk_QCborArray_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QCborArray__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QCborArray_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCborArray_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCborArray_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QCborArray_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCborArray_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCborArray_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QCborArrayFunc___iadd__)},
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QCborArrayFunc___lshift__)},
    {Py_nb_add,         reinterpret_cast<void *>(Sbk_QCborArrayFunc___add__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCborArray_spec = {
    "2:PySide6.QtCore.QCborArray",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCborArray_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCborArray_PythonToCpp_QCborArray_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCborArray_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCborArray_PythonToCpp_QCborArray_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCborArray_TypeF()))
        return QCborArray_PythonToCpp_QCborArray_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCborArray_PTR_CppToPython_QCborArray(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QCborArray_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QCborArray_COPY_CppToPython_QCborArray(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QCborArray *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QCborArray_TypeF(), new ::QCborArray(*source), true, true);
}

// Python to C++ copy conversion.
static void QCborArray_PythonToCpp_QCborArray_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QCborArray *>(cppOut) = *reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QCborArray_PythonToCpp_QCborArray_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QCborArray_TypeF()))
        return QCborArray_PythonToCpp_QCborArray_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCborArray_SignatureStrings[] = {
    "1:PySide6.QtCore.QCborArray(self)",
    "0:PySide6.QtCore.QCborArray(self,other:PySide6.QtCore.QCborArray)",
    "PySide6.QtCore.QCborArray.append(self,value:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])",
    "PySide6.QtCore.QCborArray.at(self,i:qsizetype)->PySide6.QtCore.QCborValue",
    "PySide6.QtCore.QCborArray.clear(self)",
    "PySide6.QtCore.QCborArray.compare(self,other:PySide6.QtCore.QCborArray)->int",
    "PySide6.QtCore.QCborArray.contains(self,value:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])->bool",
    "PySide6.QtCore.QCborArray.empty(self)->bool",
    "PySide6.QtCore.QCborArray.first(self)->PySide6.QtCore.QCborValue",
    "PySide6.QtCore.QCborArray.fromJsonArray(array:PySide6.QtCore.QJsonArray)->PySide6.QtCore.QCborArray",
    "PySide6.QtCore.QCborArray.fromStringList(list:QStringList)->PySide6.QtCore.QCborArray",
    "PySide6.QtCore.QCborArray.fromVariantList(list:QList[QVariant])->PySide6.QtCore.QCborArray",
    "PySide6.QtCore.QCborArray.insert(self,i:qsizetype,value:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])",
    "PySide6.QtCore.QCborArray.isEmpty(self)->bool",
    "PySide6.QtCore.QCborArray.last(self)->PySide6.QtCore.QCborValue",
    "PySide6.QtCore.QCborArray.pop_back(self)",
    "PySide6.QtCore.QCborArray.pop_front(self)",
    "PySide6.QtCore.QCborArray.prepend(self,value:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])",
    "PySide6.QtCore.QCborArray.push_back(self,t:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])",
    "PySide6.QtCore.QCborArray.push_front(self,t:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])",
    "PySide6.QtCore.QCborArray.removeAt(self,i:qsizetype)",
    "PySide6.QtCore.QCborArray.removeFirst(self)",
    "PySide6.QtCore.QCborArray.removeLast(self)",
    "PySide6.QtCore.QCborArray.size(self)->qsizetype",
    "PySide6.QtCore.QCborArray.swap(self,other:PySide6.QtCore.QCborArray)",
    "PySide6.QtCore.QCborArray.takeAt(self,i:qsizetype)->PySide6.QtCore.QCborValue",
    "PySide6.QtCore.QCborArray.takeFirst(self)->PySide6.QtCore.QCborValue",
    "PySide6.QtCore.QCborArray.takeLast(self)->PySide6.QtCore.QCborValue",
    "PySide6.QtCore.QCborArray.toCborValue(self)->PySide6.QtCore.QCborValue",
    "PySide6.QtCore.QCborArray.toJsonArray(self)->PySide6.QtCore.QJsonArray",
    "PySide6.QtCore.QCborArray.toVariantList(self)->QList[QVariant]",
    "PySide6.QtCore.QCborArray.__copy__(self)->typing.Self",
    "PySide6.QtCore.QCborArray.__add__(self,v:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])->PySide6.QtCore.QCborArray",
    "PySide6.QtCore.QCborArray.__iadd__(self,v:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])->PySide6.QtCore.QCborArray",
    "PySide6.QtCore.QCborArray.__lshift__(self,v:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])->PySide6.QtCore.QCborArray",
    "1:PySide6.QtCore.QCborArray.__ne__(self,rhs:PySide6.QtCore.QCborArray)->bool",
    "0:PySide6.QtCore.QCborArray.__ne__(self,rhs:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])->bool",
    "1:PySide6.QtCore.QCborArray.__lt__(self,rhs:PySide6.QtCore.QCborArray)->bool",
    "0:PySide6.QtCore.QCborArray.__lt__(self,rhs:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])->bool",
    "1:PySide6.QtCore.QCborArray.__le__(self,rhs:PySide6.QtCore.QCborArray)->bool",
    "0:PySide6.QtCore.QCborArray.__le__(self,rhs:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])->bool",
    "1:PySide6.QtCore.QCborArray.__eq__(self,rhs:PySide6.QtCore.QCborArray)->bool",
    "0:PySide6.QtCore.QCborArray.__eq__(self,rhs:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])->bool",
    "1:PySide6.QtCore.QCborArray.__gt__(self,rhs:PySide6.QtCore.QCborArray)->bool",
    "0:PySide6.QtCore.QCborArray.__gt__(self,rhs:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])->bool",
    "1:PySide6.QtCore.QCborArray.__ge__(self,rhs:PySide6.QtCore.QCborArray)->bool",
    "0:PySide6.QtCore.QCborArray.__ge__(self,rhs:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])->bool",
    "PySide6.QtCore.QCborArray.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QCborArray_SignatureByteSize = 607;
static constexpr uint8_t QCborArray_SignatureBytes[607] = {
    0x78, 0xda, 0xed, 0x59, 0xc1, 0x6e, 0xa3, 0x30, 0x10, 0xbd, 0xf7, 0x2b, 0x38, 0x6e, 0x56, 0x24,
    0x6a, 0xa4, 0x55, 0x0f, 0x1c, 0x22, 0xb5, 0xd5, 0xf6, 0xb0, 0x9b, 0x95, 0x16, 0xa5, 0x9b, 0x4b,
    0x55, 0x21, 0x27, 0x4c, 0xc0, 0xaa, 0x63, 0x3b, 0xb6, 0x93, 0x88, 0xfd, 0xfa, 0x35, 0x81, 0x40,
    0xbb, 0x01, 0xd3, 0x06, 0x4a, 0x7b, 0xf0, 0x05, 0x01, 0xf3, 0xe6, 0xd9, 0xcc, 0x1b, 0x0f, 0x63,
    0x18, 0x7b, 0xbf, 0x93, 0x19, 0x0e, 0xe1, 0x6a, 0xe4, 0xab, 0x5b, 0x26, 0x60, 0xe4, 0xdf, 0x2e,
    0x98, 0xb8, 0x16, 0x02, 0x25, 0x5f, 0x24, 0x90, 0xd5, 0xe0, 0xe2, 0xb2, 0x01, 0xe1, 0x32, 0x15,
    0x83, 0xa8, 0x07, 0x0d, 0x2e, 0x6a, 0x4d, 0x23, 0xc4, 0x39, 0xd0, 0x30, 0xa3, 0xd9, 0x21, 0xb2,
    0x05, 0x4f, 0x25, 0x1c, 0xd3, 0x68, 0xf4, 0x87, 0x62, 0x46, 0x1f, 0xaa, 0x1c, 0xe7, 0x29, 0xcc,
    0x75, 0xaa, 0x4c, 0x3f, 0x29, 0xdb, 0xd3, 0x7b, 0x14, 0xc9, 0x6a, 0xf3, 0x0c, 0xaf, 0x39, 0x81,
    0xfb, 0x84, 0xd7, 0xb8, 0x6b, 0xcf, 0x6a, 0xc3, 0x61, 0xc8, 0x51, 0xe6, 0xe8, 0x4f, 0x91, 0xc2,
    0x74, 0x3c, 0x53, 0x42, 0x4f, 0x53, 0x5f, 0x66, 0x27, 0x73, 0x0c, 0x7b, 0xd7, 0x59, 0x30, 0x46,
    0x4e, 0x19, 0x6e, 0x12, 0x05, 0x87, 0xa7, 0xad, 0x26, 0x37, 0x98, 0x7e, 0x21, 0x5e, 0x8c, 0xe0,
    0x3a, 0xcb, 0x18, 0x89, 0xaf, 0xae, 0x13, 0xb2, 0xed, 0x82, 0xe8, 0x89, 0x60, 0xaa, 0x5c, 0x67,
    0xa3, 0x8f, 0x57, 0xdf, 0x5c, 0x67, 0x4b, 0x25, 0x8e, 0x28, 0x84, 0xe9, 0xdd, 0x47, 0x63, 0xc0,
    0x55, 0x16, 0x6c, 0xec, 0x6d, 0x24, 0xfe, 0x0b, 0x3a, 0xda, 0x30, 0x18, 0x4e, 0x6a, 0x1f, 0xda,
    0xc0, 0xb4, 0x24, 0x80, 0x44, 0x9e, 0x22, 0x06, 0x14, 0x5b, 0x73, 0x24, 0xe0, 0x75, 0x89, 0x32,
    0x9c, 0xe8, 0xe9, 0x1b, 0xc9, 0xa8, 0x42, 0x98, 0x4a, 0x9b, 0x2f, 0xdd, 0xe6, 0xcb, 0x70, 0x92,
    0xce, 0xc4, 0x10, 0x78, 0x58, 0x73, 0x95, 0x97, 0x83, 0x46, 0xec, 0x0a, 0x0b, 0xa9, 0x8e, 0xd8,
    0x73, 0x12, 0x6b, 0x25, 0xd8, 0xfa, 0x87, 0x64, 0x34, 0xab, 0x30, 0x28, 0x3d, 0x9e, 0xe4, 0x4c,
    0x61, 0xaf, 0x19, 0xe3, 0x60, 0x6b, 0x18, 0x23, 0x8b, 0xd3, 0x14, 0xeb, 0xd9, 0x12, 0x7d, 0xf0,
    0xfc, 0xf2, 0x46, 0x0b, 0xd6, 0x39, 0x12, 0x18, 0x51, 0xf5, 0x8c, 0x36, 0x3d, 0x7d, 0xf0, 0xf3,
    0xfb, 0x8f, 0x67, 0x52, 0xeb, 0xac, 0x07, 0x71, 0xba, 0x76, 0xed, 0x22, 0xe8, 0xa3, 0x68, 0x62,
    0xf9, 0xfd, 0x0d, 0x0b, 0x80, 0xa0, 0x76, 0xf9, 0xcf, 0x19, 0x0f, 0x16, 0x68, 0xf9, 0xd4, 0x58,
    0x5b, 0x53, 0xa0, 0x4e, 0x39, 0xaa, 0x9a, 0x91, 0x02, 0xec, 0x7b, 0xb6, 0xd7, 0x94, 0xe1, 0x5b,
    0x19, 0x97, 0x2a, 0xba, 0xca, 0xc6, 0xbb, 0x87, 0x78, 0x97, 0x8b, 0xc1, 0x06, 0xfc, 0xbd, 0x03,
    0x2e, 0x60, 0xcd, 0x76, 0x70, 0x5d, 0xd1, 0x4e, 0x36, 0x3a, 0xdd, 0x95, 0x1d, 0x42, 0x23, 0x76,
    0x8a, 0x5e, 0x01, 0x4d, 0x87, 0x3e, 0x56, 0xdc, 0x62, 0x1e, 0x26, 0xfc, 0x1e, 0xf1, 0xd6, 0x5b,
    0x17, 0x85, 0x9e, 0x2a, 0x1f, 0xff, 0xbc, 0xa2, 0x9f, 0xb2, 0xdd, 0xb5, 0xed, 0x9c, 0x52, 0x92,
    0x69, 0xcb, 0xb7, 0x8f, 0x62, 0x05, 0xaa, 0x1d, 0x4d, 0xd9, 0xc2, 0xd5, 0xd0, 0x14, 0x00, 0x23,
    0xcd, 0xf3, 0x7e, 0x2a, 0x27, 0xfa, 0xaf, 0xa3, 0x32, 0xb8, 0x07, 0xc1, 0x92, 0xf1, 0x24, 0x08,
    0x8e, 0x9e, 0x79, 0x4d, 0x98, 0xe9, 0x2b, 0xa3, 0x17, 0x0a, 0xc3, 0xdc, 0xc9, 0xdd, 0xd9, 0x42,
    0xd2, 0xc9, 0x0e, 0xe3, 0x9c, 0xa6, 0x37, 0x08, 0xb0, 0x55, 0xe2, 0x93, 0x28, 0x41, 0x64, 0x8c,
    0x57, 0xca, 0x6a, 0xd1, 0x97, 0x16, 0x63, 0xcf, 0xa4, 0x06, 0x85, 0xa3, 0x12, 0x22, 0x96, 0xc6,
    0x2f, 0x2a, 0x87, 0xcd, 0xca, 0xe5, 0x1b, 0xc8, 0xac, 0xb0, 0x9d, 0x7d, 0x50, 0x31, 0x6b, 0x48,
    0x54, 0x87, 0x1a, 0xbe, 0x24, 0xb3, 0x1a, 0xf6, 0xa5, 0x61, 0x97, 0xeb, 0x90, 0xd8, 0x75, 0xf8,
    0x11, 0x1a, 0xc2, 0xa6, 0x43, 0x0d, 0x5f, 0x92, 0x59, 0x0d, 0x7b, 0xd2, 0x30, 0xea, 0xb2, 0x96,
    0x46, 0xb6, 0x96, 0x7e, 0x88, 0x86, 0x5d, 0xd6, 0xd2, 0xc8, 0xd6, 0xd2, 0xbe, 0x7f, 0x12, 0x05,
    0x41, 0x8c, 0x64, 0x5c, 0x6e, 0xb6, 0xd3, 0x7f, 0x79, 0xff, 0x00, 0x65, 0xd9, 0x9d, 0x13
};
#endif

PyTypeObject *init_QCborArray(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX].type;

    Shiboken::AutoDecRef Sbk_QCborArray_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCborArray_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCborArray",
        "QCborArray",
        &Sbk_QCborArray_spec,
        &Shiboken::callCppDestructor< ::QCborArray >,
        Sbk_QCborArray_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QCborArray_TypeF(); // references _Sbk_QCborArray_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCborArray_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCborArray_SignatureBytes, QCborArray_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCborArray_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCborArray_PythonToCpp_QCborArray_PTR,
        is_QCborArray_PythonToCpp_QCborArray_PTR_Convertible,
        QCborArray_PTR_CppToPython_QCborArray,
        QCborArray_COPY_CppToPython_QCborArray);

    Shiboken::Conversions::registerConverterName(converter, "QCborArray");
    Shiboken::Conversions::registerConverterName(converter, "QCborArray*");
    Shiboken::Conversions::registerConverterName(converter, "QCborArray&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCborArray).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QCborArray_PythonToCpp_QCborArray_COPY,
        is_QCborArray_PythonToCpp_QCborArray_COPY_Convertible);

    qRegisterMetaType< ::QCborArray >("QCborArray");

    return pyType;
}
