// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qcborstreamreader_wrapper.h"

// Argument includes
#include <QString>
#include <qbytearray.h>
#include <qcborcommon.h>
#include <qcborstreamreader.h>
#include <qiodevice.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCborStreamReader_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCborStreamReader >()))
        return -1;

    ::QCborStreamReader *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QCborStreamReader", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCborStreamReader::QCborStreamReader()
    // 1: QCborStreamReader::QCborStreamReader(QIODevice*)
    // 2: QCborStreamReader::QCborStreamReader(QByteArray)
    // 3: QCborStreamReader::QCborStreamReader(const char*,qsizetype)
    // 4: QCborStreamReader::QCborStreamReader(const quint8*,qsizetype)
    if (numArgs == 0) {
        overloadId = 0; // QCborStreamReader()
    } else if (numArgs == 2
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint8>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 4; // QCborStreamReader(const quint8*,qsizetype)
    } else if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 3; // QCborStreamReader(const char*,qsizetype)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QCborStreamReader(QByteArray)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QCborStreamReader(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QCborStreamReader()
        {

            // QCborStreamReader()
            cptr = new ::QCborStreamReader();
            break;
        }
        case 1: // QCborStreamReader(QIODevice *device)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborStreamReader(QIODevice*)
                cptr = new ::QCborStreamReader(cppArg0);
            }
            break;
        }
        case 2: // QCborStreamReader(const QByteArray &data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborStreamReader(QByteArray)
                cptr = new ::QCborStreamReader(*cppArg0);
            }
            break;
        }
        case 3: // QCborStreamReader(const char *data, qsizetype len)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborStreamReader(const char*,qsizetype)
                cptr = new ::QCborStreamReader(cppArg0, cppArg1);
            }
            break;
        }
        case 4: // QCborStreamReader(const quint8 *data, qsizetype len)
        {
            quint8 *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborStreamReader(const quint8*,qsizetype)
                cptr = new ::QCborStreamReader(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCborStreamReader >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCborStreamReaderFunc_addData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addData", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborStreamReader::addData(QByteArray)
    // 1: QCborStreamReader::addData(const char*,qsizetype)
    // 2: QCborStreamReader::addData(const quint8*,qsizetype)
    if (numArgs == 2
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint8>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 2; // addData(const quint8*,qsizetype)
    } else if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 1; // addData(const char*,qsizetype)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 0; // addData(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addData(const QByteArray &data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // addData(QByteArray)
                cppSelf->addData(*cppArg0);
            }
            break;
        }
        case 1: // addData(const char *data, qsizetype len)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addData(const char*,qsizetype)
                cppSelf->addData(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // addData(const quint8 *data, qsizetype len)
        {
            quint8 *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addData(const quint8*,qsizetype)
                cppSelf->addData(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborStreamReaderFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborStreamReaderFunc_containerDepth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // containerDepth()const
        int cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->containerDepth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_currentOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentOffset()const
        qint64 cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->currentOffset();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_currentStringChunkSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentStringChunkSize()const
        qsizetype cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->currentStringChunkSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_device(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // device()const
        QIODevice * cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->device();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_enterContainer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // enterContainer()
        bool cppResult = cppSelf->enterContainer();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_hasNext(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasNext()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->hasNext();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isArray()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isArray();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isBool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isBool()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isBool();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isByteArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isByteArray()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isByteArray();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isContainer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isContainer()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isContainer();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isDouble(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDouble()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isDouble();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isFalse(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFalse()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isFalse();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isFloat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFloat()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isFloat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isFloat16(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFloat16()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isFloat16();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isInteger(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isInteger()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isInteger();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isInvalid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isInvalid()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isInvalid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isLengthKnown(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLengthKnown()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isLengthKnown();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isMap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isMap()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isMap();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isNegativeInteger(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNegativeInteger()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isNegativeInteger();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isSimpleType(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "isSimpleType", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborStreamReader::isSimpleType()const->bool
    // 1: QCborStreamReader::isSimpleType(QCborSimpleType)const->bool
    if (numArgs == 0) {
        overloadId = 0; // isSimpleType()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborSimpleType_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // isSimpleType(QCborSimpleType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isSimpleType", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // isSimpleType() const
        {

            // isSimpleType()const
            bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isSimpleType();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            break;
        }
        case 1: // isSimpleType(QCborSimpleType st) const
        {
            ::QCborSimpleType cppArg0 = static_cast< ::QCborSimpleType>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isSimpleType(QCborSimpleType)const
                bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isSimpleType(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isString()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isString();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isTag(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isTag()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isTag();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isTrue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isTrue()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isTrue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isUndefined(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isUndefined()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isUndefined();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isUnsignedInteger(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isUnsignedInteger()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isUnsignedInteger();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_lastError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastError()const
        QCborError cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->lastError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborError_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_leaveContainer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // leaveContainer()
        bool cppResult = cppSelf->leaveContainer();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // length()const
        quint64 cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->length();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_next(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "next", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]);

    if (PyArg_ParseTuple(args, "|O:next", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborStreamReader::next(int=)->bool
    if (numArgs == 0) {
        overloadId = 0; // next(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // next(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "next", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_maxRecursion = Shiboken::String::createStaticString("maxRecursion");
            if (PyDict_Contains(kwds, key_maxRecursion) != 0) {
                value = PyDict_GetItem(kwds, key_maxRecursion);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_maxRecursion);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "next", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "next", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_maxRecursion);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "next", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]);
            }
        }
        int cppArg0 = 10000;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // next(int)
            bool cppResult = cppSelf->next(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_parentContainerType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parentContainerType()const
        QCborStreamReader::Type cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->parentContainerType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_readAllByteArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readAllByteArray()
        QByteArray cppResult = cppSelf->readAllByteArray();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_readAllString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readAllString()
        QString cppResult = cppSelf->readAllString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_readAllUtf8String(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readAllUtf8String()
        QByteArray cppResult = cppSelf->readAllUtf8String();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_readAndAppendToByteArray(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborStreamReader::readAndAppendToByteArray(QByteArray&)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // readAndAppendToByteArray(QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "readAndAppendToByteArray", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // readAndAppendToByteArray(QByteArray&)
            bool cppResult = cppSelf->readAndAppendToByteArray(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_readAndAppendToString(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborStreamReader::readAndAppendToString(QString&)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // readAndAppendToString(QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "readAndAppendToString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // readAndAppendToString(QString&)
            bool cppResult = cppSelf->readAndAppendToString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_readAndAppendToUtf8String(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborStreamReader::readAndAppendToUtf8String(QByteArray&)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // readAndAppendToUtf8String(QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "readAndAppendToUtf8String", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // readAndAppendToUtf8String(QByteArray&)
            bool cppResult = cppSelf->readAndAppendToUtf8String(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_readByteArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readByteArray()
        QCborStringResultByteArray cppResult = cppSelf->readByteArray();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStringResultByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_readString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readString()
        QCborStringResultString cppResult = cppSelf->readString();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStringResultString_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_readUtf8String(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readUtf8String()
        QCborStringResultByteArray cppResult = cppSelf->readUtf8String();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStringResultByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_reparse(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reparse()
        cppSelf->reparse();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborStreamReaderFunc_reset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reset()
        cppSelf->reset();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborStreamReaderFunc_setDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborStreamReader::setDevice(QIODevice*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDevice", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDevice(QIODevice*)
            cppSelf->setDevice(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborStreamReaderFunc_toBool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toBool()const
        bool cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->toBool();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_toDouble(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toDouble()const
        double cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->toDouble();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_toFloat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toFloat()const
        float cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->toFloat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_toInteger(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toInteger()const
        qint64 cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->toInteger();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_toSimpleType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toSimpleType()const
        QCborSimpleType cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->toSimpleType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborSimpleType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_toTag(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toTag()const
        QCborTag cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->toTag();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborTag_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_toUnsignedInteger(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toUnsignedInteger()const
        quint64 cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->toUnsignedInteger();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamReaderFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QCborStreamReader::Type cppResult = const_cast<const ::QCborStreamReader *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCborStreamReader_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QCborStreamReader_EnumFlagInfo[] = {
    "StringResultCode:Enum",
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCborStreamReader_methods[] = {
    {"addData", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_addData), METH_VARARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_clear), METH_NOARGS, nullptr},
    {"containerDepth", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_containerDepth), METH_NOARGS, nullptr},
    {"currentOffset", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_currentOffset), METH_NOARGS, nullptr},
    {"currentStringChunkSize", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_currentStringChunkSize), METH_NOARGS, nullptr},
    {"device", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_device), METH_NOARGS, nullptr},
    {"enterContainer", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_enterContainer), METH_NOARGS, nullptr},
    {"hasNext", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_hasNext), METH_NOARGS, nullptr},
    {"isArray", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isArray), METH_NOARGS, nullptr},
    {"isBool", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isBool), METH_NOARGS, nullptr},
    {"isByteArray", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isByteArray), METH_NOARGS, nullptr},
    {"isContainer", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isContainer), METH_NOARGS, nullptr},
    {"isDouble", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isDouble), METH_NOARGS, nullptr},
    {"isFalse", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isFalse), METH_NOARGS, nullptr},
    {"isFloat", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isFloat), METH_NOARGS, nullptr},
    {"isFloat16", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isFloat16), METH_NOARGS, nullptr},
    {"isInteger", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isInteger), METH_NOARGS, nullptr},
    {"isInvalid", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isInvalid), METH_NOARGS, nullptr},
    {"isLengthKnown", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isLengthKnown), METH_NOARGS, nullptr},
    {"isMap", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isMap), METH_NOARGS, nullptr},
    {"isNegativeInteger", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isNegativeInteger), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isNull), METH_NOARGS, nullptr},
    {"isSimpleType", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isSimpleType), METH_VARARGS, nullptr},
    {"isString", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isString), METH_NOARGS, nullptr},
    {"isTag", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isTag), METH_NOARGS, nullptr},
    {"isTrue", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isTrue), METH_NOARGS, nullptr},
    {"isUndefined", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isUndefined), METH_NOARGS, nullptr},
    {"isUnsignedInteger", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isUnsignedInteger), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_isValid), METH_NOARGS, nullptr},
    {"lastError", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_lastError), METH_NOARGS, nullptr},
    {"leaveContainer", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_leaveContainer), METH_NOARGS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_length), METH_NOARGS, nullptr},
    {"next", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_next), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"parentContainerType", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_parentContainerType), METH_NOARGS, nullptr},
    {"readAllByteArray", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_readAllByteArray), METH_NOARGS, nullptr},
    {"readAllString", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_readAllString), METH_NOARGS, nullptr},
    {"readAllUtf8String", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_readAllUtf8String), METH_NOARGS, nullptr},
    {"readAndAppendToByteArray", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_readAndAppendToByteArray), METH_O, nullptr},
    {"readAndAppendToString", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_readAndAppendToString), METH_O, nullptr},
    {"readAndAppendToUtf8String", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_readAndAppendToUtf8String), METH_O, nullptr},
    {"readByteArray", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_readByteArray), METH_NOARGS, nullptr},
    {"readString", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_readString), METH_NOARGS, nullptr},
    {"readUtf8String", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_readUtf8String), METH_NOARGS, nullptr},
    {"reparse", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_reparse), METH_NOARGS, nullptr},
    {"reset", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_reset), METH_NOARGS, nullptr},
    {"setDevice", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_setDevice), METH_O, nullptr},
    {"toBool", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_toBool), METH_NOARGS, nullptr},
    {"toDouble", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_toDouble), METH_NOARGS, nullptr},
    {"toFloat", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_toFloat), METH_NOARGS, nullptr},
    {"toInteger", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_toInteger), METH_NOARGS, nullptr},
    {"toSimpleType", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_toSimpleType), METH_NOARGS, nullptr},
    {"toTag", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_toTag), METH_NOARGS, nullptr},
    {"toUnsignedInteger", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_toUnsignedInteger), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QCborStreamReaderFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QCborStreamReader___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QCborStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QCborStreamReader_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCborStreamReader_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCborStreamReader_Type = nullptr;
static PyTypeObject *Sbk_QCborStreamReader_TypeF(void)
{
    return _Sbk_QCborStreamReader_Type;
}

static PyType_Slot Sbk_QCborStreamReader_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCborStreamReader_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCborStreamReader_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCborStreamReader_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCborStreamReader_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QCborStreamReader___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCborStreamReader_spec = {
    "2:PySide6.QtCore.QCborStreamReader",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCborStreamReader_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QCborStreamReader_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCborStreamReader::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCborStreamReader::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCborStreamReader_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_Type_IDX])))
        return Enum_PythonToCpp_QCborStreamReader_Type;
    return {};
}

static PyObject *QCborStreamReader_Type_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCborStreamReader::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCborStreamReader::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_Type_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QCborStreamReader_StringResultCode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCborStreamReader::StringResultCode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCborStreamReader::StringResultCode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCborStreamReader_StringResultCode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_StringResultCode_IDX])))
        return Enum_PythonToCpp_QCborStreamReader_StringResultCode;
    return {};
}

static PyObject *QCborStreamReader_StringResultCode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCborStreamReader::StringResultCode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCborStreamReader::StringResultCode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_StringResultCode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCborStreamReader_PythonToCpp_QCborStreamReader_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCborStreamReader_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCborStreamReader_PythonToCpp_QCborStreamReader_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCborStreamReader_TypeF()))
        return QCborStreamReader_PythonToCpp_QCborStreamReader_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCborStreamReader_PTR_CppToPython_QCborStreamReader(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QCborStreamReader_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCborStreamReader_SignatureStrings[] = {
    "4:PySide6.QtCore.QCborStreamReader(self)",
    "3:PySide6.QtCore.QCborStreamReader(self,device:PySide6.QtCore.QIODevice)",
    "2:PySide6.QtCore.QCborStreamReader(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "1:PySide6.QtCore.QCborStreamReader(self,data:char*,len:qsizetype)",
    "0:PySide6.QtCore.QCborStreamReader(self,data:quint8*,len:qsizetype)",
    "2:PySide6.QtCore.QCborStreamReader.addData(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "1:PySide6.QtCore.QCborStreamReader.addData(self,data:char*,len:qsizetype)",
    "0:PySide6.QtCore.QCborStreamReader.addData(self,data:quint8*,len:qsizetype)",
    "PySide6.QtCore.QCborStreamReader.clear(self)",
    "PySide6.QtCore.QCborStreamReader.containerDepth(self)->int",
    "PySide6.QtCore.QCborStreamReader.currentOffset(self)->qint64",
    "PySide6.QtCore.QCborStreamReader.currentStringChunkSize(self)->qsizetype",
    "PySide6.QtCore.QCborStreamReader.device(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtCore.QCborStreamReader.enterContainer(self)->bool",
    "PySide6.QtCore.QCborStreamReader.hasNext(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isArray(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isBool(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isByteArray(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isContainer(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isDouble(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isFalse(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isFloat(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isFloat16(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isInteger(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isInvalid(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isLengthKnown(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isMap(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isNegativeInteger(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isNull(self)->bool",
    "1:PySide6.QtCore.QCborStreamReader.isSimpleType(self)->bool",
    "0:PySide6.QtCore.QCborStreamReader.isSimpleType(self,st:PySide6.QtCore.QCborSimpleType)->bool",
    "PySide6.QtCore.QCborStreamReader.isString(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isTag(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isTrue(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isUndefined(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isUnsignedInteger(self)->bool",
    "PySide6.QtCore.QCborStreamReader.isValid(self)->bool",
    "PySide6.QtCore.QCborStreamReader.lastError(self)->PySide6.QtCore.QCborError",
    "PySide6.QtCore.QCborStreamReader.leaveContainer(self)->bool",
    "PySide6.QtCore.QCborStreamReader.length(self)->quint64",
    "PySide6.QtCore.QCborStreamReader.next(self,maxRecursion:int=10000)->bool",
    "PySide6.QtCore.QCborStreamReader.parentContainerType(self)->PySide6.QtCore.QCborStreamReader.Type",
    "PySide6.QtCore.QCborStreamReader.readAllByteArray(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QCborStreamReader.readAllString(self)->QString",
    "PySide6.QtCore.QCborStreamReader.readAllUtf8String(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QCborStreamReader.readAndAppendToByteArray(self,dst:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "PySide6.QtCore.QCborStreamReader.readAndAppendToString(self,dst:QString)->bool",
    "PySide6.QtCore.QCborStreamReader.readAndAppendToUtf8String(self,dst:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "PySide6.QtCore.QCborStreamReader.readByteArray(self)->PySide6.QtCore.QCborStringResultByteArray",
    "PySide6.QtCore.QCborStreamReader.readString(self)->PySide6.QtCore.QCborStringResultString",
    "PySide6.QtCore.QCborStreamReader.readUtf8String(self)->PySide6.QtCore.QCborStringResultByteArray",
    "PySide6.QtCore.QCborStreamReader.reparse(self)",
    "PySide6.QtCore.QCborStreamReader.reset(self)",
    "PySide6.QtCore.QCborStreamReader.setDevice(self,device:PySide6.QtCore.QIODevice)",
    "PySide6.QtCore.QCborStreamReader.toBool(self)->bool",
    "PySide6.QtCore.QCborStreamReader.toDouble(self)->double",
    "PySide6.QtCore.QCborStreamReader.toFloat(self)->float",
    "PySide6.QtCore.QCborStreamReader.toInteger(self)->qint64",
    "PySide6.QtCore.QCborStreamReader.toSimpleType(self)->PySide6.QtCore.QCborSimpleType",
    "PySide6.QtCore.QCborStreamReader.toTag(self)->PySide6.QtCore.QCborTag",
    "PySide6.QtCore.QCborStreamReader.toUnsignedInteger(self)->quint64",
    "PySide6.QtCore.QCborStreamReader.type(self)->PySide6.QtCore.QCborStreamReader.Type",
    nullptr}; // Sentinel
#else
static constexpr size_t QCborStreamReader_SignatureByteSize = 620;
static constexpr uint8_t QCborStreamReader_SignatureBytes[620] = {
    0x78, 0xda, 0xb5, 0x97, 0x4d, 0x8f, 0xda, 0x30, 0x10, 0x86, 0xef, 0xfc, 0x8a, 0x1e, 0x4b, 0x95,
    0x22, 0x68, 0x57, 0x68, 0x85, 0xd4, 0x4a, 0x2c, 0xb4, 0x12, 0x6a, 0xcb, 0x96, 0xaf, 0x5e, 0xaa,
    0x1e, 0x0c, 0x9e, 0x80, 0x55, 0x63, 0x07, 0xdb, 0xa1, 0x4b, 0x7f, 0x7d, 0x87, 0xb0, 0x49, 0x09,
    0x1f, 0x6b, 0x4f, 0x56, 0xcb, 0x89, 0xc0, 0x3c, 0xef, 0x78, 0xec, 0xf1, 0xcc, 0xe4, 0xa6, 0xf3,
    0x7d, 0x37, 0x11, 0x1c, 0xda, 0x8d, 0x91, 0xeb, 0x69, 0x03, 0x8d, 0x51, 0x6f, 0xae, 0xcd, 0xc4,
    0x19, 0x60, 0xeb, 0x31, 0x30, 0x0e, 0xe6, 0xb5, 0x05, 0x19, 0xd7, 0x6b, 0xef, 0xc3, 0x0c, 0x23,
    0x0e, 0x5b, 0xb1, 0x80, 0x33, 0xe3, 0xc1, 0x7d, 0x3f, 0xfb, 0xa3, 0x5e, 0x7b, 0x17, 0x2a, 0xc4,
    0x1c, 0xeb, 0xb8, 0x5d, 0x22, 0xd4, 0xb2, 0x31, 0x53, 0x42, 0xab, 0x9f, 0xa7, 0xdc, 0xdd, 0xce,
    0x41, 0xd7, 0x18, 0xb6, 0x8b, 0x5e, 0x2d, 0x56, 0xcc, 0xbc, 0xf9, 0x55, 0xaf, 0xb5, 0x28, 0xe2,
    0x19, 0x14, 0x49, 0x50, 0x9d, 0x8d, 0x15, 0x7f, 0x01, 0x7d, 0xe1, 0xf2, 0x9a, 0x14, 0x85, 0x4d,
    0x2a, 0x94, 0xbb, 0x3d, 0xd3, 0xf0, 0x87, 0xd8, 0x60, 0x9c, 0xf7, 0x51, 0xe1, 0x45, 0x43, 0xbd,
    0xe0, 0xa4, 0x62, 0xc8, 0x17, 0x94, 0xae, 0x84, 0xee, 0x55, 0x5a, 0x48, 0x60, 0x79, 0x4e, 0xf9,
    0x8d, 0xb5, 0x72, 0x4c, 0x28, 0x30, 0x7d, 0x48, 0xdc, 0xea, 0x40, 0xbd, 0xfd, 0x88, 0x8e, 0x03,
    0xd0, 0xd4, 0x18, 0x50, 0xee, 0x3e, 0x8e, 0x2d, 0xb8, 0x9c, 0xdc, 0x20, 0xda, 0xbe, 0x09, 0x86,
    0xf1, 0x37, 0x3c, 0x92, 0xde, 0x2a, 0x55, 0xbf, 0x27, 0x18, 0x61, 0xa1, 0x92, 0x87, 0xeb, 0x17,
    0x3a, 0xdc, 0x86, 0x1c, 0xbc, 0x76, 0x29, 0xfc, 0x3a, 0xb8, 0x18, 0x30, 0xbd, 0x7c, 0x37, 0x72,
    0xbd, 0xb9, 0xd6, 0xd2, 0xcf, 0xae, 0x98, 0x1d, 0xc2, 0x83, 0xa3, 0x41, 0xc2, 0x66, 0xe9, 0x46,
    0x85, 0xee, 0xd0, 0x8e, 0xcc, 0xe4, 0xb9, 0x4d, 0x05, 0x2b, 0xee, 0x87, 0xb0, 0x7d, 0x9d, 0xce,
    0x25, 0x50, 0xa9, 0xcf, 0x4c, 0x5a, 0x3a, 0x24, 0x35, 0x73, 0x95, 0xa0, 0x56, 0x9b, 0x8a, 0x0d,
    0x30, 0x49, 0x96, 0xf4, 0xdd, 0x18, 0xa8, 0x2d, 0x93, 0x82, 0x53, 0xb1, 0xaf, 0xa0, 0x96, 0x6e,
    0xf5, 0x45, 0xe9, 0x3f, 0x8a, 0x8a, 0x7e, 0x63, 0x09, 0x15, 0x19, 0xc2, 0x92, 0x39, 0xb1, 0x85,
    0x8a, 0x31, 0x0e, 0x53, 0x59, 0xce, 0xcb, 0x80, 0xea, 0x29, 0xec, 0x44, 0xac, 0x13, 0x09, 0x53,
    0xbc, 0xe9, 0x25, 0xb6, 0x59, 0x81, 0x8d, 0xac, 0xbb, 0x4c, 0x15, 0x66, 0x84, 0x68, 0x0e, 0x75,
    0x89, 0xba, 0x07, 0x53, 0x46, 0x47, 0x4c, 0x4a, 0xce, 0xf8, 0x99, 0xe2, 0x10, 0xe3, 0xad, 0xe4,
    0x74, 0xd0, 0x8a, 0x25, 0x72, 0x15, 0x8f, 0xf8, 0x07, 0x3d, 0x89, 0x25, 0xb3, 0xee, 0x93, 0x31,
    0xda, 0x5c, 0x2b, 0xd0, 0x7b, 0x22, 0x33, 0x08, 0xd0, 0x02, 0xb6, 0x85, 0x8a, 0x15, 0x49, 0x66,
    0x57, 0xa9, 0x68, 0x2f, 0x69, 0x60, 0x97, 0x52, 0x79, 0x55, 0x8f, 0xd6, 0xec, 0x61, 0x0c, 0xd8,
    0xb4, 0x2c, 0xce, 0x0e, 0x1d, 0xa4, 0x3f, 0xb4, 0x9a, 0xf8, 0x09, 0xf6, 0x9f, 0xb0, 0x7d, 0xb7,
    0x2b, 0x16, 0x7f, 0x9c, 0xf0, 0x5e, 0x76, 0x1a, 0xd4, 0x07, 0xf1, 0x2b, 0xef, 0x4a, 0x79, 0x56,
    0xea, 0xaf, 0xce, 0x39, 0xc1, 0x92, 0xe5, 0xbb, 0x30, 0x3a, 0x3c, 0x06, 0xd3, 0x33, 0x17, 0xdf,
    0x96, 0x15, 0x9e, 0xbb, 0x22, 0xc5, 0xbb, 0x49, 0x02, 0x8a, 0x4f, 0x75, 0x39, 0xd8, 0x88, 0x63,
    0x05, 0x20, 0xce, 0x78, 0xa1, 0xe7, 0x77, 0xe2, 0xf8, 0x28, 0xa0, 0xcc, 0xeb, 0xe3, 0xa6, 0x54,
    0x95, 0x3b, 0xd9, 0xa3, 0x97, 0x0e, 0xc4, 0x9b, 0x23, 0x8f, 0x14, 0xfa, 0x1f, 0x83, 0x4d, 0xa5,
    0x23, 0x9e, 0xd0, 0xd3, 0xc7, 0x7d, 0x2a, 0x4e, 0xc9, 0x27, 0x7f, 0x32, 0x3d, 0x6b, 0xe9, 0x78,
    0x4b, 0xf3, 0xf9, 0x23, 0xc4, 0xbc, 0x18, 0x7b, 0xfd, 0xc6, 0x68, 0xda, 0xff, 0x3f, 0xa8, 0xfa,
    0x5f, 0xe1, 0xbc, 0x82, 0x4e, 0xd3, 0x07, 0x41, 0xa7, 0xcb, 0x63, 0x19, 0xcf, 0x9e, 0x42, 0xb8,
    0xd2, 0x8c, 0x15, 0xef, 0x1f, 0x42, 0xa8, 0x93, 0x36, 0x13, 0xfa, 0x6a, 0xe0, 0xf4, 0xf9, 0x54,
    0xf0, 0x74, 0x63, 0x0f, 0xd1, 0x3c, 0xea, 0xcd, 0x97, 0xac, 0xf1, 0xef, 0x10, 0x95, 0x2b, 0x1d,
    0x34, 0xb8, 0xa1, 0x38, 0x72, 0xe1, 0xff, 0x07, 0x0e, 0xe0, 0xd3, 0x73
};
#endif

PyTypeObject *init_QCborStreamReader(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX].type;

    Shiboken::AutoDecRef Sbk_QCborStreamReader_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCborStreamReader_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCborStreamReader",
        "QCborStreamReader*",
        &Sbk_QCborStreamReader_spec,
        &Shiboken::callCppDestructor< ::QCborStreamReader >,
        Sbk_QCborStreamReader_Type_bases.object(),
        0);
    auto *pyType = Sbk_QCborStreamReader_TypeF(); // references _Sbk_QCborStreamReader_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCborStreamReader_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCborStreamReader_SignatureBytes, QCborStreamReader_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCborStreamReader_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCborStreamReader_PythonToCpp_QCborStreamReader_PTR,
        is_QCborStreamReader_PythonToCpp_QCborStreamReader_PTR_Convertible,
        QCborStreamReader_PTR_CppToPython_QCborStreamReader);

    Shiboken::Conversions::registerConverterName(converter, "QCborStreamReader");
    Shiboken::Conversions::registerConverterName(converter, "QCborStreamReader*");
    Shiboken::Conversions::registerConverterName(converter, "QCborStreamReader&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCborStreamReader).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCborStreamReader_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "UnsignedInteger",
        "NegativeInteger",
        "ByteString",
        "ByteArray",
        "TextString",
        "String",
        "Array",
        "Map",
        "Tag",
        "SimpleType",
        "HalfFloat",
        "Float16",
        "Float",
        "Double",
        "Invalid",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(QCborStreamReader::Type::UnsignedInteger), //  0x00  0
        uint8_t(QCborStreamReader::Type::NegativeInteger), //  0x20  32
        uint8_t(QCborStreamReader::Type::ByteString),      //  0x40  64
        uint8_t(QCborStreamReader::Type::ByteArray),       //  0x40  64
        uint8_t(QCborStreamReader::Type::TextString),      //  0x60  96
        uint8_t(QCborStreamReader::Type::String),          //  0x60  96
        uint8_t(QCborStreamReader::Type::Array),           //  0x80  128
        uint8_t(QCborStreamReader::Type::Map),             //  0xa0  160
        uint8_t(QCborStreamReader::Type::Tag),             //  0xc0  192
        uint8_t(QCborStreamReader::Type::SimpleType),      //  0xe0  224
        uint8_t(QCborStreamReader::Type::HalfFloat),       //  0xf9  249
        uint8_t(QCborStreamReader::Type::Float16),         //  0xf9  249
        uint8_t(QCborStreamReader::Type::Float),           //  0xfa  250
        uint8_t(QCborStreamReader::Type::Double),          //  0xfb  251
        uint8_t(QCborStreamReader::Type::Invalid)          //  0xff  255
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCborStreamReader_TypeF(),
        "2:PySide6.QtCore.QCborStreamReader.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_Type_IDX].type = EType;
    // Register converter for enum 'QCborStreamReader::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCborStreamReader_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCborStreamReader_Type,
            is_Enum_PythonToCpp_QCborStreamReader_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCborStreamReader::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    // Initialization of enum 'StringResultCode'.
    const char *StringResultCode_Initializer[] = {
        "EndOfString",
        "Ok",
        "Error",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t StringResultCode_InitializerValues[] = {
        int8_t(QCborStreamReader::StringResultCode::EndOfString), //  0x00  0
        int8_t(QCborStreamReader::StringResultCode::Ok),          //  0x01  1
        int8_t(QCborStreamReader::StringResultCode::Error)        // -0x01 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCborStreamReader_TypeF(),
        "2:PySide6.QtCore.QCborStreamReader.StringResultCode",
        StringResultCode_Initializer, StringResultCode_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_StringResultCode_IDX].type = EType;
    // Register converter for enum 'QCborStreamReader::StringResultCode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCborStreamReader_StringResultCode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCborStreamReader_StringResultCode,
            is_Enum_PythonToCpp_QCborStreamReader_StringResultCode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCborStreamReader::StringResultCode");
        Shiboken::Conversions::registerConverterAlias(converter, "StringResultCode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StringResultCode' enum.

    qRegisterMetaType< ::QCborStreamReader *>();
    qRegisterMetaType< ::QCborStreamReader::Type >("QCborStreamReader::Type");
    qRegisterMetaType< ::QCborStreamReader::StringResultCode >("QCborStreamReader::StringResultCode");

    return pyType;
}
