// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qcborstreamwriter_wrapper.h"

// Argument includes
#include <QStringView>
#include <QtCore/qlatin1stringview.h>
#include <qbytearray.h>
#include <qcborcommon.h>
#include <qiodevice.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCborStreamWriter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCborStreamWriter >()))
        return -1;

    ::QCborStreamWriter *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QCborStreamWriter", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCborStreamWriter::QCborStreamWriter(QByteArray*)
    // 1: QCborStreamWriter::QCborStreamWriter(QIODevice*)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QCborStreamWriter(QIODevice*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QCborStreamWriter(QByteArray*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QCborStreamWriter(QByteArray *data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborStreamWriter(QByteArray*)
                cptr = new ::QCborStreamWriter(cppArg0);
            }
            break;
        }
        case 1: // QCborStreamWriter(QIODevice *device)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborStreamWriter(QIODevice*)
                cptr = new ::QCborStreamWriter(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCborStreamWriter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCborStreamWriterFunc_append(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);

    if (PyArg_ParseTuple(args, "|OO:append", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborStreamWriter::append(QCborKnownTags)
    // 1: QCborStreamWriter::append(QCborSimpleType)
    // 2: QCborStreamWriter::append(QCborTag)
    // 3: QCborStreamWriter::append(QLatin1String)
    // 4: QCborStreamWriter::append(QStringView)
    // 5: QCborStreamWriter::append(bool)
    // 6: QCborStreamWriter::append(QByteArray)
    // 7: QCborStreamWriter::append(const char*,qsizetype=)
    // 8: QCborStreamWriter::append(double)
    // 9: QCborStreamWriter::append(float)
    // 10: QCborStreamWriter::append(int)
    // 11: QCborStreamWriter::append(qint64)
    // 12: QCborStreamWriter::append(quint64)
    // 13: QCborStreamWriter::append(uint)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArgs[0])))) {
        overloadId = 12; // append(quint64)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 4; // append(QStringView)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], (pyArgs[0])))) {
        overloadId = 3; // append(QLatin1String)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborTag_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 2; // append(QCborTag)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborSimpleType_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // append(QCborSimpleType)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborKnownTags_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // append(QCborKnownTags)
    } else if (numArgs == 1
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))) {
        overloadId = 8; // append(double)
    } else if (numArgs == 1
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))) {
        overloadId = 9; // append(float)
    } else if (numArgs >= 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 7; // append(const char*,qsizetype)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 7; // append(const char*,qsizetype)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 6; // append(QByteArray)
    } else if (numArgs == 1
        && PyBool_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 5; // append(bool)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        overloadId = 11; // append(qint64)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0])))) {
        overloadId = 13; // append(uint)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 10; // append(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // append(QCborKnownTags tag)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
            }
            ::QCborKnownTags cppArg0{QCborKnownTags::DateTimeString};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QCborKnownTags)
                cppSelf->append(cppArg0);
            }
            break;
        }
        case 1: // append(QCborSimpleType st)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
            }
            ::QCborSimpleType cppArg0 = static_cast< ::QCborSimpleType>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QCborSimpleType)
                cppSelf->append(cppArg0);
            }
            break;
        }
        case 2: // append(QCborTag tag)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
            }
            ::QCborTag cppArg0 = static_cast< ::QCborTag>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QCborTag)
                cppSelf->append(cppArg0);
            }
            break;
        }
        case 3: // append(QLatin1String str)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
            }
            ::QLatin1String cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QLatin1String)
                cppSelf->append(cppArg0);
            }
            break;
        }
        case 4: // append(QStringView str)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QStringView)
                cppSelf->append(QStringView(cppArg0));
            }
            break;
        }
        case 5: // append(bool b)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
            }
            bool cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(bool)
                cppSelf->append(cppArg0);
            }
            break;
        }
        case 6: // append(const QByteArray &ba)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QByteArray)
                cppSelf->append(*cppArg0);
            }
            break;
        }
        case 7: // append(const char *str, qsizetype size)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_size = Shiboken::String::createStaticString("size");
                if (PyDict_Contains(kwds, key_size) != 0) {
                    value = PyDict_GetItem(kwds, key_size);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_size);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_size);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
                }
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1 = -1;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(const char*,qsizetype)
                cppSelf->append(cppArg0, cppArg1);
            }
            break;
        }
        case 8: // append(double d)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
            }
            double cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(double)
                cppSelf->append(cppArg0);
            }
            break;
        }
        case 9: // append(float f)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
            }
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(float)
                cppSelf->append(cppArg0);
            }
            break;
        }
        case 10: // append(int i)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(int)
                cppSelf->append(cppArg0);
            }
            break;
        }
        case 11: // append(qint64 i)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
            }
            qint64 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(qint64)
                cppSelf->append(cppArg0);
            }
            break;
        }
        case 12: // append(quint64 u)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
            }
            quint64 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(quint64)
                cppSelf->append(cppArg0);
            }
            break;
        }
        case 13: // append(uint u)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);
            }
            uint cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(uint)
                cppSelf->append(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborStreamWriterFunc_appendByteString(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "appendByteString", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborStreamWriter::appendByteString(const char*,qsizetype)
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // appendByteString(const char*,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "appendByteString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // appendByteString(const char*,qsizetype)
            cppSelf->appendByteString(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborStreamWriterFunc_appendNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // appendNull()
        cppSelf->appendNull();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborStreamWriterFunc_appendTextString(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "appendTextString", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborStreamWriter::appendTextString(const char*,qsizetype)
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // appendTextString(const char*,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "appendTextString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // appendTextString(const char*,qsizetype)
            cppSelf->appendTextString(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborStreamWriterFunc_appendUndefined(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // appendUndefined()
        cppSelf->appendUndefined();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborStreamWriterFunc_device(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // device()const
        QIODevice * cppResult = const_cast<const ::QCborStreamWriter *>(cppSelf)->device();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamWriterFunc_endArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // endArray()
        bool cppResult = cppSelf->endArray();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamWriterFunc_endMap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // endMap()
        bool cppResult = cppSelf->endMap();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborStreamWriterFunc_setDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborStreamWriter::setDevice(QIODevice*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDevice", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDevice(QIODevice*)
            cppSelf->setDevice(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborStreamWriterFunc_startArray(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "startArray", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborStreamWriter::startArray()
    // 1: QCborStreamWriter::startArray(quint64)
    if (numArgs == 0) {
        overloadId = 0; // startArray()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArgs[0])))) {
        overloadId = 1; // startArray(quint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "startArray", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // startArray()
        {

            // startArray()
            cppSelf->startArray();
            break;
        }
        case 1: // startArray(quint64 count)
        {
            quint64 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // startArray(quint64)
                cppSelf->startArray(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborStreamWriterFunc_startMap(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "startMap", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborStreamWriter::startMap()
    // 1: QCborStreamWriter::startMap(quint64)
    if (numArgs == 0) {
        overloadId = 0; // startMap()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArgs[0])))) {
        overloadId = 1; // startMap(quint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "startMap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // startMap()
        {

            // startMap()
            cppSelf->startMap();
            break;
        }
        case 1: // startMap(quint64 count)
        {
            quint64 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // startMap(quint64)
                cppSelf->startMap(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QCborStreamWriter_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCborStreamWriter_methods[] = {
    {"append", reinterpret_cast<PyCFunction>(Sbk_QCborStreamWriterFunc_append), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"appendByteString", reinterpret_cast<PyCFunction>(Sbk_QCborStreamWriterFunc_appendByteString), METH_VARARGS, nullptr},
    {"appendNull", reinterpret_cast<PyCFunction>(Sbk_QCborStreamWriterFunc_appendNull), METH_NOARGS, nullptr},
    {"appendTextString", reinterpret_cast<PyCFunction>(Sbk_QCborStreamWriterFunc_appendTextString), METH_VARARGS, nullptr},
    {"appendUndefined", reinterpret_cast<PyCFunction>(Sbk_QCborStreamWriterFunc_appendUndefined), METH_NOARGS, nullptr},
    {"device", reinterpret_cast<PyCFunction>(Sbk_QCborStreamWriterFunc_device), METH_NOARGS, nullptr},
    {"endArray", reinterpret_cast<PyCFunction>(Sbk_QCborStreamWriterFunc_endArray), METH_NOARGS, nullptr},
    {"endMap", reinterpret_cast<PyCFunction>(Sbk_QCborStreamWriterFunc_endMap), METH_NOARGS, nullptr},
    {"setDevice", reinterpret_cast<PyCFunction>(Sbk_QCborStreamWriterFunc_setDevice), METH_O, nullptr},
    {"startArray", reinterpret_cast<PyCFunction>(Sbk_QCborStreamWriterFunc_startArray), METH_VARARGS, nullptr},
    {"startMap", reinterpret_cast<PyCFunction>(Sbk_QCborStreamWriterFunc_startMap), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QCborStreamWriter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCborStreamWriter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCborStreamWriter_Type = nullptr;
static PyTypeObject *Sbk_QCborStreamWriter_TypeF(void)
{
    return _Sbk_QCborStreamWriter_Type;
}

static PyType_Slot Sbk_QCborStreamWriter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCborStreamWriter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCborStreamWriter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCborStreamWriter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCborStreamWriter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCborStreamWriter_spec = {
    "2:PySide6.QtCore.QCborStreamWriter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCborStreamWriter_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCborStreamWriter_PythonToCpp_QCborStreamWriter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCborStreamWriter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCborStreamWriter_PythonToCpp_QCborStreamWriter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCborStreamWriter_TypeF()))
        return QCborStreamWriter_PythonToCpp_QCborStreamWriter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCborStreamWriter_PTR_CppToPython_QCborStreamWriter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QCborStreamWriter_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCborStreamWriter_SignatureStrings[] = {
    "1:PySide6.QtCore.QCborStreamWriter(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "0:PySide6.QtCore.QCborStreamWriter(self,device:PySide6.QtCore.QIODevice)",
    "13:PySide6.QtCore.QCborStreamWriter.append(self,tag:PySide6.QtCore.QCborKnownTags)",
    "12:PySide6.QtCore.QCborStreamWriter.append(self,st:PySide6.QtCore.QCborSimpleType)",
    "11:PySide6.QtCore.QCborStreamWriter.append(self,tag:PySide6.QtCore.QCborTag)",
    "10:PySide6.QtCore.QCborStreamWriter.append(self,str:QLatin1String)",
    "9:PySide6.QtCore.QCborStreamWriter.append(self,str:QString)",
    "8:PySide6.QtCore.QCborStreamWriter.append(self,b:bool)",
    "7:PySide6.QtCore.QCborStreamWriter.append(self,ba:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "6:PySide6.QtCore.QCborStreamWriter.append(self,str:char*,size:qsizetype=-1)",
    "5:PySide6.QtCore.QCborStreamWriter.append(self,d:double)",
    "4:PySide6.QtCore.QCborStreamWriter.append(self,f:float)",
    "3:PySide6.QtCore.QCborStreamWriter.append(self,i:int)",
    "2:PySide6.QtCore.QCborStreamWriter.append(self,i:qint64)",
    "1:PySide6.QtCore.QCborStreamWriter.append(self,u:quint64)",
    "0:PySide6.QtCore.QCborStreamWriter.append(self,u:uint)",
    "PySide6.QtCore.QCborStreamWriter.appendByteString(self,data:char*,len:qsizetype)",
    "PySide6.QtCore.QCborStreamWriter.appendNull(self)",
    "PySide6.QtCore.QCborStreamWriter.appendTextString(self,utf8:char*,len:qsizetype)",
    "PySide6.QtCore.QCborStreamWriter.appendUndefined(self)",
    "PySide6.QtCore.QCborStreamWriter.device(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtCore.QCborStreamWriter.endArray(self)->bool",
    "PySide6.QtCore.QCborStreamWriter.endMap(self)->bool",
    "PySide6.QtCore.QCborStreamWriter.setDevice(self,device:PySide6.QtCore.QIODevice)",
    "1:PySide6.QtCore.QCborStreamWriter.startArray(self)",
    "0:PySide6.QtCore.QCborStreamWriter.startArray(self,count:quint64)",
    "1:PySide6.QtCore.QCborStreamWriter.startMap(self)",
    "0:PySide6.QtCore.QCborStreamWriter.startMap(self,count:quint64)",
    nullptr}; // Sentinel
#else
static constexpr size_t QCborStreamWriter_SignatureByteSize = 375;
static constexpr uint8_t QCborStreamWriter_SignatureBytes[375] = {
    0x78, 0xda, 0xad, 0x94, 0x5f, 0x4f, 0xc2, 0x30, 0x14, 0xc5, 0xdf, 0xf7, 0x29, 0x7c, 0x74, 0x66,
    0x2c, 0x0c, 0x11, 0xb1, 0x89, 0x26, 0x0a, 0x2f, 0xc6, 0xbf, 0x0b, 0x10, 0x1f, 0x8c, 0x0f, 0x1d,
    0xbd, 0xc3, 0x26, 0xa5, 0x1d, 0xdd, 0x9d, 0x3a, 0x3f, 0xbd, 0xdd, 0x26, 0x42, 0x10, 0x43, 0xab,
    0xbe, 0xf4, 0xa5, 0xf7, 0x77, 0xee, 0x69, 0xee, 0xe9, 0x8d, 0xc8, 0x7d, 0x39, 0xe2, 0x0c, 0x7a,
    0x61, 0x8c, 0x03, 0xa5, 0x21, 0x8c, 0x07, 0x89, 0xd2, 0x23, 0xd4, 0x40, 0xe7, 0x0f, 0x9a, 0x23,
    0xe8, 0xfd, 0x1c, 0x44, 0x1a, 0x30, 0x8a, 0x94, 0x60, 0x99, 0x71, 0x39, 0x0b, 0x27, 0x92, 0x2b,
    0xf9, 0xb8, 0xc9, 0x5d, 0x94, 0x08, 0xe7, 0x5a, 0xd3, 0x32, 0xd8, 0x9b, 0x3e, 0x53, 0x7d, 0xf0,
    0xe4, 0x7b, 0x6d, 0x5b, 0x71, 0x78, 0xe1, 0x53, 0xf8, 0x56, 0x7c, 0x79, 0x37, 0xac, 0x2f, 0x7c,
    0x2f, 0x3a, 0xdc, 0xa9, 0x14, 0xd2, 0x2c, 0x03, 0xc9, 0x1a, 0x41, 0xa4, 0xb3, 0xad, 0xc0, 0x95,
    0x54, 0xaf, 0x72, 0x4c, 0x67, 0xb9, 0x91, 0xec, 0xb8, 0x49, 0xe6, 0xb8, 0xbd, 0x9e, 0xcf, 0x33,
    0x01, 0xe3, 0x32, 0xab, 0x5c, 0x46, 0xff, 0xe3, 0xd2, 0x18, 0x34, 0x62, 0x6d, 0x57, 0x7f, 0x9a,
    0xc4, 0xd7, 0x14, 0xb9, 0x8c, 0x4c, 0x8d, 0x19, 0x93, 0xef, 0x9d, 0xfc, 0x42, 0x61, 0xc9, 0xf6,
    0xdd, 0xd8, 0x84, 0x24, 0x4a, 0x09, 0xdf, 0x3b, 0x76, 0xc4, 0xdc, 0x33, 0xd5, 0x73, 0x7f, 0x54,
    0x8d, 0x06, 0x39, 0x7f, 0x07, 0xb2, 0xa8, 0x4e, 0xd3, 0x12, 0x4e, 0x5b, 0x91, 0xef, 0x1d, 0xb9,
    0x69, 0x31, 0xc2, 0x54, 0x91, 0x08, 0x33, 0xe9, 0xae, 0x1b, 0x98, 0x92, 0x54, 0x28, 0x8a, 0xbe,
    0xe7, 0x18, 0x63, 0x4e, 0xb8, 0x34, 0x54, 0xc7, 0x95, 0x5a, 0x18, 0xac, 0xd7, 0x35, 0x19, 0x72,
    0x03, 0x0b, 0xb2, 0x28, 0x3e, 0xc9, 0xb6, 0x2b, 0x59, 0xd4, 0x4e, 0x2d, 0xa1, 0x6a, 0xac, 0x4d,
    0xd0, 0xd6, 0x96, 0x4b, 0x33, 0x25, 0x01, 0x72, 0x35, 0x24, 0x6b, 0xc1, 0xdb, 0x42, 0x88, 0x5a,
    0xca, 0x9a, 0x18, 0xc3, 0x1b, 0xae, 0x5b, 0x28, 0x30, 0xed, 0xff, 0xc9, 0xc2, 0x44, 0x32, 0x48,
    0xb9, 0x04, 0x66, 0xeb, 0xa3, 0x59, 0x7a, 0x4d, 0x75, 0xeb, 0xec, 0xa7, 0xdd, 0xb7, 0x5b, 0xc7,
    0xf4, 0xae, 0xbf, 0xc8, 0x52, 0xa9, 0xfa, 0x88, 0x56, 0xd4, 0x0d, 0xcd, 0xdc, 0x98, 0x1c, 0x70,
    0xb8, 0x32, 0x6d, 0xb1, 0xb5, 0x77, 0x87, 0x28, 0x47, 0xaa, 0x71, 0xcd, 0xbe, 0x4d, 0xf0, 0x36,
    0x98, 0x60, 0xaa, 0x0a, 0x89, 0xab, 0xe8, 0xda, 0x76, 0xfd, 0x7a, 0xbe, 0x75, 0xcf, 0x25, 0xb1,
    0xd9, 0xf1, 0x03, 0x44, 0x0a, 0x99, 0x6f
};
#endif

PyTypeObject *init_QCborStreamWriter(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX].type;

    Shiboken::AutoDecRef Sbk_QCborStreamWriter_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCborStreamWriter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCborStreamWriter",
        "QCborStreamWriter*",
        &Sbk_QCborStreamWriter_spec,
        &Shiboken::callCppDestructor< ::QCborStreamWriter >,
        Sbk_QCborStreamWriter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QCborStreamWriter_TypeF(); // references _Sbk_QCborStreamWriter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCborStreamWriter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCborStreamWriter_SignatureBytes, QCborStreamWriter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCborStreamWriter_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCborStreamWriter_PythonToCpp_QCborStreamWriter_PTR,
        is_QCborStreamWriter_PythonToCpp_QCborStreamWriter_PTR_Convertible,
        QCborStreamWriter_PTR_CppToPython_QCborStreamWriter);

    Shiboken::Conversions::registerConverterName(converter, "QCborStreamWriter");
    Shiboken::Conversions::registerConverterName(converter, "QCborStreamWriter*");
    Shiboken::Conversions::registerConverterName(converter, "QCborStreamWriter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCborStreamWriter).name());

    qRegisterMetaType< ::QCborStreamWriter *>();

    return pyType;
}
