// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qcollator_wrapper.h"

// Argument includes
#include <QString>
#include <QStringView>
#include <qchar.h>
#include <qcollator.h>
#include <qlocale.h>
#include <qnamespace.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCollator_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCollator >()))
        return -1;

    ::QCollator *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QCollator", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCollator::QCollator()
    // 1: QCollator::QCollator(QCollator)
    // 2: QCollator::QCollator(QLocale)
    if (numArgs == 0) {
        overloadId = 0; // QCollator()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QCollator(QLocale)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QCollator(QCollator)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QCollator()
        {

            // QCollator()
            cptr = new ::QCollator();
            break;
        }
        case 1: // QCollator(const QCollator &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QCollator *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCollator(QCollator)
                cptr = new ::QCollator(*cppArg0);
            }
            break;
        }
        case 2: // QCollator(const QLocale &locale)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QLocale cppArg0_local;
            ::QLocale *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCollator(QLocale)
                cptr = new ::QCollator(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCollator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCollatorFunc_caseSensitivity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCollator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // caseSensitivity()const
        Qt::CaseSensitivity cppResult = const_cast<const ::QCollator *>(cppSelf)->caseSensitivity();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CaseSensitivity_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCollatorFunc_compare(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCollator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 3)
        return Shiboken::returnWrongArguments(args, "compare", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]);

    if (PyArg_UnpackTuple(args, "compare", 2, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCollator::compare(QStringView,QStringView)const->int
    // 1: QCollator::compare(const QChar*,qsizetype,const QChar*,qsizetype)const->int
    // 2: QCollator::compare(QString,QString)const->int
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[3])))) {
        overloadId = 1; // compare(const QChar*,qsizetype,const QChar*,qsizetype)const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 2; // compare(QString,QString)const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // compare(QStringView,QStringView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "compare", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // compare(QStringView s1, QStringView s2) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // compare(QStringView,QStringView)const
                int cppResult = const_cast<const ::QCollator *>(cppSelf)->compare(QStringView(cppArg0), QStringView(cppArg1));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
        case 1: // compare(const QChar *s1, qsizetype len1, const QChar *s2, qsizetype len2) const
        {
            ::QChar *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QChar *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qsizetype cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // compare(const QChar*,qsizetype,const QChar*,qsizetype)const
                int cppResult = const_cast<const ::QCollator *>(cppSelf)->compare(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
        case 2: // compare(const QString &s1, const QString &s2) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // compare(QString,QString)const
                int cppResult = const_cast<const ::QCollator *>(cppSelf)->compare(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCollatorFunc_defaultCompare(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "defaultCompare", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QCollator::defaultCompare(QStringView,QStringView)->int
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // defaultCompare(QStringView,QStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "defaultCompare", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // defaultCompare(QStringView,QStringView)
            int cppResult = ::QCollator::defaultCompare(QStringView(cppArg0), QStringView(cppArg1));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCollatorFunc_defaultSortKey(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCollator::defaultSortKey(QStringView)->QCollatorSortKey
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // defaultSortKey(QStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "defaultSortKey", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // defaultSortKey(QStringView)
            QCollatorSortKey* cppResult = new QCollatorSortKey(::QCollator::defaultSortKey(QStringView(cppArg0)));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollatorSortKey_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCollatorFunc_ignorePunctuation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCollator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ignorePunctuation()const
        bool cppResult = const_cast<const ::QCollator *>(cppSelf)->ignorePunctuation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCollatorFunc_locale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCollator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // locale()const
        QLocale cppResult = const_cast<const ::QCollator *>(cppSelf)->locale();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCollatorFunc_numericMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCollator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // numericMode()const
        bool cppResult = const_cast<const ::QCollator *>(cppSelf)->numericMode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCollatorFunc___call__(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCollator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "__call__", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCollator::operator()(QStringView,QStringView)const->bool
    // 1: QCollator::operator()(QString,QString)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 1; // operator()(QString,QString)const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // operator()(QStringView,QStringView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "operator()", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // operator()(QStringView s1, QStringView s2) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator()(QStringView,QStringView)const
                bool cppResult = const_cast<const ::QCollator *>(cppSelf)->operator()(QStringView(cppArg0), QStringView(cppArg1));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // operator()(const QString &s1, const QString &s2) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator()(QString,QString)const
                bool cppResult = const_cast<const ::QCollator *>(cppSelf)->operator()(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCollatorFunc_setCaseSensitivity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCollator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCollator::setCaseSensitivity(Qt::CaseSensitivity)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CaseSensitivity_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setCaseSensitivity(Qt::CaseSensitivity)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCaseSensitivity", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]);

    // Call function/method
    {
        ::Qt::CaseSensitivity cppArg0{Qt::CaseInsensitive};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCaseSensitivity(Qt::CaseSensitivity)
            cppSelf->setCaseSensitivity(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCollatorFunc_setIgnorePunctuation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCollator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCollator::setIgnorePunctuation(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setIgnorePunctuation(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIgnorePunctuation", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIgnorePunctuation(bool)
            cppSelf->setIgnorePunctuation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCollatorFunc_setLocale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCollator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCollator::setLocale(QLocale)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
        overloadId = 0; // setLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLocale", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocale(QLocale)
            cppSelf->setLocale(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCollatorFunc_setNumericMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCollator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCollator::setNumericMode(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setNumericMode(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNumericMode", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNumericMode(bool)
            cppSelf->setNumericMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCollatorFunc_sortKey(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCollator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCollator::sortKey(QString)const->QCollatorSortKey
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // sortKey(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "sortKey", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sortKey(QString)const
            QCollatorSortKey* cppResult = new QCollatorSortKey(const_cast<const ::QCollator *>(cppSelf)->sortKey(cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollatorSortKey_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCollatorFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCollator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCollator::swap(QCollator&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QCollator&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCollator *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QCollator&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QCollator_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCollator_methods[] = {
    {"caseSensitivity", reinterpret_cast<PyCFunction>(Sbk_QCollatorFunc_caseSensitivity), METH_NOARGS, nullptr},
    {"compare", reinterpret_cast<PyCFunction>(Sbk_QCollatorFunc_compare), METH_VARARGS, nullptr},
    {"defaultCompare", reinterpret_cast<PyCFunction>(Sbk_QCollatorFunc_defaultCompare), METH_VARARGS|METH_STATIC, nullptr},
    {"defaultSortKey", reinterpret_cast<PyCFunction>(Sbk_QCollatorFunc_defaultSortKey), METH_O|METH_STATIC, nullptr},
    {"ignorePunctuation", reinterpret_cast<PyCFunction>(Sbk_QCollatorFunc_ignorePunctuation), METH_NOARGS, nullptr},
    {"locale", reinterpret_cast<PyCFunction>(Sbk_QCollatorFunc_locale), METH_NOARGS, nullptr},
    {"numericMode", reinterpret_cast<PyCFunction>(Sbk_QCollatorFunc_numericMode), METH_NOARGS, nullptr},
    {"setCaseSensitivity", reinterpret_cast<PyCFunction>(Sbk_QCollatorFunc_setCaseSensitivity), METH_O, nullptr},
    {"setIgnorePunctuation", reinterpret_cast<PyCFunction>(Sbk_QCollatorFunc_setIgnorePunctuation), METH_O, nullptr},
    {"setLocale", reinterpret_cast<PyCFunction>(Sbk_QCollatorFunc_setLocale), METH_O, nullptr},
    {"setNumericMode", reinterpret_cast<PyCFunction>(Sbk_QCollatorFunc_setNumericMode), METH_O, nullptr},
    {"sortKey", reinterpret_cast<PyCFunction>(Sbk_QCollatorFunc_sortKey), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QCollatorFunc_swap), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QCollator_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCollator_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCollator_Type = nullptr;
static PyTypeObject *Sbk_QCollator_TypeF(void)
{
    return _Sbk_QCollator_Type;
}

static PyType_Slot Sbk_QCollator_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_call,        reinterpret_cast<void *>(&Sbk_QCollatorFunc___call__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCollator_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCollator_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCollator_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCollator_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCollator_spec = {
    "2:PySide6.QtCore.QCollator",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCollator_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCollator_PythonToCpp_QCollator_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCollator_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCollator_PythonToCpp_QCollator_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCollator_TypeF()))
        return QCollator_PythonToCpp_QCollator_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCollator_PTR_CppToPython_QCollator(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QCollator_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCollator_SignatureStrings[] = {
    "2:PySide6.QtCore.QCollator(self)",
    "1:PySide6.QtCore.QCollator(self,arg__1:PySide6.QtCore.QCollator)",
    "0:PySide6.QtCore.QCollator(self,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])",
    "PySide6.QtCore.QCollator.caseSensitivity(self)->PySide6.QtCore.Qt.CaseSensitivity",
    "2:PySide6.QtCore.QCollator.compare(self,s1:QString,s2:QString)->int",
    "1:PySide6.QtCore.QCollator.compare(self,s1:QChar*,len1:qsizetype,s2:QChar*,len2:qsizetype)->int",
    "0:PySide6.QtCore.QCollator.compare(self,s1:QString,s2:QString)->int",
    "PySide6.QtCore.QCollator.defaultCompare(s1:QString,s2:QString)->int",
    "PySide6.QtCore.QCollator.defaultSortKey(key:QString)->PySide6.QtCore.QCollatorSortKey",
    "PySide6.QtCore.QCollator.ignorePunctuation(self)->bool",
    "PySide6.QtCore.QCollator.locale(self)->PySide6.QtCore.QLocale",
    "PySide6.QtCore.QCollator.numericMode(self)->bool",
    "1:PySide6.QtCore.QCollator.__call__(self,s1:QString,s2:QString)->bool",
    "0:PySide6.QtCore.QCollator.__call__(self,s1:QString,s2:QString)->bool",
    "PySide6.QtCore.QCollator.setCaseSensitivity(self,cs:PySide6.QtCore.Qt.CaseSensitivity)",
    "PySide6.QtCore.QCollator.setIgnorePunctuation(self,on:bool)",
    "PySide6.QtCore.QCollator.setLocale(self,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])",
    "PySide6.QtCore.QCollator.setNumericMode(self,on:bool)",
    "PySide6.QtCore.QCollator.sortKey(self,string:QString)->PySide6.QtCore.QCollatorSortKey",
    "PySide6.QtCore.QCollator.swap(self,other:PySide6.QtCore.QCollator)",
    nullptr}; // Sentinel
#else
static constexpr size_t QCollator_SignatureByteSize = 338;
static constexpr uint8_t QCollator_SignatureBytes[338] = {
    0x78, 0xda, 0xbd, 0x94, 0x3d, 0x4f, 0xc3, 0x30, 0x10, 0x86, 0xf7, 0xfc, 0x0a, 0xc6, 0x06, 0x05,
    0x2b, 0xcd, 0xc0, 0xe0, 0x81, 0x25, 0x13, 0x22, 0xa0, 0x56, 0x11, 0x13, 0x42, 0x91, 0x49, 0xae,
    0xa9, 0x85, 0x6b, 0x07, 0xfb, 0x02, 0x0a, 0xbf, 0x1e, 0x93, 0xa4, 0x94, 0x86, 0xda, 0x45, 0xa2,
    0x62, 0xb3, 0xce, 0x77, 0xcf, 0x7d, 0xbc, 0x67, 0x27, 0x74, 0xd1, 0xe5, 0xbc, 0x82, 0x4b, 0xb2,
    0xc4, 0x54, 0x69, 0x20, 0xcb, 0x54, 0x09, 0xc1, 0x50, 0xe9, 0x99, 0x01, 0xb1, 0x0a, 0x83, 0xb9,
    0xdf, 0x21, 0x62, 0xba, 0x2e, 0x0a, 0xb7, 0x53, 0x18, 0xc4, 0x47, 0x00, 0x42, 0x95, 0x4c, 0x00,
    0xc5, 0xae, 0xe1, 0xb2, 0x26, 0xf7, 0x92, 0x2b, 0xf9, 0x30, 0x8d, 0xc8, 0x7a, 0x9f, 0xe8, 0xec,
    0xb0, 0x9d, 0x64, 0x4c, 0xd6, 0x2d, 0xab, 0xe1, 0x31, 0x0c, 0x5c, 0xb9, 0x48, 0xc9, 0x0c, 0xe4,
    0x20, 0x0d, 0x47, 0xfe, 0xca, 0xb1, 0x1b, 0xba, 0xbb, 0xb8, 0x9a, 0xfa, 0x23, 0x49, 0xf7, 0x1d,
    0x83, 0x84, 0xba, 0x99, 0x6a, 0xd3, 0x30, 0x0d, 0x43, 0x1f, 0x66, 0x4e, 0x97, 0x39, 0x6a, 0xdb,
    0x44, 0x64, 0x92, 0xed, 0xd1, 0x66, 0xe0, 0x12, 0x3d, 0x43, 0xfc, 0xc9, 0x48, 0xd7, 0x4c, 0x9f,
    0x47, 0x02, 0xe4, 0x9c, 0xbe, 0x18, 0xfe, 0x0e, 0x76, 0x30, 0xd0, 0x13, 0xbf, 0x2e, 0x92, 0xdd,
    0xc5, 0xc8, 0x8f, 0x4f, 0x50, 0xa3, 0x93, 0x50, 0xc1, 0x8a, 0xb5, 0xc2, 0x5a, 0x47, 0xd0, 0x1f,
    0x18, 0xb9, 0xd2, 0x78, 0x03, 0xdd, 0xec, 0x19, 0xba, 0x6f, 0x91, 0xae, 0xa8, 0xd1, 0xdb, 0x4d,
    0xe5, 0xb5, 0xb4, 0x86, 0x45, 0x2b, 0x4b, 0x6c, 0x19, 0xda, 0xc5, 0xd9, 0xaa, 0xfa, 0xa4, 0x94,
    0x70, 0x87, 0x0d, 0x1b, 0xe7, 0xda, 0x80, 0x61, 0xa7, 0xdc, 0xd1, 0xb2, 0xdd, 0x80, 0xe6, 0xe5,
    0xad, 0xaa, 0x60, 0x2f, 0x9d, 0x47, 0xe3, 0xa2, 0xb0, 0x48, 0x51, 0x14, 0x7e, 0x11, 0x7a, 0x4a,
    0x7c, 0x12, 0x8a, 0x93, 0x61, 0x00, 0xd3, 0x03, 0x0f, 0x21, 0x2a, 0x0d, 0x3d, 0xfa, 0x12, 0x42,
    0x2f, 0xf6, 0xfa, 0xa0, 0x16, 0x91, 0x92, 0xf4, 0xb3, 0x22, 0x7f, 0x6c, 0xb6, 0x13, 0xe4, 0xbf,
    0xbe, 0x03, 0x9b, 0xf5, 0x6e, 0x22, 0xe4, 0x6f, 0x6a, 0x1d, 0xf7, 0x77, 0x50, 0xa0, 0x1f, 0xf9,
    0x29, 0xf6, 0xd8, 0xbc, 0xb1, 0x66, 0x2c, 0x01, 0xd7, 0xa0, 0x3d, 0x9f, 0xe9, 0x07, 0x1b, 0xc4,
    0x05, 0xb0
};
#endif

PyTypeObject *init_QCollator(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX].type;

    Shiboken::AutoDecRef Sbk_QCollator_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCollator_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCollator",
        "QCollator*",
        &Sbk_QCollator_spec,
        &Shiboken::callCppDestructor< ::QCollator >,
        Sbk_QCollator_Type_bases.object(),
        0);
    auto *pyType = Sbk_QCollator_TypeF(); // references _Sbk_QCollator_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCollator_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCollator_SignatureBytes, QCollator_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCollator_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QCollator_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCollator_PythonToCpp_QCollator_PTR,
        is_QCollator_PythonToCpp_QCollator_PTR_Convertible,
        QCollator_PTR_CppToPython_QCollator);

    Shiboken::Conversions::registerConverterName(converter, "QCollator");
    Shiboken::Conversions::registerConverterName(converter, "QCollator*");
    Shiboken::Conversions::registerConverterName(converter, "QCollator&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCollator).name());

    qRegisterMetaType< ::QCollator *>();

    return pyType;
}
