// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qcommandlineparser_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <qcommandlineoption.h>
#include <qcommandlineparser.h>
#include <qcoreapplication.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCommandLineParser_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCommandLineParser >()))
        return -1;

    ::QCommandLineParser *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QCommandLineParser()
        cptr = new ::QCommandLineParser();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCommandLineParser >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCommandLineParserFunc_addHelpOption(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // addHelpOption()
        QCommandLineOption* cppResult = new QCommandLineOption(cppSelf->addHelpOption());
        pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineOption_IDX]), cppResult, true, true);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_addOption(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::addOption(QCommandLineOption)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineOption_IDX]), (pyArg)))) {
        overloadId = 0; // addOption(QCommandLineOption)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addOption", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCommandLineOption *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addOption(QCommandLineOption)
            bool cppResult = cppSelf->addOption(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_addOptions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::addOptions(QList<QCommandLineOption>)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QCommandLineOption_IDX], (pyArg)))) {
        overloadId = 0; // addOptions(QList<QCommandLineOption>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addOptions", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);

    // Call function/method
    {
        ::QList<QCommandLineOption> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addOptions(QList<QCommandLineOption>)
            bool cppResult = cppSelf->addOptions(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_addPositionalArgument(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addPositionalArgument", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:addPositionalArgument", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCommandLineParser::addPositionalArgument(QString,QString,const QString&=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // addPositionalArgument(QString,QString,QString)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 0; // addPositionalArgument(QString,QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addPositionalArgument", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_syntax = Shiboken::String::createStaticString("syntax");
            if (PyDict_Contains(kwds, key_syntax) != 0) {
                value = PyDict_GetItem(kwds, key_syntax);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_syntax);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "addPositionalArgument", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "addPositionalArgument", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_syntax);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "addPositionalArgument", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2 = QString();
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addPositionalArgument(QString,QString,QString)
            cppSelf->addPositionalArgument(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_addVersionOption(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // addVersionOption()
        QCommandLineOption* cppResult = new QCommandLineOption(cppSelf->addVersionOption());
        pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineOption_IDX]), cppResult, true, true);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_applicationDescription(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // applicationDescription()const
        QString cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->applicationDescription();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_clearPositionalArguments(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearPositionalArguments()
        cppSelf->clearPositionalArguments();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_errorText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorText()const
        QString cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->errorText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_helpText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // helpText()const
        QString cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->helpText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_isSet(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::isSet(QCommandLineOption)const->bool
    // 1: QCommandLineParser::isSet(QString)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // isSet(QString)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineOption_IDX]), (pyArg)))) {
        overloadId = 0; // isSet(QCommandLineOption)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isSet", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // isSet(const QCommandLineOption &option) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QCommandLineOption *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isSet(QCommandLineOption)const
                bool cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->isSet(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // isSet(const QString &name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isSet(QString)const
                bool cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->isSet(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_optionNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // optionNames()const
        QStringList cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->optionNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_parse(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::parse(QStringList)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // parse(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "parse", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // parse(QStringList)
            bool cppResult = cppSelf->parse(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_positionalArguments(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // positionalArguments()const
        QStringList cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->positionalArguments();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_process(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::process(QCoreApplication)
    // 1: QCommandLineParser::process(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 1; // process(QStringList)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX]), (pyArg)))) {
        overloadId = 0; // process(QCoreApplication)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "process", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // process(const QCoreApplication &app)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QCoreApplication *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // process(QCoreApplication)
                cppSelf->process(*cppArg0);
            }
            break;
        }
        case 1: // process(const QStringList &arguments)
        {
            ::QStringList cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // process(QStringList)
                cppSelf->process(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_setApplicationDescription(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::setApplicationDescription(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setApplicationDescription(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setApplicationDescription", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setApplicationDescription(QString)
            cppSelf->setApplicationDescription(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_setOptionsAfterPositionalArgumentsMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::setOptionsAfterPositionalArgumentsMode(QCommandLineParser::OptionsAfterPositionalArgumentsMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_OptionsAfterPositionalArgumentsMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setOptionsAfterPositionalArgumentsMode(QCommandLineParser::OptionsAfterPositionalArgumentsMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOptionsAfterPositionalArgumentsMode", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);

    // Call function/method
    {
        ::QCommandLineParser::OptionsAfterPositionalArgumentsMode cppArg0{QCommandLineParser::ParseAsOptions};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOptionsAfterPositionalArgumentsMode(QCommandLineParser::OptionsAfterPositionalArgumentsMode)
            cppSelf->setOptionsAfterPositionalArgumentsMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_setSingleDashWordOptionMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::setSingleDashWordOptionMode(QCommandLineParser::SingleDashWordOptionMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_SingleDashWordOptionMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSingleDashWordOptionMode(QCommandLineParser::SingleDashWordOptionMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSingleDashWordOptionMode", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);

    // Call function/method
    {
        ::QCommandLineParser::SingleDashWordOptionMode cppArg0{QCommandLineParser::ParseAsCompactedShortOptions};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSingleDashWordOptionMode(QCommandLineParser::SingleDashWordOptionMode)
            cppSelf->setSingleDashWordOptionMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_showHelp(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "showHelp", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);

    if (PyArg_ParseTuple(args, "|O:showHelp", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCommandLineParser::showHelp(int=)
    if (numArgs == 0) {
        overloadId = 0; // showHelp(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // showHelp(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "showHelp", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_exitCode = Shiboken::String::createStaticString("exitCode");
            if (PyDict_Contains(kwds, key_exitCode) != 0) {
                value = PyDict_GetItem(kwds, key_exitCode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_exitCode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "showHelp", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "showHelp", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_exitCode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "showHelp", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);
            }
        }
        int cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // showHelp(int)
            cppSelf->showHelp(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_showVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // showVersion()
        cppSelf->showVersion();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_unknownOptionNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unknownOptionNames()const
        QStringList cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->unknownOptionNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_value(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::value(QCommandLineOption)const->QString
    // 1: QCommandLineParser::value(QString)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // value(QString)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineOption_IDX]), (pyArg)))) {
        overloadId = 0; // value(QCommandLineOption)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "value", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // value(const QCommandLineOption &option) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QCommandLineOption *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // value(QCommandLineOption)const
                QString cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->value(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // value(const QString &name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // value(QString)const
                QString cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->value(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_values(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::values(QCommandLineOption)const->QStringList
    // 1: QCommandLineParser::values(QString)const->QStringList
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // values(QString)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineOption_IDX]), (pyArg)))) {
        overloadId = 0; // values(QCommandLineOption)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "values", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // values(const QCommandLineOption &option) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QCommandLineOption *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // values(QCommandLineOption)const
                QStringList cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->values(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
            }
            break;
        }
        case 1: // values(const QString &name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // values(QString)const
                QStringList cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->values(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCommandLineParser_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QCommandLineParser_EnumFlagInfo[] = {
    "OptionsAfterPositionalArgumentsMode:Enum",
    "SingleDashWordOptionMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCommandLineParser_methods[] = {
    {"addHelpOption", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_addHelpOption), METH_NOARGS, nullptr},
    {"addOption", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_addOption), METH_O, nullptr},
    {"addOptions", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_addOptions), METH_O, nullptr},
    {"addPositionalArgument", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_addPositionalArgument), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addVersionOption", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_addVersionOption), METH_NOARGS, nullptr},
    {"applicationDescription", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_applicationDescription), METH_NOARGS, nullptr},
    {"clearPositionalArguments", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_clearPositionalArguments), METH_NOARGS, nullptr},
    {"errorText", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_errorText), METH_NOARGS, nullptr},
    {"helpText", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_helpText), METH_NOARGS, nullptr},
    {"isSet", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_isSet), METH_O, nullptr},
    {"optionNames", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_optionNames), METH_NOARGS, nullptr},
    {"parse", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_parse), METH_O, nullptr},
    {"positionalArguments", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_positionalArguments), METH_NOARGS, nullptr},
    {"process", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_process), METH_O, nullptr},
    {"setApplicationDescription", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_setApplicationDescription), METH_O, nullptr},
    {"setOptionsAfterPositionalArgumentsMode", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_setOptionsAfterPositionalArgumentsMode), METH_O, nullptr},
    {"setSingleDashWordOptionMode", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_setSingleDashWordOptionMode), METH_O, nullptr},
    {"showHelp", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_showHelp), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"showVersion", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_showVersion), METH_NOARGS, nullptr},
    {"unknownOptionNames", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_unknownOptionNames), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_value), METH_O, nullptr},
    {"values", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_values), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QCommandLineParser_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCommandLineParser_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCommandLineParser_Type = nullptr;
static PyTypeObject *Sbk_QCommandLineParser_TypeF(void)
{
    return _Sbk_QCommandLineParser_Type;
}

static PyType_Slot Sbk_QCommandLineParser_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCommandLineParser_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCommandLineParser_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCommandLineParser_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCommandLineParser_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCommandLineParser_spec = {
    "2:PySide6.QtCore.QCommandLineParser",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCommandLineParser_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QCommandLineParser_SingleDashWordOptionMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCommandLineParser::SingleDashWordOptionMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCommandLineParser::SingleDashWordOptionMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCommandLineParser_SingleDashWordOptionMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_SingleDashWordOptionMode_IDX])))
        return Enum_PythonToCpp_QCommandLineParser_SingleDashWordOptionMode;
    return {};
}

static PyObject *QCommandLineParser_SingleDashWordOptionMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCommandLineParser::SingleDashWordOptionMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCommandLineParser::SingleDashWordOptionMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_SingleDashWordOptionMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QCommandLineParser_OptionsAfterPositionalArgumentsMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCommandLineParser::OptionsAfterPositionalArgumentsMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCommandLineParser::OptionsAfterPositionalArgumentsMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCommandLineParser_OptionsAfterPositionalArgumentsMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_OptionsAfterPositionalArgumentsMode_IDX])))
        return Enum_PythonToCpp_QCommandLineParser_OptionsAfterPositionalArgumentsMode;
    return {};
}

static PyObject *QCommandLineParser_OptionsAfterPositionalArgumentsMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QCommandLineParser::OptionsAfterPositionalArgumentsMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QCommandLineParser::OptionsAfterPositionalArgumentsMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_OptionsAfterPositionalArgumentsMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCommandLineParser_PythonToCpp_QCommandLineParser_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCommandLineParser_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCommandLineParser_PythonToCpp_QCommandLineParser_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCommandLineParser_TypeF()))
        return QCommandLineParser_PythonToCpp_QCommandLineParser_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCommandLineParser_PTR_CppToPython_QCommandLineParser(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QCommandLineParser_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCommandLineParser_SignatureStrings[] = {
    "PySide6.QtCore.QCommandLineParser(self)",
    "PySide6.QtCore.QCommandLineParser.addHelpOption(self)->PySide6.QtCore.QCommandLineOption",
    "PySide6.QtCore.QCommandLineParser.addOption(self,commandLineOption:PySide6.QtCore.QCommandLineOption)->bool",
    "PySide6.QtCore.QCommandLineParser.addOptions(self,options:QList[PySide6.QtCore.QCommandLineOption])->bool",
    "PySide6.QtCore.QCommandLineParser.addPositionalArgument(self,name:QString,description:QString,syntax:QString=QString())",
    "PySide6.QtCore.QCommandLineParser.addVersionOption(self)->PySide6.QtCore.QCommandLineOption",
    "PySide6.QtCore.QCommandLineParser.applicationDescription(self)->QString",
    "PySide6.QtCore.QCommandLineParser.clearPositionalArguments(self)",
    "PySide6.QtCore.QCommandLineParser.errorText(self)->QString",
    "PySide6.QtCore.QCommandLineParser.helpText(self)->QString",
    "1:PySide6.QtCore.QCommandLineParser.isSet(self,option:PySide6.QtCore.QCommandLineOption)->bool",
    "0:PySide6.QtCore.QCommandLineParser.isSet(self,name:QString)->bool",
    "PySide6.QtCore.QCommandLineParser.optionNames(self)->QStringList",
    "PySide6.QtCore.QCommandLineParser.parse(self,arguments:QStringList)->bool",
    "PySide6.QtCore.QCommandLineParser.positionalArguments(self)->QStringList",
    "1:PySide6.QtCore.QCommandLineParser.process(self,app:PySide6.QtCore.QCoreApplication)",
    "0:PySide6.QtCore.QCommandLineParser.process(self,arguments:QStringList)",
    "PySide6.QtCore.QCommandLineParser.setApplicationDescription(self,description:QString)",
    "PySide6.QtCore.QCommandLineParser.setOptionsAfterPositionalArgumentsMode(self,mode:PySide6.QtCore.QCommandLineParser.OptionsAfterPositionalArgumentsMode)",
    "PySide6.QtCore.QCommandLineParser.setSingleDashWordOptionMode(self,parsingMode:PySide6.QtCore.QCommandLineParser.SingleDashWordOptionMode)",
    "PySide6.QtCore.QCommandLineParser.showHelp(self,exitCode:int=0)",
    "PySide6.QtCore.QCommandLineParser.showVersion(self)",
    "PySide6.QtCore.QCommandLineParser.unknownOptionNames(self)->QStringList",
    "1:PySide6.QtCore.QCommandLineParser.value(self,option:PySide6.QtCore.QCommandLineOption)->QString",
    "0:PySide6.QtCore.QCommandLineParser.value(self,name:QString)->QString",
    "1:PySide6.QtCore.QCommandLineParser.values(self,option:PySide6.QtCore.QCommandLineOption)->QStringList",
    "0:PySide6.QtCore.QCommandLineParser.values(self,name:QString)->QStringList",
    nullptr}; // Sentinel
#else
static constexpr size_t QCommandLineParser_SignatureByteSize = 417;
static constexpr uint8_t QCommandLineParser_SignatureBytes[417] = {
    0x78, 0xda, 0xb5, 0x55, 0xb1, 0x4e, 0xc3, 0x30, 0x10, 0xdd, 0xf9, 0x92, 0x56, 0x2a, 0x55, 0x58,
    0x18, 0x22, 0x15, 0x29, 0x2a, 0x03, 0x43, 0x0b, 0x89, 0x82, 0x60, 0x40, 0x0c, 0x26, 0xb9, 0xb6,
    0x16, 0x8e, 0x6d, 0xd9, 0x2e, 0x6d, 0xff, 0x1e, 0xa7, 0x76, 0xd4, 0xb4, 0x24, 0xe4, 0x8c, 0xc4,
    0xe4, 0x24, 0xba, 0x7b, 0xef, 0x9d, 0xef, 0xdd, 0x25, 0x3d, 0xe4, 0xb4, 0x84, 0xdb, 0x69, 0x66,
    0xe6, 0x42, 0xc1, 0x34, 0x9b, 0x8b, 0xaa, 0x22, 0xbc, 0x5c, 0x50, 0x0e, 0x29, 0x51, 0x1a, 0xd4,
    0x48, 0x03, 0x5b, 0x8d, 0xaf, 0xd2, 0xa1, 0xb8, 0x29, 0x29, 0xcb, 0x07, 0x60, 0xf2, 0x49, 0x1a,
    0x2a, 0xb8, 0xcb, 0xba, 0xbe, 0xfb, 0x25, 0xcd, 0x05, 0xe2, 0x80, 0x5b, 0xa0, 0x93, 0xe2, 0x12,
    0x22, 0x1e, 0x24, 0xb1, 0x42, 0x3e, 0x84, 0x60, 0x21, 0x5c, 0xda, 0x91, 0x09, 0xf7, 0x12, 0x67,
    0x0b, 0xaa, 0xcd, 0xdb, 0x20, 0xd1, 0x7b, 0x10, 0x53, 0x2a, 0x34, 0xad, 0xb3, 0x08, 0x4b, 0xd4,
    0x7a, 0x5b, 0x01, 0x37, 0x8e, 0x94, 0x93, 0x0a, 0xe2, 0x2c, 0x37, 0x8a, 0xf2, 0xf5, 0xa4, 0x04,
    0x5d, 0x28, 0xea, 0x0a, 0x6d, 0xbe, 0xe9, 0x03, 0x37, 0x64, 0xdf, 0xbc, 0xce, 0xfc, 0x39, 0x1a,
    0x23, 0xdb, 0xf4, 0x02, 0x4a, 0x5b, 0xb8, 0x7f, 0xe8, 0x94, 0x94, 0x8c, 0x16, 0xa4, 0x8e, 0xbe,
    0x3f, 0xc9, 0x6e, 0x18, 0xbc, 0x4c, 0x04, 0x4e, 0xc1, 0x80, 0xa8, 0x9f, 0xb7, 0xa3, 0xd1, 0x5e,
    0x04, 0xa5, 0x84, 0x7a, 0x86, 0xbd, 0x09, 0xe7, 0xde, 0x58, 0x0f, 0x77, 0x65, 0xde, 0xc4, 0xc3,
    0xb9, 0x54, 0xe7, 0x60, 0xda, 0xc6, 0xc1, 0x5b, 0x33, 0x0a, 0x83, 0x6f, 0x5b, 0x04, 0xef, 0x39,
    0x27, 0xea, 0xd1, 0xe6, 0xea, 0x8b, 0xf2, 0x6a, 0x7b, 0x23, 0x00, 0x64, 0x7d, 0x38, 0x05, 0xa4,
    0x69, 0x4a, 0xdc, 0x82, 0xc0, 0x4b, 0x91, 0x7d, 0xdd, 0x3d, 0x97, 0x84, 0xb9, 0x75, 0xa9, 0x44,
    0x01, 0xda, 0x0f, 0xac, 0xb5, 0x60, 0x47, 0x8a, 0x82, 0xe4, 0x64, 0xcd, 0x31, 0xea, 0xb2, 0xcf,
    0x51, 0x3b, 0x8b, 0x45, 0x94, 0xa9, 0xc1, 0x24, 0xfd, 0x43, 0xd1, 0x35, 0xdc, 0x48, 0x54, 0xbf,
    0xa5, 0x92, 0x95, 0x81, 0xae, 0x49, 0x59, 0x8a, 0xd2, 0xf7, 0xa9, 0xb2, 0x4f, 0x88, 0x72, 0x11,
    0x78, 0x48, 0x65, 0xb9, 0x2d, 0x82, 0xc1, 0x3d, 0xd1, 0x9b, 0x57, 0xa1, 0xfc, 0x36, 0x3d, 0xc9,
    0xa9, 0x1d, 0x64, 0x03, 0x96, 0x38, 0x55, 0x7d, 0x58, 0x28, 0x29, 0x1b, 0xb1, 0xab, 0x7f, 0x48,
    0x8e, 0x17, 0xf6, 0xd4, 0x46, 0x5a, 0x52, 0xca, 0xcd, 0x2c, 0xc2, 0xe6, 0xfb, 0x4d, 0x89, 0xde,
    0x3b, 0x5b, 0xfe, 0xc9, 0xc5, 0xce, 0x6f, 0xd6, 0xde, 0x39, 0xc3, 0x98, 0xfa, 0x8b, 0xb0, 0x2d,
    0x04, 0xaf, 0x92, 0x66, 0x59, 0x45, 0x61, 0x0c, 0x17, 0xdb, 0x24, 0x64, 0xe5, 0x1d, 0x51, 0xf4,
    0x5f, 0x85, 0x1e, 0xaf, 0x23, 0x0a, 0xa4, 0xe9, 0x56, 0x7b, 0x84, 0xfa, 0x06, 0x5b, 0x86, 0x3a,
    0xb5
};
#endif

PyTypeObject *init_QCommandLineParser(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX].type;

    Shiboken::AutoDecRef Sbk_QCommandLineParser_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCommandLineParser_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCommandLineParser",
        "QCommandLineParser*",
        &Sbk_QCommandLineParser_spec,
        &Shiboken::callCppDestructor< ::QCommandLineParser >,
        Sbk_QCommandLineParser_Type_bases.object(),
        0);
    auto *pyType = Sbk_QCommandLineParser_TypeF(); // references _Sbk_QCommandLineParser_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCommandLineParser_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCommandLineParser_SignatureBytes, QCommandLineParser_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCommandLineParser_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCommandLineParser_PythonToCpp_QCommandLineParser_PTR,
        is_QCommandLineParser_PythonToCpp_QCommandLineParser_PTR_Convertible,
        QCommandLineParser_PTR_CppToPython_QCommandLineParser);

    Shiboken::Conversions::registerConverterName(converter, "QCommandLineParser");
    Shiboken::Conversions::registerConverterName(converter, "QCommandLineParser*");
    Shiboken::Conversions::registerConverterName(converter, "QCommandLineParser&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCommandLineParser).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCommandLineParser_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SingleDashWordOptionMode'.
    const char *SingleDashWordOptionMode_Initializer[] = {
        "ParseAsCompactedShortOptions",
        "ParseAsLongOptions",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SingleDashWordOptionMode_InitializerValues[] = {
        uint8_t(QCommandLineParser::SingleDashWordOptionMode::ParseAsCompactedShortOptions), //  0x00  0
        uint8_t(QCommandLineParser::SingleDashWordOptionMode::ParseAsLongOptions)            //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCommandLineParser_TypeF(),
        "2:PySide6.QtCore.QCommandLineParser.SingleDashWordOptionMode",
        SingleDashWordOptionMode_Initializer, SingleDashWordOptionMode_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_SingleDashWordOptionMode_IDX].type = EType;
    // Register converter for enum 'QCommandLineParser::SingleDashWordOptionMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCommandLineParser_SingleDashWordOptionMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCommandLineParser_SingleDashWordOptionMode,
            is_Enum_PythonToCpp_QCommandLineParser_SingleDashWordOptionMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCommandLineParser::SingleDashWordOptionMode");
        Shiboken::Conversions::registerConverterAlias(converter, "SingleDashWordOptionMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SingleDashWordOptionMode' enum.

    // Initialization of enum 'OptionsAfterPositionalArgumentsMode'.
    const char *OptionsAfterPositionalArgumentsMode_Initializer[] = {
        "ParseAsOptions",
        "ParseAsPositionalArguments",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t OptionsAfterPositionalArgumentsMode_InitializerValues[] = {
        uint8_t(QCommandLineParser::OptionsAfterPositionalArgumentsMode::ParseAsOptions),            //  0x00  0
        uint8_t(QCommandLineParser::OptionsAfterPositionalArgumentsMode::ParseAsPositionalArguments) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCommandLineParser_TypeF(),
        "2:PySide6.QtCore.QCommandLineParser.OptionsAfterPositionalArgumentsMode",
        OptionsAfterPositionalArgumentsMode_Initializer, OptionsAfterPositionalArgumentsMode_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_OptionsAfterPositionalArgumentsMode_IDX].type = EType;
    // Register converter for enum 'QCommandLineParser::OptionsAfterPositionalArgumentsMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCommandLineParser_OptionsAfterPositionalArgumentsMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCommandLineParser_OptionsAfterPositionalArgumentsMode,
            is_Enum_PythonToCpp_QCommandLineParser_OptionsAfterPositionalArgumentsMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QCommandLineParser::OptionsAfterPositionalArgumentsMode");
        Shiboken::Conversions::registerConverterAlias(converter, "OptionsAfterPositionalArgumentsMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'OptionsAfterPositionalArgumentsMode' enum.

    qRegisterMetaType< ::QCommandLineParser *>();
    qRegisterMetaType< ::QCommandLineParser::SingleDashWordOptionMode >("QCommandLineParser::SingleDashWordOptionMode");
    qRegisterMetaType< ::QCommandLineParser::OptionsAfterPositionalArgumentsMode >("QCommandLineParser::OptionsAfterPositionalArgumentsMode");

    return pyType;
}
