// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qcontactspermission_wrapper.h"

// Argument includes
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpermissions.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QContactsPermission_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QContactsPermission >()))
        return -1;

    ::QContactsPermission *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QContactsPermission", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QContactsPermission::QContactsPermission()
    // 1: QContactsPermission::QContactsPermission(QContactsPermission)
    if (numArgs == 0) {
        overloadId = 0; // QContactsPermission()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QContactsPermission(QContactsPermission)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QContactsPermission()
        {

            // QContactsPermission()
            cptr = new ::QContactsPermission();
            break;
        }
        case 1: // QContactsPermission(const QContactsPermission &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QContactsPermission cppArg0_local;
            ::QContactsPermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QContactsPermission(QContactsPermission)
                cptr = new ::QContactsPermission(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QContactsPermission >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QContactsPermissionFunc_accessMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QContactsPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // accessMode()const
        QContactsPermission::AccessMode cppResult = const_cast<const ::QContactsPermission *>(cppSelf)->accessMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_AccessMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QContactsPermissionFunc_setAccessMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QContactsPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QContactsPermission::setAccessMode(QContactsPermission::AccessMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_AccessMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAccessMode(QContactsPermission::AccessMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAccessMode", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX]);

    // Call function/method
    {
        ::QContactsPermission::AccessMode cppArg0{QContactsPermission::ReadOnly};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAccessMode(QContactsPermission::AccessMode)
            cppSelf->setAccessMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QContactsPermissionFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QContactsPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QContactsPermission::swap(QContactsPermission&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QContactsPermission&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QContactsPermission cppArg0_local;
        ::QContactsPermission *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QContactsPermission&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QContactsPermission__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QContactsPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QContactsPermission_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QContactsPermission_EnumFlagInfo[] = {
    "AccessMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QContactsPermission_methods[] = {
    {"accessMode", reinterpret_cast<PyCFunction>(Sbk_QContactsPermissionFunc_accessMode), METH_NOARGS, nullptr},
    {"setAccessMode", reinterpret_cast<PyCFunction>(Sbk_QContactsPermissionFunc_setAccessMode), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QContactsPermissionFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QContactsPermission__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QContactsPermission_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QContactsPermission_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QContactsPermission_Type = nullptr;
static PyTypeObject *Sbk_QContactsPermission_TypeF(void)
{
    return _Sbk_QContactsPermission_Type;
}

static PyType_Slot Sbk_QContactsPermission_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QContactsPermission_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QContactsPermission_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QContactsPermission_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QContactsPermission_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QContactsPermission_spec = {
    "2:PySide6.QtCore.QContactsPermission",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QContactsPermission_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QContactsPermission_AccessMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QContactsPermission::AccessMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QContactsPermission::AccessMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QContactsPermission_AccessMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_AccessMode_IDX])))
        return Enum_PythonToCpp_QContactsPermission_AccessMode;
    return {};
}

static PyObject *QContactsPermission_AccessMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QContactsPermission::AccessMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QContactsPermission::AccessMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_AccessMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QContactsPermission_PythonToCpp_QContactsPermission_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QContactsPermission_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QContactsPermission_PythonToCpp_QContactsPermission_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QContactsPermission_TypeF()))
        return QContactsPermission_PythonToCpp_QContactsPermission_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QContactsPermission_PTR_CppToPython_QContactsPermission(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QContactsPermission_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QContactsPermission_COPY_CppToPython_QContactsPermission(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QContactsPermission *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QContactsPermission_TypeF(), new ::QContactsPermission(*source), true, true);
}

// Python to C++ copy conversion.
static void QContactsPermission_PythonToCpp_QContactsPermission_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QContactsPermission *>(cppOut) = *reinterpret_cast< ::QContactsPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QContactsPermission_PythonToCpp_QContactsPermission_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QContactsPermission_TypeF()))
        return QContactsPermission_PythonToCpp_QContactsPermission_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QContactsPermission_SignatureStrings[] = {
    "1:PySide6.QtCore.QContactsPermission(self)",
    "0:PySide6.QtCore.QContactsPermission(self,other:PySide6.QtCore.QContactsPermission)",
    "PySide6.QtCore.QContactsPermission.accessMode(self)->PySide6.QtCore.QContactsPermission.AccessMode",
    "PySide6.QtCore.QContactsPermission.setAccessMode(self,mode:PySide6.QtCore.QContactsPermission.AccessMode)",
    "PySide6.QtCore.QContactsPermission.swap(self,other:PySide6.QtCore.QContactsPermission)",
    "PySide6.QtCore.QContactsPermission.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QContactsPermission_SignatureByteSize = 134;
static constexpr uint8_t QContactsPermission_SignatureBytes[134] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0x74, 0xce, 0xcf, 0x2b, 0x49, 0x4c, 0x2e, 0x29, 0x0e, 0x48, 0x2d, 0xca,
    0xcd, 0x2c, 0x2e, 0xce, 0xcc, 0xcf, 0xd3, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x20, 0x56,
    0xa9, 0x4e, 0x7e, 0x49, 0x46, 0x6a, 0x11, 0x11, 0xaa, 0x35, 0xb9, 0x08, 0xab, 0xd1, 0x4b, 0x4c,
    0x4e, 0x4e, 0x2d, 0x2e, 0xf6, 0xcd, 0x4f, 0x49, 0x85, 0xb8, 0x43, 0xd7, 0x8e, 0x08, 0x4d, 0x8e,
    0x70, 0x4d, 0xc4, 0x58, 0x51, 0x9c, 0x5a, 0xe2, 0x88, 0x6a, 0x8b, 0x4e, 0x2e, 0x90, 0x65, 0x45,
    0x92, 0x45, 0x44, 0x79, 0xa6, 0xb8, 0x3c, 0xb1, 0x80, 0x06, 0x61, 0x14, 0x1f, 0x9f, 0x9c, 0x5f,
    0x50, 0x19, 0x1f, 0x0f, 0x0b, 0xa1, 0x92, 0xca, 0x82, 0xcc, 0xbc, 0x74, 0xbd, 0x60, 0x20, 0x8f,
    0x0b, 0x00, 0x83, 0x9b, 0xb1, 0x0c
};
#endif

PyTypeObject *init_QContactsPermission(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX].type;

    Shiboken::AutoDecRef Sbk_QContactsPermission_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QContactsPermission_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QContactsPermission",
        "QContactsPermission",
        &Sbk_QContactsPermission_spec,
        &Shiboken::callCppDestructor< ::QContactsPermission >,
        Sbk_QContactsPermission_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QContactsPermission_TypeF(); // references _Sbk_QContactsPermission_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QContactsPermission_SignatureStrings);
#else
    InitSignatureBytes(pyType, QContactsPermission_SignatureBytes, QContactsPermission_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QContactsPermission_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QContactsPermission_PythonToCpp_QContactsPermission_PTR,
        is_QContactsPermission_PythonToCpp_QContactsPermission_PTR_Convertible,
        QContactsPermission_PTR_CppToPython_QContactsPermission,
        QContactsPermission_COPY_CppToPython_QContactsPermission);

    Shiboken::Conversions::registerConverterName(converter, "QContactsPermission");
    Shiboken::Conversions::registerConverterName(converter, "QContactsPermission*");
    Shiboken::Conversions::registerConverterName(converter, "QContactsPermission&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QContactsPermission).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QContactsPermission_PythonToCpp_QContactsPermission_COPY,
        is_QContactsPermission_PythonToCpp_QContactsPermission_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QContactsPermission_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'AccessMode'.
    const char *AccessMode_Initializer[] = {
        "ReadOnly",
        "ReadWrite",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t AccessMode_InitializerValues[] = {
        uint8_t(QContactsPermission::AccessMode::ReadOnly), //  0x00  0
        uint8_t(QContactsPermission::AccessMode::ReadWrite) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QContactsPermission_TypeF(),
        "2:PySide6.QtCore.QContactsPermission.AccessMode",
        AccessMode_Initializer, AccessMode_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_AccessMode_IDX].type = EType;
    // Register converter for enum 'QContactsPermission::AccessMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QContactsPermission_AccessMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QContactsPermission_AccessMode,
            is_Enum_PythonToCpp_QContactsPermission_AccessMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QContactsPermission::AccessMode");
        Shiboken::Conversions::registerConverterAlias(converter, "AccessMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AccessMode' enum.

    qRegisterMetaType< ::QContactsPermission >("QContactsPermission");
    qRegisterMetaType< ::QContactsPermission::AccessMode >("QContactsPermission::AccessMode");

    return pyType;
}
