// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qdate_wrapper.h"

// Extra includes
#include <datetime.h>

// Argument includes
#include <QString>
#include <QStringView>
#include <qcalendar.h>
#include <qdatetime.h>
#include <qnamespace.h>
#include <qtimezone.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (core-snippets-p-h)]
#include "glue/core_snippets_p.h"
// END of custom code block [file: ../glue/qtcore.cpp (core-snippets-p-h)]
// ========================================================================
// End of code injection



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDate_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDate >()))
        return -1;

    ::QDate *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    if (PyArg_UnpackTuple(args, "QDate", 0, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDate::QDate()
    // 1: QDate::QDate(QDate)
    // 2: QDate::QDate(int,int,int)
    // 3: QDate::QDate(int,int,int,QCalendar)
    if (numArgs == 0) {
        overloadId = 0; // QDate()
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 2; // QDate(int,int,int)
        } else if (numArgs == 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[3])))) {
            overloadId = 3; // QDate(int,int,int,QCalendar)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDate(QDate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDate()
        {

            // QDate()
            cptr = new ::QDate();
            break;
        }
        case 1: // QDate(const QDate &QDate)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDate cppArg0_local;
            ::QDate *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDate(QDate)
                cptr = new ::QDate(*cppArg0);
            }
            break;
        }
        case 2: // QDate(int y, int m, int d)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDate(int,int,int)
                cptr = new ::QDate(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 3: // QDate(int y, int m, int d, QCalendar cal)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QCalendar cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDate(int,int,int,QCalendar)
                cptr = new ::QDate(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDate >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDateFunc___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __reduce__()
        // Begin code injection
        // TEMPLATE - reduce_code - START
        pyResult = Py_BuildValue("(N(iii))", PyObject_Type(self), cppSelf->year(), cppSelf->month(), cppSelf->day());
        // TEMPLATE - reduce_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - repr_code - START
        QString format = QString::asprintf("%s(%i, %i, %i)",
            Py_TYPE(self)->tp_name, cppSelf->year(), cppSelf->month(), cppSelf->day());
        pyResult = Shiboken::String::fromCString(qPrintable(format));
        // TEMPLATE - repr_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_addDays(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDate::addDays(qint64)const->QDate
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // addDays(qint64)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addDays", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addDays(qint64)const
            QDate cppResult = const_cast<const ::QDate *>(cppSelf)->addDays(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_addMonths(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addMonths", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDate::addMonths(int)const->QDate
    // 1: QDate::addMonths(int,QCalendar)const->QDate
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addMonths(int)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[1])))) {
            overloadId = 1; // addMonths(int,QCalendar)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addMonths", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addMonths(int months) const
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addMonths(int)const
                QDate cppResult = const_cast<const ::QDate *>(cppSelf)->addMonths(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 1: // addMonths(int months, QCalendar cal) const
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QCalendar cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addMonths(int,QCalendar)const
                QDate cppResult = const_cast<const ::QDate *>(cppSelf)->addMonths(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_addYears(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addYears", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDate::addYears(int)const->QDate
    // 1: QDate::addYears(int,QCalendar)const->QDate
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addYears(int)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[1])))) {
            overloadId = 1; // addYears(int,QCalendar)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addYears", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addYears(int years) const
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addYears(int)const
                QDate cppResult = const_cast<const ::QDate *>(cppSelf)->addYears(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 1: // addYears(int years, QCalendar cal) const
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QCalendar cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addYears(int,QCalendar)const
                QDate cppResult = const_cast<const ::QDate *>(cppSelf)->addYears(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_currentDate(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentDate()
        QDate cppResult = ::QDate::currentDate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_day(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "day", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDate::day()const->int
    // 1: QDate::day(QCalendar)const->int
    if (numArgs == 0) {
        overloadId = 0; // day()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[0])))) {
        overloadId = 1; // day(QCalendar)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "day", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // day() const
        {

            // day()const
            int cppResult = const_cast<const ::QDate *>(cppSelf)->day();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            break;
        }
        case 1: // day(QCalendar cal) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QCalendar cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // day(QCalendar)const
                int cppResult = const_cast<const ::QDate *>(cppSelf)->day(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_dayOfWeek(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "dayOfWeek", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDate::dayOfWeek()const->int
    // 1: QDate::dayOfWeek(QCalendar)const->int
    if (numArgs == 0) {
        overloadId = 0; // dayOfWeek()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[0])))) {
        overloadId = 1; // dayOfWeek(QCalendar)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dayOfWeek", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // dayOfWeek() const
        {

            // dayOfWeek()const
            int cppResult = const_cast<const ::QDate *>(cppSelf)->dayOfWeek();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            break;
        }
        case 1: // dayOfWeek(QCalendar cal) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QCalendar cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // dayOfWeek(QCalendar)const
                int cppResult = const_cast<const ::QDate *>(cppSelf)->dayOfWeek(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_dayOfYear(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "dayOfYear", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDate::dayOfYear()const->int
    // 1: QDate::dayOfYear(QCalendar)const->int
    if (numArgs == 0) {
        overloadId = 0; // dayOfYear()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[0])))) {
        overloadId = 1; // dayOfYear(QCalendar)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dayOfYear", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // dayOfYear() const
        {

            // dayOfYear()const
            int cppResult = const_cast<const ::QDate *>(cppSelf)->dayOfYear();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            break;
        }
        case 1: // dayOfYear(QCalendar cal) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QCalendar cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // dayOfYear(QCalendar)const
                int cppResult = const_cast<const ::QDate *>(cppSelf)->dayOfYear(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_daysInMonth(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "daysInMonth", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDate::daysInMonth()const->int
    // 1: QDate::daysInMonth(QCalendar)const->int
    if (numArgs == 0) {
        overloadId = 0; // daysInMonth()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[0])))) {
        overloadId = 1; // daysInMonth(QCalendar)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "daysInMonth", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // daysInMonth() const
        {

            // daysInMonth()const
            int cppResult = const_cast<const ::QDate *>(cppSelf)->daysInMonth();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            break;
        }
        case 1: // daysInMonth(QCalendar cal) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QCalendar cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // daysInMonth(QCalendar)const
                int cppResult = const_cast<const ::QDate *>(cppSelf)->daysInMonth(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_daysInYear(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "daysInYear", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDate::daysInYear()const->int
    // 1: QDate::daysInYear(QCalendar)const->int
    if (numArgs == 0) {
        overloadId = 0; // daysInYear()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[0])))) {
        overloadId = 1; // daysInYear(QCalendar)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "daysInYear", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // daysInYear() const
        {

            // daysInYear()const
            int cppResult = const_cast<const ::QDate *>(cppSelf)->daysInYear();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            break;
        }
        case 1: // daysInYear(QCalendar cal) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QCalendar cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // daysInYear(QCalendar)const
                int cppResult = const_cast<const ::QDate *>(cppSelf)->daysInYear(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_daysTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDate::daysTo(QDate)const->qint64
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // daysTo(QDate)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "daysTo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // daysTo(QDate)const
            qint64 cppResult = const_cast<const ::QDate *>(cppSelf)->daysTo(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_endOfDay(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "endOfDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    if (PyArg_ParseTuple(args, "|OO:endOfDay", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDate::endOfDay()const->QDateTime
    // 1: QDate::endOfDay(Qt::TimeSpec,int=)const->QDateTime
    // 2: QDate::endOfDay(QTimeZone)const->QDateTime
    if (numArgs == 0) {
        overloadId = 0; // endOfDay()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))) {
        overloadId = 2; // endOfDay(QTimeZone)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimeSpec_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // endOfDay(Qt::TimeSpec,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // endOfDay(Qt::TimeSpec,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "endOfDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // endOfDay() const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "endOfDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
            }

            // endOfDay()const
            QDateTime cppResult = const_cast<const ::QDate *>(cppSelf)->endOfDay();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            break;
        }
        case 1: // endOfDay(Qt::TimeSpec spec, int offsetSeconds) const
        {
            Shiboken::Warnings::warnDeprecated("QDate", "endOfDay(Qt.TimeSpec spec, int offsetSeconds) const");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_offsetSeconds = Shiboken::String::createStaticString("offsetSeconds");
                if (PyDict_Contains(kwds, key_offsetSeconds) != 0) {
                    value = PyDict_GetItem(kwds, key_offsetSeconds);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_offsetSeconds);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "endOfDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "endOfDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_offsetSeconds);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "endOfDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                }
            }
            ::Qt::TimeSpec cppArg0{Qt::LocalTime};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // endOfDay(Qt::TimeSpec,int)const
                QDateTime cppResult = const_cast<const ::QDate *>(cppSelf)->endOfDay(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            }
            break;
        }
        case 2: // endOfDay(const QTimeZone &zone) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "endOfDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTimeZone cppArg0_local;
            ::QTimeZone *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // endOfDay(QTimeZone)const
                QDateTime cppResult = const_cast<const ::QDate *>(cppSelf)->endOfDay(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_fromJulianDay(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDate::fromJulianDay(qint64)->QDate
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // fromJulianDay(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromJulianDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromJulianDay(qint64)
            QDate cppResult = ::QDate::fromJulianDay(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_fromString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:fromString", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QDate::fromString(QStringView,QStringView,QCalendar)->QDate
    // 1: static QDate::fromString(QStringView,QStringView,int=)->QDate
    // 2: static QDate::fromString(QStringView,QStringView,int,QCalendar)->QDate
    // 3: static QDate::fromString(QStringView,Qt::DateFormat=)->QDate
    // 4: static QDate::fromString(QString,QStringView,QCalendar)->QDate
    // 5: static QDate::fromString(QString,QStringView,int=)->QDate
    // 6: static QDate::fromString(QString,QStringView,int,QCalendar)->QDate
    // 7: static QDate::fromString(QString,Qt::DateFormat=)->QDate
    // 8: static QDate::fromString(QString,QString,QCalendar)->QDate
    // 9: static QDate::fromString(QString,QString,int=)->QDate
    // 10: static QDate::fromString(QString,QString,int,QCalendar)->QDate
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 7; // fromString(QString,Qt::DateFormat)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 9; // fromString(QString,QString,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 9; // fromString(QString,QString,int)
                } else if (numArgs == 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[3])))) {
                    overloadId = 10; // fromString(QString,QString,int,QCalendar)
                }
            } else if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[2])))) {
                overloadId = 8; // fromString(QString,QString,QCalendar)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DateFormat_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 7; // fromString(QString,Qt::DateFormat)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 5; // fromString(QString,QStringView,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 5; // fromString(QString,QStringView,int)
                } else if (numArgs == 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[3])))) {
                    overloadId = 6; // fromString(QString,QStringView,int,QCalendar)
                }
            } else if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[2])))) {
                overloadId = 4; // fromString(QString,QStringView,QCalendar)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // fromString(QStringView,Qt::DateFormat)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DateFormat_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 3; // fromString(QStringView,Qt::DateFormat)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // fromString(QStringView,QStringView,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // fromString(QStringView,QStringView,int)
                } else if (numArgs == 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[3])))) {
                    overloadId = 2; // fromString(QStringView,QStringView,int,QCalendar)
                }
            } else if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[2])))) {
                overloadId = 0; // fromString(QStringView,QStringView,QCalendar)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // fromString(QStringView string, QStringView format, QCalendar cal)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QCalendar cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QStringView,QStringView,QCalendar)
                QDate cppResult = ::QDate::fromString(QStringView(cppArg0), QStringView(cppArg1), cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 1: // fromString(QStringView string, QStringView format, int baseYear)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_baseYear = Shiboken::String::createStaticString("baseYear");
                if (PyDict_Contains(kwds, key_baseYear) != 0) {
                    value = PyDict_GetItem(kwds, key_baseYear);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_baseYear);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_baseYear);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = QLocale::DefaultTwoDigitBaseYear;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QStringView,QStringView,int)
                QDate cppResult = ::QDate::fromString(QStringView(cppArg0), QStringView(cppArg1), cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 2: // fromString(QStringView string, QStringView format, int baseYear, QCalendar cal)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QCalendar cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QStringView,QStringView,int,QCalendar)
                QDate cppResult = ::QDate::fromString(QStringView(cppArg0), QStringView(cppArg1), cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 3: // fromString(QStringView string, Qt::DateFormat format)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DateFormat_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::DateFormat cppArg1(Qt::TextDate);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QStringView,Qt::DateFormat)
                QDate cppResult = ::QDate::fromString(QStringView(cppArg0), cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 4: // fromString(const QString &string, QStringView format, QCalendar cal)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QCalendar cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QString,QStringView,QCalendar)
                QDate cppResult = ::QDate::fromString(cppArg0, QStringView(cppArg1), cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 5: // fromString(const QString &string, QStringView format, int baseYear)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_baseYear = Shiboken::String::createStaticString("baseYear");
                if (PyDict_Contains(kwds, key_baseYear) != 0) {
                    value = PyDict_GetItem(kwds, key_baseYear);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_baseYear);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_baseYear);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = QLocale::DefaultTwoDigitBaseYear;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QString,QStringView,int)
                QDate cppResult = ::QDate::fromString(cppArg0, QStringView(cppArg1), cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 6: // fromString(const QString &string, QStringView format, int baseYear, QCalendar cal)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QCalendar cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QString,QStringView,int,QCalendar)
                QDate cppResult = ::QDate::fromString(cppArg0, QStringView(cppArg1), cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 7: // fromString(const QString &string, Qt::DateFormat format)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DateFormat_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::DateFormat cppArg1(Qt::TextDate);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QString,Qt::DateFormat)
                QDate cppResult = ::QDate::fromString(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 8: // fromString(const QString &string, const QString &format, QCalendar cal)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QCalendar cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QString,QString,QCalendar)
                QDate cppResult = ::QDate::fromString(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 9: // fromString(const QString &string, const QString &format, int baseYear)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_baseYear = Shiboken::String::createStaticString("baseYear");
                if (PyDict_Contains(kwds, key_baseYear) != 0) {
                    value = PyDict_GetItem(kwds, key_baseYear);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_baseYear);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_baseYear);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = QLocale::DefaultTwoDigitBaseYear;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QString,QString,int)
                QDate cppResult = ::QDate::fromString(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 10: // fromString(const QString &string, const QString &format, int baseYear, QCalendar cal)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QCalendar cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QString,QString,int,QCalendar)
                QDate cppResult = ::QDate::fromString(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_getDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getDate(int*,int*,int*)const
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qdate-getdate)]
            int year, month, day;
            cppSelf->getDate(&year, &month, &day);
            pyResult = PyTuple_New(3);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &year));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &month));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &day));
            // END of custom code block [file: ../glue/qtcore.cpp (qdate-getdate)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_isLeapYear(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDate::isLeapYear(int)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // isLeapYear(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isLeapYear", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isLeapYear(int)
            bool cppResult = ::QDate::isLeapYear(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QDate *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_isValid(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QDate *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 1 || numArgs == 2)
        return Shiboken::returnWrongArguments(args, "isValid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    if (PyArg_UnpackTuple(args, "isValid", 0, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDate::isValid()const->bool
    // 1: static QDate::isValid(int,int,int)->bool
    if (numArgs == 0) {
        overloadId = 0; // isValid()const
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 1; // isValid(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isValid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // isValid() const
        {

            // isValid()const
            bool cppResult = const_cast<const ::QDate *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            break;
        }
        case 1: // isValid(int y, int m, int d)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isValid(int,int,int)
                bool cppResult = ::QDate::isValid(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_month(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "month", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDate::month()const->int
    // 1: QDate::month(QCalendar)const->int
    if (numArgs == 0) {
        overloadId = 0; // month()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[0])))) {
        overloadId = 1; // month(QCalendar)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "month", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // month() const
        {

            // month()const
            int cppResult = const_cast<const ::QDate *>(cppSelf)->month();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            break;
        }
        case 1: // month(QCalendar cal) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QCalendar cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // month(QCalendar)const
                int cppResult = const_cast<const ::QDate *>(cppSelf)->month(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_setDate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDate", 3, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDate::setDate(int,int,int)->bool
    // 1: QDate::setDate(int,int,int,QCalendar)->bool
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // setDate(int,int,int)
        } else if (numArgs == 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[3])))) {
            overloadId = 1; // setDate(int,int,int,QCalendar)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDate", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setDate(int year, int month, int day)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setDate(int,int,int)
                bool cppResult = cppSelf->setDate(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // setDate(int year, int month, int day, QCalendar cal)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QCalendar cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setDate(int,int,int,QCalendar)
                bool cppResult = cppSelf->setDate(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_startOfDay(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "startOfDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    if (PyArg_ParseTuple(args, "|OO:startOfDay", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDate::startOfDay()const->QDateTime
    // 1: QDate::startOfDay(Qt::TimeSpec,int=)const->QDateTime
    // 2: QDate::startOfDay(QTimeZone)const->QDateTime
    if (numArgs == 0) {
        overloadId = 0; // startOfDay()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))) {
        overloadId = 2; // startOfDay(QTimeZone)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimeSpec_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // startOfDay(Qt::TimeSpec,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // startOfDay(Qt::TimeSpec,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "startOfDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // startOfDay() const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "startOfDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
            }

            // startOfDay()const
            QDateTime cppResult = const_cast<const ::QDate *>(cppSelf)->startOfDay();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            break;
        }
        case 1: // startOfDay(Qt::TimeSpec spec, int offsetSeconds) const
        {
            Shiboken::Warnings::warnDeprecated("QDate", "startOfDay(Qt.TimeSpec spec, int offsetSeconds) const");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_offsetSeconds = Shiboken::String::createStaticString("offsetSeconds");
                if (PyDict_Contains(kwds, key_offsetSeconds) != 0) {
                    value = PyDict_GetItem(kwds, key_offsetSeconds);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_offsetSeconds);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "startOfDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "startOfDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_offsetSeconds);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "startOfDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                }
            }
            ::Qt::TimeSpec cppArg0{Qt::LocalTime};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // startOfDay(Qt::TimeSpec,int)const
                QDateTime cppResult = const_cast<const ::QDate *>(cppSelf)->startOfDay(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            }
            break;
        }
        case 2: // startOfDay(const QTimeZone &zone) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "startOfDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTimeZone cppArg0_local;
            ::QTimeZone *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // startOfDay(QTimeZone)const
                QDateTime cppResult = const_cast<const ::QDate *>(cppSelf)->startOfDay(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_toJulianDay(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toJulianDay()const
        qint64 cppResult = const_cast<const ::QDate *>(cppSelf)->toJulianDay();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_toPython(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toPython()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtcore.cpp (qdate-topython)]
        if (!PyDateTimeAPI)
            PyDateTime_IMPORT;
        pyResult = PyDate_FromDate(cppSelf->year(), cppSelf->month(), cppSelf->day());
        // END of custom code block [file: ../glue/qtcore.cpp (qdate-topython)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_toString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    if (PyArg_ParseTuple(args, "|OO:toString", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDate::toString(QStringView)const->QString
    // 1: QDate::toString(QStringView,QCalendar)const->QString
    // 2: QDate::toString(Qt::DateFormat=)const->QString
    // 3: QDate::toString(QString)const->QString
    // 4: QDate::toString(QString,QCalendar)const->QString
    if (numArgs == 0) {
        overloadId = 2; // toString(Qt::DateFormat)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // toString(QString)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[1])))) {
            overloadId = 4; // toString(QString,QCalendar)const
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DateFormat_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 2; // toString(Qt::DateFormat)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // toString(QStringView)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[1])))) {
            overloadId = 1; // toString(QStringView,QCalendar)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // toString(QStringView format) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QStringView)const
                QString cppResult = const_cast<const ::QDate *>(cppSelf)->toString(QStringView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // toString(QStringView format, QCalendar cal) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QCalendar cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QStringView,QCalendar)const
                QString cppResult = const_cast<const ::QDate *>(cppSelf)->toString(QStringView(cppArg0), cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 2: // toString(Qt::DateFormat format) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DateFormat_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
                }
            }
            ::Qt::DateFormat cppArg0(Qt::TextDate);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(Qt::DateFormat)const
                QString cppResult = const_cast<const ::QDate *>(cppSelf)->toString(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 3: // toString(const QString &format) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QString)const
                QString cppResult = const_cast<const ::QDate *>(cppSelf)->toString(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 4: // toString(const QString &format, QCalendar cal) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QCalendar cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QString,QCalendar)const
                QString cppResult = const_cast<const ::QDate *>(cppSelf)->toString(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_weekNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        int* removed_cppArg0 = nullptr;
        SBK_UNUSED(removed_cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // weekNumber(int*)const
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qdate-weeknumber)]
            int yearNumber;
            int week = cppSelf->weekNumber(&yearNumber);
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &week));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &yearNumber));
            // END of custom code block [file: ../glue/qtcore.cpp (qdate-weeknumber)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDateFunc_year(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "year", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDate::year()const->int
    // 1: QDate::year(QCalendar)const->int
    if (numArgs == 0) {
        overloadId = 0; // year()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[0])))) {
        overloadId = 1; // year(QCalendar)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "year", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // year() const
        {

            // year()const
            int cppResult = const_cast<const ::QDate *>(cppSelf)->year();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            break;
        }
        case 1: // year(QCalendar cal) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QCalendar cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // year(QCalendar)const
                int cppResult = const_cast<const ::QDate *>(cppSelf)->year(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDate__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QDateMethod_isValid = {"isValid", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_isValid), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_QDate_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDate_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QDateFunc___reduce__), METH_NOARGS, nullptr},
    {"addDays", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_addDays), METH_O, nullptr},
    {"addMonths", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_addMonths), METH_VARARGS, nullptr},
    {"addYears", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_addYears), METH_VARARGS, nullptr},
    {"currentDate", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_currentDate), METH_NOARGS|METH_STATIC, nullptr},
    {"day", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_day), METH_VARARGS, nullptr},
    {"dayOfWeek", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_dayOfWeek), METH_VARARGS, nullptr},
    {"dayOfYear", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_dayOfYear), METH_VARARGS, nullptr},
    {"daysInMonth", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_daysInMonth), METH_VARARGS, nullptr},
    {"daysInYear", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_daysInYear), METH_VARARGS, nullptr},
    {"daysTo", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_daysTo), METH_O, nullptr},
    {"endOfDay", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_endOfDay), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"fromJulianDay", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_fromJulianDay), METH_O|METH_STATIC, nullptr},
    {"fromString", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_fromString), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"getDate", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_getDate), METH_NOARGS, nullptr},
    {"isLeapYear", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_isLeapYear), METH_O|METH_STATIC, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_isNull), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_isValid), METH_VARARGS|METH_STATIC, nullptr},
    {"month", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_month), METH_VARARGS, nullptr},
    {"setDate", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_setDate), METH_VARARGS, nullptr},
    {"startOfDay", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_startOfDay), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toJulianDay", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_toJulianDay), METH_NOARGS, nullptr},
    {"toPython", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_toPython), METH_NOARGS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_toString), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"weekNumber", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_weekNumber), METH_NOARGS, nullptr},
    {"year", reinterpret_cast<PyCFunction>(Sbk_QDateFunc_year), METH_VARARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDate__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QDate_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QDateMethod_isValid = {
        Sbk_QDateMethod_isValid.ml_name,
        Sbk_QDateMethod_isValid.ml_meth,
        Sbk_QDateMethod_isValid.ml_flags & (~METH_STATIC),
        Sbk_QDateMethod_isValid.ml_doc,
    };
    if (Shiboken::String::compare(name, "isValid") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QDateMethod_isValid, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

static int Sbk_QDate___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QDate_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
                // operator!=(const QDate &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDate cppArg0_local;
                ::QDate *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
                // operator<(const QDate &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDate cppArg0_local;
                ::QDate *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
                // operator<=(const QDate &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDate cppArg0_local;
                ::QDate *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
                // operator==(const QDate &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDate cppArg0_local;
                ::QDate *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
                // operator>(const QDate &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDate cppArg0_local;
                ::QDate *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
                // operator>=(const QDate &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDate cppArg0_local;
                ::QDate *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QDate_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QDate_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDate_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDate_Type = nullptr;
static PyTypeObject *Sbk_QDate_TypeF(void)
{
    return _Sbk_QDate_Type;
}

static PyType_Slot Sbk_QDate_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QDateFunc___repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QDate_HashFunc)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QDate_getattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDate_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDate_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QDate_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDate_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDate_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QDate___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDate_spec = {
    "2:PySide6.QtCore.QDate",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDate_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDate_PythonToCpp_QDate_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDate_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDate_PythonToCpp_QDate_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDate_TypeF()))
        return QDate_PythonToCpp_QDate_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDate_PTR_CppToPython_QDate(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDate_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDate_COPY_CppToPython_QDate(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDate *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDate_TypeF(), new ::QDate(*source), true, true);
}

// Python to C++ copy conversion.
static void QDate_PythonToCpp_QDate_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDate *>(cppOut) = *reinterpret_cast< ::QDate *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDate_PythonToCpp_QDate_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDate_TypeF()))
        return QDate_PythonToCpp_QDate_COPY;
    return {};
}

// Python to C++ conversions for type 'QDate'.
static void Py_None_PythonToCpp_QDate(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pynone)]
    SBK_UNUSED(pyIn)
    *reinterpret_cast<::QDate *>(cppOut) = QDate();
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pynone)]
    // ========================================================================

}
static PythonToCppFunc is_Py_None_PythonToCpp_QDate_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Py_None_PythonToCpp_QDate;
    return {};
}
static void PyDate_PythonToCpp_QDate(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-qdate-pydate)]
    int day = PyDateTime_GET_DAY(pyIn);
    int month = PyDateTime_GET_MONTH(pyIn);
    int year = PyDateTime_GET_YEAR(pyIn);
    *reinterpret_cast<::QDate *>(cppOut) = QDate(year, month, day);
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-qdate-pydate)]
    // ========================================================================

}
static PythonToCppFunc is_PyDate_PythonToCpp_QDate_Convertible(PyObject *pyIn)
{
    if (PyDate_ImportAndCheck(pyIn))
        return PyDate_PythonToCpp_QDate;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDate_SignatureStrings[] = {
    "3:PySide6.QtCore.QDate(self)",
    "2:PySide6.QtCore.QDate(self,QDate:PySide6.QtCore.QDate)",
    "1:PySide6.QtCore.QDate(self,y:int,m:int,d:int)",
    "0:PySide6.QtCore.QDate(self,y:int,m:int,d:int,cal:PySide6.QtCore.QCalendar)",
    "PySide6.QtCore.QDate.__reduce__(self)->str",
    "PySide6.QtCore.QDate.__repr__(self)->str",
    "PySide6.QtCore.QDate.addDays(self,days:qint64)->PySide6.QtCore.QDate",
    "1:PySide6.QtCore.QDate.addMonths(self,months:int)->PySide6.QtCore.QDate",
    "0:PySide6.QtCore.QDate.addMonths(self,months:int,cal:PySide6.QtCore.QCalendar)->PySide6.QtCore.QDate",
    "1:PySide6.QtCore.QDate.addYears(self,years:int)->PySide6.QtCore.QDate",
    "0:PySide6.QtCore.QDate.addYears(self,years:int,cal:PySide6.QtCore.QCalendar)->PySide6.QtCore.QDate",
    "PySide6.QtCore.QDate.currentDate()->PySide6.QtCore.QDate",
    "1:PySide6.QtCore.QDate.day(self)->int",
    "0:PySide6.QtCore.QDate.day(self,cal:PySide6.QtCore.QCalendar)->int",
    "1:PySide6.QtCore.QDate.dayOfWeek(self)->int",
    "0:PySide6.QtCore.QDate.dayOfWeek(self,cal:PySide6.QtCore.QCalendar)->int",
    "1:PySide6.QtCore.QDate.dayOfYear(self)->int",
    "0:PySide6.QtCore.QDate.dayOfYear(self,cal:PySide6.QtCore.QCalendar)->int",
    "1:PySide6.QtCore.QDate.daysInMonth(self)->int",
    "0:PySide6.QtCore.QDate.daysInMonth(self,cal:PySide6.QtCore.QCalendar)->int",
    "1:PySide6.QtCore.QDate.daysInYear(self)->int",
    "0:PySide6.QtCore.QDate.daysInYear(self,cal:PySide6.QtCore.QCalendar)->int",
    "PySide6.QtCore.QDate.daysTo(self,d:PySide6.QtCore.QDate)->qint64",
    "2:PySide6.QtCore.QDate.endOfDay(self)->PySide6.QtCore.QDateTime",
    "1:PySide6.QtCore.QDate.endOfDay(self,spec:PySide6.QtCore.Qt.TimeSpec,offsetSeconds:int=0)->PySide6.QtCore.QDateTime",
    "0:PySide6.QtCore.QDate.endOfDay(self,zone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->PySide6.QtCore.QDateTime",
    "PySide6.QtCore.QDate.fromJulianDay(jd_:qint64)->PySide6.QtCore.QDate",
    "10:PySide6.QtCore.QDate.fromString(string:QString,format:QString,cal:PySide6.QtCore.QCalendar)->PySide6.QtCore.QDate",
    "9:PySide6.QtCore.QDate.fromString(string:QString,format:QString,baseYear:int=QLocale.DefaultTwoDigitBaseYear)->PySide6.QtCore.QDate",
    "8:PySide6.QtCore.QDate.fromString(string:QString,format:QString,baseYear:int,cal:PySide6.QtCore.QCalendar)->PySide6.QtCore.QDate",
    "7:PySide6.QtCore.QDate.fromString(string:QString,format:PySide6.QtCore.Qt.DateFormat=Qt.TextDate)->PySide6.QtCore.QDate",
    "6:PySide6.QtCore.QDate.fromString(string:QString,format:QString,cal:PySide6.QtCore.QCalendar)->PySide6.QtCore.QDate",
    "5:PySide6.QtCore.QDate.fromString(string:QString,format:QString,baseYear:int=QLocale.DefaultTwoDigitBaseYear)->PySide6.QtCore.QDate",
    "4:PySide6.QtCore.QDate.fromString(string:QString,format:QString,baseYear:int,cal:PySide6.QtCore.QCalendar)->PySide6.QtCore.QDate",
    "3:PySide6.QtCore.QDate.fromString(string:QString,format:PySide6.QtCore.Qt.DateFormat=Qt.TextDate)->PySide6.QtCore.QDate",
    "2:PySide6.QtCore.QDate.fromString(string:QString,format:QString,cal:PySide6.QtCore.QCalendar)->PySide6.QtCore.QDate",
    "1:PySide6.QtCore.QDate.fromString(string:QString,format:QString,baseYear:int=QLocale.DefaultTwoDigitBaseYear)->PySide6.QtCore.QDate",
    "0:PySide6.QtCore.QDate.fromString(string:QString,format:QString,baseYear:int,cal:PySide6.QtCore.QCalendar)->PySide6.QtCore.QDate",
    "PySide6.QtCore.QDate.getDate(self)->Tuple[int, int, int]",
    "PySide6.QtCore.QDate.isLeapYear(year:int)->bool",
    "PySide6.QtCore.QDate.isNull(self)->bool",
    "1:PySide6.QtCore.QDate.isValid(self)->bool",
    "0:PySide6.QtCore.QDate.isValid(y:int,m:int,d:int)->bool",
    "1:PySide6.QtCore.QDate.month(self)->int",
    "0:PySide6.QtCore.QDate.month(self,cal:PySide6.QtCore.QCalendar)->int",
    "1:PySide6.QtCore.QDate.setDate(self,year:int,month:int,day:int)->bool",
    "0:PySide6.QtCore.QDate.setDate(self,year:int,month:int,day:int,cal:PySide6.QtCore.QCalendar)->bool",
    "2:PySide6.QtCore.QDate.startOfDay(self)->PySide6.QtCore.QDateTime",
    "1:PySide6.QtCore.QDate.startOfDay(self,spec:PySide6.QtCore.Qt.TimeSpec,offsetSeconds:int=0)->PySide6.QtCore.QDateTime",
    "0:PySide6.QtCore.QDate.startOfDay(self,zone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->PySide6.QtCore.QDateTime",
    "PySide6.QtCore.QDate.toJulianDay(self)->qint64",
    "PySide6.QtCore.QDate.toPython(self)->PyObject",
    "4:PySide6.QtCore.QDate.toString(self,format:QString)->QString",
    "3:PySide6.QtCore.QDate.toString(self,format:QString,cal:PySide6.QtCore.QCalendar)->QString",
    "2:PySide6.QtCore.QDate.toString(self,format:PySide6.QtCore.Qt.DateFormat=Qt.TextDate)->QString",
    "1:PySide6.QtCore.QDate.toString(self,format:QString)->QString",
    "0:PySide6.QtCore.QDate.toString(self,format:QString,cal:PySide6.QtCore.QCalendar)->QString",
    "PySide6.QtCore.QDate.weekNumber(self)->Tuple[int, int]",
    "1:PySide6.QtCore.QDate.year(self)->int",
    "0:PySide6.QtCore.QDate.year(self,cal:PySide6.QtCore.QCalendar)->int",
    "PySide6.QtCore.QDate.__copy__(self)->typing.Self",
    "PySide6.QtCore.QDate.__ne__(self,rhs:PySide6.QtCore.QDate)->bool",
    "PySide6.QtCore.QDate.__lt__(self,rhs:PySide6.QtCore.QDate)->bool",
    "PySide6.QtCore.QDate.__le__(self,rhs:PySide6.QtCore.QDate)->bool",
    "PySide6.QtCore.QDate.__eq__(self,rhs:PySide6.QtCore.QDate)->bool",
    "PySide6.QtCore.QDate.__gt__(self,rhs:PySide6.QtCore.QDate)->bool",
    "PySide6.QtCore.QDate.__ge__(self,rhs:PySide6.QtCore.QDate)->bool",
    "PySide6.QtCore.QDate.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QDate_SignatureByteSize = 731;
static constexpr uint8_t QDate_SignatureBytes[731] = {
    0x78, 0xda, 0xcd, 0x58, 0xd1, 0x4e, 0xdb, 0x30, 0x14, 0x7d, 0xef, 0x57, 0xf0, 0x48, 0xa5, 0x10,
    0xa5, 0xc0, 0xd8, 0x56, 0x09, 0x1e, 0x46, 0x35, 0x89, 0x89, 0x01, 0x55, 0xbb, 0x4d, 0x1b, 0x42,
    0x91, 0x9b, 0xdc, 0xb4, 0x66, 0x89, 0x5d, 0x6c, 0x47, 0x2c, 0x7c, 0xfd, 0x6c, 0x37, 0xa1, 0x2d,
    0xb5, 0xd3, 0xb4, 0x66, 0x2b, 0x2f, 0x69, 0x22, 0x9f, 0x7b, 0xce, 0xb9, 0xbe, 0xce, 0x8d, 0xdd,
    0xa3, 0xee, 0x4d, 0x31, 0xc0, 0x31, 0x9c, 0xf8, 0x7d, 0x71, 0x4e, 0x19, 0xf8, 0xfd, 0x1e, 0x12,
    0xb0, 0xcf, 0x21, 0x4d, 0xda, 0xad, 0x43, 0xfb, 0xa0, 0xa7, 0x6f, 0x8d, 0xe3, 0xed, 0x56, 0xa7,
    0x26, 0xae, 0xe8, 0x62, 0x22, 0xbc, 0x4c, 0x5f, 0x63, 0x75, 0x6d, 0xb7, 0x82, 0x4d, 0xe0, 0x5e,
    0x84, 0xd2, 0x15, 0xfc, 0x39, 0x4a, 0x81, 0xc4, 0x88, 0xb5, 0x5b, 0x26, 0x26, 0x3f, 0x0c, 0x19,
    0xc4, 0x79, 0x04, 0x61, 0x38, 0x4b, 0xec, 0xe0, 0x8c, 0x0b, 0x66, 0x87, 0x4e, 0x59, 0x03, 0x20,
    0x8a, 0xe3, 0x1e, 0x2a, 0xf8, 0xcc, 0x65, 0x2c, 0xef, 0xba, 0x0f, 0xd2, 0xdd, 0xc9, 0xb1, 0x8c,
    0x31, 0xe1, 0x2d, 0x73, 0xa2, 0x68, 0xbe, 0x52, 0x22, 0x26, 0x25, 0x51, 0xa6, 0xef, 0xf5, 0xb4,
    0x58, 0x78, 0x82, 0x0d, 0x79, 0xea, 0xe7, 0x6b, 0x63, 0xb3, 0x3f, 0x01, 0xb1, 0x52, 0xa3, 0x50,
    0xb7, 0xdb, 0x59, 0x35, 0xb1, 0x6c, 0x65, 0xd4, 0x28, 0x10, 0xe5, 0x8c, 0x01, 0x11, 0x7a, 0x11,
    0x6d, 0x98, 0xa1, 0x2c, 0x64, 0x55, 0x79, 0x69, 0xc9, 0x96, 0x41, 0x85, 0x5a, 0x67, 0x59, 0x51,
    0xd8, 0x85, 0xae, 0x93, 0x1f, 0x00, 0xbf, 0x9b, 0xc9, 0x2d, 0x60, 0x5d, 0x45, 0xd5, 0xdc, 0x37,
    0x15, 0x7d, 0xc6, 0xba, 0x89, 0xf2, 0x0b, 0xa2, 0x17, 0x67, 0x33, 0xd9, 0x25, 0xb4, 0xb3, 0x70,
    0xf3, 0x74, 0x17, 0xc1, 0x4d, 0x64, 0xad, 0x3c, 0x43, 0x5a, 0x76, 0x05, 0x73, 0x7b, 0x3c, 0x38,
    0x9b, 0x75, 0x0a, 0x4b, 0x7b, 0xf5, 0xa5, 0xc6, 0x75, 0xd2, 0x9b, 0x2f, 0x44, 0x13, 0x68, 0x88,
    0x33, 0xeb, 0x1a, 0x5e, 0x8a, 0xf7, 0xf8, 0x14, 0xa2, 0x15, 0x9c, 0xf0, 0x15, 0xc1, 0x40, 0x0e,
    0x79, 0x34, 0x49, 0x38, 0x88, 0x01, 0x44, 0x94, 0xc4, 0xfa, 0x3d, 0x3c, 0x0d, 0xea, 0x34, 0x83,
    0x26, 0x9a, 0x4f, 0x94, 0x40, 0x57, 0x14, 0x53, 0x4c, 0xc6, 0xfe, 0x37, 0x82, 0x29, 0xb9, 0x7d,
    0x19, 0xa4, 0xb8, 0x7e, 0x49, 0x94, 0xb7, 0x67, 0x1b, 0xf1, 0x2f, 0x08, 0x16, 0x18, 0xa5, 0xf8,
    0x09, 0x09, 0xc9, 0x70, 0x57, 0x67, 0xca, 0x68, 0x29, 0x61, 0x34, 0xfb, 0x92, 0xa7, 0x18, 0x11,
    0xe5, 0xeb, 0x3e, 0x0e, 0xd7, 0x35, 0x68, 0x4b, 0x6a, 0x8a, 0x67, 0x20, 0x98, 0xcc, 0x65, 0x9f,
    0xeb, 0x9f, 0x6e, 0x7f, 0xf6, 0xe8, 0x25, 0x94, 0x65, 0x48, 0x3c, 0x3f, 0x6e, 0xd3, 0xbf, 0x3e,
    0x3a, 0x6a, 0x8e, 0x10, 0x07, 0xb5, 0x68, 0x75, 0xe1, 0xfa, 0x97, 0x54, 0x7a, 0x00, 0xbf, 0x07,
    0x09, 0xca, 0x53, 0x31, 0x7c, 0xa4, 0x3d, 0x3c, 0xc6, 0xe2, 0x53, 0x89, 0xb1, 0x79, 0xf8, 0xf0,
    0x8a, 0x1e, 0xb6, 0x9a, 0x84, 0xf7, 0x5b, 0x1a, 0x58, 0x5d, 0xd5, 0x2a, 0xee, 0xb3, 0x1e, 0x3c,
    0x55, 0x6b, 0x1c, 0xfe, 0x88, 0xf2, 0x8d, 0x33, 0xea, 0x9e, 0xec, 0xa0, 0xe0, 0xef, 0xde, 0x40,
    0xc1, 0x8f, 0x77, 0x5d, 0xf0, 0xa3, 0x1d, 0x15, 0xfc, 0x70, 0x07, 0x05, 0xef, 0xbc, 0x81, 0x82,
    0x07, 0xbb, 0x2e, 0xb8, 0x51, 0x7e, 0x0c, 0x62, 0x7e, 0xd6, 0x38, 0x38, 0x1b, 0xe6, 0xd3, 0x14,
    0x6e, 0x95, 0xc2, 0x5e, 0x75, 0xb9, 0x33, 0x07, 0x62, 0x7e, 0x09, 0x68, 0xaa, 0xbf, 0xd5, 0x45,
    0xe9, 0x4a, 0xc6, 0x8f, 0x28, 0x4d, 0x6d, 0xf8, 0xab, 0x3c, 0x4d, 0x2b, 0x1d, 0x8d, 0xb3, 0x54,
    0x05, 0xf3, 0xef, 0xf2, 0x8b, 0x13, 0x2f, 0x41, 0x83, 0x7a, 0xe8, 0xea, 0x79, 0xa6, 0x5e, 0x22,
    0x6b, 0xb8, 0x11, 0xca, 0x5e, 0x63, 0x0b, 0xc4, 0x17, 0xa6, 0xd8, 0xab, 0xe6, 0x6a, 0x76, 0x38,
    0x98, 0x19, 0x46, 0xc5, 0xa2, 0xe5, 0xc0, 0x89, 0x65, 0x9d, 0x4f, 0x2d, 0x61, 0x79, 0x05, 0xb9,
    0x40, 0x4c, 0x38, 0xed, 0x7a, 0x5e, 0x30, 0xfc, 0xa7, 0x7d, 0xcf, 0x4b, 0xd5, 0x37, 0xb1, 0xf3,
    0x11, 0x74, 0xbe, 0xef, 0x29, 0x67, 0xb3, 0xdc, 0x71, 0x5a, 0xe0, 0x37, 0x85, 0x98, 0x50, 0x32,
    0x9f, 0xf9, 0xeb, 0xd1, 0x3d, 0x44, 0xc2, 0xf6, 0x9d, 0x10, 0xb4, 0x6a, 0x1a, 0x2a, 0xe3, 0xe5,
    0x56, 0x21, 0xc3, 0xcb, 0x3b, 0x5b, 0x93, 0xaf, 0x8b, 0x5e, 0xb7, 0x82, 0x2a, 0xea, 0xc3, 0x0d,
    0xa8, 0x37, 0xf8, 0x66, 0x54, 0xf4, 0x1d, 0xa7, 0xbc, 0x83, 0x7f, 0x97, 0xb7, 0x91, 0xf8, 0x51,
    0x1e, 0x0c, 0xaf, 0xf2, 0x6c, 0x04, 0xcc, 0xdc, 0x49, 0xef, 0x6c, 0xf9, 0x14, 0xcd, 0x4e, 0x46,
    0x85, 0xf3, 0x99, 0x28, 0x0c, 0x23, 0x3a, 0x2d, 0xe6, 0xff, 0xa9, 0x94, 0xef, 0xc7, 0x40, 0x3e,
    0xd9, 0x02, 0x48, 0xf5, 0x5f, 0x8d, 0xc7, 0x26, 0xdc, 0x76, 0x8c, 0xb2, 0x77, 0xfc, 0x30, 0x4c,
    0x85, 0x2b, 0x81, 0xab, 0x03, 0x78, 0x70, 0x24, 0x18, 0xbb, 0xa6, 0x30, 0x76, 0x4d, 0x61, 0x82,
    0xf8, 0x64, 0x5e, 0x36, 0x55, 0xdf, 0xbf, 0x5a, 0x28, 0x07, 0x42
};
#endif

PyTypeObject *init_QDate(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX].type;

    Shiboken::AutoDecRef Sbk_QDate_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDate_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDate",
        "QDate",
        &Sbk_QDate_spec,
        &Shiboken::callCppDestructor< ::QDate >,
        Sbk_QDate_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDate_TypeF(); // references _Sbk_QDate_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDate_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDate_SignatureBytes, QDate_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDate_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDate_PythonToCpp_QDate_PTR,
        is_QDate_PythonToCpp_QDate_PTR_Convertible,
        QDate_PTR_CppToPython_QDate,
        QDate_COPY_CppToPython_QDate);

    Shiboken::Conversions::registerConverterName(converter, "QDate");
    Shiboken::Conversions::registerConverterName(converter, "QDate*");
    Shiboken::Conversions::registerConverterName(converter, "QDate&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDate).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDate_PythonToCpp_QDate_COPY,
        is_QDate_PythonToCpp_QDate_COPY_Convertible);
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Py_None_PythonToCpp_QDate,
        is_Py_None_PythonToCpp_QDate_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PyDate_PythonToCpp_QDate,
        is_PyDate_PythonToCpp_QDate_Convertible);




    return pyType;
}

