// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qdeadlinetimer_wrapper.h"

// Argument includes
#include <qdeadlinetimer.h>
#include <qnamespace.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDeadlineTimer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDeadlineTimer >()))
        return -1;

    ::QDeadlineTimer *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QDeadlineTimer", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDeadlineTimer::QDeadlineTimer()
    // 1: QDeadlineTimer::QDeadlineTimer(QDeadlineTimer::ForeverConstant,Qt::TimerType=)
    // 2: QDeadlineTimer::QDeadlineTimer(Qt::TimerType)
    // 3: QDeadlineTimer::QDeadlineTimer(QDeadlineTimer)
    // 4: QDeadlineTimer::QDeadlineTimer(qint64,Qt::TimerType=)
    if (numArgs == 0) {
        overloadId = 0; // QDeadlineTimer()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 4; // QDeadlineTimer(qint64,Qt::TimerType)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 4; // QDeadlineTimer(qint64,Qt::TimerType)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 2; // QDeadlineTimer(Qt::TimerType)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_ForeverConstant_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QDeadlineTimer(QDeadlineTimer::ForeverConstant,Qt::TimerType)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // QDeadlineTimer(QDeadlineTimer::ForeverConstant,Qt::TimerType)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QDeadlineTimer(QDeadlineTimer)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDeadlineTimer()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
            }

            // QDeadlineTimer()
            cptr = new ::QDeadlineTimer();
            break;
        }
        case 1: // QDeadlineTimer(QDeadlineTimer::ForeverConstant arg__1, Qt::TimerType type_)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_type_ = Shiboken::String::createStaticString("type_");
                if (PyDict_Contains(kwds, key_type_) != 0) {
                    value = PyDict_GetItem(kwds, key_type_);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_type_);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_type_);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
            }
            ::QDeadlineTimer::ForeverConstant cppArg0{QDeadlineTimer::ForeverConstant::Forever};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::TimerType cppArg1(Qt::CoarseTimer);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDeadlineTimer(QDeadlineTimer::ForeverConstant,Qt::TimerType)
                cptr = new ::QDeadlineTimer(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QDeadlineTimer(Qt::TimerType type_)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
            }
            ::Qt::TimerType cppArg0{Qt::PreciseTimer};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDeadlineTimer(Qt::TimerType)
                cptr = new ::QDeadlineTimer(cppArg0);
            }
            break;
        }
        case 3: // QDeadlineTimer(const QDeadlineTimer &QDeadlineTimer)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDeadlineTimer cppArg0_local;
            ::QDeadlineTimer *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDeadlineTimer(QDeadlineTimer)
                cptr = new ::QDeadlineTimer(*cppArg0);
            }
            break;
        }
        case 4: // QDeadlineTimer(qint64 msecs, Qt::TimerType type)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_type = Shiboken::String::createStaticString("type");
                if (PyDict_Contains(kwds, key_type) != 0) {
                    value = PyDict_GetItem(kwds, key_type);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_type);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_type);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
            }
            qint64 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::TimerType cppArg1(Qt::CoarseTimer);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDeadlineTimer(qint64,Qt::TimerType)
                cptr = new ::QDeadlineTimer(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDeadlineTimer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDeadlineTimerFunc_addNSecs(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addNSecs", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QDeadlineTimer::addNSecs(QDeadlineTimer,qint64)->QDeadlineTimer
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))) {
        overloadId = 0; // addNSecs(QDeadlineTimer,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addNSecs", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDeadlineTimer cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qint64 cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addNSecs(QDeadlineTimer,qint64)
            QDeadlineTimer cppResult = ::QDeadlineTimer::addNSecs(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDeadlineTimerFunc_current(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "current", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    if (PyArg_ParseTuple(args, "|O:current", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QDeadlineTimer::current(Qt::TimerType=)->QDeadlineTimer
    if (numArgs == 0) {
        overloadId = 0; // current(Qt::TimerType)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // current(Qt::TimerType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "current", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_timerType = Shiboken::String::createStaticString("timerType");
            if (PyDict_Contains(kwds, key_timerType) != 0) {
                value = PyDict_GetItem(kwds, key_timerType);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_timerType);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "current", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "current", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_timerType);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "current", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
            }
        }
        ::Qt::TimerType cppArg0(Qt::CoarseTimer);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // current(Qt::TimerType)
            QDeadlineTimer cppResult = ::QDeadlineTimer::current(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDeadlineTimerFunc_deadline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // deadline()const
        qint64 cppResult = const_cast<const ::QDeadlineTimer *>(cppSelf)->deadline();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDeadlineTimerFunc_deadlineNSecs(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // deadlineNSecs()const
        qint64 cppResult = const_cast<const ::QDeadlineTimer *>(cppSelf)->deadlineNSecs();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDeadlineTimerFunc_hasExpired(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasExpired()const
        bool cppResult = const_cast<const ::QDeadlineTimer *>(cppSelf)->hasExpired();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDeadlineTimerFunc_isForever(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isForever()const
        bool cppResult = const_cast<const ::QDeadlineTimer *>(cppSelf)->isForever();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDeadlineTimerFunc_remainingTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // remainingTime()const
        qint64 cppResult = const_cast<const ::QDeadlineTimer *>(cppSelf)->remainingTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDeadlineTimerFunc_remainingTimeNSecs(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // remainingTimeNSecs()const
        qint64 cppResult = const_cast<const ::QDeadlineTimer *>(cppSelf)->remainingTimeNSecs();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDeadlineTimerFunc_setDeadline(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setDeadline", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setDeadline", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDeadlineTimer::setDeadline(qint64,Qt::TimerType=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setDeadline(qint64,Qt::TimerType)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setDeadline(qint64,Qt::TimerType)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDeadline", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_timerType = Shiboken::String::createStaticString("timerType");
            if (PyDict_Contains(kwds, key_timerType) != 0) {
                value = PyDict_GetItem(kwds, key_timerType);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_timerType);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setDeadline", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setDeadline", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_timerType);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setDeadline", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
            }
        }
        qint64 cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::TimerType cppArg1(Qt::CoarseTimer);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDeadline(qint64,Qt::TimerType)
            cppSelf->setDeadline(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDeadlineTimerFunc_setPreciseDeadline(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setPreciseDeadline", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setPreciseDeadline", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDeadlineTimer::setPreciseDeadline(qint64,qint64=,Qt::TimerType=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setPreciseDeadline(qint64,qint64,Qt::TimerType)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setPreciseDeadline(qint64,qint64,Qt::TimerType)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 0; // setPreciseDeadline(qint64,qint64,Qt::TimerType)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPreciseDeadline", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_nsecs = Shiboken::String::createStaticString("nsecs");
            if (PyDict_Contains(kwds, key_nsecs) != 0) {
                value = PyDict_GetItem(kwds, key_nsecs);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_nsecs);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setPreciseDeadline", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setPreciseDeadline", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_nsecs);
            }
            static PyObject *const key_type = Shiboken::String::createStaticString("type");
            if (PyDict_Contains(kwds, key_type) != 0) {
                value = PyDict_GetItem(kwds, key_type);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_type);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setPreciseDeadline", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "setPreciseDeadline", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_type);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setPreciseDeadline", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
            }
        }
        qint64 cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qint64 cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::Qt::TimerType cppArg2(Qt::CoarseTimer);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPreciseDeadline(qint64,qint64,Qt::TimerType)
            cppSelf->setPreciseDeadline(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDeadlineTimerFunc_setPreciseRemainingTime(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setPreciseRemainingTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setPreciseRemainingTime", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDeadlineTimer::setPreciseRemainingTime(qint64,qint64=,Qt::TimerType=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setPreciseRemainingTime(qint64,qint64,Qt::TimerType)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setPreciseRemainingTime(qint64,qint64,Qt::TimerType)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 0; // setPreciseRemainingTime(qint64,qint64,Qt::TimerType)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPreciseRemainingTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_nsecs = Shiboken::String::createStaticString("nsecs");
            if (PyDict_Contains(kwds, key_nsecs) != 0) {
                value = PyDict_GetItem(kwds, key_nsecs);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_nsecs);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setPreciseRemainingTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setPreciseRemainingTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_nsecs);
            }
            static PyObject *const key_type = Shiboken::String::createStaticString("type");
            if (PyDict_Contains(kwds, key_type) != 0) {
                value = PyDict_GetItem(kwds, key_type);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_type);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setPreciseRemainingTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "setPreciseRemainingTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_type);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setPreciseRemainingTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
            }
        }
        qint64 cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qint64 cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::Qt::TimerType cppArg2(Qt::CoarseTimer);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPreciseRemainingTime(qint64,qint64,Qt::TimerType)
            cppSelf->setPreciseRemainingTime(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDeadlineTimerFunc_setRemainingTime(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setRemainingTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setRemainingTime", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDeadlineTimer::setRemainingTime(qint64,Qt::TimerType=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setRemainingTime(qint64,Qt::TimerType)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setRemainingTime(qint64,Qt::TimerType)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRemainingTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_type = Shiboken::String::createStaticString("type");
            if (PyDict_Contains(kwds, key_type) != 0) {
                value = PyDict_GetItem(kwds, key_type);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_type);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setRemainingTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setRemainingTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_type);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setRemainingTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);
            }
        }
        qint64 cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::TimerType cppArg1(Qt::CoarseTimer);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRemainingTime(qint64,Qt::TimerType)
            cppSelf->setRemainingTime(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDeadlineTimerFunc_setTimerType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDeadlineTimer::setTimerType(Qt::TimerType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTimerType(Qt::TimerType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTimerType", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    // Call function/method
    {
        ::Qt::TimerType cppArg0{Qt::PreciseTimer};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTimerType(Qt::TimerType)
            cppSelf->setTimerType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDeadlineTimerFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDeadlineTimer::swap(QDeadlineTimer&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QDeadlineTimer&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDeadlineTimer cppArg0_local;
        ::QDeadlineTimer *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QDeadlineTimer&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDeadlineTimerFunc_timerType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // timerType()const
        Qt::TimerType cppResult = const_cast<const ::QDeadlineTimer *>(cppSelf)->timerType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDeadlineTimer__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDeadlineTimer_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDeadlineTimer_EnumFlagInfo[] = {
    "ForeverConstant:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDeadlineTimer_methods[] = {
    {"addNSecs", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimerFunc_addNSecs), METH_VARARGS|METH_STATIC, nullptr},
    {"current", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimerFunc_current), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"deadline", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimerFunc_deadline), METH_NOARGS, nullptr},
    {"deadlineNSecs", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimerFunc_deadlineNSecs), METH_NOARGS, nullptr},
    {"hasExpired", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimerFunc_hasExpired), METH_NOARGS, nullptr},
    {"isForever", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimerFunc_isForever), METH_NOARGS, nullptr},
    {"remainingTime", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimerFunc_remainingTime), METH_NOARGS, nullptr},
    {"remainingTimeNSecs", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimerFunc_remainingTimeNSecs), METH_NOARGS, nullptr},
    {"setDeadline", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimerFunc_setDeadline), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setPreciseDeadline", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimerFunc_setPreciseDeadline), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setPreciseRemainingTime", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimerFunc_setPreciseRemainingTime), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setRemainingTime", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimerFunc_setRemainingTime), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setTimerType", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimerFunc_setTimerType), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimerFunc_swap), METH_O, nullptr},
    {"timerType", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimerFunc_timerType), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDeadlineTimer__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QDeadlineTimerFunc___add__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDeadlineTimer::operator+(qint64)->QDeadlineTimer
    if (isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // operator+(qint64,QDeadlineTimer)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+(qint64,QDeadlineTimer) [reverse operator]
            QDeadlineTimer cppResult = cppArg0 + (*cppSelf);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDeadlineTimerFunc___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDeadlineTimer::operator+=(qint64)->QDeadlineTimer&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // operator+=(qint64)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+=", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+=(qint64)
            (*cppSelf) += cppArg0;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QDeadlineTimerFunc___sub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDeadlineTimer::operator-(QDeadlineTimer)->qint64
    // 1: QDeadlineTimer::operator-(qint64)->QDeadlineTimer
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 1; // operator-(QDeadlineTimer,qint64)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArg)))) {
        overloadId = 0; // operator-(QDeadlineTimer,QDeadlineTimer)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // operator-(QDeadlineTimer dt2)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDeadlineTimer cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator-(QDeadlineTimer,QDeadlineTimer)
                qint64 cppResult = (*cppSelf) - cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
            }
            break;
        }
        case 1: // operator-(qint64 msecs)
        {
            qint64 cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator-(QDeadlineTimer,qint64)
                QDeadlineTimer cppResult = (*cppSelf) - cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDeadlineTimerFunc___isub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDeadlineTimer::operator-=(qint64)->QDeadlineTimer&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // operator-=(qint64)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-=", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator-=(qint64)
            (*cppSelf) -= cppArg0;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

// Rich comparison
static PyObject * Sbk_QDeadlineTimer_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArg)))) {
                // operator!=(const QDeadlineTimer &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDeadlineTimer cppArg0_local;
                ::QDeadlineTimer *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArg)))) {
                // operator<(const QDeadlineTimer &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDeadlineTimer cppArg0_local;
                ::QDeadlineTimer *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArg)))) {
                // operator<=(const QDeadlineTimer &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDeadlineTimer cppArg0_local;
                ::QDeadlineTimer *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArg)))) {
                // operator==(const QDeadlineTimer &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDeadlineTimer cppArg0_local;
                ::QDeadlineTimer *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArg)))) {
                // operator>(const QDeadlineTimer &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDeadlineTimer cppArg0_local;
                ::QDeadlineTimer *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArg)))) {
                // operator>=(const QDeadlineTimer &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDeadlineTimer cppArg0_local;
                ::QDeadlineTimer *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QDeadlineTimer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDeadlineTimer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDeadlineTimer_Type = nullptr;
static PyTypeObject *Sbk_QDeadlineTimer_TypeF(void)
{
    return _Sbk_QDeadlineTimer_Type;
}

static PyType_Slot Sbk_QDeadlineTimer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDeadlineTimer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDeadlineTimer_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QDeadlineTimer_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDeadlineTimer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDeadlineTimer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QDeadlineTimerFunc___iadd__)},
    {Py_nb_subtract,    reinterpret_cast<void *>(Sbk_QDeadlineTimerFunc___sub__)},
    {Py_nb_inplace_subtract,reinterpret_cast<void *>(Sbk_QDeadlineTimerFunc___isub__)},
    {Py_nb_add,         reinterpret_cast<void *>(Sbk_QDeadlineTimerFunc___add__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDeadlineTimer_spec = {
    "2:PySide6.QtCore.QDeadlineTimer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDeadlineTimer_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDeadlineTimer_ForeverConstant(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDeadlineTimer::ForeverConstant>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDeadlineTimer::ForeverConstant *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDeadlineTimer_ForeverConstant_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_ForeverConstant_IDX])))
        return Enum_PythonToCpp_QDeadlineTimer_ForeverConstant;
    return {};
}

static PyObject *QDeadlineTimer_ForeverConstant_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDeadlineTimer::ForeverConstant>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDeadlineTimer::ForeverConstant *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_ForeverConstant_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDeadlineTimer_PythonToCpp_QDeadlineTimer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDeadlineTimer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDeadlineTimer_PythonToCpp_QDeadlineTimer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDeadlineTimer_TypeF()))
        return QDeadlineTimer_PythonToCpp_QDeadlineTimer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDeadlineTimer_PTR_CppToPython_QDeadlineTimer(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDeadlineTimer_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDeadlineTimer_COPY_CppToPython_QDeadlineTimer(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDeadlineTimer *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDeadlineTimer_TypeF(), new ::QDeadlineTimer(*source), true, true);
}

// Python to C++ copy conversion.
static void QDeadlineTimer_PythonToCpp_QDeadlineTimer_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDeadlineTimer *>(cppOut) = *reinterpret_cast< ::QDeadlineTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDeadlineTimer_PythonToCpp_QDeadlineTimer_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDeadlineTimer_TypeF()))
        return QDeadlineTimer_PythonToCpp_QDeadlineTimer_COPY;
    return {};
}

// Implicit conversions.
static void QDeadlineTimer_ForeverConstant_PythonToCpp_QDeadlineTimer(PyObject *pyIn, void *cppOut)
{
    ::QDeadlineTimer::ForeverConstant cppIn{QDeadlineTimer::ForeverConstant::Forever};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_ForeverConstant_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QDeadlineTimer *>(cppOut) = ::QDeadlineTimer(cppIn);
}
static PythonToCppFunc is_QDeadlineTimer_ForeverConstant_PythonToCpp_QDeadlineTimer_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_ForeverConstant_IDX]), pyIn))
        return QDeadlineTimer_ForeverConstant_PythonToCpp_QDeadlineTimer;
    return {};
}

static void qint64_PythonToCpp_QDeadlineTimer(PyObject *pyIn, void *cppOut)
{
    qint64 cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyIn, &cppIn);
    *reinterpret_cast<::QDeadlineTimer *>(cppOut) = ::QDeadlineTimer(cppIn);
}
static PythonToCppFunc is_qint64_PythonToCpp_QDeadlineTimer_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return qint64_PythonToCpp_QDeadlineTimer;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDeadlineTimer_SignatureStrings[] = {
    "4:PySide6.QtCore.QDeadlineTimer(self)",
    "3:PySide6.QtCore.QDeadlineTimer(self,arg__1:PySide6.QtCore.QDeadlineTimer.ForeverConstant,type_:PySide6.QtCore.Qt.TimerType=Qt.CoarseTimer)",
    "2:PySide6.QtCore.QDeadlineTimer(self,type_:PySide6.QtCore.Qt.TimerType)",
    "1:PySide6.QtCore.QDeadlineTimer(self,QDeadlineTimer:PySide6.QtCore.QDeadlineTimer)",
    "0:PySide6.QtCore.QDeadlineTimer(self,msecs:qint64,type:PySide6.QtCore.Qt.TimerType=Qt.CoarseTimer)",
    "PySide6.QtCore.QDeadlineTimer.addNSecs(dt:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64],nsecs:qint64)->PySide6.QtCore.QDeadlineTimer",
    "PySide6.QtCore.QDeadlineTimer.current(timerType:PySide6.QtCore.Qt.TimerType=Qt.CoarseTimer)->PySide6.QtCore.QDeadlineTimer",
    "PySide6.QtCore.QDeadlineTimer.deadline(self)->qint64",
    "PySide6.QtCore.QDeadlineTimer.deadlineNSecs(self)->qint64",
    "PySide6.QtCore.QDeadlineTimer.hasExpired(self)->bool",
    "PySide6.QtCore.QDeadlineTimer.isForever(self)->bool",
    "PySide6.QtCore.QDeadlineTimer.remainingTime(self)->qint64",
    "PySide6.QtCore.QDeadlineTimer.remainingTimeNSecs(self)->qint64",
    "PySide6.QtCore.QDeadlineTimer.setDeadline(self,msecs:qint64,timerType:PySide6.QtCore.Qt.TimerType=Qt.CoarseTimer)",
    "PySide6.QtCore.QDeadlineTimer.setPreciseDeadline(self,secs:qint64,nsecs:qint64=0,type:PySide6.QtCore.Qt.TimerType=Qt.CoarseTimer)",
    "PySide6.QtCore.QDeadlineTimer.setPreciseRemainingTime(self,secs:qint64,nsecs:qint64=0,type:PySide6.QtCore.Qt.TimerType=Qt.CoarseTimer)",
    "PySide6.QtCore.QDeadlineTimer.setRemainingTime(self,msecs:qint64,type:PySide6.QtCore.Qt.TimerType=Qt.CoarseTimer)",
    "PySide6.QtCore.QDeadlineTimer.setTimerType(self,type:PySide6.QtCore.Qt.TimerType)",
    "PySide6.QtCore.QDeadlineTimer.swap(self,other:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64])",
    "PySide6.QtCore.QDeadlineTimer.timerType(self)->PySide6.QtCore.Qt.TimerType",
    "PySide6.QtCore.QDeadlineTimer.__copy__(self)->typing.Self",
    "PySide6.QtCore.QDeadlineTimer.__add__(self,msecs:qint64)->PySide6.QtCore.QDeadlineTimer",
    "PySide6.QtCore.QDeadlineTimer.__iadd__(self,msecs:qint64)->PySide6.QtCore.QDeadlineTimer",
    "1:PySide6.QtCore.QDeadlineTimer.__sub__(self,dt2:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64])->qint64",
    "0:PySide6.QtCore.QDeadlineTimer.__sub__(self,msecs:qint64)->PySide6.QtCore.QDeadlineTimer",
    "PySide6.QtCore.QDeadlineTimer.__isub__(self,msecs:qint64)->PySide6.QtCore.QDeadlineTimer",
    "PySide6.QtCore.QDeadlineTimer.__ne__(self,rhs:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64])->bool",
    "PySide6.QtCore.QDeadlineTimer.__lt__(self,rhs:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64])->bool",
    "PySide6.QtCore.QDeadlineTimer.__le__(self,rhs:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64])->bool",
    "PySide6.QtCore.QDeadlineTimer.__eq__(self,rhs:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64])->bool",
    "PySide6.QtCore.QDeadlineTimer.__gt__(self,rhs:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64])->bool",
    "PySide6.QtCore.QDeadlineTimer.__ge__(self,rhs:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QDeadlineTimer_SignatureByteSize = 412;
static constexpr uint8_t QDeadlineTimer_SignatureBytes[412] = {
    0x78, 0xda, 0xcd, 0x55, 0xcb, 0x6e, 0xc2, 0x30, 0x10, 0xbc, 0xe7, 0x2b, 0x38, 0x12, 0x29, 0x44,
    0x40, 0x11, 0x07, 0x24, 0xb8, 0x40, 0x7b, 0xac, 0xa0, 0xd0, 0x53, 0x55, 0x59, 0x26, 0xde, 0x06,
    0x4b, 0xc1, 0x0e, 0xb6, 0x69, 0xcb, 0xdf, 0xd7, 0x25, 0x04, 0x92, 0x82, 0xe2, 0x98, 0x57, 0x73,
    0x5c, 0xc7, 0x33, 0x3b, 0xfb, 0xc8, 0xb8, 0xd3, 0x1b, 0x6f, 0xa6, 0x94, 0x40, 0xd7, 0x9f, 0xa8,
    0x21, 0x17, 0xe0, 0x4f, 0x46, 0x80, 0x49, 0x44, 0x19, 0xcc, 0xe8, 0x12, 0x44, 0x5d, 0x42, 0xf4,
    0xe1, 0x3a, 0x0f, 0x25, 0x6e, 0x79, 0x58, 0x84, 0x08, 0xb5, 0x8a, 0x6f, 0xfa, 0x4f, 0xfa, 0xec,
    0x13, 0xc4, 0x90, 0x33, 0xa9, 0x30, 0x53, 0x9e, 0xda, 0xc4, 0x80, 0x8e, 0x30, 0xca, 0xdf, 0xde,
    0x9e, 0xe9, 0x8f, 0x7d, 0x1d, 0x0c, 0x39, 0x16, 0x32, 0x21, 0x70, 0x9d, 0x76, 0x19, 0x2d, 0x46,
    0x5a, 0xd7, 0x69, 0x95, 0xe1, 0xc9, 0x9f, 0x15, 0x23, 0x5c, 0xa7, 0x59, 0x86, 0x72, 0x29, 0x21,
    0x90, 0xbd, 0x15, 0x65, 0xaa, 0xdb, 0xd9, 0xea, 0xb4, 0xaa, 0xbe, 0xb8, 0xbb, 0x98, 0x90, 0xe7,
    0xa9, 0xa6, 0xaf, 0x13, 0xd5, 0xd3, 0xd4, 0x94, 0x85, 0xfe, 0x2b, 0xa3, 0x9c, 0xbd, 0x15, 0xc2,
    0xbc, 0x9a, 0xdd, 0xcc, 0x6a, 0x89, 0xf8, 0x77, 0x8f, 0x65, 0x4a, 0x71, 0x1b, 0x83, 0x42, 0x16,
    0x83, 0xf2, 0x60, 0x2d, 0x04, 0x30, 0x55, 0x57, 0x69, 0xe5, 0x36, 0x5d, 0xb9, 0x2c, 0x35, 0xd9,
    0x45, 0xc9, 0xae, 0x37, 0x06, 0x49, 0x3d, 0x25, 0x41, 0x49, 0xbb, 0x6d, 0x90, 0x0b, 0x2c, 0x1f,
    0xbf, 0x63, 0x2a, 0x80, 0xa4, 0xb0, 0x39, 0xe7, 0x91, 0x01, 0x44, 0xe5, 0x6e, 0x08, 0x16, 0x18,
    0x01, 0x4b, 0x4c, 0x99, 0xde, 0x81, 0xdf, 0xd0, 0x4a, 0x62, 0x0e, 0x69, 0x5f, 0xa1, 0x04, 0x35,
    0xca, 0xf6, 0xf4, 0xcf, 0xca, 0x9f, 0x33, 0x61, 0x73, 0xc6, 0xb1, 0x80, 0x80, 0x4a, 0xc8, 0x27,
    0xce, 0xe6, 0xcd, 0x2e, 0x6b, 0xbf, 0x79, 0xed, 0x3f, 0xef, 0xa0, 0xe0, 0xe5, 0xa8, 0xed, 0xf7,
    0x95, 0x71, 0x22, 0xff, 0x2d, 0x2d, 0x47, 0x67, 0xdc, 0x43, 0x0f, 0xde, 0x5b, 0x6c, 0xbd, 0x06,
    0xc6, 0x2f, 0x1c, 0x27, 0x4c, 0x5c, 0x2d, 0xb4, 0xe9, 0xde, 0xde, 0xc8, 0x4c, 0x8a, 0x54, 0xae,
    0xc0, 0x13, 0x76, 0x93, 0xa9, 0xce, 0x40, 0x85, 0x50, 0xc0, 0xe3, 0x0d, 0x42, 0x29, 0xd3, 0xae,
    0xb8, 0xa9, 0x8e, 0x8c, 0x48, 0xed, 0xee, 0x3b, 0x60, 0x6e, 0xa2, 0x17, 0xda, 0x1f, 0x42, 0xf4,
    0x5c, 0x62, 0xd3, 0x63, 0x8f, 0x90, 0x5c, 0xcf, 0x53, 0x66, 0xa2, 0xda, 0xf7, 0x18, 0xe5, 0xde,
    0xa3, 0x9a, 0x36, 0xe2, 0xae, 0xdb, 0xcf, 0x5b, 0x11, 0x33, 0x48, 0x69, 0xc5, 0x42, 0xde, 0xa7,
    0x99, 0x25, 0xde, 0x19, 0x84, 0x22, 0x55, 0x51, 0x5d, 0x15, 0xed, 0x17, 0xac, 0xaa, 0xa9, 0x2b,
    0xac, 0xe8, 0x1c, 0xc3, 0x7f, 0x9a, 0xe3, 0x0f, 0x8c, 0x4a, 0xb1, 0xef
};
#endif

PyTypeObject *init_QDeadlineTimer(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX].type;

    Shiboken::AutoDecRef Sbk_QDeadlineTimer_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDeadlineTimer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDeadlineTimer",
        "QDeadlineTimer",
        &Sbk_QDeadlineTimer_spec,
        &Shiboken::callCppDestructor< ::QDeadlineTimer >,
        Sbk_QDeadlineTimer_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDeadlineTimer_TypeF(); // references _Sbk_QDeadlineTimer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDeadlineTimer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDeadlineTimer_SignatureBytes, QDeadlineTimer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDeadlineTimer_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDeadlineTimer_PythonToCpp_QDeadlineTimer_PTR,
        is_QDeadlineTimer_PythonToCpp_QDeadlineTimer_PTR_Convertible,
        QDeadlineTimer_PTR_CppToPython_QDeadlineTimer,
        QDeadlineTimer_COPY_CppToPython_QDeadlineTimer);

    Shiboken::Conversions::registerConverterName(converter, "QDeadlineTimer");
    Shiboken::Conversions::registerConverterName(converter, "QDeadlineTimer*");
    Shiboken::Conversions::registerConverterName(converter, "QDeadlineTimer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDeadlineTimer).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDeadlineTimer_PythonToCpp_QDeadlineTimer_COPY,
        is_QDeadlineTimer_PythonToCpp_QDeadlineTimer_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDeadlineTimer_ForeverConstant_PythonToCpp_QDeadlineTimer,
        is_QDeadlineTimer_ForeverConstant_PythonToCpp_QDeadlineTimer_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        qint64_PythonToCpp_QDeadlineTimer,
        is_qint64_PythonToCpp_QDeadlineTimer_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDeadlineTimer_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ForeverConstant'.
    const char *ForeverConstant_Initializer[] = {
        "Forever",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t ForeverConstant_InitializerValues[] = {
        int8_t(QDeadlineTimer::ForeverConstant::Forever) //  0x00  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDeadlineTimer_TypeF(),
        "2:PySide6.QtCore.QDeadlineTimer.ForeverConstant",
        ForeverConstant_Initializer, ForeverConstant_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_ForeverConstant_IDX].type = EType;
    // Register converter for enum 'QDeadlineTimer::ForeverConstant'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDeadlineTimer_ForeverConstant_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDeadlineTimer_ForeverConstant,
            is_Enum_PythonToCpp_QDeadlineTimer_ForeverConstant_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDeadlineTimer::ForeverConstant");
        Shiboken::Conversions::registerConverterAlias(converter, "ForeverConstant");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ForeverConstant' enum.

    qRegisterMetaType< ::QDeadlineTimer >("QDeadlineTimer");
    qRegisterMetaType< ::QDeadlineTimer::ForeverConstant >("QDeadlineTimer::ForeverConstant");

    return pyType;
}

PyTypeObject *init_QDeadlineTimerStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QDeadlineTimer");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "Forever",
                         Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_ForeverConstant_IDX])))->converter, &QDeadlineTimer::Forever));
    return type;
}
