// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qdir_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <qchar.h>
#include <qdir.h>
#include <qfileinfo.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDir_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDir >()))
        return -1;

    ::QDir *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:QDir", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDir::QDir(QDir)
    // 1: QDir::QDir(PyPathLike=)
    // 2: QDir::QDir(PyPathLike,QString,QFlags<QDir::SortFlag>=,QFlags<QDir::Filter>=)
    if (numArgs == 0) {
        overloadId = 1; // QDir(QString)
    } else if (numArgs >= 1
        && Shiboken::String::checkPath(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QDir(QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // QDir(QString,QString,QFlags<QDir::SortFlag>,QFlags<QDir::Filter>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_SortFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 2; // QDir(QString,QString,QFlags<QDir::SortFlag>,QFlags<QDir::Filter>)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArgs[3])))) {
                    overloadId = 2; // QDir(QString,QString,QFlags<QDir::SortFlag>,QFlags<QDir::Filter>)
                }
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QDir(QDir)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDir(const QDir &arg__1)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDir cppArg0_local;
            ::QDir *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDir(QDir)
                cptr = new ::QDir(*cppArg0);
            }
            break;
        }
        case 1: // QDir(const QString &path)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_path = Shiboken::String::createStaticString("path");
                if (PyDict_Contains(kwds, key_path) != 0) {
                    value = PyDict_GetItem(kwds, key_path);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_path);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!Shiboken::String::checkPath(pyArgs[0]))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_path);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                }
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDir(QString)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                auto cppArg0 = PySide::pyPathToQString(pyArgs[1-1]);
                // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                // ========================================================================
                // End of code injection

                cptr = new ::QDir(cppArg0);
            }
            break;
        }
        case 2: // QDir(const QString &path, const QString &nameFilter, QFlags<QDir::SortFlag> sort, QFlags<QDir::Filter> filter)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sort = Shiboken::String::createStaticString("sort");
                if (PyDict_Contains(kwds, key_sort) != 0) {
                    value = PyDict_GetItem(kwds, key_sort);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_sort);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_SortFlag_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sort);
                }
                static PyObject *const key_filter = Shiboken::String::createStaticString("filter");
                if (PyDict_Contains(kwds, key_filter) != 0) {
                    value = PyDict_GetItem(kwds, key_filter);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_filter);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_filter);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                }
            }
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QDir::SortFlag> cppArg2 = QDir::SortFlags(QDir::SortFlag::Name | QDir::SortFlag::IgnoreCase);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<QDir::Filter> cppArg3(QDir::Filter::AllEntries);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDir(QString,QString,QFlags<QDir::SortFlag>,QFlags<QDir::Filter>)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                auto cppArg0 = PySide::pyPathToQString(pyArgs[1-1]);
                // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                // ========================================================================
                // End of code injection

                cptr = new ::QDir(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDir >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDirFunc___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __reduce__()
        // Begin code injection
        // TEMPLATE - reduce_code - START
        pyResult = Py_BuildValue("(N(s))", PyObject_Type(self), qPrintable(cppSelf->path()));
        // TEMPLATE - reduce_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_absoluteFilePath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDir::absoluteFilePath(QString)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // absoluteFilePath(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "absoluteFilePath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // absoluteFilePath(QString)const
            QString cppResult = const_cast<const ::QDir *>(cppSelf)->absoluteFilePath(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_absolutePath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // absolutePath()const
        QString cppResult = const_cast<const ::QDir *>(cppSelf)->absolutePath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_addSearchPath(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addSearchPath", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QDir::addSearchPath(QString,PyPathLike)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && Shiboken::String::checkPath(pyArgs[1])) {
        overloadId = 0; // addSearchPath(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addSearchPath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addSearchPath(QString,QString)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-2)]
            auto cppArg1 = PySide::pyPathToQString(pyArgs[2-1]);
            // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-2)]
            // ========================================================================
            // End of code injection

            ::QDir::addSearchPath(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDirFunc_canonicalPath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // canonicalPath()const
        QString cppResult = const_cast<const ::QDir *>(cppSelf)->canonicalPath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_cd(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDir::cd(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // cd(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "cd", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // cd(QString)
            bool cppResult = cppSelf->cd(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_cdUp(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cdUp()
        bool cppResult = cppSelf->cdUp();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_cleanPath(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDir::cleanPath(QString)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // cleanPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "cleanPath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // cleanPath(QString)
            QString cppResult = ::QDir::cleanPath(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        qsizetype cppResult = const_cast<const ::QDir *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_current(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // current()
        QDir cppResult = ::QDir::current();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_currentPath(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentPath()
        QString cppResult = ::QDir::currentPath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_dirName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dirName()const
        QString cppResult = const_cast<const ::QDir *>(cppSelf)->dirName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_drives(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // drives()
        QList<QFileInfo> cppResult = ::QDir::drives();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QFileInfo_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_entryInfoList(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "entryInfoList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:entryInfoList", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDir::entryInfoList(QFlags<QDir::Filter>=,QFlags<QDir::SortFlag>=)const->QList<QFileInfo>
    // 1: QDir::entryInfoList(QStringList,QFlags<QDir::Filter>=,QFlags<QDir::SortFlag>=)const->QList<QFileInfo>
    if (numArgs == 0) {
        overloadId = 0; // entryInfoList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // entryInfoList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // entryInfoList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_SortFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 1; // entryInfoList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // entryInfoList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_SortFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // entryInfoList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "entryInfoList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // entryInfoList(QFlags<QDir::Filter> filters, QFlags<QDir::SortFlag> sort) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_filters = Shiboken::String::createStaticString("filters");
                if (PyDict_Contains(kwds, key_filters) != 0) {
                    value = PyDict_GetItem(kwds, key_filters);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_filters);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "entryInfoList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "entryInfoList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_filters);
                }
                static PyObject *const key_sort = Shiboken::String::createStaticString("sort");
                if (PyDict_Contains(kwds, key_sort) != 0) {
                    value = PyDict_GetItem(kwds, key_sort);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_sort);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "entryInfoList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_SortFlag_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "entryInfoList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sort);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "entryInfoList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                }
            }
            ::QFlags<QDir::Filter> cppArg0(QDir::Filter::NoFilter);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QDir::SortFlag> cppArg1(QDir::SortFlag::NoSort);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // entryInfoList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
                QList<QFileInfo> cppResult = const_cast<const ::QDir *>(cppSelf)->entryInfoList(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QFileInfo_IDX], &cppResult);
            }
            break;
        }
        case 1: // entryInfoList(const QStringList &nameFilters, QFlags<QDir::Filter> filters, QFlags<QDir::SortFlag> sort) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_filters = Shiboken::String::createStaticString("filters");
                if (PyDict_Contains(kwds, key_filters) != 0) {
                    value = PyDict_GetItem(kwds, key_filters);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_filters);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "entryInfoList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "entryInfoList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_filters);
                }
                static PyObject *const key_sort = Shiboken::String::createStaticString("sort");
                if (PyDict_Contains(kwds, key_sort) != 0) {
                    value = PyDict_GetItem(kwds, key_sort);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_sort);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "entryInfoList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_SortFlag_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "entryInfoList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sort);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "entryInfoList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                }
            }
            ::QStringList cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QDir::Filter> cppArg1(QDir::Filter::NoFilter);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QDir::SortFlag> cppArg2(QDir::SortFlag::NoSort);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // entryInfoList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
                QList<QFileInfo> cppResult = const_cast<const ::QDir *>(cppSelf)->entryInfoList(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QFileInfo_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_entryList(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "entryList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:entryList", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDir::entryList(QFlags<QDir::Filter>=,QFlags<QDir::SortFlag>=)const->QStringList
    // 1: QDir::entryList(QStringList,QFlags<QDir::Filter>=,QFlags<QDir::SortFlag>=)const->QStringList
    if (numArgs == 0) {
        overloadId = 0; // entryList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // entryList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // entryList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_SortFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 1; // entryList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // entryList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_SortFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // entryList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "entryList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // entryList(QFlags<QDir::Filter> filters, QFlags<QDir::SortFlag> sort) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_filters = Shiboken::String::createStaticString("filters");
                if (PyDict_Contains(kwds, key_filters) != 0) {
                    value = PyDict_GetItem(kwds, key_filters);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_filters);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "entryList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "entryList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_filters);
                }
                static PyObject *const key_sort = Shiboken::String::createStaticString("sort");
                if (PyDict_Contains(kwds, key_sort) != 0) {
                    value = PyDict_GetItem(kwds, key_sort);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_sort);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "entryList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_SortFlag_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "entryList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sort);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "entryList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                }
            }
            ::QFlags<QDir::Filter> cppArg0(QDir::Filter::NoFilter);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QDir::SortFlag> cppArg1(QDir::SortFlag::NoSort);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // entryList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
                QStringList cppResult = const_cast<const ::QDir *>(cppSelf)->entryList(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
            }
            break;
        }
        case 1: // entryList(const QStringList &nameFilters, QFlags<QDir::Filter> filters, QFlags<QDir::SortFlag> sort) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_filters = Shiboken::String::createStaticString("filters");
                if (PyDict_Contains(kwds, key_filters) != 0) {
                    value = PyDict_GetItem(kwds, key_filters);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_filters);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "entryList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "entryList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_filters);
                }
                static PyObject *const key_sort = Shiboken::String::createStaticString("sort");
                if (PyDict_Contains(kwds, key_sort) != 0) {
                    value = PyDict_GetItem(kwds, key_sort);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_sort);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "entryList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_SortFlag_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "entryList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sort);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "entryList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                }
            }
            ::QStringList cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QDir::Filter> cppArg1(QDir::Filter::NoFilter);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QDir::SortFlag> cppArg2(QDir::SortFlag::NoSort);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // entryList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
                QStringList cppResult = const_cast<const ::QDir *>(cppSelf)->entryList(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_exists(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "exists", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDir::exists()const->bool
    // 1: QDir::exists(QString)const->bool
    if (numArgs == 0) {
        overloadId = 0; // exists()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // exists(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "exists", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // exists() const
        {

            // exists()const
            bool cppResult = const_cast<const ::QDir *>(cppSelf)->exists();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            break;
        }
        case 1: // exists(const QString &name) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // exists(QString)const
                bool cppResult = const_cast<const ::QDir *>(cppSelf)->exists(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_filePath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDir::filePath(QString)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // filePath(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "filePath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // filePath(QString)const
            QString cppResult = const_cast<const ::QDir *>(cppSelf)->filePath(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_filter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // filter()const
        QFlags<QDir::Filter> cppResult = const_cast<const ::QDir *>(cppSelf)->filter();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_fromNativeSeparators(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDir::fromNativeSeparators(QString)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // fromNativeSeparators(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromNativeSeparators", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromNativeSeparators(QString)
            QString cppResult = ::QDir::fromNativeSeparators(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_home(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // home()
        QDir cppResult = ::QDir::home();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_homePath(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // homePath()
        QString cppResult = ::QDir::homePath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_isAbsolute(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAbsolute()const
        bool cppResult = const_cast<const ::QDir *>(cppSelf)->isAbsolute();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_isAbsolutePath(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDir::isAbsolutePath(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // isAbsolutePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isAbsolutePath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isAbsolutePath(QString)
            bool cppResult = ::QDir::isAbsolutePath(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_isEmpty(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "isEmpty", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    if (PyArg_ParseTuple(args, "|O:isEmpty", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDir::isEmpty(QFlags<QDir::Filter>=)const->bool
    if (numArgs == 0) {
        overloadId = 0; // isEmpty(QFlags<QDir::Filter>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // isEmpty(QFlags<QDir::Filter>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isEmpty", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_filters = Shiboken::String::createStaticString("filters");
            if (PyDict_Contains(kwds, key_filters) != 0) {
                value = PyDict_GetItem(kwds, key_filters);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_filters);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "isEmpty", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "isEmpty", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_filters);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "isEmpty", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);
            }
        }
        ::QFlags<QDir::Filter> cppArg0 = QDir::Filters(QDir::Filter::AllEntries | QDir::Filter::NoDotAndDotDot);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isEmpty(QFlags<QDir::Filter>)const
            bool cppResult = const_cast<const ::QDir *>(cppSelf)->isEmpty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_isReadable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isReadable()const
        bool cppResult = const_cast<const ::QDir *>(cppSelf)->isReadable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_isRelative(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRelative()const
        bool cppResult = const_cast<const ::QDir *>(cppSelf)->isRelative();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_isRelativePath(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDir::isRelativePath(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // isRelativePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isRelativePath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isRelativePath(QString)
            bool cppResult = ::QDir::isRelativePath(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_isRoot(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRoot()const
        bool cppResult = const_cast<const ::QDir *>(cppSelf)->isRoot();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_listSeparator(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // listSeparator()
        QChar cppResult = ::QDir::listSeparator();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_makeAbsolute(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // makeAbsolute()
        bool cppResult = cppSelf->makeAbsolute();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_match(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "match", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QDir::match(QString,QString)->bool
    // 1: static QDir::match(QStringList,QString)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 1; // match(QStringList,QString)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // match(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "match", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // match(const QString &filter, const QString &fileName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // match(QString,QString)
                bool cppResult = ::QDir::match(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // match(const QStringList &filters, const QString &fileName)
        {
            ::QStringList cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // match(QStringList,QString)
                bool cppResult = ::QDir::match(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_mkdir(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "mkdir", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDir::mkdir(QString)const->bool
    // 1: QDir::mkdir(QString,QFlags<QFileDevice::Permission>)const->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // mkdir(QString)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_Permission_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 1; // mkdir(QString,QFlags<QFileDevice::Permission>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mkdir", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // mkdir(const QString &dirName) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mkdir(QString)const
                bool cppResult = const_cast<const ::QDir *>(cppSelf)->mkdir(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // mkdir(const QString &dirName, QFlags<QFileDevice::Permission> permissions) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QFileDevice::Permission> cppArg1 = QFlags<QFileDevice::Permission>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mkdir(QString,QFlags<QFileDevice::Permission>)const
                bool cppResult = const_cast<const ::QDir *>(cppSelf)->mkdir(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_mkpath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDir::mkpath(QString)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // mkpath(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mkpath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mkpath(QString)const
            bool cppResult = const_cast<const ::QDir *>(cppSelf)->mkpath(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_nameFilters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nameFilters()const
        QStringList cppResult = const_cast<const ::QDir *>(cppSelf)->nameFilters();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_nameFiltersFromString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDir::nameFiltersFromString(QString)->QStringList
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // nameFiltersFromString(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "nameFiltersFromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // nameFiltersFromString(QString)
            QStringList cppResult = ::QDir::nameFiltersFromString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_path(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // path()const
        QString cppResult = const_cast<const ::QDir *>(cppSelf)->path();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_refresh(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // refresh()const
        const_cast<const ::QDir *>(cppSelf)->refresh();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDirFunc_relativeFilePath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDir::relativeFilePath(QString)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // relativeFilePath(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "relativeFilePath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // relativeFilePath(QString)const
            QString cppResult = const_cast<const ::QDir *>(cppSelf)->relativeFilePath(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_remove(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDir::remove(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // remove(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "remove", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // remove(QString)
            bool cppResult = cppSelf->remove(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_removeRecursively(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // removeRecursively()
        bool cppResult = cppSelf->removeRecursively();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_rename(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "rename", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDir::rename(QString,QString)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // rename(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rename", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rename(QString,QString)
            bool cppResult = cppSelf->rename(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_rmdir(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDir::rmdir(QString)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // rmdir(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rmdir", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rmdir(QString)const
            bool cppResult = const_cast<const ::QDir *>(cppSelf)->rmdir(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_rmpath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDir::rmpath(QString)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // rmpath(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rmpath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rmpath(QString)const
            bool cppResult = const_cast<const ::QDir *>(cppSelf)->rmpath(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_root(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // root()
        QDir cppResult = ::QDir::root();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_rootPath(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rootPath()
        QString cppResult = ::QDir::rootPath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_searchPaths(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDir::searchPaths(QString)->QStringList
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // searchPaths(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "searchPaths", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // searchPaths(QString)
            QStringList cppResult = ::QDir::searchPaths(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_separator(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // separator()
        QChar cppResult = ::QDir::separator();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_setCurrent(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDir::setCurrent(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setCurrent(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCurrent", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurrent(QString)
            bool cppResult = ::QDir::setCurrent(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_setFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDir::setFilter(QFlags<QDir::Filter>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setFilter(QFlags<QDir::Filter>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFilter", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QFlags<QDir::Filter> cppArg0 = QFlags<QDir::Filter>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFilter(QFlags<QDir::Filter>)
            cppSelf->setFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDirFunc_setNameFilters(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDir::setNameFilters(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setNameFilters(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNameFilters", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNameFilters(QStringList)
            cppSelf->setNameFilters(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDirFunc_setPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDir::setPath(PyPathLike)
    if (Shiboken::String::checkPath(pyArg)) {
        overloadId = 0; // setPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPath(QString)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
            auto cppArg0 = PySide::pyPathToQString(pyArg);
            // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
            // ========================================================================
            // End of code injection

            cppSelf->setPath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDirFunc_setSearchPaths(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setSearchPaths", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QDir::setSearchPaths(QString,QStringList)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1])))) {
        overloadId = 0; // setSearchPaths(QString,QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSearchPaths", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QStringList cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSearchPaths(QString,QStringList)
            ::QDir::setSearchPaths(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDirFunc_setSorting(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDir::setSorting(QFlags<QDir::SortFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_SortFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setSorting(QFlags<QDir::SortFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSorting", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QFlags<QDir::SortFlag> cppArg0 = QFlags<QDir::SortFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSorting(QFlags<QDir::SortFlag>)
            cppSelf->setSorting(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDirFunc_sorting(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sorting()const
        QFlags<QDir::SortFlag> cppResult = const_cast<const ::QDir *>(cppSelf)->sorting();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_SortFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDir::swap(QDir&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QDir&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDir cppArg0_local;
        ::QDir *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QDir&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDirFunc_temp(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // temp()
        QDir cppResult = ::QDir::temp();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_tempPath(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tempPath()
        QString cppResult = ::QDir::tempPath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirFunc_toNativeSeparators(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDir::toNativeSeparators(QString)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // toNativeSeparators(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "toNativeSeparators", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toNativeSeparators(QString)
            QString cppResult = ::QDir::toNativeSeparators(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDir__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDir_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDir_EnumFlagInfo[] = {
    "Filter:Flag:Filters",
    "SortFlag:Flag:SortFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDir_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QDirFunc___reduce__), METH_NOARGS, nullptr},
    {"absoluteFilePath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_absoluteFilePath), METH_O, nullptr},
    {"absolutePath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_absolutePath), METH_NOARGS, nullptr},
    {"addSearchPath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_addSearchPath), METH_VARARGS|METH_STATIC, nullptr},
    {"canonicalPath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_canonicalPath), METH_NOARGS, nullptr},
    {"cd", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_cd), METH_O, nullptr},
    {"cdUp", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_cdUp), METH_NOARGS, nullptr},
    {"cleanPath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_cleanPath), METH_O|METH_STATIC, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_count), METH_NOARGS, nullptr},
    {"current", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_current), METH_NOARGS|METH_STATIC, nullptr},
    {"currentPath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_currentPath), METH_NOARGS|METH_STATIC, nullptr},
    {"dirName", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_dirName), METH_NOARGS, nullptr},
    {"drives", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_drives), METH_NOARGS|METH_STATIC, nullptr},
    {"entryInfoList", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_entryInfoList), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"entryList", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_entryList), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"exists", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_exists), METH_VARARGS, nullptr},
    {"filePath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_filePath), METH_O, nullptr},
    {"filter", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_filter), METH_NOARGS, nullptr},
    {"fromNativeSeparators", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_fromNativeSeparators), METH_O|METH_STATIC, nullptr},
    {"home", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_home), METH_NOARGS|METH_STATIC, nullptr},
    {"homePath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_homePath), METH_NOARGS|METH_STATIC, nullptr},
    {"isAbsolute", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_isAbsolute), METH_NOARGS, nullptr},
    {"isAbsolutePath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_isAbsolutePath), METH_O|METH_STATIC, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_isEmpty), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"isReadable", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_isReadable), METH_NOARGS, nullptr},
    {"isRelative", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_isRelative), METH_NOARGS, nullptr},
    {"isRelativePath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_isRelativePath), METH_O|METH_STATIC, nullptr},
    {"isRoot", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_isRoot), METH_NOARGS, nullptr},
    {"listSeparator", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_listSeparator), METH_NOARGS|METH_STATIC, nullptr},
    {"makeAbsolute", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_makeAbsolute), METH_NOARGS, nullptr},
    {"match", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_match), METH_VARARGS|METH_STATIC, nullptr},
    {"mkdir", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_mkdir), METH_VARARGS, nullptr},
    {"mkpath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_mkpath), METH_O, nullptr},
    {"nameFilters", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_nameFilters), METH_NOARGS, nullptr},
    {"nameFiltersFromString", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_nameFiltersFromString), METH_O|METH_STATIC, nullptr},
    {"path", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_path), METH_NOARGS, nullptr},
    {"refresh", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_refresh), METH_NOARGS, nullptr},
    {"relativeFilePath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_relativeFilePath), METH_O, nullptr},
    {"remove", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_remove), METH_O, nullptr},
    {"removeRecursively", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_removeRecursively), METH_NOARGS, nullptr},
    {"rename", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_rename), METH_VARARGS, nullptr},
    {"rmdir", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_rmdir), METH_O, nullptr},
    {"rmpath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_rmpath), METH_O, nullptr},
    {"root", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_root), METH_NOARGS|METH_STATIC, nullptr},
    {"rootPath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_rootPath), METH_NOARGS|METH_STATIC, nullptr},
    {"searchPaths", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_searchPaths), METH_O|METH_STATIC, nullptr},
    {"separator", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_separator), METH_NOARGS|METH_STATIC, nullptr},
    {"setCurrent", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_setCurrent), METH_O|METH_STATIC, nullptr},
    {"setFilter", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_setFilter), METH_O, nullptr},
    {"setNameFilters", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_setNameFilters), METH_O, nullptr},
    {"setPath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_setPath), METH_O, nullptr},
    {"setSearchPaths", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_setSearchPaths), METH_VARARGS|METH_STATIC, nullptr},
    {"setSorting", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_setSorting), METH_O, nullptr},
    {"sorting", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_sorting), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_swap), METH_O, nullptr},
    {"temp", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_temp), METH_NOARGS|METH_STATIC, nullptr},
    {"tempPath", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_tempPath), METH_NOARGS|METH_STATIC, nullptr},
    {"toNativeSeparators", reinterpret_cast<PyCFunction>(Sbk_QDirFunc_toNativeSeparators), METH_O|METH_STATIC, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDir__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QDir_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), (pyArg)))) {
                // operator!=(const QDir &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDir cppArg0_local;
                ::QDir *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), (pyArg)))) {
                // operator==(const QDir &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDir cppArg0_local;
                ::QDir *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QDir_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDir_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QDir__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDir_Type = nullptr;
static PyTypeObject *Sbk_QDir_TypeF(void)
{
    return _Sbk_QDir_Type;
}

static PyType_Slot Sbk_QDir_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QDir__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDir_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDir_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QDir_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDir_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDir_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDir_spec = {
    "2:PySide6.QtCore.QDir",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDir_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDir_Filter(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDir::Filter>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDir::Filter *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDir_Filter_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_Filter_IDX])))
        return Enum_PythonToCpp_QDir_Filter;
    return {};
}

static PyObject *QDir_Filter_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDir::Filter>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDir::Filter *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_Filter_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QDir_Filter(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QDir::Filter>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QDir::Filter> *>(cppOut) = value;

}

static PyObject *QDir_Filter_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QDir::Filter> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_Filter_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QDir_SortFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDir::SortFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDir::SortFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDir_SortFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_SortFlag_IDX])))
        return Enum_PythonToCpp_QDir_SortFlag;
    return {};
}

static PyObject *QDir_SortFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDir::SortFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDir::SortFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_SortFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QDir_SortFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QDir::SortFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QDir::SortFlag> *>(cppOut) = value;

}

static PyObject *QDir_SortFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QDir::SortFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_SortFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDir_PythonToCpp_QDir_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDir_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDir_PythonToCpp_QDir_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDir_TypeF()))
        return QDir_PythonToCpp_QDir_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDir_PTR_CppToPython_QDir(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDir_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDir_COPY_CppToPython_QDir(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDir *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDir_TypeF(), new ::QDir(*source), true, true);
}

// Python to C++ copy conversion.
static void QDir_PythonToCpp_QDir_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDir *>(cppOut) = *reinterpret_cast< ::QDir *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDir_PythonToCpp_QDir_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDir_TypeF()))
        return QDir_PythonToCpp_QDir_COPY;
    return {};
}

// Implicit conversions.
// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDir_SignatureStrings[] = {
    "2:PySide6.QtCore.QDir(self,arg__1:PySide6.QtCore.QDir)",
    "1:PySide6.QtCore.QDir(self,path:Optional[PyPathLike]=QString())",
    "0:PySide6.QtCore.QDir(self,path:PyPathLike,nameFilter:QString,sort:PySide6.QtCore.QDir.SortFlag=QDir.SortFlags(QDir.SortFlag.Name | QDir.SortFlag.IgnoreCase),filter:PySide6.QtCore.QDir.Filter=QDir.Filter.AllEntries)",
    "PySide6.QtCore.QDir.__reduce__(self)->str",
    "PySide6.QtCore.QDir.absoluteFilePath(self,fileName:QString)->QString",
    "PySide6.QtCore.QDir.absolutePath(self)->QString",
    "PySide6.QtCore.QDir.addSearchPath(prefix:QString,path:PyPathLike)",
    "PySide6.QtCore.QDir.canonicalPath(self)->QString",
    "PySide6.QtCore.QDir.cd(self,dirName:QString)->bool",
    "PySide6.QtCore.QDir.cdUp(self)->bool",
    "PySide6.QtCore.QDir.cleanPath(path:QString)->QString",
    "PySide6.QtCore.QDir.count(self)->qsizetype",
    "PySide6.QtCore.QDir.current()->PySide6.QtCore.QDir",
    "PySide6.QtCore.QDir.currentPath()->QString",
    "PySide6.QtCore.QDir.dirName(self)->QString",
    "PySide6.QtCore.QDir.drives()->QList[PySide6.QtCore.QFileInfo]",
    "1:PySide6.QtCore.QDir.entryInfoList(self,filters:PySide6.QtCore.QDir.Filter=QDir.Filter.NoFilter,sort:PySide6.QtCore.QDir.SortFlag=QDir.SortFlag.NoSort)->QList[PySide6.QtCore.QFileInfo]",
    "0:PySide6.QtCore.QDir.entryInfoList(self,nameFilters:QStringList,filters:PySide6.QtCore.QDir.Filter=QDir.Filter.NoFilter,sort:PySide6.QtCore.QDir.SortFlag=QDir.SortFlag.NoSort)->QList[PySide6.QtCore.QFileInfo]",
    "1:PySide6.QtCore.QDir.entryList(self,filters:PySide6.QtCore.QDir.Filter=QDir.Filter.NoFilter,sort:PySide6.QtCore.QDir.SortFlag=QDir.SortFlag.NoSort)->QStringList",
    "0:PySide6.QtCore.QDir.entryList(self,nameFilters:QStringList,filters:PySide6.QtCore.QDir.Filter=QDir.Filter.NoFilter,sort:PySide6.QtCore.QDir.SortFlag=QDir.SortFlag.NoSort)->QStringList",
    "1:PySide6.QtCore.QDir.exists(self)->bool",
    "0:PySide6.QtCore.QDir.exists(self,name:QString)->bool",
    "PySide6.QtCore.QDir.filePath(self,fileName:QString)->QString",
    "PySide6.QtCore.QDir.filter(self)->PySide6.QtCore.QDir.Filter",
    "PySide6.QtCore.QDir.fromNativeSeparators(pathName:QString)->QString",
    "PySide6.QtCore.QDir.home()->PySide6.QtCore.QDir",
    "PySide6.QtCore.QDir.homePath()->QString",
    "PySide6.QtCore.QDir.isAbsolute(self)->bool",
    "PySide6.QtCore.QDir.isAbsolutePath(path:QString)->bool",
    "PySide6.QtCore.QDir.isEmpty(self,filters:PySide6.QtCore.QDir.Filter=QDir.Filters(QDir.Filter.AllEntries | QDir.Filter.NoDotAndDotDot))->bool",
    "PySide6.QtCore.QDir.isReadable(self)->bool",
    "PySide6.QtCore.QDir.isRelative(self)->bool",
    "PySide6.QtCore.QDir.isRelativePath(path:QString)->bool",
    "PySide6.QtCore.QDir.isRoot(self)->bool",
    "PySide6.QtCore.QDir.listSeparator()->QChar",
    "PySide6.QtCore.QDir.makeAbsolute(self)->bool",
    "1:PySide6.QtCore.QDir.match(filter:QString,fileName:QString)->bool",
    "0:PySide6.QtCore.QDir.match(filters:QStringList,fileName:QString)->bool",
    "1:PySide6.QtCore.QDir.mkdir(self,dirName:QString)->bool",
    "0:PySide6.QtCore.QDir.mkdir(self,dirName:QString,permissions:PySide6.QtCore.QFileDevice.Permission)->bool",
    "PySide6.QtCore.QDir.mkpath(self,dirPath:QString)->bool",
    "PySide6.QtCore.QDir.nameFilters(self)->QStringList",
    "PySide6.QtCore.QDir.nameFiltersFromString(nameFilter:QString)->QStringList",
    "PySide6.QtCore.QDir.path(self)->QString",
    "PySide6.QtCore.QDir.refresh(self)",
    "PySide6.QtCore.QDir.relativeFilePath(self,fileName:QString)->QString",
    "PySide6.QtCore.QDir.remove(self,fileName:QString)->bool",
    "PySide6.QtCore.QDir.removeRecursively(self)->bool",
    "PySide6.QtCore.QDir.rename(self,oldName:QString,newName:QString)->bool",
    "PySide6.QtCore.QDir.rmdir(self,dirName:QString)->bool",
    "PySide6.QtCore.QDir.rmpath(self,dirPath:QString)->bool",
    "PySide6.QtCore.QDir.root()->PySide6.QtCore.QDir",
    "PySide6.QtCore.QDir.rootPath()->QString",
    "PySide6.QtCore.QDir.searchPaths(prefix:QString)->QStringList",
    "PySide6.QtCore.QDir.separator()->QChar",
    "PySide6.QtCore.QDir.setCurrent(path:QString)->bool",
    "PySide6.QtCore.QDir.setFilter(self,filter:PySide6.QtCore.QDir.Filter)",
    "PySide6.QtCore.QDir.setNameFilters(self,nameFilters:QStringList)",
    "PySide6.QtCore.QDir.setPath(self,path:PyPathLike)",
    "PySide6.QtCore.QDir.setSearchPaths(prefix:QString,searchPaths:QStringList)",
    "PySide6.QtCore.QDir.setSorting(self,sort:PySide6.QtCore.QDir.SortFlag)",
    "PySide6.QtCore.QDir.sorting(self)->PySide6.QtCore.QDir.SortFlag",
    "PySide6.QtCore.QDir.swap(self,other:PySide6.QtCore.QDir)",
    "PySide6.QtCore.QDir.temp()->PySide6.QtCore.QDir",
    "PySide6.QtCore.QDir.tempPath()->QString",
    "PySide6.QtCore.QDir.toNativeSeparators(pathName:QString)->QString",
    "PySide6.QtCore.QDir.__copy__(self)->typing.Self",
    "PySide6.QtCore.QDir.__ne__(self,rhs:PySide6.QtCore.QDir)->bool",
    "PySide6.QtCore.QDir.__eq__(self,rhs:PySide6.QtCore.QDir)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QDir_SignatureByteSize = 813;
static constexpr uint8_t QDir_SignatureBytes[813] = {
    0x78, 0xda, 0xcd, 0x57, 0x4b, 0x4f, 0xe3, 0x30, 0x10, 0xbe, 0xf3, 0x2b, 0x38, 0x36, 0x52, 0x36,
    0x2a, 0x7b, 0xd8, 0x03, 0x12, 0x2b, 0xa1, 0x42, 0x25, 0x24, 0xd4, 0x2d, 0xad, 0xf6, 0x84, 0x50,
    0x64, 0x92, 0x69, 0x63, 0xd5, 0x89, 0x83, 0xed, 0x02, 0x59, 0xed, 0x8f, 0xdf, 0x71, 0x5e, 0x7d,
    0xd9, 0x89, 0x03, 0x87, 0x45, 0x42, 0xc8, 0xae, 0x67, 0xc6, 0xf3, 0xfc, 0xf2, 0xf9, 0xfb, 0xe5,
    0xbc, 0x58, 0xd2, 0x18, 0x7e, 0x04, 0x0f, 0x6a, 0xc2, 0x05, 0x04, 0x0f, 0x37, 0x54, 0x8c, 0x24,
    0xb0, 0x95, 0x4f, 0xc4, 0x3a, 0x0c, 0x2f, 0x4c, 0xe7, 0xde, 0xd9, 0x85, 0x5d, 0x2d, 0x27, 0x2a,
    0xb9, 0xfc, 0x95, 0x2b, 0xca, 0x33, 0xc2, 0x1e, 0xe7, 0xc5, 0x1c, 0xf7, 0xf7, 0x74, 0x03, 0x4f,
    0x57, 0x0f, 0x4b, 0x25, 0x68, 0xb6, 0x1e, 0x79, 0xde, 0xd9, 0xb8, 0x47, 0x7f, 0xa7, 0xe6, 0x67,
    0x24, 0x85, 0x29, 0x65, 0x0a, 0xc4, 0x65, 0x6d, 0xc0, 0x97, 0x5c, 0x28, 0x93, 0x81, 0x60, 0x89,
    0x07, 0x53, 0x46, 0xd6, 0x57, 0x07, 0x3b, 0x39, 0x3a, 0xd8, 0x06, 0x33, 0xb4, 0x78, 0xfe, 0xf7,
    0xfc, 0xf0, 0xc7, 0xbb, 0x75, 0x86, 0x66, 0x26, 0x44, 0x82, 0xe7, 0xaf, 0xaa, 0xeb, 0x4c, 0x37,
    0x54, 0x9e, 0x5c, 0xed, 0xad, 0x83, 0x6b, 0xc6, 0x6e, 0x33, 0x74, 0x0c, 0xa4, 0x77, 0x66, 0x52,
    0x09, 0x43, 0x01, 0xf1, 0x36, 0x82, 0x30, 0x2c, 0x03, 0xf4, 0xbe, 0xfd, 0x94, 0x4a, 0x18, 0x25,
    0xc9, 0xb3, 0xe4, 0x6c, 0xab, 0x74, 0xb8, 0xa0, 0xe3, 0xaf, 0x12, 0x82, 0xde, 0x80, 0x76, 0xb9,
    0x09, 0x1f, 0x0d, 0xd4, 0xab, 0x4e, 0x23, 0xad, 0x81, 0x3e, 0xf9, 0x38, 0x5e, 0x02, 0x11, 0x51,
    0x52, 0x2a, 0xe4, 0x02, 0x56, 0xf4, 0xbd, 0xcd, 0xf4, 0x51, 0x31, 0xcc, 0x01, 0x46, 0x24, 0xe3,
    0x19, 0x8d, 0x08, 0x73, 0xbd, 0x32, 0x8a, 0xab, 0xc8, 0x62, 0x2a, 0x8e, 0x02, 0x7b, 0xe6, 0x9c,
    0x59, 0x54, 0x7e, 0xe7, 0x8d, 0x69, 0xbb, 0x10, 0x03, 0x92, 0x55, 0x61, 0x68, 0xbf, 0xdd, 0xf2,
    0x15, 0xf1, 0x6d, 0xa6, 0x1a, 0xd3, 0x2f, 0x92, 0xfe, 0x01, 0x55, 0xe4, 0x60, 0x16, 0xdd, 0x0a,
    0x01, 0x28, 0x8c, 0x82, 0x86, 0xe3, 0x2e, 0x95, 0xd2, 0xa9, 0x1e, 0x47, 0xea, 0x6c, 0xb8, 0x24,
    0x30, 0x16, 0xf4, 0x15, 0x64, 0x69, 0xf0, 0x9e, 0x4a, 0xf5, 0x78, 0x2c, 0xa3, 0x1b, 0xe8, 0x2e,
    0x5b, 0xf1, 0x27, 0xf3, 0xa0, 0x06, 0xe8, 0x91, 0x28, 0xb4, 0x80, 0xd6, 0x6e, 0xbb, 0x0c, 0x9b,
    0x59, 0xba, 0x36, 0xfd, 0x8c, 0x57, 0x8b, 0xa1, 0xb3, 0x88, 0x8a, 0x7a, 0xe9, 0xe0, 0xf9, 0xd8,
    0xd5, 0xf3, 0x1d, 0x40, 0xc8, 0xa6, 0xe4, 0xfa, 0xf0, 0xeb, 0x45, 0xd4, 0x51, 0x8b, 0xff, 0x59,
    0x87, 0x5d, 0xca, 0xba, 0x72, 0xfe, 0x15, 0xf3, 0xbd, 0xe7, 0xb9, 0x25, 0xb7, 0xef, 0x78, 0x26,
    0x0f, 0x70, 0x63, 0xdc, 0x27, 0x58, 0xc6, 0xe7, 0x02, 0x49, 0xab, 0xcf, 0xa0, 0x74, 0x95, 0xac,
    0xc6, 0x33, 0x7b, 0xca, 0xcc, 0xca, 0x82, 0xa7, 0x33, 0xa2, 0x10, 0x03, 0x96, 0x90, 0x13, 0x41,
    0x14, 0x17, 0xb2, 0x84, 0xbc, 0x01, 0x0e, 0x24, 0x1c, 0xa1, 0x66, 0x00, 0x90, 0x69, 0x79, 0x17,
    0x14, 0xa3, 0xf2, 0xba, 0xfe, 0x00, 0xf5, 0xc2, 0xf5, 0x4e, 0xd4, 0x84, 0xd9, 0x1d, 0x6a, 0xb7,
    0x69, 0xae, 0x8a, 0x8f, 0x8c, 0x4b, 0xcd, 0x04, 0x4e, 0x3e, 0xdc, 0x0d, 0x1b, 0x68, 0x5b, 0xf3,
    0x86, 0xab, 0xeb, 0x2c, 0xc6, 0xff, 0xf8, 0xe7, 0x75, 0x3b, 0xb3, 0x00, 0x12, 0x93, 0x67, 0xe6,
    0x12, 0xee, 0x02, 0x58, 0x59, 0xb5, 0x01, 0xa2, 0x03, 0x33, 0xb3, 0xe0, 0x5c, 0xf5, 0x5a, 0x67,
    0xd8, 0xeb, 0x6d, 0xe3, 0x94, 0xf5, 0x9c, 0x24, 0xc4, 0x5c, 0xf5, 0x94, 0x6c, 0xc0, 0x58, 0x4f,
    0xf3, 0xbc, 0xa5, 0x44, 0x45, 0xc9, 0x68, 0x75, 0xc8, 0xd6, 0x0c, 0x93, 0xd1, 0x31, 0x89, 0xfb,
    0x26, 0x4e, 0xf0, 0xc5, 0x68, 0xc7, 0xe2, 0xca, 0x26, 0x6e, 0x18, 0xa5, 0x85, 0x66, 0x8c, 0x07,
    0xea, 0xf9, 0x39, 0x88, 0x94, 0x4a, 0x89, 0xc4, 0xf6, 0xb4, 0xdf, 0x34, 0xca, 0xdf, 0xc0, 0x2b,
    0x8d, 0x20, 0x98, 0xb7, 0x62, 0x5d, 0x45, 0x48, 0x37, 0x79, 0x8b, 0x1d, 0x78, 0xd1, 0xdc, 0xb1,
    0xc4, 0x7b, 0xe0, 0x7b, 0x44, 0x14, 0x4a, 0x18, 0xec, 0x51, 0x99, 0x22, 0x70, 0xd4, 0x24, 0xfc,
    0x94, 0x56, 0x3b, 0x98, 0xca, 0x1d, 0x09, 0x1e, 0x92, 0x48, 0x01, 0xb2, 0x16, 0xb5, 0x48, 0x54,
    0xfd, 0xfd, 0x29, 0xaa, 0x2b, 0x20, 0xe5, 0xf5, 0x34, 0x59, 0xbb, 0xc3, 0xae, 0xb7, 0x00, 0x24,
    0x67, 0x12, 0x7d, 0x60, 0x45, 0xef, 0xc8, 0x20, 0x87, 0x6b, 0xa8, 0x99, 0xcf, 0x59, 0x7c, 0xd0,
    0x16, 0x19, 0xbc, 0x39, 0x5f, 0x9c, 0xf6, 0x35, 0xa5, 0x59, 0xeb, 0x43, 0xad, 0x22, 0x34, 0x16,
    0x0c, 0x40, 0x78, 0x2d, 0xef, 0x82, 0xf0, 0xb2, 0x7d, 0x2d, 0xc8, 0xa3, 0xe7, 0x82, 0x43, 0x07,
    0x49, 0x37, 0xdc, 0x91, 0xa0, 0x26, 0x35, 0xd9, 0x76, 0x05, 0x3f, 0x54, 0x99, 0xee, 0x3e, 0xaa,
    0xfd, 0x6f, 0x38, 0xcf, 0x66, 0x65, 0x76, 0x34, 0x62, 0x36, 0xc2, 0x63, 0x35, 0xb0, 0xeb, 0x67,
    0xa7, 0xe7, 0x13, 0x6a, 0x2c, 0xad, 0x29, 0xf5, 0xf7, 0xb2, 0xed, 0x74, 0xb9, 0xe6, 0x46, 0x7a,
    0xbe, 0xcb, 0xfb, 0x7b, 0xa9, 0x95, 0xc5, 0xcc, 0x9e, 0x0d, 0x0b, 0x3b, 0x69, 0x0c, 0x98, 0xf5,
    0xdf, 0x48, 0x5e, 0xcf, 0x8a, 0x4a, 0xcc, 0x45, 0x30, 0x5f, 0xac, 0x20, 0xcd, 0x87, 0xb4, 0xac,
    0x96, 0x77, 0x69, 0x59, 0xc5, 0x3f, 0x4b, 0x97, 0xc2, 0x30, 0xe2, 0x79, 0xb1, 0x7b, 0xc2, 0xe3,
    0x1b, 0x11, 0x45, 0x83, 0x25, 0xee, 0x2c, 0xf2, 0x59, 0xf3, 0xe0, 0xf7, 0x45, 0x62, 0xe4, 0x27,
    0x5d, 0xcd, 0x1c, 0x86, 0xf0, 0xe2, 0xa8, 0xfe, 0x0f, 0xb3, 0xfb, 0x3f, 0xc3
};
#endif

PyTypeObject *init_QDir(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX].type;

    Shiboken::AutoDecRef Sbk_QDir_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDir_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDir",
        "QDir",
        &Sbk_QDir_spec,
        &Shiboken::callCppDestructor< ::QDir >,
        Sbk_QDir_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDir_TypeF(); // references _Sbk_QDir_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDir_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDir_SignatureBytes, QDir_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDir_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDir_PythonToCpp_QDir_PTR,
        is_QDir_PythonToCpp_QDir_PTR_Convertible,
        QDir_PTR_CppToPython_QDir,
        QDir_COPY_CppToPython_QDir);

    Shiboken::Conversions::registerConverterName(converter, "QDir");
    Shiboken::Conversions::registerConverterName(converter, "QDir*");
    Shiboken::Conversions::registerConverterName(converter, "QDir&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDir).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDir_PythonToCpp_QDir_COPY,
        is_QDir_PythonToCpp_QDir_COPY_Convertible);
    // Add implicit conversions to type converter.

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDir_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Filter'.
    const char *Filter_Initializer[] = {
        "Dirs",
        "Files",
        "Drives",
        "NoSymLinks",
        "AllEntries",
        "TypeMask",
        "Readable",
        "Writable",
        "Executable",
        "PermissionMask",
        "Modified",
        "Hidden",
        "System",
        "AccessMask",
        "AllDirs",
        "CaseSensitive",
        "NoDot",
        "NoDotDot",
        "NoDotAndDotDot",
        "NoFilter",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t Filter_InitializerValues[] = {
        int16_t(QDir::Filter::Dirs),           //  0x0001  1
        int16_t(QDir::Filter::Files),          //  0x0002  2
        int16_t(QDir::Filter::Drives),         //  0x0004  4
        int16_t(QDir::Filter::NoSymLinks),     //  0x0008  8
        int16_t(QDir::Filter::AllEntries),     //  0x0007  7
        int16_t(QDir::Filter::TypeMask),       //  0x000f  15
        int16_t(QDir::Filter::Readable),       //  0x0010  16
        int16_t(QDir::Filter::Writable),       //  0x0020  32
        int16_t(QDir::Filter::Executable),     //  0x0040  64
        int16_t(QDir::Filter::PermissionMask), //  0x0070  112
        int16_t(QDir::Filter::Modified),       //  0x0080  128
        int16_t(QDir::Filter::Hidden),         //  0x0100  256
        int16_t(QDir::Filter::System),         //  0x0200  512
        int16_t(QDir::Filter::AccessMask),     //  0x03f0  1008
        int16_t(QDir::Filter::AllDirs),        //  0x0400  1024
        int16_t(QDir::Filter::CaseSensitive),  //  0x0800  2048
        int16_t(QDir::Filter::NoDot),          //  0x2000  8192
        int16_t(QDir::Filter::NoDotDot),       //  0x4000  16384
        int16_t(QDir::Filter::NoDotAndDotDot), //  0x6000  24576
        int16_t(QDir::Filter::NoFilter)        // -0x0001 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDir_TypeF(),
        "2:PySide6.QtCore.QDir.Filter",
        Filter_Initializer, Filter_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QDir_Filter_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX].type =
        EType;
    // Register converter for enum 'QDir::Filter'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDir_Filter_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDir_Filter,
            is_Enum_PythonToCpp_QDir_Filter_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDir::Filter");
        Shiboken::Conversions::registerConverterAlias(converter, "Filter");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QDir_Filter_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QDir_Filter,
            is_Enum_PythonToCpp_QDir_Filter_Convertible);
        // Register converter for flag 'QFlags<QDir::Filter>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QDir::Filter>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QDir::Filters");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Filter' enum/flags.

    // Initialization of enum 'SortFlag'.
    const char *SortFlag_Initializer[] = {
        "Name",
        "Time",
        "Size",
        "Unsorted",
        "SortByMask",
        "DirsFirst",
        "Reversed",
        "IgnoreCase",
        "DirsLast",
        "LocaleAware",
        "Type",
        "NoSort",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t SortFlag_InitializerValues[] = {
        int16_t(QDir::SortFlag::Name),        //  0x0000  0
        int16_t(QDir::SortFlag::Time),        //  0x0001  1
        int16_t(QDir::SortFlag::Size),        //  0x0002  2
        int16_t(QDir::SortFlag::Unsorted),    //  0x0003  3
        int16_t(QDir::SortFlag::SortByMask),  //  0x0003  3
        int16_t(QDir::SortFlag::DirsFirst),   //  0x0004  4
        int16_t(QDir::SortFlag::Reversed),    //  0x0008  8
        int16_t(QDir::SortFlag::IgnoreCase),  //  0x0010  16
        int16_t(QDir::SortFlag::DirsLast),    //  0x0020  32
        int16_t(QDir::SortFlag::LocaleAware), //  0x0040  64
        int16_t(QDir::SortFlag::Type),        //  0x0080  128
        int16_t(QDir::SortFlag::NoSort)       // -0x0001 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDir_TypeF(),
        "2:PySide6.QtCore.QDir.SortFlag",
        SortFlag_Initializer, SortFlag_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QDir_SortFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_SortFlag_IDX].type =
        EType;
    // Register converter for enum 'QDir::SortFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDir_SortFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDir_SortFlag,
            is_Enum_PythonToCpp_QDir_SortFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDir::SortFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "SortFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QDir_SortFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QDir_SortFlag,
            is_Enum_PythonToCpp_QDir_SortFlag_Convertible);
        // Register converter for flag 'QFlags<QDir::SortFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QDir::SortFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QDir::SortFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'SortFlag' enum/flags.

    qRegisterMetaType< ::QDir >("QDir");
    qRegisterMetaType< ::QDir::Filter >("QDir::Filter");
    qRegisterMetaType< ::QDir::SortFlag >("QDir::SortFlag");

    return pyType;
}
