// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qdiriterator_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <qdir.h>
#include <qfileinfo.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDirIterator_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDirIterator >()))
        return -1;

    ::QDirIterator *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:QDirIterator", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDirIterator::QDirIterator(QDir,QFlags<QDirIterator::IteratorFlag>=)
    // 1: QDirIterator::QDirIterator(QString,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>=)
    // 2: QDirIterator::QDirIterator(QString,QFlags<QDirIterator::IteratorFlag>=)
    // 3: QDirIterator::QDirIterator(QString,QStringList,QFlags<QDir::Filter>=,QFlags<QDirIterator::IteratorFlag>=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QDirIterator(QString,QFlags<QDirIterator::IteratorFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 3; // QDirIterator(QString,QStringList,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 3; // QDirIterator(QString,QStringList,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDirIterator_IteratorFlag_IDX])))->flagsConverter, (pyArgs[3])))) {
                    overloadId = 3; // QDirIterator(QString,QStringList,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDirIterator_IteratorFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 2; // QDirIterator(QString,QFlags<QDirIterator::IteratorFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // QDirIterator(QString,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDirIterator_IteratorFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 1; // QDirIterator(QString,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QDirIterator(QDir,QFlags<QDirIterator::IteratorFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDirIterator_IteratorFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // QDirIterator(QDir,QFlags<QDirIterator::IteratorFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDirIterator(const QDir &dir, QFlags<QDirIterator::IteratorFlag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDirIterator_IteratorFlag_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDir cppArg0_local;
            ::QDir *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QFlags<QDirIterator::IteratorFlag> cppArg1(QDirIterator::IteratorFlag::NoIteratorFlags);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDirIterator(QDir,QFlags<QDirIterator::IteratorFlag>)
                cptr = new ::QDirIterator(*cppArg0, cppArg1);
            }
            break;
        }
        case 1: // QDirIterator(const QString &path, QFlags<QDir::Filter> filter, QFlags<QDirIterator::IteratorFlag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDirIterator_IteratorFlag_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QDir::Filter> cppArg1 = QFlags<QDir::Filter>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QDirIterator::IteratorFlag> cppArg2(QDirIterator::IteratorFlag::NoIteratorFlags);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDirIterator(QString,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
                cptr = new ::QDirIterator(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 2: // QDirIterator(const QString &path, QFlags<QDirIterator::IteratorFlag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDirIterator_IteratorFlag_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QDirIterator::IteratorFlag> cppArg1(QDirIterator::IteratorFlag::NoIteratorFlags);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDirIterator(QString,QFlags<QDirIterator::IteratorFlag>)
                cptr = new ::QDirIterator(cppArg0, cppArg1);
            }
            break;
        }
        case 3: // QDirIterator(const QString &path, const QStringList &nameFilters, QFlags<QDir::Filter> filters, QFlags<QDirIterator::IteratorFlag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_filters = Shiboken::String::createStaticString("filters");
                if (PyDict_Contains(kwds, key_filters) != 0) {
                    value = PyDict_GetItem(kwds, key_filters);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_filters);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_filters);
                }
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDirIterator_IteratorFlag_IDX])))->flagsConverter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QStringList cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QDir::Filter> cppArg2(QDir::NoFilter);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<QDirIterator::IteratorFlag> cppArg3(QDirIterator::IteratorFlag::NoIteratorFlags);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDirIterator(QString,QStringList,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
                cptr = new ::QDirIterator(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDirIterator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDirIteratorFunc_fileInfo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDirIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileInfo()const
        QFileInfo cppResult = const_cast<const ::QDirIterator *>(cppSelf)->fileInfo();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirIteratorFunc_fileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDirIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileName()const
        QString cppResult = const_cast<const ::QDirIterator *>(cppSelf)->fileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirIteratorFunc_filePath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDirIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // filePath()const
        QString cppResult = const_cast<const ::QDirIterator *>(cppSelf)->filePath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirIteratorFunc_hasNext(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDirIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasNext()const
        bool cppResult = const_cast<const ::QDirIterator *>(cppSelf)->hasNext();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirIteratorFunc_next(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDirIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // next()
        QString cppResult = cppSelf->next();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirIteratorFunc_nextFileInfo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDirIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nextFileInfo()
        QFileInfo cppResult = cppSelf->nextFileInfo();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirIteratorFunc_path(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDirIterator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // path()const
        QString cppResult = const_cast<const ::QDirIterator *>(cppSelf)->path();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDirIterator_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDirIterator_EnumFlagInfo[] = {
    "IteratorFlag:Flag:IteratorFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDirIterator_methods[] = {
    {"fileInfo", reinterpret_cast<PyCFunction>(Sbk_QDirIteratorFunc_fileInfo), METH_NOARGS, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QDirIteratorFunc_fileName), METH_NOARGS, nullptr},
    {"filePath", reinterpret_cast<PyCFunction>(Sbk_QDirIteratorFunc_filePath), METH_NOARGS, nullptr},
    {"hasNext", reinterpret_cast<PyCFunction>(Sbk_QDirIteratorFunc_hasNext), METH_NOARGS, nullptr},
    {"next", reinterpret_cast<PyCFunction>(Sbk_QDirIteratorFunc_next), METH_NOARGS, nullptr},
    {"nextFileInfo", reinterpret_cast<PyCFunction>(Sbk_QDirIteratorFunc_nextFileInfo), METH_NOARGS, nullptr},
    {"path", reinterpret_cast<PyCFunction>(Sbk_QDirIteratorFunc_path), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QDirIterator_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDirIterator_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDirIterator_Type = nullptr;
static PyTypeObject *Sbk_QDirIterator_TypeF(void)
{
    return _Sbk_QDirIterator_Type;
}

static PyType_Slot Sbk_QDirIterator_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDirIterator_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDirIterator_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDirIterator_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDirIterator_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDirIterator_spec = {
    "2:PySide6.QtCore.QDirIterator",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDirIterator_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDirIterator_IteratorFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDirIterator::IteratorFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDirIterator::IteratorFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDirIterator_IteratorFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IteratorFlag_IDX])))
        return Enum_PythonToCpp_QDirIterator_IteratorFlag;
    return {};
}

static PyObject *QDirIterator_IteratorFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDirIterator::IteratorFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDirIterator::IteratorFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IteratorFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QDirIterator_IteratorFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QDirIterator::IteratorFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QDirIterator::IteratorFlag> *>(cppOut) = value;

}

static PyObject *QDirIterator_IteratorFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QDirIterator::IteratorFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IteratorFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDirIterator_PythonToCpp_QDirIterator_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDirIterator_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDirIterator_PythonToCpp_QDirIterator_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDirIterator_TypeF()))
        return QDirIterator_PythonToCpp_QDirIterator_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDirIterator_PTR_CppToPython_QDirIterator(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDirIterator_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDirIterator_SignatureStrings[] = {
    "3:PySide6.QtCore.QDirIterator(self,dir:PySide6.QtCore.QDir,flags:PySide6.QtCore.QDirIterator.IteratorFlag=QDirIterator.IteratorFlag.NoIteratorFlags)",
    "2:PySide6.QtCore.QDirIterator(self,path:QString,filter:PySide6.QtCore.QDir.Filter,flags:PySide6.QtCore.QDirIterator.IteratorFlag=QDirIterator.IteratorFlag.NoIteratorFlags)",
    "1:PySide6.QtCore.QDirIterator(self,path:QString,flags:PySide6.QtCore.QDirIterator.IteratorFlag=QDirIterator.IteratorFlag.NoIteratorFlags)",
    "0:PySide6.QtCore.QDirIterator(self,path:QString,nameFilters:QStringList,filters:PySide6.QtCore.QDir.Filter=QDir.NoFilter,flags:PySide6.QtCore.QDirIterator.IteratorFlag=QDirIterator.IteratorFlag.NoIteratorFlags)",
    "PySide6.QtCore.QDirIterator.fileInfo(self)->PySide6.QtCore.QFileInfo",
    "PySide6.QtCore.QDirIterator.fileName(self)->QString",
    "PySide6.QtCore.QDirIterator.filePath(self)->QString",
    "PySide6.QtCore.QDirIterator.hasNext(self)->bool",
    "PySide6.QtCore.QDirIterator.next(self)->QString",
    "PySide6.QtCore.QDirIterator.nextFileInfo(self)->PySide6.QtCore.QFileInfo",
    "PySide6.QtCore.QDirIterator.path(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QDirIterator_SignatureByteSize = 203;
static constexpr uint8_t QDirIterator_SignatureBytes[203] = {
    0x78, 0xda, 0xb5, 0x90, 0xdd, 0x0a, 0xc2, 0x20, 0x18, 0x86, 0xcf, 0xbb, 0x92, 0x06, 0x26, 0xfd,
    0x40, 0x07, 0x83, 0x3a, 0x29, 0x84, 0x41, 0x8c, 0x8d, 0x5d, 0x81, 0xb1, 0xcf, 0x4d, 0x30, 0x1d,
    0xea, 0x41, 0xdd, 0x7d, 0xb6, 0x26, 0x8c, 0x58, 0xae, 0x41, 0x3b, 0x53, 0xdf, 0x1f, 0x1e, 0xdf,
    0x5d, 0x9c, 0x3d, 0x0a, 0x5e, 0xc2, 0x1e, 0xe7, 0xf6, 0xa4, 0x34, 0xe0, 0xfc, 0xcc, 0x75, 0x62,
    0x41, 0x53, 0xab, 0xf4, 0xd2, 0x80, 0x60, 0xa8, 0xe4, 0x7a, 0xc8, 0x84, 0x98, 0xa0, 0x95, 0x09,
    0xc5, 0xb1, 0x3f, 0x10, 0xe7, 0x3c, 0x7c, 0x55, 0x70, 0xaa, 0xfa, 0x57, 0x13, 0x2d, 0xb6, 0xe3,
    0x50, 0x0d, 0xb5, 0x75, 0x9c, 0x17, 0x56, 0x73, 0x59, 0x21, 0xc6, 0x85, 0x13, 0x87, 0x42, 0x98,
    0xb4, 0xd2, 0x8c, 0xac, 0x9b, 0xa9, 0xac, 0xb3, 0x91, 0xac, 0x27, 0x92, 0x48, 0x7a, 0x83, 0xf7,
    0x3c, 0xc6, 0xbf, 0x5d, 0xb8, 0xb1, 0xdd, 0x9a, 0x26, 0x30, 0x67, 0x4b, 0xe5, 0x00, 0x66, 0x1f,
    0x37, 0xd4, 0xe9, 0x30, 0x21, 0x91, 0x4c, 0xb5, 0x3f, 0x8b, 0x56, 0xc7, 0x4f, 0x2f, 0xe9, 0xf4,
    0xd1, 0x92, 0xd4, 0xed, 0xe0, 0x4b, 0xba, 0x1d, 0x46, 0x33, 0x99, 0x1b, 0x72, 0x4a, 0xa6, 0xa6,
    0x26, 0x85, 0xbb, 0xf5, 0x91, 0xab, 0x52, 0x22, 0xe8, 0x97, 0x3d, 0xf3, 0x2f, 0xfd, 0x2f, 0x3f,
    0xf9, 0xc7, 0x20, 0xcd, 0xc0, 0xc7, 0x9e, 0x29, 0x49, 0x7e, 0xaf
};
#endif

PyTypeObject *init_QDirIterator(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX].type;

    Shiboken::AutoDecRef Sbk_QDirIterator_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDirIterator_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDirIterator",
        "QDirIterator*",
        &Sbk_QDirIterator_spec,
        &Shiboken::callCppDestructor< ::QDirIterator >,
        Sbk_QDirIterator_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDirIterator_TypeF(); // references _Sbk_QDirIterator_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDirIterator_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDirIterator_SignatureBytes, QDirIterator_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDirIterator_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDirIterator_PythonToCpp_QDirIterator_PTR,
        is_QDirIterator_PythonToCpp_QDirIterator_PTR_Convertible,
        QDirIterator_PTR_CppToPython_QDirIterator);

    Shiboken::Conversions::registerConverterName(converter, "QDirIterator");
    Shiboken::Conversions::registerConverterName(converter, "QDirIterator*");
    Shiboken::Conversions::registerConverterName(converter, "QDirIterator&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDirIterator).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDirIterator_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'IteratorFlag'.
    const char *IteratorFlag_Initializer[] = {
        "NoIteratorFlags",
        "FollowSymlinks",
        "Subdirectories",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t IteratorFlag_InitializerValues[] = {
        uint8_t(QDirIterator::IteratorFlag::NoIteratorFlags), //  0x00  0
        uint8_t(QDirIterator::IteratorFlag::FollowSymlinks),  //  0x01  1
        uint8_t(QDirIterator::IteratorFlag::Subdirectories)   //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDirIterator_TypeF(),
        "2:PySide6.QtCore.QDirIterator.IteratorFlag",
        IteratorFlag_Initializer, IteratorFlag_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QDirIterator_IteratorFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDirIterator_IteratorFlag_IDX].type =
        EType;
    // Register converter for enum 'QDirIterator::IteratorFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDirIterator_IteratorFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDirIterator_IteratorFlag,
            is_Enum_PythonToCpp_QDirIterator_IteratorFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDirIterator::IteratorFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "IteratorFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QDirIterator_IteratorFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QDirIterator_IteratorFlag,
            is_Enum_PythonToCpp_QDirIterator_IteratorFlag_Convertible);
        // Register converter for flag 'QFlags<QDirIterator::IteratorFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QDirIterator::IteratorFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QDirIterator::IteratorFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'IteratorFlag' enum/flags.

    qRegisterMetaType< ::QDirIterator *>();
    qRegisterMetaType< ::QDirIterator::IteratorFlag >("QDirIterator::IteratorFlag");

    return pyType;
}
