// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qdirlisting_wrapper.h"

// inner classes
#include "qdirlisting_direntry_wrapper.h"

// Extra includes
#include "qtcorehelper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <qdirlisting.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDirListing_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDirListing >()))
        return -1;

    ::QDirListing *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:QDirListing", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDirListing::QDirListing(QString,QFlags<QDirListing::IteratorFlag>=)
    // 1: QDirListing::QDirListing(QString,QStringList,QFlags<QDirListing::IteratorFlag>=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QDirListing(QString,QFlags<QDirListing::IteratorFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // QDirListing(QString,QStringList,QFlags<QDirListing::IteratorFlag>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDirListing_IteratorFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 1; // QDirListing(QString,QStringList,QFlags<QDirListing::IteratorFlag>)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDirListing_IteratorFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // QDirListing(QString,QFlags<QDirListing::IteratorFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDirListing(const QString &path, QFlags<QDirListing::IteratorFlag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDirListing_IteratorFlag_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QDirListing::IteratorFlag> cppArg1(QDirListing::IteratorFlag::Default);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDirListing(QString,QFlags<QDirListing::IteratorFlag>)
                cptr = new ::QDirListing(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // QDirListing(const QString &path, const QStringList &nameFilters, QFlags<QDirListing::IteratorFlag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDirListing_IteratorFlag_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QStringList cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QDirListing::IteratorFlag> cppArg2(QDirListing::IteratorFlag::Default);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDirListing(QString,QStringList,QFlags<QDirListing::IteratorFlag>)
                cptr = new ::QDirListing(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDirListing >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDirListingFunc___iter__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDirListing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __iter__()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtcore.cpp (qdirlisting-iter)]
        auto result = QtCoreHelper::QDirListingIterator(*cppSelf);
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QDirListingIterator_IDX]), &result);
        // END of custom code block [file: ../glue/qtcore.cpp (qdirlisting-iter)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirListingFunc_iteratorFlags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDirListing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // iteratorFlags()const
        QFlags<QDirListing::IteratorFlag> cppResult = const_cast<const ::QDirListing *>(cppSelf)->iteratorFlags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDirListing_IteratorFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirListingFunc_iteratorPath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDirListing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // iteratorPath()const
        QString cppResult = const_cast<const ::QDirListing *>(cppSelf)->iteratorPath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirListingFunc_nameFilters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDirListing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nameFilters()const
        QStringList cppResult = const_cast<const ::QDirListing *>(cppSelf)->nameFilters();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDirListingFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDirListing *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDirListing::swap(QDirListing&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QDirListing&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDirListing *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QDirListing&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QDirListing_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDirListing_EnumFlagInfo[] = {
    "IteratorFlag:Flag:IteratorFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDirListing_methods[] = {
    {"iteratorFlags", reinterpret_cast<PyCFunction>(Sbk_QDirListingFunc_iteratorFlags), METH_NOARGS, nullptr},
    {"iteratorPath", reinterpret_cast<PyCFunction>(Sbk_QDirListingFunc_iteratorPath), METH_NOARGS, nullptr},
    {"nameFilters", reinterpret_cast<PyCFunction>(Sbk_QDirListingFunc_nameFilters), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QDirListingFunc_swap), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QDirListing_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDirListing_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDirListing_Type = nullptr;
static PyTypeObject *Sbk_QDirListing_TypeF(void)
{
    return _Sbk_QDirListing_Type;
}

static PyType_Slot Sbk_QDirListing_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDirListing_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDirListing_clear)},
    {Py_tp_iter,        reinterpret_cast<void *>(Sbk_QDirListingFunc___iter__)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDirListing_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDirListing_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDirListing_spec = {
    "2:PySide6.QtCore.QDirListing",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDirListing_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDirListing_IteratorFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDirListing::IteratorFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDirListing::IteratorFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDirListing_IteratorFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IteratorFlag_IDX])))
        return Enum_PythonToCpp_QDirListing_IteratorFlag;
    return {};
}

static PyObject *QDirListing_IteratorFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDirListing::IteratorFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDirListing::IteratorFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IteratorFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QDirListing_IteratorFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QDirListing::IteratorFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QDirListing::IteratorFlag> *>(cppOut) = value;

}

static PyObject *QDirListing_IteratorFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QDirListing::IteratorFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IteratorFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDirListing_PythonToCpp_QDirListing_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDirListing_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDirListing_PythonToCpp_QDirListing_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDirListing_TypeF()))
        return QDirListing_PythonToCpp_QDirListing_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDirListing_PTR_CppToPython_QDirListing(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDirListing_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDirListing_SignatureStrings[] = {
    "1:PySide6.QtCore.QDirListing(self,path:QString,flags:PySide6.QtCore.QDirListing.IteratorFlag=QDirListing.IteratorFlag.Default)",
    "0:PySide6.QtCore.QDirListing(self,path:QString,nameFilters:QStringList,flags:PySide6.QtCore.QDirListing.IteratorFlag=QDirListing.IteratorFlag.Default)",
    "PySide6.QtCore.QDirListing.__iter__(self)->PyObject",
    "PySide6.QtCore.QDirListing.iteratorFlags(self)->PySide6.QtCore.QDirListing.IteratorFlag",
    "PySide6.QtCore.QDirListing.iteratorPath(self)->QString",
    "PySide6.QtCore.QDirListing.nameFilters(self)->QStringList",
    "PySide6.QtCore.QDirListing.swap(self,other:PySide6.QtCore.QDirListing)",
    nullptr}; // Sentinel
#else
static constexpr size_t QDirListing_SignatureByteSize = 177;
static constexpr uint8_t QDirListing_SignatureBytes[177] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0x74, 0xc9, 0x2c, 0xf2, 0xc9, 0x2c, 0x2e, 0xc9, 0xcc, 0x4b, 0xd7, 0x28,
    0x4e, 0xcd, 0x49, 0xd3, 0x29, 0x48, 0x2c, 0xc9, 0xb0, 0x0a, 0x0c, 0x2e, 0x29, 0x02, 0x8a, 0xe8,
    0xa4, 0xe5, 0x24, 0xa6, 0x17, 0xe3, 0xd1, 0xa2, 0xe7, 0x59, 0x92, 0x5a, 0x94, 0x58, 0x92, 0x5f,
    0xe4, 0x06, 0x54, 0x68, 0x8b, 0x4b, 0x42, 0xcf, 0x25, 0x35, 0x2d, 0xb1, 0x34, 0xa7, 0x44, 0x93,
    0xcb, 0x80, 0x34, 0xeb, 0xf3, 0x12, 0x73, 0x53, 0xdd, 0x32, 0x73, 0x80, 0x46, 0x15, 0xc3, 0xc4,
    0x40, 0x8a, 0xa9, 0xee, 0x2c, 0x3c, 0x26, 0xc5, 0xc7, 0x67, 0x02, 0xb5, 0xc4, 0xc7, 0x83, 0x5d,
    0xa7, 0xa9, 0x6b, 0x17, 0x50, 0xe9, 0x9f, 0x94, 0x95, 0x9a, 0x5c, 0x82, 0x4f, 0x4f, 0x26, 0x92,
    0x25, 0xc5, 0x08, 0x8d, 0x44, 0xb9, 0x96, 0x18, 0x73, 0x03, 0x80, 0x61, 0x04, 0x33, 0x16, 0x1a,
    0x2c, 0xf8, 0xb4, 0x21, 0x85, 0x22, 0x9a, 0x2e, 0x90, 0x0a, 0x7c, 0x3a, 0x8b, 0xcb, 0x13, 0x0b,
    0x20, 0xd1, 0x92, 0x5f, 0x92, 0x91, 0x5a, 0x84, 0x27, 0xc4, 0x35, 0xb9, 0x00, 0x2f, 0x29, 0xd9,
    0xc8
};
#endif

PyTypeObject *init_QDirListing(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX].type;

    Shiboken::AutoDecRef Sbk_QDirListing_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDirListing_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDirListing",
        "QDirListing*",
        &Sbk_QDirListing_spec,
        &Shiboken::callCppDestructor< ::QDirListing >,
        Sbk_QDirListing_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDirListing_TypeF(); // references _Sbk_QDirListing_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDirListing_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDirListing_SignatureBytes, QDirListing_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDirListing_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDirListing_PythonToCpp_QDirListing_PTR,
        is_QDirListing_PythonToCpp_QDirListing_PTR_Convertible,
        QDirListing_PTR_CppToPython_QDirListing);

    Shiboken::Conversions::registerConverterName(converter, "QDirListing");
    Shiboken::Conversions::registerConverterName(converter, "QDirListing*");
    Shiboken::Conversions::registerConverterName(converter, "QDirListing&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDirListing).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDirListing_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'IteratorFlag'.
    const char *IteratorFlag_Initializer[] = {
        "Default",
        "ExcludeFiles",
        "ExcludeDirs",
        "ExcludeSpecial",
        "ResolveSymlinks",
        "FilesOnly",
        "DirsOnly",
        "IncludeHidden",
        "IncludeDotAndDotDot",
        "CaseSensitive",
        "Recursive",
        "FollowDirSymlinks",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t IteratorFlag_InitializerValues[] = {
        int16_t(QDirListing::IteratorFlag::Default),             //  0x0000  0
        int16_t(QDirListing::IteratorFlag::ExcludeFiles),        //  0x0004  4
        int16_t(QDirListing::IteratorFlag::ExcludeDirs),         //  0x0008  8
        int16_t(QDirListing::IteratorFlag::ExcludeSpecial),      //  0x0010  16
        int16_t(QDirListing::IteratorFlag::ResolveSymlinks),     //  0x0020  32
        int16_t(QDirListing::IteratorFlag::FilesOnly),           //  0x0018  24
        int16_t(QDirListing::IteratorFlag::DirsOnly),            //  0x0014  20
        int16_t(QDirListing::IteratorFlag::IncludeHidden),       //  0x0040  64
        int16_t(QDirListing::IteratorFlag::IncludeDotAndDotDot), //  0x0080  128
        int16_t(QDirListing::IteratorFlag::CaseSensitive),       //  0x0100  256
        int16_t(QDirListing::IteratorFlag::Recursive),           //  0x0400  1024
        int16_t(QDirListing::IteratorFlag::FollowDirSymlinks)    //  0x0800  2048
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDirListing_TypeF(),
        "2:PySide6.QtCore.QDirListing.IteratorFlag",
        IteratorFlag_Initializer, IteratorFlag_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QDirListing_IteratorFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDirListing_IteratorFlag_IDX].type =
        EType;
    // Register converter for enum 'QDirListing::IteratorFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDirListing_IteratorFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDirListing_IteratorFlag,
            is_Enum_PythonToCpp_QDirListing_IteratorFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDirListing::IteratorFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "IteratorFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QDirListing_IteratorFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QDirListing_IteratorFlag,
            is_Enum_PythonToCpp_QDirListing_IteratorFlag_Convertible);
        // Register converter for flag 'QFlags<QDirListing::IteratorFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QDirListing::IteratorFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QDirListing::IteratorFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'IteratorFlag' enum/flags.

    qRegisterMetaType< ::QDirListing *>();
    qRegisterMetaType< ::QDirListing::IteratorFlag >("QDirListing::IteratorFlag");

    return pyType;
}
