// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qeasingcurve_wrapper.h"

// Extra includes
#include <pysideweakref.h>
#include "glue/qeasingcurve_glue.h"

// Argument includes
#include <QList>
#include <qeasingcurve.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QEasingCurve_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QEasingCurve >()))
        return -1;

    ::QEasingCurve *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);

    if (PyArg_ParseTuple(args, "|O:QEasingCurve", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QEasingCurve::QEasingCurve(QEasingCurve::Type=)
    // 1: QEasingCurve::QEasingCurve(QEasingCurve)
    if (numArgs == 0) {
        overloadId = 0; // QEasingCurve(QEasingCurve::Type)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_Type_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QEasingCurve(QEasingCurve::Type)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QEasingCurve(QEasingCurve)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QEasingCurve(QEasingCurve::Type type)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_type = Shiboken::String::createStaticString("type");
                if (PyDict_Contains(kwds, key_type) != 0) {
                    value = PyDict_GetItem(kwds, key_type);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_type);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_Type_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_type);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);
                }
            }
            ::QEasingCurve::Type cppArg0(QEasingCurve::Type::Linear);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QEasingCurve(QEasingCurve::Type)
                cptr = new ::QEasingCurve(cppArg0);
            }
            break;
        }
        case 1: // QEasingCurve(const QEasingCurve &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QEasingCurve cppArg0_local;
            ::QEasingCurve *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QEasingCurve(QEasingCurve)
                cptr = new ::QEasingCurve(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QEasingCurve >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QEasingCurveFunc_addCubicBezierSegment(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addCubicBezierSegment", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QEasingCurve::addCubicBezierSegment(QPointF,QPointF,QPointF)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[2])))) {
        overloadId = 0; // addCubicBezierSegment(QPointF,QPointF,QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addCubicBezierSegment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPointF cppArg1_local;
        ::QPointF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPointF cppArg2_local;
        ::QPointF *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // addCubicBezierSegment(QPointF,QPointF,QPointF)
            cppSelf->addCubicBezierSegment(*cppArg0, *cppArg1, *cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QEasingCurveFunc_addTCBSegment(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addTCBSegment", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QEasingCurve::addTCBSegment(QPointF,qreal,qreal,qreal)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        overloadId = 0; // addTCBSegment(QPointF,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addTCBSegment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        qreal cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        qreal cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addTCBSegment(QPointF,qreal,qreal,qreal)
            cppSelf->addTCBSegment(*cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QEasingCurveFunc_amplitude(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // amplitude()const
        qreal cppResult = const_cast<const ::QEasingCurve *>(cppSelf)->amplitude();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEasingCurveFunc_customType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // customType()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtcore.cpp (qeasingcurve-customtype)]
        //customType()
        pyResult = PySideEasingCurveFunctor::callable(self);
        // END of custom code block [file: ../glue/qtcore.cpp (qeasingcurve-customtype)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEasingCurveFunc_overshoot(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // overshoot()const
        qreal cppResult = const_cast<const ::QEasingCurve *>(cppSelf)->overshoot();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEasingCurveFunc_period(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // period()const
        qreal cppResult = const_cast<const ::QEasingCurve *>(cppSelf)->period();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEasingCurveFunc_setAmplitude(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QEasingCurve::setAmplitude(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setAmplitude(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAmplitude", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAmplitude(qreal)
            cppSelf->setAmplitude(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QEasingCurveFunc_setCustomType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QEasingCurve::setCustomType(PyObject*)
    if (true) {
        overloadId = 0; // setCustomType(PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCustomType", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCustomType(PyObject*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qeasingcurve-setcustomtype)]
            QEasingCurve::EasingFunction func = PySideEasingCurveFunctor::createCustomFunction(self, pyArg);
            if (func)
                cppSelf->setCustomType(func);
            // END of custom code block [file: ../glue/qtcore.cpp (qeasingcurve-setcustomtype)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QEasingCurveFunc_setOvershoot(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QEasingCurve::setOvershoot(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setOvershoot(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOvershoot", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOvershoot(qreal)
            cppSelf->setOvershoot(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QEasingCurveFunc_setPeriod(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QEasingCurve::setPeriod(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setPeriod(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPeriod", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPeriod(qreal)
            cppSelf->setPeriod(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QEasingCurveFunc_setType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QEasingCurve::setType(QEasingCurve::Type)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_Type_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setType(QEasingCurve::Type)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setType", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);

    // Call function/method
    {
        ::QEasingCurve::Type cppArg0{QEasingCurve::Linear};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setType(QEasingCurve::Type)
            cppSelf->setType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QEasingCurveFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QEasingCurve::swap(QEasingCurve&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QEasingCurve&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEasingCurve cppArg0_local;
        ::QEasingCurve *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QEasingCurve&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QEasingCurveFunc_toCubicSpline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toCubicSpline()const
        QList<QPointF> cppResult = const_cast<const ::QEasingCurve *>(cppSelf)->toCubicSpline();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QPointF_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEasingCurveFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QEasingCurve::Type cppResult = const_cast<const ::QEasingCurve *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEasingCurveFunc_valueForProgress(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QEasingCurve::valueForProgress(qreal)const->qreal
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // valueForProgress(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "valueForProgress", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // valueForProgress(qreal)const
            qreal cppResult = const_cast<const ::QEasingCurve *>(cppSelf)->valueForProgress(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEasingCurve__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QEasingCurve_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QEasingCurve_EnumFlagInfo[] = {
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QEasingCurve_methods[] = {
    {"addCubicBezierSegment", reinterpret_cast<PyCFunction>(Sbk_QEasingCurveFunc_addCubicBezierSegment), METH_VARARGS, nullptr},
    {"addTCBSegment", reinterpret_cast<PyCFunction>(Sbk_QEasingCurveFunc_addTCBSegment), METH_VARARGS, nullptr},
    {"amplitude", reinterpret_cast<PyCFunction>(Sbk_QEasingCurveFunc_amplitude), METH_NOARGS, nullptr},
    {"customType", reinterpret_cast<PyCFunction>(Sbk_QEasingCurveFunc_customType), METH_NOARGS, nullptr},
    {"overshoot", reinterpret_cast<PyCFunction>(Sbk_QEasingCurveFunc_overshoot), METH_NOARGS, nullptr},
    {"period", reinterpret_cast<PyCFunction>(Sbk_QEasingCurveFunc_period), METH_NOARGS, nullptr},
    {"setAmplitude", reinterpret_cast<PyCFunction>(Sbk_QEasingCurveFunc_setAmplitude), METH_O, nullptr},
    {"setCustomType", reinterpret_cast<PyCFunction>(Sbk_QEasingCurveFunc_setCustomType), METH_O, nullptr},
    {"setOvershoot", reinterpret_cast<PyCFunction>(Sbk_QEasingCurveFunc_setOvershoot), METH_O, nullptr},
    {"setPeriod", reinterpret_cast<PyCFunction>(Sbk_QEasingCurveFunc_setPeriod), METH_O, nullptr},
    {"setType", reinterpret_cast<PyCFunction>(Sbk_QEasingCurveFunc_setType), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QEasingCurveFunc_swap), METH_O, nullptr},
    {"toCubicSpline", reinterpret_cast<PyCFunction>(Sbk_QEasingCurveFunc_toCubicSpline), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QEasingCurveFunc_type), METH_NOARGS, nullptr},
    {"valueForProgress", reinterpret_cast<PyCFunction>(Sbk_QEasingCurveFunc_valueForProgress), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QEasingCurve__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QEasingCurve_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), (pyArg)))) {
                // operator!=(const QEasingCurve &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QEasingCurve cppArg0_local;
                ::QEasingCurve *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), (pyArg)))) {
                // operator==(const QEasingCurve &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QEasingCurve cppArg0_local;
                ::QEasingCurve *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QEasingCurve_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QEasingCurve_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QEasingCurve__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QEasingCurve_Type = nullptr;
static PyTypeObject *Sbk_QEasingCurve_TypeF(void)
{
    return _Sbk_QEasingCurve_Type;
}

static PyType_Slot Sbk_QEasingCurve_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QEasingCurve__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QEasingCurve_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QEasingCurve_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QEasingCurve_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QEasingCurve_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QEasingCurve_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QEasingCurve_spec = {
    "2:PySide6.QtCore.QEasingCurve",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QEasingCurve_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QEasingCurve_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QEasingCurve::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QEasingCurve::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QEasingCurve_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_Type_IDX])))
        return Enum_PythonToCpp_QEasingCurve_Type;
    return {};
}

static PyObject *QEasingCurve_Type_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QEasingCurve::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QEasingCurve::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_Type_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QEasingCurve_PythonToCpp_QEasingCurve_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QEasingCurve_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QEasingCurve_PythonToCpp_QEasingCurve_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QEasingCurve_TypeF()))
        return QEasingCurve_PythonToCpp_QEasingCurve_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QEasingCurve_PTR_CppToPython_QEasingCurve(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QEasingCurve_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QEasingCurve_COPY_CppToPython_QEasingCurve(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QEasingCurve *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QEasingCurve_TypeF(), new ::QEasingCurve(*source), true, true);
}

// Python to C++ copy conversion.
static void QEasingCurve_PythonToCpp_QEasingCurve_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QEasingCurve *>(cppOut) = *reinterpret_cast< ::QEasingCurve *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QEasingCurve_PythonToCpp_QEasingCurve_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QEasingCurve_TypeF()))
        return QEasingCurve_PythonToCpp_QEasingCurve_COPY;
    return {};
}

// Implicit conversions.
static void QEasingCurve_Type_PythonToCpp_QEasingCurve(PyObject *pyIn, void *cppOut)
{
    ::QEasingCurve::Type cppIn{QEasingCurve::Linear};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_Type_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QEasingCurve *>(cppOut) = ::QEasingCurve(cppIn);
}
static PythonToCppFunc is_QEasingCurve_Type_PythonToCpp_QEasingCurve_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_Type_IDX]), pyIn))
        return QEasingCurve_Type_PythonToCpp_QEasingCurve;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QEasingCurve_SignatureStrings[] = {
    "1:PySide6.QtCore.QEasingCurve(self,type:PySide6.QtCore.QEasingCurve.Type=QEasingCurve.Type.Linear)",
    "0:PySide6.QtCore.QEasingCurve(self,other:PySide6.QtCore.QEasingCurve)",
    "PySide6.QtCore.QEasingCurve.addCubicBezierSegment(self,c1:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint],c2:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint],endPoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint])",
    "PySide6.QtCore.QEasingCurve.addTCBSegment(self,nextPoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint],t:qreal,c:qreal,b:qreal)",
    "PySide6.QtCore.QEasingCurve.amplitude(self)->qreal",
    "PySide6.QtCore.QEasingCurve.customType(self)->PyObject",
    "PySide6.QtCore.QEasingCurve.overshoot(self)->qreal",
    "PySide6.QtCore.QEasingCurve.period(self)->qreal",
    "PySide6.QtCore.QEasingCurve.setAmplitude(self,amplitude:qreal)",
    "PySide6.QtCore.QEasingCurve.setCustomType(self,callable:PyObject)",
    "PySide6.QtCore.QEasingCurve.setOvershoot(self,overshoot:qreal)",
    "PySide6.QtCore.QEasingCurve.setPeriod(self,period:qreal)",
    "PySide6.QtCore.QEasingCurve.setType(self,type:PySide6.QtCore.QEasingCurve.Type)",
    "PySide6.QtCore.QEasingCurve.swap(self,other:typing.Union[PySide6.QtCore.QEasingCurve, PySide6.QtCore.QEasingCurve.Type])",
    "PySide6.QtCore.QEasingCurve.toCubicSpline(self)->QList[PySide6.QtCore.QPointF]",
    "PySide6.QtCore.QEasingCurve.type(self)->PySide6.QtCore.QEasingCurve.Type",
    "PySide6.QtCore.QEasingCurve.valueForProgress(self,progress:qreal)->qreal",
    "PySide6.QtCore.QEasingCurve.__copy__(self)->typing.Self",
    "PySide6.QtCore.QEasingCurve.__ne__(self,rhs:typing.Union[PySide6.QtCore.QEasingCurve, PySide6.QtCore.QEasingCurve.Type])->bool",
    "PySide6.QtCore.QEasingCurve.__eq__(self,rhs:typing.Union[PySide6.QtCore.QEasingCurve, PySide6.QtCore.QEasingCurve.Type])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QEasingCurve_SignatureByteSize = 371;
static constexpr uint8_t QEasingCurve_SignatureBytes[371] = {
    0x78, 0xda, 0xb5, 0x54, 0xcb, 0x6e, 0xc2, 0x30, 0x10, 0xbc, 0xf3, 0x15, 0x3d, 0x16, 0xc9, 0x44,
    0xa5, 0x87, 0x1e, 0x90, 0x8a, 0x54, 0xa2, 0x72, 0x42, 0x22, 0x28, 0xf4, 0x54, 0xa1, 0xc8, 0x71,
    0xb6, 0xc1, 0x95, 0xf1, 0x06, 0xdb, 0xa1, 0x4d, 0xbf, 0xbe, 0x81, 0x84, 0x47, 0xa0, 0xb5, 0x23,
    0xd1, 0x9e, 0xfc, 0xd0, 0xce, 0xec, 0x8c, 0x77, 0xd7, 0xfd, 0x41, 0x50, 0x84, 0x3c, 0x81, 0x07,
    0x6f, 0x66, 0x7c, 0x54, 0xe0, 0xcd, 0x9e, 0xa9, 0xe6, 0x32, 0xf5, 0x73, 0xb5, 0x81, 0x5b, 0x0d,
    0xe2, 0x8d, 0x98, 0x22, 0x03, 0x5b, 0x94, 0x37, 0x2f, 0x03, 0x1e, 0x2f, 0x6e, 0xbc, 0x09, 0x97,
    0x40, 0x55, 0xb7, 0x73, 0xe7, 0x4e, 0x81, 0x66, 0x09, 0xca, 0x16, 0xd6, 0xed, 0xd8, 0x04, 0xd0,
    0x24, 0xf1, 0xf3, 0x98, 0xb3, 0x11, 0x7c, 0x71, 0x50, 0x21, 0xa4, 0x2b, 0x90, 0xa6, 0x62, 0x66,
    0xfd, 0x41, 0xa9, 0xbf, 0x8c, 0xf4, 0x5e, 0x24, 0x47, 0xf9, 0x7a, 0x4e, 0x13, 0x20, 0x97, 0x66,
    0x4c, 0x6e, 0x7e, 0xbc, 0x5f, 0x10, 0x76, 0x7f, 0x15, 0x1c, 0x64, 0xb2, 0xdb, 0x5d, 0x43, 0xe2,
    0xb4, 0x3e, 0xf7, 0x47, 0x0d, 0xcb, 0x12, 0x3e, 0xcd, 0xd5, 0x59, 0x89, 0x19, 0xac, 0x15, 0x50,
    0x41, 0x58, 0xbd, 0xc6, 0xd5, 0xea, 0x50, 0xb3, 0xca, 0x04, 0x37, 0x79, 0x52, 0x95, 0xb5, 0xdb,
    0x1b, 0xee, 0x30, 0x56, 0x08, 0xcb, 0xb5, 0xc1, 0xd5, 0xb6, 0x61, 0xf6, 0x98, 0xa0, 0x98, 0xc6,
    0xef, 0xc0, 0x8c, 0x15, 0x86, 0x1b, 0x50, 0x7a, 0x89, 0x68, 0xda, 0x67, 0xca, 0x40, 0x71, 0x4c,
    0xda, 0xc7, 0x6b, 0x30, 0x4f, 0x0d, 0x3f, 0xe4, 0x60, 0xaf, 0xcd, 0x5b, 0x94, 0x70, 0xbf, 0xe9,
    0x8d, 0x30, 0x2a, 0x04, 0x8d, 0xc5, 0x76, 0x9a, 0x2a, 0x8b, 0x4e, 0x86, 0x69, 0xc3, 0x26, 0x39,
    0xb8, 0x6e, 0x29, 0x20, 0x38, 0x5a, 0x26, 0x95, 0xfd, 0x96, 0xc0, 0xa3, 0xe6, 0x56, 0xd3, 0xef,
    0xe0, 0xfb, 0xa0, 0xd9, 0xe9, 0x9c, 0x5b, 0xdb, 0xf2, 0x04, 0x78, 0xd9, 0x9b, 0xe7, 0x79, 0x1d,
    0xc3, 0x61, 0x70, 0xf7, 0x2d, 0x84, 0x65, 0xd5, 0xe4, 0xa1, 0xbd, 0x66, 0x13, 0xae, 0xcd, 0x2f,
    0xd3, 0xb0, 0xb0, 0xd3, 0x35, 0x9a, 0xd4, 0xae, 0xcc, 0x4a, 0xb4, 0xa1, 0x22, 0x87, 0x31, 0xaa,
    0x40, 0x61, 0xaa, 0x40, 0xeb, 0xba, 0x40, 0xf5, 0xa9, 0x2e, 0x51, 0x9b, 0x16, 0x8d, 0x22, 0x86,
    0x59, 0x11, 0x45, 0x7b, 0x55, 0xf5, 0xcb, 0x86, 0xe5, 0xc9, 0x81, 0x93, 0x50, 0xa3, 0x88, 0x5a,
    0xea, 0x3f, 0xad, 0x48, 0x6f, 0x18, 0x23, 0xba, 0x64, 0xc3, 0xfa, 0x9f, 0xd3, 0x7f, 0x03, 0x5f,
    0x55, 0x76, 0x93
};
#endif

PyTypeObject *init_QEasingCurve(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX].type;

    Shiboken::AutoDecRef Sbk_QEasingCurve_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QEasingCurve_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QEasingCurve",
        "QEasingCurve",
        &Sbk_QEasingCurve_spec,
        &Shiboken::callCppDestructor< ::QEasingCurve >,
        Sbk_QEasingCurve_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QEasingCurve_TypeF(); // references _Sbk_QEasingCurve_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QEasingCurve_SignatureStrings);
#else
    InitSignatureBytes(pyType, QEasingCurve_SignatureBytes, QEasingCurve_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QEasingCurve_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QEasingCurve_PythonToCpp_QEasingCurve_PTR,
        is_QEasingCurve_PythonToCpp_QEasingCurve_PTR_Convertible,
        QEasingCurve_PTR_CppToPython_QEasingCurve,
        QEasingCurve_COPY_CppToPython_QEasingCurve);

    Shiboken::Conversions::registerConverterName(converter, "QEasingCurve");
    Shiboken::Conversions::registerConverterName(converter, "QEasingCurve*");
    Shiboken::Conversions::registerConverterName(converter, "QEasingCurve&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QEasingCurve).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QEasingCurve_PythonToCpp_QEasingCurve_COPY,
        is_QEasingCurve_PythonToCpp_QEasingCurve_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QEasingCurve_Type_PythonToCpp_QEasingCurve,
        is_QEasingCurve_Type_PythonToCpp_QEasingCurve_Convertible);

    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (qeasingcurve)]
    PySideEasingCurveFunctor::init();
    // END of custom code block [file: ../glue/qtcore.cpp (qeasingcurve)]
    // ========================================================================
    // End of code injection


    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QEasingCurve_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "Linear",
        "InQuad",
        "OutQuad",
        "InOutQuad",
        "OutInQuad",
        "InCubic",
        "OutCubic",
        "InOutCubic",
        "OutInCubic",
        "InQuart",
        "OutQuart",
        "InOutQuart",
        "OutInQuart",
        "InQuint",
        "OutQuint",
        "InOutQuint",
        "OutInQuint",
        "InSine",
        "OutSine",
        "InOutSine",
        "OutInSine",
        "InExpo",
        "OutExpo",
        "InOutExpo",
        "OutInExpo",
        "InCirc",
        "OutCirc",
        "InOutCirc",
        "OutInCirc",
        "InElastic",
        "OutElastic",
        "InOutElastic",
        "OutInElastic",
        "InBack",
        "OutBack",
        "InOutBack",
        "OutInBack",
        "InBounce",
        "OutBounce",
        "InOutBounce",
        "OutInBounce",
        "InCurve",
        "OutCurve",
        "SineCurve",
        "CosineCurve",
        "BezierSpline",
        "TCBSpline",
        "Custom",
        "NCurveTypes",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(QEasingCurve::Type::Linear),       //  0x00  0
        uint8_t(QEasingCurve::Type::InQuad),       //  0x01  1
        uint8_t(QEasingCurve::Type::OutQuad),      //  0x02  2
        uint8_t(QEasingCurve::Type::InOutQuad),    //  0x03  3
        uint8_t(QEasingCurve::Type::OutInQuad),    //  0x04  4
        uint8_t(QEasingCurve::Type::InCubic),      //  0x05  5
        uint8_t(QEasingCurve::Type::OutCubic),     //  0x06  6
        uint8_t(QEasingCurve::Type::InOutCubic),   //  0x07  7
        uint8_t(QEasingCurve::Type::OutInCubic),   //  0x08  8
        uint8_t(QEasingCurve::Type::InQuart),      //  0x09  9
        uint8_t(QEasingCurve::Type::OutQuart),     //  0x0a  10
        uint8_t(QEasingCurve::Type::InOutQuart),   //  0x0b  11
        uint8_t(QEasingCurve::Type::OutInQuart),   //  0x0c  12
        uint8_t(QEasingCurve::Type::InQuint),      //  0x0d  13
        uint8_t(QEasingCurve::Type::OutQuint),     //  0x0e  14
        uint8_t(QEasingCurve::Type::InOutQuint),   //  0x0f  15
        uint8_t(QEasingCurve::Type::OutInQuint),   //  0x10  16
        uint8_t(QEasingCurve::Type::InSine),       //  0x11  17
        uint8_t(QEasingCurve::Type::OutSine),      //  0x12  18
        uint8_t(QEasingCurve::Type::InOutSine),    //  0x13  19
        uint8_t(QEasingCurve::Type::OutInSine),    //  0x14  20
        uint8_t(QEasingCurve::Type::InExpo),       //  0x15  21
        uint8_t(QEasingCurve::Type::OutExpo),      //  0x16  22
        uint8_t(QEasingCurve::Type::InOutExpo),    //  0x17  23
        uint8_t(QEasingCurve::Type::OutInExpo),    //  0x18  24
        uint8_t(QEasingCurve::Type::InCirc),       //  0x19  25
        uint8_t(QEasingCurve::Type::OutCirc),      //  0x1a  26
        uint8_t(QEasingCurve::Type::InOutCirc),    //  0x1b  27
        uint8_t(QEasingCurve::Type::OutInCirc),    //  0x1c  28
        uint8_t(QEasingCurve::Type::InElastic),    //  0x1d  29
        uint8_t(QEasingCurve::Type::OutElastic),   //  0x1e  30
        uint8_t(QEasingCurve::Type::InOutElastic), //  0x1f  31
        uint8_t(QEasingCurve::Type::OutInElastic), //  0x20  32
        uint8_t(QEasingCurve::Type::InBack),       //  0x21  33
        uint8_t(QEasingCurve::Type::OutBack),      //  0x22  34
        uint8_t(QEasingCurve::Type::InOutBack),    //  0x23  35
        uint8_t(QEasingCurve::Type::OutInBack),    //  0x24  36
        uint8_t(QEasingCurve::Type::InBounce),     //  0x25  37
        uint8_t(QEasingCurve::Type::OutBounce),    //  0x26  38
        uint8_t(QEasingCurve::Type::InOutBounce),  //  0x27  39
        uint8_t(QEasingCurve::Type::OutInBounce),  //  0x28  40
        uint8_t(QEasingCurve::Type::InCurve),      //  0x29  41
        uint8_t(QEasingCurve::Type::OutCurve),     //  0x2a  42
        uint8_t(QEasingCurve::Type::SineCurve),    //  0x2b  43
        uint8_t(QEasingCurve::Type::CosineCurve),  //  0x2c  44
        uint8_t(QEasingCurve::Type::BezierSpline), //  0x2d  45
        uint8_t(QEasingCurve::Type::TCBSpline),    //  0x2e  46
        uint8_t(QEasingCurve::Type::Custom),       //  0x2f  47
        uint8_t(QEasingCurve::Type::NCurveTypes)   //  0x30  48
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QEasingCurve_TypeF(),
        "2:PySide6.QtCore.QEasingCurve.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_Type_IDX].type = EType;
    // Register converter for enum 'QEasingCurve::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QEasingCurve_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QEasingCurve_Type,
            is_Enum_PythonToCpp_QEasingCurve_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QEasingCurve::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.


    qRegisterMetaType< ::QEasingCurve >("QEasingCurve");
    qRegisterMetaType< ::QEasingCurve::Type >("QEasingCurve::Type");

    return pyType;
}

