// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qelapsedtimer_wrapper.h"

// Argument includes
#include <qelapsedtimer.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QElapsedTimer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QElapsedTimer >()))
        return -1;

    ::QElapsedTimer *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QElapsedTimer", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QElapsedTimer::QElapsedTimer()
    // 1: QElapsedTimer::QElapsedTimer(QElapsedTimer)
    if (numArgs == 0) {
        overloadId = 0; // QElapsedTimer()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QElapsedTimer(QElapsedTimer)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QElapsedTimer()
        {

            // QElapsedTimer()
            cptr = new ::QElapsedTimer();
            break;
        }
        case 1: // QElapsedTimer(const QElapsedTimer &QElapsedTimer)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QElapsedTimer cppArg0_local;
            ::QElapsedTimer *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QElapsedTimer(QElapsedTimer)
                cptr = new ::QElapsedTimer(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QElapsedTimer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QElapsedTimerFunc_clockType(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clockType()
        QElapsedTimer::ClockType cppResult = ::QElapsedTimer::clockType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_ClockType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_elapsed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // elapsed()const
        qint64 cppResult = const_cast<const ::QElapsedTimer *>(cppSelf)->elapsed();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_hasExpired(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QElapsedTimer::hasExpired(qint64)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // hasExpired(qint64)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasExpired", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasExpired(qint64)const
            bool cppResult = const_cast<const ::QElapsedTimer *>(cppSelf)->hasExpired(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_invalidate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invalidate()
        cppSelf->invalidate();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QElapsedTimerFunc_isMonotonic(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isMonotonic()
        bool cppResult = ::QElapsedTimer::isMonotonic();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QElapsedTimer *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_msecsSinceReference(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // msecsSinceReference()const
        qint64 cppResult = const_cast<const ::QElapsedTimer *>(cppSelf)->msecsSinceReference();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_msecsTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QElapsedTimer::msecsTo(QElapsedTimer)const->qint64
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), (pyArg)))) {
        overloadId = 0; // msecsTo(QElapsedTimer)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "msecsTo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QElapsedTimer cppArg0_local;
        ::QElapsedTimer *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // msecsTo(QElapsedTimer)const
            qint64 cppResult = const_cast<const ::QElapsedTimer *>(cppSelf)->msecsTo(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_nsecsElapsed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nsecsElapsed()const
        qint64 cppResult = const_cast<const ::QElapsedTimer *>(cppSelf)->nsecsElapsed();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_restart(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // restart()
        qint64 cppResult = cppSelf->restart();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_secsTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QElapsedTimer::secsTo(QElapsedTimer)const->qint64
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), (pyArg)))) {
        overloadId = 0; // secsTo(QElapsedTimer)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "secsTo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QElapsedTimer cppArg0_local;
        ::QElapsedTimer *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // secsTo(QElapsedTimer)const
            qint64 cppResult = const_cast<const ::QElapsedTimer *>(cppSelf)->secsTo(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_start(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // start()
        cppSelf->start();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QElapsedTimer__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QElapsedTimer_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QElapsedTimer_EnumFlagInfo[] = {
    "ClockType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QElapsedTimer_methods[] = {
    {"clockType", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_clockType), METH_NOARGS|METH_STATIC, nullptr},
    {"elapsed", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_elapsed), METH_NOARGS, nullptr},
    {"hasExpired", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_hasExpired), METH_O, nullptr},
    {"invalidate", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_invalidate), METH_NOARGS, nullptr},
    {"isMonotonic", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_isMonotonic), METH_NOARGS|METH_STATIC, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_isValid), METH_NOARGS, nullptr},
    {"msecsSinceReference", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_msecsSinceReference), METH_NOARGS, nullptr},
    {"msecsTo", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_msecsTo), METH_O, nullptr},
    {"nsecsElapsed", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_nsecsElapsed), METH_NOARGS, nullptr},
    {"restart", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_restart), METH_NOARGS, nullptr},
    {"secsTo", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_secsTo), METH_O, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_start), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimer__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QElapsedTimer_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), (pyArg)))) {
                // operator!=(const QElapsedTimer &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QElapsedTimer cppArg0_local;
                ::QElapsedTimer *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), (pyArg)))) {
                // operator<=(const QElapsedTimer &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QElapsedTimer cppArg0_local;
                ::QElapsedTimer *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), (pyArg)))) {
                // operator==(const QElapsedTimer &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QElapsedTimer cppArg0_local;
                ::QElapsedTimer *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), (pyArg)))) {
                // operator>(const QElapsedTimer &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QElapsedTimer cppArg0_local;
                ::QElapsedTimer *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), (pyArg)))) {
                // operator>=(const QElapsedTimer &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QElapsedTimer cppArg0_local;
                ::QElapsedTimer *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QElapsedTimer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QElapsedTimer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QElapsedTimer_Type = nullptr;
static PyTypeObject *Sbk_QElapsedTimer_TypeF(void)
{
    return _Sbk_QElapsedTimer_Type;
}

static PyType_Slot Sbk_QElapsedTimer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QElapsedTimer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QElapsedTimer_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QElapsedTimer_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QElapsedTimer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QElapsedTimer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QElapsedTimer_spec = {
    "2:PySide6.QtCore.QElapsedTimer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QElapsedTimer_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QElapsedTimer_ClockType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QElapsedTimer::ClockType>(Shiboken::Enum::getValue(pyIn));
    switch (value) {
    case QElapsedTimer::ClockType::TickCounter:
        Shiboken::Warnings::warnDeprecatedEnumValue("QElapsedTimer::ClockType", "TickCounter");
        break;
    default:
        break;
    }
    *reinterpret_cast<::QElapsedTimer::ClockType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QElapsedTimer_ClockType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_ClockType_IDX])))
        return Enum_PythonToCpp_QElapsedTimer_ClockType;
    return {};
}

static PyObject *QElapsedTimer_ClockType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QElapsedTimer::ClockType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QElapsedTimer::ClockType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_ClockType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QElapsedTimer_PythonToCpp_QElapsedTimer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QElapsedTimer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QElapsedTimer_PythonToCpp_QElapsedTimer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QElapsedTimer_TypeF()))
        return QElapsedTimer_PythonToCpp_QElapsedTimer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QElapsedTimer_PTR_CppToPython_QElapsedTimer(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QElapsedTimer_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QElapsedTimer_COPY_CppToPython_QElapsedTimer(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QElapsedTimer *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QElapsedTimer_TypeF(), new ::QElapsedTimer(*source), true, true);
}

// Python to C++ copy conversion.
static void QElapsedTimer_PythonToCpp_QElapsedTimer_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QElapsedTimer *>(cppOut) = *reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QElapsedTimer_PythonToCpp_QElapsedTimer_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QElapsedTimer_TypeF()))
        return QElapsedTimer_PythonToCpp_QElapsedTimer_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QElapsedTimer_SignatureStrings[] = {
    "1:PySide6.QtCore.QElapsedTimer(self)",
    "0:PySide6.QtCore.QElapsedTimer(self,QElapsedTimer:PySide6.QtCore.QElapsedTimer)",
    "PySide6.QtCore.QElapsedTimer.clockType()->PySide6.QtCore.QElapsedTimer.ClockType",
    "PySide6.QtCore.QElapsedTimer.elapsed(self)->qint64",
    "PySide6.QtCore.QElapsedTimer.hasExpired(self,timeout:qint64)->bool",
    "PySide6.QtCore.QElapsedTimer.invalidate(self)",
    "PySide6.QtCore.QElapsedTimer.isMonotonic()->bool",
    "PySide6.QtCore.QElapsedTimer.isValid(self)->bool",
    "PySide6.QtCore.QElapsedTimer.msecsSinceReference(self)->qint64",
    "PySide6.QtCore.QElapsedTimer.msecsTo(self,other:PySide6.QtCore.QElapsedTimer)->qint64",
    "PySide6.QtCore.QElapsedTimer.nsecsElapsed(self)->qint64",
    "PySide6.QtCore.QElapsedTimer.restart(self)->qint64",
    "PySide6.QtCore.QElapsedTimer.secsTo(self,other:PySide6.QtCore.QElapsedTimer)->qint64",
    "PySide6.QtCore.QElapsedTimer.start(self)",
    "PySide6.QtCore.QElapsedTimer.__copy__(self)->typing.Self",
    "PySide6.QtCore.QElapsedTimer.__ne__(self,rhs:PySide6.QtCore.QElapsedTimer)->bool",
    "PySide6.QtCore.QElapsedTimer.__le__(self,rhs:PySide6.QtCore.QElapsedTimer)->bool",
    "PySide6.QtCore.QElapsedTimer.__eq__(self,rhs:PySide6.QtCore.QElapsedTimer)->bool",
    "PySide6.QtCore.QElapsedTimer.__gt__(self,rhs:PySide6.QtCore.QElapsedTimer)->bool",
    "PySide6.QtCore.QElapsedTimer.__ge__(self,rhs:PySide6.QtCore.QElapsedTimer)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QElapsedTimer_SignatureByteSize = 252;
static constexpr uint8_t QElapsedTimer_SignatureBytes[252] = {
    0x78, 0xda, 0xb5, 0x92, 0x31, 0x6b, 0xc3, 0x30, 0x10, 0x85, 0xf7, 0xfc, 0x12, 0x1b, 0x1c, 0xd3,
    0x42, 0xc9, 0x90, 0x21, 0x4b, 0xf0, 0x58, 0x68, 0x6a, 0xd3, 0x55, 0x28, 0xf2, 0x25, 0x3e, 0xa2,
    0xe8, 0x14, 0xe9, 0x5a, 0xea, 0x7f, 0x1f, 0x27, 0xb6, 0x21, 0x5d, 0xa4, 0x18, 0xdc, 0x4d, 0x27,
    0xbd, 0xf7, 0xf1, 0xee, 0x4e, 0xaf, 0xeb, 0x8f, 0xb6, 0xc4, 0x1a, 0x56, 0xf9, 0x8e, 0xb7, 0xe4,
    0x20, 0xdf, 0x15, 0x5a, 0x5a, 0x0f, 0x75, 0x85, 0x67, 0x70, 0x89, 0x07, 0x7d, 0x48, 0x17, 0x2f,
    0x71, 0x51, 0xf6, 0xe7, 0x2a, 0xa8, 0x4f, 0x17, 0xa1, 0xd7, 0x5c, 0x69, 0x52, 0xa7, 0xaa, 0xb5,
    0x90, 0xa4, 0xcb, 0x4d, 0x50, 0xb9, 0x1d, 0x95, 0x61, 0x20, 0xf4, 0x45, 0xdf, 0xcb, 0x72, 0x73,
    0x41, 0xc3, 0xab, 0xb7, 0xb0, 0xa5, 0x91, 0xbe, 0xf8, 0xb5, 0xe8, 0x06, 0x57, 0xc6, 0xdd, 0x2d,
    0x7d, 0xf3, 0xba, 0xf7, 0x76, 0x90, 0x3d, 0x91, 0x0e, 0x23, 0xd0, 0xfc, 0x48, 0x8d, 0xb5, 0x64,
    0x18, 0x86, 0x18, 0x56, 0xfb, 0x77, 0x32, 0xc4, 0x64, 0x50, 0x25, 0xcf, 0xe1, 0xfd, 0xd7, 0x0d,
    0x3f, 0x36, 0x15, 0x37, 0x9c, 0x3d, 0x28, 0x5f, 0xa2, 0x51, 0xf0, 0x09, 0x07, 0x70, 0xd0, 0x1d,
    0xa6, 0x4c, 0xe4, 0x6e, 0xaf, 0xa8, 0x1f, 0x07, 0x71, 0x13, 0xdb, 0xf1, 0x73, 0x54, 0x73, 0xa3,
    0x16, 0xd3, 0xf7, 0xe3, 0xc0, 0xb3, 0x74, 0x3c, 0xc5, 0xf2, 0x2f, 0xf9, 0x1f, 0x52, 0x84, 0x85,
    0x42, 0x28, 0xb2, 0xad, 0x10, 0x63, 0x62, 0x6e, 0x2d, 0x9a, 0x63, 0x5e, 0x76, 0x55, 0xcc, 0x68,
    0x60, 0xb0, 0x65, 0xae, 0xf1, 0xb1, 0xd0, 0xf1, 0x7f, 0x20, 0x84, 0x9e, 0x1b, 0x08, 0x97, 0x99,
    0x81, 0x47, 0x9e, 0x1b, 0x38, 0xb9, 0xe5, 0x2b, 0xd7, 0xa2, 0xcf, 0xa6
};
#endif

PyTypeObject *init_QElapsedTimer(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX].type;

    Shiboken::AutoDecRef Sbk_QElapsedTimer_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QElapsedTimer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QElapsedTimer",
        "QElapsedTimer",
        &Sbk_QElapsedTimer_spec,
        &Shiboken::callCppDestructor< ::QElapsedTimer >,
        Sbk_QElapsedTimer_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QElapsedTimer_TypeF(); // references _Sbk_QElapsedTimer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QElapsedTimer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QElapsedTimer_SignatureBytes, QElapsedTimer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QElapsedTimer_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QElapsedTimer_PythonToCpp_QElapsedTimer_PTR,
        is_QElapsedTimer_PythonToCpp_QElapsedTimer_PTR_Convertible,
        QElapsedTimer_PTR_CppToPython_QElapsedTimer,
        QElapsedTimer_COPY_CppToPython_QElapsedTimer);

    Shiboken::Conversions::registerConverterName(converter, "QElapsedTimer");
    Shiboken::Conversions::registerConverterName(converter, "QElapsedTimer*");
    Shiboken::Conversions::registerConverterName(converter, "QElapsedTimer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QElapsedTimer).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QElapsedTimer_PythonToCpp_QElapsedTimer_COPY,
        is_QElapsedTimer_PythonToCpp_QElapsedTimer_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QElapsedTimer_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ClockType'.
    const char *ClockType_Initializer[] = {
        "SystemTime",
        "MonotonicClock",
        "TickCounter",
        "MachAbsoluteTime",
        "PerformanceCounter",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ClockType_InitializerValues[] = {
        uint8_t(QElapsedTimer::ClockType::SystemTime),        //  0x00  0
        uint8_t(QElapsedTimer::ClockType::MonotonicClock),    //  0x01  1
        uint8_t(QElapsedTimer::ClockType::TickCounter),       //  0x02  2
        uint8_t(QElapsedTimer::ClockType::MachAbsoluteTime),  //  0x03  3
        uint8_t(QElapsedTimer::ClockType::PerformanceCounter) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QElapsedTimer_TypeF(),
        "2:PySide6.QtCore.QElapsedTimer.ClockType",
        ClockType_Initializer, ClockType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_ClockType_IDX].type = EType;
    // Register converter for enum 'QElapsedTimer::ClockType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QElapsedTimer_ClockType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QElapsedTimer_ClockType,
            is_Enum_PythonToCpp_QElapsedTimer_ClockType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QElapsedTimer::ClockType");
        Shiboken::Conversions::registerConverterAlias(converter, "ClockType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ClockType' enum.

    qRegisterMetaType< ::QElapsedTimer >("QElapsedTimer");
    qRegisterMetaType< ::QElapsedTimer::ClockType >("QElapsedTimer::ClockType");

    return pyType;
}
