// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qfileinfo_wrapper.h"

// Extra includes
#include <QDateTime>
#include <QDir>

// Argument includes
#include <QString>
#include <qdatetime.h>
#include <qdir.h>
#include <qfiledevice.h>
#include <qfileinfo.h>
#include <qtimezone.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFileInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFileInfo >()))
        return -1;

    ::QFileInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QFileInfo", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QFileInfo::QFileInfo()
    // 1: QFileInfo::QFileInfo(QDir,PyPathLike)
    // 2: QFileInfo::QFileInfo(QFileDevice)
    // 3: QFileInfo::QFileInfo(QFileInfo)
    // 4: QFileInfo::QFileInfo(PyPathLike)
    if (numArgs == 0) {
        overloadId = 0; // QFileInfo()
    } else if (numArgs == 1
        && Shiboken::String::checkPath(pyArgs[0])) {
        overloadId = 4; // QFileInfo(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QFileInfo(QFileInfo)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QFileInfo(QFileDevice)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), (pyArgs[0])))
        && Shiboken::String::checkPath(pyArgs[1])) {
        overloadId = 1; // QFileInfo(QDir,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QFileInfo()
        {

            // QFileInfo()
            cptr = new ::QFileInfo();
            break;
        }
        case 1: // QFileInfo(const QDir &dir, const QString &file)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDir cppArg0_local;
            ::QDir *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QFileInfo(QDir,QString)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-2)]
                auto cppArg1 = PySide::pyPathToQString(pyArgs[2-1]);
                // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-2)]
                // ========================================================================
                // End of code injection

                cptr = new ::QFileInfo(*cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QFileInfo(const QFileDevice &file)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QFileDevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFileInfo(QFileDevice)
                cptr = new ::QFileInfo(*cppArg0);
            }
            break;
        }
        case 3: // QFileInfo(const QFileInfo &fileinfo)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QFileInfo cppArg0_local;
            ::QFileInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QFileInfo(QFileInfo)
                cptr = new ::QFileInfo(*cppArg0);
            }
            break;
        }
        case 4: // QFileInfo(const QString &file)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFileInfo(QString)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                auto cppArg0 = PySide::pyPathToQString(pyArgs[1-1]);
                // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                // ========================================================================
                // End of code injection

                cptr = new ::QFileInfo(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QFileInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QFileInfoFunc___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __reduce__()
        // Begin code injection
        // TEMPLATE - reduce_code - START
        pyResult = Py_BuildValue("(N(s))", PyObject_Type(self), qPrintable(cppSelf->filePath()));
        // TEMPLATE - reduce_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_absoluteDir(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // absoluteDir()const
        QDir cppResult = const_cast<const ::QFileInfo *>(cppSelf)->absoluteDir();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_absoluteFilePath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // absoluteFilePath()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->absoluteFilePath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_absolutePath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // absolutePath()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->absolutePath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_baseName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // baseName()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->baseName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_birthTime(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "birthTime", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileInfo::birthTime()const->QDateTime
    // 1: QFileInfo::birthTime(QTimeZone)const->QDateTime
    if (numArgs == 0) {
        overloadId = 0; // birthTime()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))) {
        overloadId = 1; // birthTime(QTimeZone)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "birthTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // birthTime() const
        {

            // birthTime()const
            QDateTime cppResult = const_cast<const ::QFileInfo *>(cppSelf)->birthTime();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            break;
        }
        case 1: // birthTime(const QTimeZone &tz) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTimeZone cppArg0_local;
            ::QTimeZone *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // birthTime(QTimeZone)const
                QDateTime cppResult = const_cast<const ::QFileInfo *>(cppSelf)->birthTime(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_bundleName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bundleName()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->bundleName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_caching(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // caching()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->caching();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_canonicalFilePath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // canonicalFilePath()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->canonicalFilePath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_canonicalPath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // canonicalPath()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->canonicalPath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_completeBaseName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // completeBaseName()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->completeBaseName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_completeSuffix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // completeSuffix()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->completeSuffix();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_dir(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dir()const
        QDir cppResult = const_cast<const ::QFileInfo *>(cppSelf)->dir();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_exists(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QFileInfo *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "exists", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileInfo::exists()const->bool
    // 1: static QFileInfo::exists(QString)->bool
    if (numArgs == 0) {
        overloadId = 0; // exists()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // exists(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "exists", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // exists() const
        {

            // exists()const
            bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->exists();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            break;
        }
        case 1: // exists(const QString &file)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // exists(QString)
                bool cppResult = ::QFileInfo::exists(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_fileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileName()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->fileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_filePath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // filePath()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->filePath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_fileTime(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "fileTime", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileInfo::fileTime(QFileDevice::FileTime)const->QDateTime
    // 1: QFileInfo::fileTime(QFileDevice::FileTime,QTimeZone)const->QDateTime
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_FileTime_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fileTime(QFileDevice::FileTime)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
            overloadId = 1; // fileTime(QFileDevice::FileTime,QTimeZone)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fileTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // fileTime(QFileDevice::FileTime time) const
        {
            ::QFileDevice::FileTime cppArg0{QFileDevice::FileAccessTime};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fileTime(QFileDevice::FileTime)const
                QDateTime cppResult = const_cast<const ::QFileInfo *>(cppSelf)->fileTime(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            }
            break;
        }
        case 1: // fileTime(QFileDevice::FileTime time, const QTimeZone &tz) const
        {
            ::QFileDevice::FileTime cppArg0{QFileDevice::FileAccessTime};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTimeZone cppArg1_local;
            ::QTimeZone *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // fileTime(QFileDevice::FileTime,QTimeZone)const
                QDateTime cppResult = const_cast<const ::QFileInfo *>(cppSelf)->fileTime(cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_group(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // group()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->group();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_groupId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // groupId()const
        uint cppResult = const_cast<const ::QFileInfo *>(cppSelf)->groupId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isAbsolute(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAbsolute()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isAbsolute();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isAlias(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAlias()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isAlias();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isBundle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isBundle()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isBundle();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isDir(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDir()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isDir();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isExecutable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isExecutable()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isExecutable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isFile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFile()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isFile();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isHidden(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isHidden()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isHidden();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isJunction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isJunction()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isJunction();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isNativePath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNativePath()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isNativePath();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isReadable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isReadable()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isReadable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isRelative(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRelative()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isRelative();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isRoot(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRoot()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isRoot();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isShortcut(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isShortcut()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isShortcut();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isSymLink(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSymLink()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isSymLink();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isSymbolicLink(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSymbolicLink()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isSymbolicLink();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_isWritable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isWritable()const
        bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->isWritable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_junctionTarget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // junctionTarget()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->junctionTarget();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_lastModified(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "lastModified", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileInfo::lastModified()const->QDateTime
    // 1: QFileInfo::lastModified(QTimeZone)const->QDateTime
    if (numArgs == 0) {
        overloadId = 0; // lastModified()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))) {
        overloadId = 1; // lastModified(QTimeZone)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "lastModified", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // lastModified() const
        {

            // lastModified()const
            QDateTime cppResult = const_cast<const ::QFileInfo *>(cppSelf)->lastModified();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            break;
        }
        case 1: // lastModified(const QTimeZone &tz) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTimeZone cppArg0_local;
            ::QTimeZone *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // lastModified(QTimeZone)const
                QDateTime cppResult = const_cast<const ::QFileInfo *>(cppSelf)->lastModified(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_lastRead(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "lastRead", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileInfo::lastRead()const->QDateTime
    // 1: QFileInfo::lastRead(QTimeZone)const->QDateTime
    if (numArgs == 0) {
        overloadId = 0; // lastRead()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))) {
        overloadId = 1; // lastRead(QTimeZone)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "lastRead", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // lastRead() const
        {

            // lastRead()const
            QDateTime cppResult = const_cast<const ::QFileInfo *>(cppSelf)->lastRead();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            break;
        }
        case 1: // lastRead(const QTimeZone &tz) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTimeZone cppArg0_local;
            ::QTimeZone *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // lastRead(QTimeZone)const
                QDateTime cppResult = const_cast<const ::QFileInfo *>(cppSelf)->lastRead(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_makeAbsolute(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // makeAbsolute()
        bool cppResult = cppSelf->makeAbsolute();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_metadataChangeTime(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "metadataChangeTime", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileInfo::metadataChangeTime()const->QDateTime
    // 1: QFileInfo::metadataChangeTime(QTimeZone)const->QDateTime
    if (numArgs == 0) {
        overloadId = 0; // metadataChangeTime()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))) {
        overloadId = 1; // metadataChangeTime(QTimeZone)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "metadataChangeTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // metadataChangeTime() const
        {

            // metadataChangeTime()const
            QDateTime cppResult = const_cast<const ::QFileInfo *>(cppSelf)->metadataChangeTime();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            break;
        }
        case 1: // metadataChangeTime(const QTimeZone &tz) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTimeZone cppArg0_local;
            ::QTimeZone *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // metadataChangeTime(QTimeZone)const
                QDateTime cppResult = const_cast<const ::QFileInfo *>(cppSelf)->metadataChangeTime(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_owner(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // owner()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->owner();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_ownerId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ownerId()const
        uint cppResult = const_cast<const ::QFileInfo *>(cppSelf)->ownerId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_path(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // path()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->path();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_permission(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileInfo::permission(QFlags<QFileDevice::Permission>)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_Permission_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // permission(QFlags<QFileDevice::Permission>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "permission", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]);

    // Call function/method
    {
        ::QFlags<QFileDevice::Permission> cppArg0 = QFlags<QFileDevice::Permission>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // permission(QFlags<QFileDevice::Permission>)const
            bool cppResult = const_cast<const ::QFileInfo *>(cppSelf)->permission(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_permissions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // permissions()const
        QFlags<QFileDevice::Permission> cppResult = const_cast<const ::QFileInfo *>(cppSelf)->permissions();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_Permission_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_readSymLink(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readSymLink()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->readSymLink();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_refresh(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // refresh()
        cppSelf->refresh();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileInfoFunc_setCaching(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileInfo::setCaching(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setCaching(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCaching", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCaching(bool)
            cppSelf->setCaching(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileInfoFunc_setFile(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setFile", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileInfo::setFile(QDir,QString)
    // 1: QFileInfo::setFile(QFileDevice)
    // 2: QFileInfo::setFile(PyPathLike)
    if (numArgs == 1
        && Shiboken::String::checkPath(pyArgs[0])) {
        overloadId = 2; // setFile(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), (pyArgs[0])))) {
        overloadId = 1; // setFile(QFileDevice)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // setFile(QDir,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFile", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setFile(const QDir &dir, const QString &file)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDir cppArg0_local;
            ::QDir *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setFile(QDir,QString)
                cppSelf->setFile(*cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setFile(const QFileDevice &file)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QFileDevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setFile(QFileDevice)
                cppSelf->setFile(*cppArg0);
            }
            break;
        }
        case 2: // setFile(const QString &file)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // setFile(QString)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                auto cppArg0 = PySide::pyPathToQString(pyArgs[1-1]);
                // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
                // ========================================================================
                // End of code injection

                cppSelf->setFile(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileInfoFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        qint64 cppResult = const_cast<const ::QFileInfo *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_stat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stat()
        cppSelf->stat();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileInfoFunc_suffix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // suffix()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->suffix();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfoFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileInfo::swap(QFileInfo&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QFileInfo&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFileInfo cppArg0_local;
        ::QFileInfo *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QFileInfo&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileInfoFunc_symLinkTarget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // symLinkTarget()const
        QString cppResult = const_cast<const ::QFileInfo *>(cppSelf)->symLinkTarget();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QFileInfoMethod_exists = {"exists", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_exists), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_QFileInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFileInfo_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc___reduce__), METH_NOARGS, nullptr},
    {"absoluteDir", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_absoluteDir), METH_NOARGS, nullptr},
    {"absoluteFilePath", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_absoluteFilePath), METH_NOARGS, nullptr},
    {"absolutePath", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_absolutePath), METH_NOARGS, nullptr},
    {"baseName", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_baseName), METH_NOARGS, nullptr},
    {"birthTime", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_birthTime), METH_VARARGS, nullptr},
    {"bundleName", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_bundleName), METH_NOARGS, nullptr},
    {"caching", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_caching), METH_NOARGS, nullptr},
    {"canonicalFilePath", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_canonicalFilePath), METH_NOARGS, nullptr},
    {"canonicalPath", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_canonicalPath), METH_NOARGS, nullptr},
    {"completeBaseName", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_completeBaseName), METH_NOARGS, nullptr},
    {"completeSuffix", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_completeSuffix), METH_NOARGS, nullptr},
    {"dir", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_dir), METH_NOARGS, nullptr},
    {"exists", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_exists), METH_VARARGS|METH_STATIC, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_fileName), METH_NOARGS, nullptr},
    {"filePath", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_filePath), METH_NOARGS, nullptr},
    {"fileTime", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_fileTime), METH_VARARGS, nullptr},
    {"group", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_group), METH_NOARGS, nullptr},
    {"groupId", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_groupId), METH_NOARGS, nullptr},
    {"isAbsolute", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isAbsolute), METH_NOARGS, nullptr},
    {"isAlias", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isAlias), METH_NOARGS, nullptr},
    {"isBundle", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isBundle), METH_NOARGS, nullptr},
    {"isDir", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isDir), METH_NOARGS, nullptr},
    {"isExecutable", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isExecutable), METH_NOARGS, nullptr},
    {"isFile", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isFile), METH_NOARGS, nullptr},
    {"isHidden", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isHidden), METH_NOARGS, nullptr},
    {"isJunction", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isJunction), METH_NOARGS, nullptr},
    {"isNativePath", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isNativePath), METH_NOARGS, nullptr},
    {"isReadable", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isReadable), METH_NOARGS, nullptr},
    {"isRelative", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isRelative), METH_NOARGS, nullptr},
    {"isRoot", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isRoot), METH_NOARGS, nullptr},
    {"isShortcut", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isShortcut), METH_NOARGS, nullptr},
    {"isSymLink", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isSymLink), METH_NOARGS, nullptr},
    {"isSymbolicLink", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isSymbolicLink), METH_NOARGS, nullptr},
    {"isWritable", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_isWritable), METH_NOARGS, nullptr},
    {"junctionTarget", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_junctionTarget), METH_NOARGS, nullptr},
    {"lastModified", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_lastModified), METH_VARARGS, nullptr},
    {"lastRead", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_lastRead), METH_VARARGS, nullptr},
    {"makeAbsolute", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_makeAbsolute), METH_NOARGS, nullptr},
    {"metadataChangeTime", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_metadataChangeTime), METH_VARARGS, nullptr},
    {"owner", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_owner), METH_NOARGS, nullptr},
    {"ownerId", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_ownerId), METH_NOARGS, nullptr},
    {"path", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_path), METH_NOARGS, nullptr},
    {"permission", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_permission), METH_O, nullptr},
    {"permissions", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_permissions), METH_NOARGS, nullptr},
    {"readSymLink", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_readSymLink), METH_NOARGS, nullptr},
    {"refresh", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_refresh), METH_NOARGS, nullptr},
    {"setCaching", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_setCaching), METH_O, nullptr},
    {"setFile", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_setFile), METH_VARARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_size), METH_NOARGS, nullptr},
    {"stat", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_stat), METH_NOARGS, nullptr},
    {"suffix", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_suffix), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_swap), METH_O, nullptr},
    {"symLinkTarget", reinterpret_cast<PyCFunction>(Sbk_QFileInfoFunc_symLinkTarget), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QFileInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QFileInfo_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QFileInfoMethod_exists = {
        Sbk_QFileInfoMethod_exists.ml_name,
        Sbk_QFileInfoMethod_exists.ml_meth,
        Sbk_QFileInfoMethod_exists.ml_flags & (~METH_STATIC),
        Sbk_QFileInfoMethod_exists.ml_doc,
    };
    if (Shiboken::String::compare(name, "exists") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QFileInfoMethod_exists, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

// Rich comparison
static PyObject * Sbk_QFileInfo_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), (pyArg)))) {
                // operator!=(const QFileInfo &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QFileInfo cppArg0_local;
                ::QFileInfo *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), (pyArg)))) {
                // operator==(const QFileInfo &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QFileInfo cppArg0_local;
                ::QFileInfo *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QFileInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFileInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QFileInfo__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFileInfo_Type = nullptr;
static PyTypeObject *Sbk_QFileInfo_TypeF(void)
{
    return _Sbk_QFileInfo_Type;
}

static PyType_Slot Sbk_QFileInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QFileInfo__repr__)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QFileInfo_getattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFileInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFileInfo_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QFileInfo_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFileInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFileInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFileInfo_spec = {
    "2:PySide6.QtCore.QFileInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFileInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFileInfo_PythonToCpp_QFileInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFileInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFileInfo_PythonToCpp_QFileInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFileInfo_TypeF()))
        return QFileInfo_PythonToCpp_QFileInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFileInfo_PTR_CppToPython_QFileInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QFileInfo_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QFileInfo_COPY_CppToPython_QFileInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QFileInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QFileInfo_TypeF(), new ::QFileInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QFileInfo_PythonToCpp_QFileInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QFileInfo *>(cppOut) = *reinterpret_cast< ::QFileInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QFileInfo_PythonToCpp_QFileInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QFileInfo_TypeF()))
        return QFileInfo_PythonToCpp_QFileInfo_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFileInfo_SignatureStrings[] = {
    "4:PySide6.QtCore.QFileInfo(self)",
    "3:PySide6.QtCore.QFileInfo(self,dir:PySide6.QtCore.QDir,file:PyPathLike)",
    "2:PySide6.QtCore.QFileInfo(self,file:PySide6.QtCore.QFileDevice)",
    "1:PySide6.QtCore.QFileInfo(self,fileinfo:PySide6.QtCore.QFileInfo)",
    "0:PySide6.QtCore.QFileInfo(self,file:PyPathLike)",
    "PySide6.QtCore.QFileInfo.__reduce__(self)->str",
    "PySide6.QtCore.QFileInfo.absoluteDir(self)->PySide6.QtCore.QDir",
    "PySide6.QtCore.QFileInfo.absoluteFilePath(self)->QString",
    "PySide6.QtCore.QFileInfo.absolutePath(self)->QString",
    "PySide6.QtCore.QFileInfo.baseName(self)->QString",
    "1:PySide6.QtCore.QFileInfo.birthTime(self)->PySide6.QtCore.QDateTime",
    "0:PySide6.QtCore.QFileInfo.birthTime(self,tz:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->PySide6.QtCore.QDateTime",
    "PySide6.QtCore.QFileInfo.bundleName(self)->QString",
    "PySide6.QtCore.QFileInfo.caching(self)->bool",
    "PySide6.QtCore.QFileInfo.canonicalFilePath(self)->QString",
    "PySide6.QtCore.QFileInfo.canonicalPath(self)->QString",
    "PySide6.QtCore.QFileInfo.completeBaseName(self)->QString",
    "PySide6.QtCore.QFileInfo.completeSuffix(self)->QString",
    "PySide6.QtCore.QFileInfo.dir(self)->PySide6.QtCore.QDir",
    "1:PySide6.QtCore.QFileInfo.exists(self)->bool",
    "0:PySide6.QtCore.QFileInfo.exists(file:QString)->bool",
    "PySide6.QtCore.QFileInfo.fileName(self)->QString",
    "PySide6.QtCore.QFileInfo.filePath(self)->QString",
    "1:PySide6.QtCore.QFileInfo.fileTime(self,time:PySide6.QtCore.QFileDevice.FileTime)->PySide6.QtCore.QDateTime",
    "0:PySide6.QtCore.QFileInfo.fileTime(self,time:PySide6.QtCore.QFileDevice.FileTime,tz:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->PySide6.QtCore.QDateTime",
    "PySide6.QtCore.QFileInfo.group(self)->QString",
    "PySide6.QtCore.QFileInfo.groupId(self)->uint",
    "PySide6.QtCore.QFileInfo.isAbsolute(self)->bool",
    "PySide6.QtCore.QFileInfo.isAlias(self)->bool",
    "PySide6.QtCore.QFileInfo.isBundle(self)->bool",
    "PySide6.QtCore.QFileInfo.isDir(self)->bool",
    "PySide6.QtCore.QFileInfo.isExecutable(self)->bool",
    "PySide6.QtCore.QFileInfo.isFile(self)->bool",
    "PySide6.QtCore.QFileInfo.isHidden(self)->bool",
    "PySide6.QtCore.QFileInfo.isJunction(self)->bool",
    "PySide6.QtCore.QFileInfo.isNativePath(self)->bool",
    "PySide6.QtCore.QFileInfo.isReadable(self)->bool",
    "PySide6.QtCore.QFileInfo.isRelative(self)->bool",
    "PySide6.QtCore.QFileInfo.isRoot(self)->bool",
    "PySide6.QtCore.QFileInfo.isShortcut(self)->bool",
    "PySide6.QtCore.QFileInfo.isSymLink(self)->bool",
    "PySide6.QtCore.QFileInfo.isSymbolicLink(self)->bool",
    "PySide6.QtCore.QFileInfo.isWritable(self)->bool",
    "PySide6.QtCore.QFileInfo.junctionTarget(self)->QString",
    "1:PySide6.QtCore.QFileInfo.lastModified(self)->PySide6.QtCore.QDateTime",
    "0:PySide6.QtCore.QFileInfo.lastModified(self,tz:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->PySide6.QtCore.QDateTime",
    "1:PySide6.QtCore.QFileInfo.lastRead(self)->PySide6.QtCore.QDateTime",
    "0:PySide6.QtCore.QFileInfo.lastRead(self,tz:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->PySide6.QtCore.QDateTime",
    "PySide6.QtCore.QFileInfo.makeAbsolute(self)->bool",
    "1:PySide6.QtCore.QFileInfo.metadataChangeTime(self)->PySide6.QtCore.QDateTime",
    "0:PySide6.QtCore.QFileInfo.metadataChangeTime(self,tz:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->PySide6.QtCore.QDateTime",
    "PySide6.QtCore.QFileInfo.owner(self)->QString",
    "PySide6.QtCore.QFileInfo.ownerId(self)->uint",
    "PySide6.QtCore.QFileInfo.path(self)->QString",
    "PySide6.QtCore.QFileInfo.permission(self,permissions:PySide6.QtCore.QFileDevice.Permission)->bool",
    "PySide6.QtCore.QFileInfo.permissions(self)->PySide6.QtCore.QFileDevice.Permission",
    "PySide6.QtCore.QFileInfo.readSymLink(self)->QString",
    "PySide6.QtCore.QFileInfo.refresh(self)",
    "PySide6.QtCore.QFileInfo.setCaching(self,on:bool)",
    "2:PySide6.QtCore.QFileInfo.setFile(self,dir:PySide6.QtCore.QDir,file:QString)",
    "1:PySide6.QtCore.QFileInfo.setFile(self,file:PySide6.QtCore.QFileDevice)",
    "0:PySide6.QtCore.QFileInfo.setFile(self,file:PyPathLike)",
    "PySide6.QtCore.QFileInfo.size(self)->qint64",
    "PySide6.QtCore.QFileInfo.stat(self)",
    "PySide6.QtCore.QFileInfo.suffix(self)->QString",
    "PySide6.QtCore.QFileInfo.swap(self,other:PySide6.QtCore.QFileInfo)",
    "PySide6.QtCore.QFileInfo.symLinkTarget(self)->QString",
    "PySide6.QtCore.QFileInfo.__copy__(self)->typing.Self",
    "PySide6.QtCore.QFileInfo.__ne__(self,rhs:PySide6.QtCore.QFileInfo)->bool",
    "PySide6.QtCore.QFileInfo.__eq__(self,rhs:PySide6.QtCore.QFileInfo)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QFileInfo_SignatureByteSize = 677;
static constexpr uint8_t QFileInfo_SignatureBytes[677] = {
    0x78, 0xda, 0xcd, 0x97, 0x4d, 0x4f, 0xdb, 0x40, 0x10, 0x86, 0xef, 0xf9, 0x15, 0x3d, 0x16, 0xc9,
    0xb5, 0xd2, 0x16, 0x71, 0xc8, 0xa1, 0x52, 0x09, 0x45, 0x4d, 0x45, 0x11, 0x10, 0xaa, 0x4a, 0xad,
    0xaa, 0x68, 0x6d, 0x8f, 0xe3, 0x29, 0xce, 0xae, 0xd9, 0x1d, 0x03, 0xc9, 0xaf, 0xef, 0x3a, 0xd8,
    0x49, 0x48, 0xb2, 0x5f, 0x20, 0x55, 0xdc, 0xe2, 0xf8, 0x79, 0xc7, 0xbb, 0xf3, 0xb5, 0x3b, 0x87,
    0x83, 0x8b, 0xf9, 0x18, 0x33, 0x38, 0x8a, 0x2f, 0x69, 0x28, 0x24, 0xc4, 0x97, 0xa7, 0x58, 0xc2,
    0x88, 0xe7, 0xe2, 0xad, 0x82, 0x32, 0x3f, 0xe8, 0x7d, 0xb4, 0x03, 0x51, 0x86, 0x72, 0x87, 0x38,
    0x41, 0x19, 0xe5, 0x9a, 0xd2, 0x2f, 0x2e, 0x18, 0x15, 0x67, 0x78, 0x03, 0x07, 0xbd, 0x0f, 0x0e,
    0x43, 0xad, 0x60, 0x17, 0x39, 0x81, 0x3b, 0x4c, 0xb5, 0x81, 0xf7, 0x1e, 0x06, 0x50, 0x3f, 0x19,
    0xb1, 0x83, 0x5e, 0xdf, 0x6f, 0x0d, 0xeb, 0x45, 0x9b, 0xf0, 0x78, 0x32, 0x91, 0x90, 0xd5, 0x29,
    0x4c, 0x26, 0x8f, 0x7e, 0x7a, 0xf7, 0x49, 0x91, 0x34, 0xe3, 0x2c, 0x51, 0xa2, 0xac, 0x09, 0xb4,
    0x67, 0x3a, 0x7e, 0x8f, 0xd3, 0xdc, 0xfa, 0xe6, 0x8f, 0x66, 0x75, 0x9d, 0x91, 0xcb, 0x31, 0x49,
    0xe4, 0x53, 0xb7, 0x30, 0x48, 0x94, 0x30, 0x05, 0xe7, 0x6c, 0x06, 0xdb, 0x02, 0x73, 0x04, 0xe2,
    0x04, 0x25, 0x15, 0xd7, 0xb8, 0xd6, 0xec, 0x6c, 0x8f, 0x11, 0x34, 0xef, 0x2d, 0x31, 0xd8, 0x32,
    0x12, 0xd1, 0x62, 0x40, 0xf3, 0x4a, 0x7f, 0x38, 0xfe, 0xc1, 0x51, 0xf0, 0xdf, 0xdb, 0xba, 0x86,
    0xfc, 0x25, 0x38, 0x44, 0x6f, 0x4c, 0x6f, 0xe2, 0x11, 0x47, 0x42, 0x56, 0xe2, 0x82, 0x91, 0xb6,
    0xf0, 0xc7, 0xb6, 0x2e, 0xf3, 0xaa, 0x6a, 0x9e, 0x95, 0x7b, 0xfd, 0x61, 0x94, 0xa4, 0x2c, 0x2d,
    0x34, 0xd0, 0xf1, 0x89, 0x10, 0xa5, 0x0d, 0xe6, 0x82, 0x63, 0xca, 0xca, 0xe0, 0xe0, 0xae, 0x94,
    0x61, 0x2a, 0x31, 0xab, 0x4a, 0x20, 0x38, 0x36, 0x44, 0xd9, 0x29, 0x1c, 0xd7, 0x79, 0x8e, 0x0f,
    0xde, 0xb2, 0xcc, 0x9e, 0xf3, 0x96, 0xa4, 0x82, 0x07, 0x54, 0xa4, 0x9e, 0x78, 0xb1, 0xef, 0xa4,
    0x97, 0x35, 0xdc, 0x2e, 0xca, 0xe9, 0xfb, 0x06, 0x0e, 0xf2, 0x41, 0x6e, 0x88, 0x91, 0x65, 0x17,
    0x8d, 0x64, 0x23, 0xa9, 0xf5, 0x2f, 0x4b, 0x9b, 0x8b, 0x4f, 0x5b, 0xfa, 0x99, 0x25, 0xf4, 0xbc,
    0x8f, 0xbd, 0x96, 0x52, 0x9b, 0x4a, 0x51, 0x57, 0xde, 0xb1, 0x58, 0xd2, 0xa3, 0xac, 0xe3, 0x6b,
    0xe4, 0x64, 0x86, 0x51, 0x7d, 0x6e, 0x5b, 0xa1, 0x5f, 0x55, 0x6a, 0xbe, 0x44, 0xa6, 0x7c, 0xe1,
    0xe3, 0x65, 0x93, 0xf0, 0xa5, 0x37, 0x8e, 0x01, 0x17, 0xfa, 0xe5, 0x01, 0xd2, 0x9a, 0x58, 0xe2,
    0x6f, 0xbc, 0xf9, 0xe9, 0xcb, 0x7e, 0xc5, 0x2c, 0x03, 0xee, 0x4b, 0x7f, 0xab, 0x79, 0xda, 0x04,
    0xd7, 0x97, 0x3f, 0xd7, 0xa9, 0x70, 0xf7, 0xa4, 0x5c, 0x5c, 0x8a, 0x2b, 0x60, 0x59, 0xc8, 0x5e,
    0xaf, 0xa0, 0x5c, 0x7e, 0xc3, 0x9b, 0x17, 0x82, 0x7c, 0xd9, 0x71, 0x21, 0x24, 0x69, 0xdf, 0x7b,
    0xf3, 0xf3, 0xd9, 0x19, 0xf2, 0x9b, 0x00, 0x3c, 0x11, 0x25, 0xa6, 0x21, 0x9a, 0x9f, 0x12, 0x03,
    0x52, 0xe1, 0x6f, 0x1b, 0xae, 0x6b, 0x26, 0xa7, 0x40, 0x01, 0x1d, 0xab, 0x64, 0x8a, 0xbe, 0x8b,
    0x0c, 0x73, 0x84, 0xec, 0x25, 0xe7, 0xf9, 0x8e, 0x9d, 0xff, 0xdc, 0x67, 0x1c, 0x5b, 0x6c, 0x92,
    0xed, 0xa5, 0xdb, 0x5b, 0xd9, 0x78, 0x2d, 0x2d, 0x74, 0xc6, 0x6e, 0x60, 0x6f, 0xa7, 0xb3, 0x38,
    0x63, 0x06, 0xa4, 0xcb, 0x8e, 0xd8, 0xb0, 0x60, 0x7c, 0x0a, 0x2f, 0xbd, 0xc5, 0x19, 0xac, 0xbd,
    0x16, 0x07, 0x89, 0x7b, 0x0e, 0xd2, 0xfb, 0x8c, 0x59, 0xd2, 0xbe, 0x67, 0x4c, 0x15, 0x72, 0x0d,
    0xab, 0x40, 0xce, 0x50, 0xa9, 0xae, 0x9d, 0x46, 0xeb, 0x67, 0x65, 0x3b, 0xb2, 0x2f, 0x56, 0x98,
    0xb3, 0xfe, 0x37, 0x2c, 0x9a, 0xe2, 0xb9, 0xd7, 0xb0, 0xd9, 0xa2, 0xd4, 0xd9, 0xbe, 0xd5, 0xe6,
    0x9c, 0xfb, 0x94, 0x90, 0x4b, 0x50, 0xad, 0x5f, 0xcc, 0x98, 0x02, 0x1a, 0x6e, 0xdc, 0x9a, 0x23,
    0xc1, 0x07, 0xcd, 0xee, 0x6c, 0x73, 0x63, 0xa3, 0x59, 0x1d, 0x76, 0xf6, 0x41, 0xb4, 0xbb, 0x0f,
    0xda, 0xaa, 0xe0, 0x89, 0x35, 0xe7, 0x34, 0xda, 0x0f, 0x33, 0xe4, 0x31, 0x52, 0x2a, 0x5c, 0xac,
    0xea, 0xee, 0x56, 0xe7, 0xd9, 0xd1, 0xa1, 0x85, 0x25, 0x46, 0x4e, 0x8f, 0x86, 0x5d, 0xd3, 0xd5,
    0x3d, 0xab, 0x5a, 0xd7, 0x53, 0x01, 0xd2, 0x32, 0x45, 0x9b, 0x4d, 0x3c, 0xa6, 0xc6, 0xfe, 0xf3,
    0xc6, 0x32, 0x4a, 0xa7, 0xa2, 0x9a, 0xaf, 0x07, 0xe9, 0xb6, 0x49, 0x8c, 0xf5, 0x93, 0x4d, 0xc4,
    0xbb, 0xd9, 0x3b, 0x92, 0x85, 0x32, 0xaf, 0xd6, 0x55, 0x24, 0x93, 0x09, 0xdc, 0x86, 0x18, 0xfa,
    0x07, 0xd9, 0xc6, 0x0b, 0x09
};
#endif

PyTypeObject *init_QFileInfo(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QFileInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QFileInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFileInfo",
        "QFileInfo",
        &Sbk_QFileInfo_spec,
        &Shiboken::callCppDestructor< ::QFileInfo >,
        Sbk_QFileInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QFileInfo_TypeF(); // references _Sbk_QFileInfo_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFileInfo_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFileInfo_SignatureBytes, QFileInfo_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFileInfo_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFileInfo_PythonToCpp_QFileInfo_PTR,
        is_QFileInfo_PythonToCpp_QFileInfo_PTR_Convertible,
        QFileInfo_PTR_CppToPython_QFileInfo,
        QFileInfo_COPY_CppToPython_QFileInfo);

    Shiboken::Conversions::registerConverterName(converter, "QFileInfo");
    Shiboken::Conversions::registerConverterName(converter, "QFileInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QFileInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFileInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QFileInfo_PythonToCpp_QFileInfo_COPY,
        is_QFileInfo_PythonToCpp_QFileInfo_COPY_Convertible);

    qRegisterMetaType< ::QFileInfo >("QFileInfo");

    return pyType;
}
