// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qfutureinterfacebase_wrapper.h"

// Argument includes
#include <QString>
#include <qfutureinterface.h>
#include <qmutex.h>
#include <qrunnable.h>
#include <qthreadpool.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

QFutureInterfaceBaseWrapper::QFutureInterfaceBaseWrapper(::QFutureInterfaceBase::State initialState) : QFutureInterfaceBase(initialState)
{
}

QFutureInterfaceBaseWrapper::~QFutureInterfaceBaseWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFutureInterfaceBase_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFutureInterfaceBase >()))
        return -1;

    QFutureInterfaceBaseWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    if (PyArg_ParseTuple(args, "|O:QFutureInterfaceBase", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QFutureInterfaceBase::QFutureInterfaceBase(QFutureInterfaceBase::State=)
    // 1: QFutureInterfaceBase::QFutureInterfaceBase(QFutureInterfaceBase)
    if (numArgs == 0) {
        overloadId = 0; // QFutureInterfaceBase(QFutureInterfaceBase::State)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QFutureInterfaceBase(QFutureInterfaceBase)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_State_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QFutureInterfaceBase(QFutureInterfaceBase::State)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QFutureInterfaceBase(QFutureInterfaceBase::State initialState)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_initialState = Shiboken::String::createStaticString("initialState");
                if (PyDict_Contains(kwds, key_initialState) != 0) {
                    value = PyDict_GetItem(kwds, key_initialState);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_initialState);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_State_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_initialState);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);
                }
            }
            ::QFutureInterfaceBase::State cppArg0(QFutureInterfaceBase::State::NoState);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFutureInterfaceBase(QFutureInterfaceBase::State)
                cptr = new QFutureInterfaceBaseWrapper(cppArg0);
            }
            break;
        }
        case 1: // QFutureInterfaceBase(const QFutureInterfaceBase &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QFutureInterfaceBase *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFutureInterfaceBase(QFutureInterfaceBase)
                cptr = new QFutureInterfaceBaseWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QFutureInterfaceBase >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_cancel(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "cancel", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFutureInterfaceBase::cancel()
    // 1: QFutureInterfaceBase::cancel(QFutureInterfaceBase::CancelMode)
    if (numArgs == 0) {
        overloadId = 0; // cancel()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_CancelMode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // cancel(QFutureInterfaceBase::CancelMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "cancel", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // cancel()
        {

            // cancel()
            cppSelf->cancel();
            break;
        }
        case 1: // cancel(QFutureInterfaceBase::CancelMode mode)
        {
            ::QFutureInterfaceBase::CancelMode cppArg0{QFutureInterfaceBase::CancelMode::CancelOnly};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // cancel(QFutureInterfaceBase::CancelMode)
                cppSelf->cancel(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_cancelAndFinish(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cancelAndFinish()
        cppSelf->cancelAndFinish();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_cleanContinuation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cleanContinuation()
        cppSelf->cleanContinuation();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_derefT(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // derefT()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->derefT();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_expectedResultCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // expectedResultCount()
        int cppResult = cppSelf->expectedResultCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_hasException(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasException()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->hasException();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_isCanceled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isCanceled()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->isCanceled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_isChainCanceled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isChainCanceled()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->isChainCanceled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_isFinished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFinished()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->isFinished();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_isPaused(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QFutureInterfaceBase", "isPaused() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // isPaused()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->isPaused();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_isProgressUpdateNeeded(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isProgressUpdateNeeded()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->isProgressUpdateNeeded();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_isResultReadyAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureInterfaceBase::isResultReadyAt(int)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // isResultReadyAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isResultReadyAt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isResultReadyAt(int)const
            bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->isResultReadyAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_isRunning(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRunning()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->isRunning();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_isRunningOrPending(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRunningOrPending()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->isRunningOrPending();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_isStarted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isStarted()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->isStarted();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_isSuspended(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSuspended()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->isSuspended();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_isSuspending(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSuspending()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->isSuspending();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_isThrottled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isThrottled()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->isThrottled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_launchAsync(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // launchAsync()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->launchAsync();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_loadState(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // loadState()const
        int cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->loadState();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_mutex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mutex()const
        QMutex & cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->mutex();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMutex_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_progressMaximum(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // progressMaximum()const
        int cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->progressMaximum();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_progressMinimum(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // progressMinimum()const
        int cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->progressMinimum();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_progressText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // progressText()const
        QString cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->progressText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_progressValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // progressValue()const
        int cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->progressValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_queryState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureInterfaceBase::queryState(QFutureInterfaceBase::State)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_State_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // queryState(QFutureInterfaceBase::State)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "queryState", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        ::QFutureInterfaceBase::State cppArg0{QFutureInterfaceBase::NoState};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // queryState(QFutureInterfaceBase::State)const
            bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->queryState(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_refT(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // refT()const
        bool cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->refT();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_reportCanceled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reportCanceled()
        cppSelf->reportCanceled();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_reportFinished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reportFinished()
        cppSelf->reportFinished();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_reportResultsReady(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "reportResultsReady", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFutureInterfaceBase::reportResultsReady(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // reportResultsReady(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "reportResultsReady", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // reportResultsReady(int,int)
            cppSelf->reportResultsReady(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_reportStarted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reportStarted()
        cppSelf->reportStarted();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_reportSuspended(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reportSuspended()const
        const_cast<const ::QFutureInterfaceBase *>(cppSelf)->reportSuspended();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_reset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reset()
        cppSelf->reset();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_resultCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resultCount()const
        int cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->resultCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_rethrowPossibleException(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rethrowPossibleException()
        cppSelf->rethrowPossibleException();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_runContinuation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // runContinuation()const
        const_cast<const ::QFutureInterfaceBase *>(cppSelf)->runContinuation();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_setExpectedResultCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureInterfaceBase::setExpectedResultCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setExpectedResultCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExpectedResultCount", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExpectedResultCount(int)
            cppSelf->setExpectedResultCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_setFilterMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureInterfaceBase::setFilterMode(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFilterMode(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFilterMode", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFilterMode(bool)
            cppSelf->setFilterMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_setLaunchAsync(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureInterfaceBase::setLaunchAsync(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setLaunchAsync(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLaunchAsync", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLaunchAsync(bool)
            cppSelf->setLaunchAsync(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_setPaused(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureInterfaceBase::setPaused(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setPaused(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPaused", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QFutureInterfaceBase", "setPaused(bool paused)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPaused(bool)
            cppSelf->setPaused(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_setProgressRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setProgressRange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFutureInterfaceBase::setProgressRange(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setProgressRange(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setProgressRange", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProgressRange(int,int)
            cppSelf->setProgressRange(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_setProgressValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureInterfaceBase::setProgressValue(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setProgressValue(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProgressValue", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProgressValue(int)
            cppSelf->setProgressValue(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_setProgressValueAndText(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setProgressValueAndText", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFutureInterfaceBase::setProgressValueAndText(int,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // setProgressValueAndText(int,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setProgressValueAndText", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProgressValueAndText(int,QString)
            cppSelf->setProgressValueAndText(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_setRunnable(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureInterfaceBase::setRunnable(QRunnable*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRunnable_IDX]), (pyArg)))) {
        overloadId = 0; // setRunnable(QRunnable*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRunnable", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRunnable *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRunnable(QRunnable*)
            cppSelf->setRunnable(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_setSuspended(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureInterfaceBase::setSuspended(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSuspended(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSuspended", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSuspended(bool)
            cppSelf->setSuspended(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_setThreadPool(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureInterfaceBase::setThreadPool(QThreadPool*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), (pyArg)))) {
        overloadId = 0; // setThreadPool(QThreadPool*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setThreadPool", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QThreadPool *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setThreadPool(QThreadPool*)
            cppSelf->setThreadPool(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_setThrottled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureInterfaceBase::setThrottled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setThrottled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setThrottled", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setThrottled(bool)
            cppSelf->setThrottled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_suspendIfRequested(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // suspendIfRequested()
        cppSelf->suspendIfRequested();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureInterfaceBase::swap(QFutureInterfaceBase&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QFutureInterfaceBase&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFutureInterfaceBase *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QFutureInterfaceBase&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_threadPool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // threadPool()const
        QThreadPool * cppResult = const_cast<const ::QFutureInterfaceBase *>(cppSelf)->threadPool();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_togglePaused(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QFutureInterfaceBase", "togglePaused()");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // togglePaused()
        cppSelf->togglePaused();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_toggleSuspended(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toggleSuspended()
        cppSelf->toggleSuspended();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_waitForFinished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // waitForFinished()
        cppSelf->waitForFinished();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_waitForNextResult(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // waitForNextResult()
        bool cppResult = cppSelf->waitForNextResult();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_waitForResult(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureInterfaceBase::waitForResult(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // waitForResult(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "waitForResult", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForResult(int)
            cppSelf->waitForResult(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFutureInterfaceBaseFunc_waitForResume(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // waitForResume()
        cppSelf->waitForResume();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QFutureInterfaceBase_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QFutureInterfaceBase_EnumFlagInfo[] = {
    "CancelMode:Enum",
    "State:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFutureInterfaceBase_methods[] = {
    {"cancel", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_cancel), METH_VARARGS, nullptr},
    {"cancelAndFinish", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_cancelAndFinish), METH_NOARGS, nullptr},
    {"cleanContinuation", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_cleanContinuation), METH_NOARGS, nullptr},
    {"derefT", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_derefT), METH_NOARGS, nullptr},
    {"expectedResultCount", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_expectedResultCount), METH_NOARGS, nullptr},
    {"hasException", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_hasException), METH_NOARGS, nullptr},
    {"isCanceled", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_isCanceled), METH_NOARGS, nullptr},
    {"isChainCanceled", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_isChainCanceled), METH_NOARGS, nullptr},
    {"isFinished", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_isFinished), METH_NOARGS, nullptr},
    {"isPaused", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_isPaused), METH_NOARGS, nullptr},
    {"isProgressUpdateNeeded", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_isProgressUpdateNeeded), METH_NOARGS, nullptr},
    {"isResultReadyAt", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_isResultReadyAt), METH_O, nullptr},
    {"isRunning", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_isRunning), METH_NOARGS, nullptr},
    {"isRunningOrPending", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_isRunningOrPending), METH_NOARGS, nullptr},
    {"isStarted", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_isStarted), METH_NOARGS, nullptr},
    {"isSuspended", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_isSuspended), METH_NOARGS, nullptr},
    {"isSuspending", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_isSuspending), METH_NOARGS, nullptr},
    {"isThrottled", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_isThrottled), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_isValid), METH_NOARGS, nullptr},
    {"launchAsync", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_launchAsync), METH_NOARGS, nullptr},
    {"loadState", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_loadState), METH_NOARGS, nullptr},
    {"mutex", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_mutex), METH_NOARGS, nullptr},
    {"progressMaximum", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_progressMaximum), METH_NOARGS, nullptr},
    {"progressMinimum", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_progressMinimum), METH_NOARGS, nullptr},
    {"progressText", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_progressText), METH_NOARGS, nullptr},
    {"progressValue", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_progressValue), METH_NOARGS, nullptr},
    {"queryState", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_queryState), METH_O, nullptr},
    {"refT", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_refT), METH_NOARGS, nullptr},
    {"reportCanceled", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_reportCanceled), METH_NOARGS, nullptr},
    {"reportFinished", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_reportFinished), METH_NOARGS, nullptr},
    {"reportResultsReady", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_reportResultsReady), METH_VARARGS, nullptr},
    {"reportStarted", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_reportStarted), METH_NOARGS, nullptr},
    {"reportSuspended", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_reportSuspended), METH_NOARGS, nullptr},
    {"reset", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_reset), METH_NOARGS, nullptr},
    {"resultCount", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_resultCount), METH_NOARGS, nullptr},
    {"rethrowPossibleException", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_rethrowPossibleException), METH_NOARGS, nullptr},
    {"runContinuation", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_runContinuation), METH_NOARGS, nullptr},
    {"setExpectedResultCount", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_setExpectedResultCount), METH_O, nullptr},
    {"setFilterMode", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_setFilterMode), METH_O, nullptr},
    {"setLaunchAsync", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_setLaunchAsync), METH_O, nullptr},
    {"setPaused", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_setPaused), METH_O, nullptr},
    {"setProgressRange", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_setProgressRange), METH_VARARGS, nullptr},
    {"setProgressValue", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_setProgressValue), METH_O, nullptr},
    {"setProgressValueAndText", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_setProgressValueAndText), METH_VARARGS, nullptr},
    {"setRunnable", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_setRunnable), METH_O, nullptr},
    {"setSuspended", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_setSuspended), METH_O, nullptr},
    {"setThreadPool", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_setThreadPool), METH_O, nullptr},
    {"setThrottled", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_setThrottled), METH_O, nullptr},
    {"suspendIfRequested", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_suspendIfRequested), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_swap), METH_O, nullptr},
    {"threadPool", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_threadPool), METH_NOARGS, nullptr},
    {"togglePaused", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_togglePaused), METH_NOARGS, nullptr},
    {"toggleSuspended", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_toggleSuspended), METH_NOARGS, nullptr},
    {"waitForFinished", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_waitForFinished), METH_NOARGS, nullptr},
    {"waitForNextResult", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_waitForNextResult), METH_NOARGS, nullptr},
    {"waitForResult", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_waitForResult), METH_O, nullptr},
    {"waitForResume", reinterpret_cast<PyCFunction>(Sbk_QFutureInterfaceBaseFunc_waitForResume), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QFutureInterfaceBase_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QFutureInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), (pyArg)))) {
                // operator!=(const QFutureInterfaceBase &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QFutureInterfaceBase *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX]), (pyArg)))) {
                // operator==(const QFutureInterfaceBase &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QFutureInterfaceBase *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QFutureInterfaceBase_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFutureInterfaceBase_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFutureInterfaceBase_Type = nullptr;
static PyTypeObject *Sbk_QFutureInterfaceBase_TypeF(void)
{
    return _Sbk_QFutureInterfaceBase_Type;
}

static PyType_Slot Sbk_QFutureInterfaceBase_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFutureInterfaceBase_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFutureInterfaceBase_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QFutureInterfaceBase_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFutureInterfaceBase_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFutureInterfaceBase_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFutureInterfaceBase_spec = {
    "2:PySide6.QtCore.QFutureInterfaceBase",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFutureInterfaceBase_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QFutureInterfaceBase_State(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFutureInterfaceBase::State>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFutureInterfaceBase::State *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFutureInterfaceBase_State_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_State_IDX])))
        return Enum_PythonToCpp_QFutureInterfaceBase_State;
    return {};
}

static PyObject *QFutureInterfaceBase_State_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFutureInterfaceBase::State>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFutureInterfaceBase::State *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_State_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QFutureInterfaceBase_CancelMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFutureInterfaceBase::CancelMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFutureInterfaceBase::CancelMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFutureInterfaceBase_CancelMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_CancelMode_IDX])))
        return Enum_PythonToCpp_QFutureInterfaceBase_CancelMode;
    return {};
}

static PyObject *QFutureInterfaceBase_CancelMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFutureInterfaceBase::CancelMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFutureInterfaceBase::CancelMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_CancelMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFutureInterfaceBase_PythonToCpp_QFutureInterfaceBase_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFutureInterfaceBase_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFutureInterfaceBase_PythonToCpp_QFutureInterfaceBase_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFutureInterfaceBase_TypeF()))
        return QFutureInterfaceBase_PythonToCpp_QFutureInterfaceBase_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFutureInterfaceBase_PTR_CppToPython_QFutureInterfaceBase(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QFutureInterfaceBase *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QFutureInterfaceBase_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFutureInterfaceBase_SignatureStrings[] = {
    "1:PySide6.QtCore.QFutureInterfaceBase(self,initialState:PySide6.QtCore.QFutureInterfaceBase.State=QFutureInterfaceBase.State.NoState)",
    "0:PySide6.QtCore.QFutureInterfaceBase(self,other:PySide6.QtCore.QFutureInterfaceBase)",
    "1:PySide6.QtCore.QFutureInterfaceBase.cancel(self)",
    "0:PySide6.QtCore.QFutureInterfaceBase.cancel(self,mode:PySide6.QtCore.QFutureInterfaceBase.CancelMode)",
    "PySide6.QtCore.QFutureInterfaceBase.cancelAndFinish(self)",
    "PySide6.QtCore.QFutureInterfaceBase.cleanContinuation(self)",
    "PySide6.QtCore.QFutureInterfaceBase.derefT(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.expectedResultCount(self)->int",
    "PySide6.QtCore.QFutureInterfaceBase.hasException(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.isCanceled(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.isChainCanceled(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.isFinished(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.isPaused(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.isProgressUpdateNeeded(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.isResultReadyAt(self,index:int)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.isRunning(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.isRunningOrPending(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.isStarted(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.isSuspended(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.isSuspending(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.isThrottled(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.isValid(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.launchAsync(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.loadState(self)->int",
    "PySide6.QtCore.QFutureInterfaceBase.mutex(self)->PySide6.QtCore.QMutex",
    "PySide6.QtCore.QFutureInterfaceBase.progressMaximum(self)->int",
    "PySide6.QtCore.QFutureInterfaceBase.progressMinimum(self)->int",
    "PySide6.QtCore.QFutureInterfaceBase.progressText(self)->QString",
    "PySide6.QtCore.QFutureInterfaceBase.progressValue(self)->int",
    "PySide6.QtCore.QFutureInterfaceBase.queryState(self,state:PySide6.QtCore.QFutureInterfaceBase.State)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.refT(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.reportCanceled(self)",
    "PySide6.QtCore.QFutureInterfaceBase.reportFinished(self)",
    "PySide6.QtCore.QFutureInterfaceBase.reportResultsReady(self,beginIndex:int,endIndex:int)",
    "PySide6.QtCore.QFutureInterfaceBase.reportStarted(self)",
    "PySide6.QtCore.QFutureInterfaceBase.reportSuspended(self)",
    "PySide6.QtCore.QFutureInterfaceBase.reset(self)",
    "PySide6.QtCore.QFutureInterfaceBase.resultCount(self)->int",
    "PySide6.QtCore.QFutureInterfaceBase.rethrowPossibleException(self)",
    "PySide6.QtCore.QFutureInterfaceBase.runContinuation(self)",
    "PySide6.QtCore.QFutureInterfaceBase.setExpectedResultCount(self,resultCount:int)",
    "PySide6.QtCore.QFutureInterfaceBase.setFilterMode(self,enable:bool)",
    "PySide6.QtCore.QFutureInterfaceBase.setLaunchAsync(self,value:bool)",
    "PySide6.QtCore.QFutureInterfaceBase.setPaused(self,paused:bool)",
    "PySide6.QtCore.QFutureInterfaceBase.setProgressRange(self,minimum:int,maximum:int)",
    "PySide6.QtCore.QFutureInterfaceBase.setProgressValue(self,progressValue:int)",
    "PySide6.QtCore.QFutureInterfaceBase.setProgressValueAndText(self,progressValue:int,progressText:QString)",
    "PySide6.QtCore.QFutureInterfaceBase.setRunnable(self,runnable:PySide6.QtCore.QRunnable)",
    "PySide6.QtCore.QFutureInterfaceBase.setSuspended(self,suspend:bool)",
    "PySide6.QtCore.QFutureInterfaceBase.setThreadPool(self,pool:PySide6.QtCore.QThreadPool)",
    "PySide6.QtCore.QFutureInterfaceBase.setThrottled(self,enable:bool)",
    "PySide6.QtCore.QFutureInterfaceBase.suspendIfRequested(self)",
    "PySide6.QtCore.QFutureInterfaceBase.swap(self,other:PySide6.QtCore.QFutureInterfaceBase)",
    "PySide6.QtCore.QFutureInterfaceBase.threadPool(self)->PySide6.QtCore.QThreadPool",
    "PySide6.QtCore.QFutureInterfaceBase.togglePaused(self)",
    "PySide6.QtCore.QFutureInterfaceBase.toggleSuspended(self)",
    "PySide6.QtCore.QFutureInterfaceBase.waitForFinished(self)",
    "PySide6.QtCore.QFutureInterfaceBase.waitForNextResult(self)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.waitForResult(self,resultIndex:int)",
    "PySide6.QtCore.QFutureInterfaceBase.waitForResume(self)",
    "PySide6.QtCore.QFutureInterfaceBase.__ne__(self,other:PySide6.QtCore.QFutureInterfaceBase)->bool",
    "PySide6.QtCore.QFutureInterfaceBase.__eq__(self,other:PySide6.QtCore.QFutureInterfaceBase)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QFutureInterfaceBase_SignatureByteSize = 659;
static constexpr uint8_t QFutureInterfaceBase_SignatureBytes[659] = {
    0x78, 0xda, 0xa5, 0x57, 0xdb, 0x8e, 0xda, 0x30, 0x10, 0x7d, 0xe7, 0x4b, 0x8a, 0x94, 0xa2, 0xee,
    0xcb, 0x3e, 0x20, 0xb5, 0x12, 0x45, 0x8b, 0x84, 0x54, 0xd8, 0x70, 0x69, 0x5f, 0x23, 0x13, 0x0f,
    0x89, 0xa5, 0xc4, 0xce, 0xfa, 0x52, 0xc2, 0xdf, 0xd7, 0x89, 0x03, 0x24, 0xd0, 0x95, 0x3c, 0xe6,
    0x89, 0x04, 0xe6, 0x1c, 0xcf, 0xc5, 0x73, 0x66, 0x78, 0x99, 0xc6, 0xe7, 0x1d, 0xa3, 0xf0, 0x3a,
    0xd9, 0xe8, 0xb9, 0x90, 0x30, 0xd9, 0x2c, 0x8c, 0x36, 0x12, 0x96, 0x5c, 0x83, 0x3c, 0x92, 0x14,
    0x7e, 0x12, 0x05, 0x5f, 0x14, 0x14, 0xc7, 0x88, 0x71, 0xa6, 0x19, 0x29, 0x76, 0x9a, 0x68, 0xf0,
    0x41, 0x4d, 0x5a, 0xcb, 0xef, 0x9f, 0xff, 0x34, 0x59, 0x8b, 0xf6, 0x73, 0x3c, 0xfa, 0xe6, 0xef,
    0x85, 0xd0, 0x39, 0x48, 0x1f, 0xf3, 0xf1, 0xe8, 0xc5, 0xcb, 0xcb, 0x94, 0xf0, 0x14, 0x8a, 0x96,
    0xdc, 0xd3, 0x91, 0x3e, 0x24, 0x2a, 0x05, 0xf5, 0xcb, 0xc6, 0xbc, 0x05, 0xad, 0xac, 0xf9, 0x78,
    0xe4, 0x7f, 0xc8, 0x8c, 0xd3, 0x85, 0x4d, 0xbc, 0xca, 0x3b, 0x07, 0xbd, 0x90, 0x05, 0x10, 0x3e,
    0x17, 0x5c, 0x33, 0x6e, 0x88, 0x66, 0x82, 0x23, 0xb0, 0x14, 0x24, 0x1c, 0xf7, 0x0e, 0xf0, 0xf5,
    0xc7, 0x41, 0x88, 0xc2, 0x0b, 0x06, 0x75, 0x05, 0xa9, 0x06, 0xba, 0x05, 0x65, 0x0a, 0x6b, 0x67,
    0xb8, 0xbe, 0x70, 0x30, 0xae, 0xbd, 0x28, 0x72, 0xa2, 0xde, 0xea, 0x14, 0xaa, 0x9b, 0xc3, 0x88,
    0xf3, 0x99, 0x72, 0xe9, 0x05, 0x1a, 0x02, 0xcd, 0x09, 0xe3, 0x4f, 0xe0, 0x5d, 0x81, 0x82, 0xa0,
    0x31, 0x31, 0x2a, 0x0c, 0x28, 0x45, 0x26, 0x41, 0xa9, 0xdf, 0x15, 0xb5, 0x1d, 0xb4, 0x06, 0xa0,
    0x41, 0x34, 0xae, 0x5e, 0x5b, 0x20, 0xf4, 0x3c, 0xd3, 0x97, 0x36, 0xa7, 0x50, 0x4f, 0x6d, 0xd5,
    0x90, 0x4c, 0x86, 0x73, 0xc6, 0xb3, 0x10, 0x1f, 0x1c, 0xf2, 0x5d, 0xc6, 0xc0, 0x69, 0x18, 0x85,
    0x95, 0x11, 0xa9, 0x83, 0x12, 0xb0, 0x33, 0xaa, 0xb2, 0xc7, 0x3e, 0x83, 0x0d, 0x73, 0x79, 0x9f,
    0x4b, 0xa1, 0x75, 0xd8, 0x85, 0xfb, 0x43, 0x0a, 0x86, 0xc7, 0x15, 0xc4, 0xf0, 0x34, 0x9f, 0xa9,
    0x33, 0x4f, 0xf1, 0x58, 0x41, 0x68, 0xab, 0xd5, 0xd8, 0xae, 0x2e, 0x8d, 0x86, 0xfa, 0x02, 0xba,
    0x07, 0xac, 0x9a, 0x1f, 0xbd, 0x68, 0xaa, 0xee, 0xba, 0xaf, 0x48, 0xcd, 0x4a, 0x53, 0x62, 0xbd,
    0xb8, 0xc2, 0x6d, 0xa7, 0x3e, 0x01, 0xdf, 0x43, 0x7d, 0x95, 0xb5, 0xcd, 0x4e, 0x4b, 0x5b, 0x79,
    0x14, 0xde, 0xd6, 0xcd, 0xa0, 0x33, 0xf8, 0x61, 0x40, 0x9e, 0x6f, 0xb9, 0x8f, 0x14, 0x6e, 0xfe,
    0x62, 0xaa, 0x1c, 0x24, 0xfd, 0x12, 0x2a, 0x21, 0xf5, 0x50, 0x3e, 0x11, 0xc0, 0xa1, 0x78, 0x22,
    0x80, 0x4e, 0xba, 0x54, 0xab, 0x5d, 0x2e, 0x33, 0x07, 0xc8, 0x18, 0x5f, 0x5e, 0xe4, 0x2b, 0xb2,
    0xad, 0x79, 0x7d, 0xc1, 0x10, 0x0f, 0xc4, 0x04, 0x83, 0x1b, 0x4a, 0x89, 0x27, 0x52, 0x81, 0xc6,
    0xd9, 0x87, 0xce, 0x57, 0x09, 0xda, 0x4a, 0xce, 0x29, 0x16, 0x4a, 0xb1, 0x43, 0x01, 0x77, 0xb3,
    0xd6, 0x8f, 0xc2, 0x84, 0xae, 0x15, 0x36, 0xca, 0xb7, 0x4f, 0x56, 0x84, 0xa8, 0x17, 0x93, 0x7f,
    0xa9, 0x2c, 0xe1, 0x82, 0x15, 0xf6, 0x9b, 0x66, 0xa1, 0x72, 0x3c, 0xc0, 0x89, 0x8d, 0x6b, 0xda,
    0x5c, 0x5c, 0x6f, 0x8e, 0x5f, 0x77, 0x9a, 0x18, 0xfd, 0x6d, 0x5a, 0x14, 0xc7, 0xd1, 0x9b, 0xe1,
    0x51, 0xd5, 0x3e, 0x23, 0xf1, 0x9d, 0x3a, 0x6c, 0x09, 0xcf, 0xba, 0x50, 0x4a, 0xa7, 0x53, 0xed,
    0x35, 0x2e, 0x9d, 0xe4, 0xa1, 0x52, 0x13, 0x3f, 0x08, 0x4e, 0x34, 0xd0, 0xa0, 0x70, 0x32, 0xbb,
    0x8f, 0x5e, 0x55, 0xf0, 0x91, 0x33, 0xea, 0x2b, 0xe5, 0xb4, 0x93, 0x48, 0xef, 0x83, 0x9a, 0x45,
    0xa0, 0x29, 0x61, 0x77, 0x2d, 0xba, 0xb7, 0x07, 0xa9, 0xbb, 0x98, 0x79, 0xf3, 0x0e, 0x1b, 0x33,
    0x52, 0xee, 0x15, 0x57, 0x24, 0x3b, 0xae, 0xad, 0xd0, 0xc4, 0x16, 0xd2, 0x85, 0x6e, 0x9f, 0x1e,
    0x3c, 0xbb, 0x19, 0x61, 0x78, 0x7b, 0x6b, 0x40, 0xc0, 0x1d, 0x76, 0xc1, 0x2c, 0x8f, 0x5b, 0xb0,
    0x83, 0x42, 0xe1, 0x74, 0x4b, 0x9d, 0x48, 0x85, 0xfe, 0x57, 0xe5, 0x43, 0xac, 0x87, 0xd9, 0xfa,
    0xcf, 0xe8, 0xbf, 0xa5, 0xca, 0x8f, 0x50, 0x64, 0x59, 0x01, 0xfd, 0x6d, 0x19, 0x01, 0x0b, 0x11,
    0xe6, 0x13, 0x61, 0x7a, 0x21, 0x64, 0xc0, 0x74, 0xea, 0x90, 0x6b, 0xdb, 0x01, 0x4e, 0xea, 0xd0,
    0x13, 0xb5, 0x63, 0xe8, 0xa1, 0x3b, 0x8d, 0x44, 0x8e, 0xb3, 0x1e, 0x4f, 0x09, 0x88, 0x08, 0x92,
    0x84, 0x43, 0x92, 0x60, 0x2f, 0x06, 0x22, 0xc0, 0x24, 0x81, 0x8f, 0xe0, 0x03, 0xfe, 0x01, 0x06,
    0x32, 0x1e, 0xa6
};
#endif

PyTypeObject *init_QFutureInterfaceBase(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX].type;

    Shiboken::AutoDecRef Sbk_QFutureInterfaceBase_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QFutureInterfaceBase_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFutureInterfaceBase",
        "QFutureInterfaceBase*",
        &Sbk_QFutureInterfaceBase_spec,
        &Shiboken::callCppDestructor< QFutureInterfaceBase >,
        Sbk_QFutureInterfaceBase_Type_bases.object(),
        0);
    auto *pyType = Sbk_QFutureInterfaceBase_TypeF(); // references _Sbk_QFutureInterfaceBase_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFutureInterfaceBase_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFutureInterfaceBase_SignatureBytes, QFutureInterfaceBase_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFutureInterfaceBase_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFutureInterfaceBase_PythonToCpp_QFutureInterfaceBase_PTR,
        is_QFutureInterfaceBase_PythonToCpp_QFutureInterfaceBase_PTR_Convertible,
        QFutureInterfaceBase_PTR_CppToPython_QFutureInterfaceBase);

    Shiboken::Conversions::registerConverterName(converter, "QFutureInterfaceBase");
    Shiboken::Conversions::registerConverterName(converter, "QFutureInterfaceBase*");
    Shiboken::Conversions::registerConverterName(converter, "QFutureInterfaceBase&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFutureInterfaceBase).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QFutureInterfaceBaseWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QFutureInterfaceBase_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'State'.
    const char *State_Initializer[] = {
        "NoState",
        "Running",
        "Started",
        "Finished",
        "Canceled",
        "Suspending",
        "Suspended",
        "Throttled",
        "Pending",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t State_InitializerValues[] = {
        uint8_t(QFutureInterfaceBase::State::NoState),    //  0x00  0
        uint8_t(QFutureInterfaceBase::State::Running),    //  0x01  1
        uint8_t(QFutureInterfaceBase::State::Started),    //  0x02  2
        uint8_t(QFutureInterfaceBase::State::Finished),   //  0x04  4
        uint8_t(QFutureInterfaceBase::State::Canceled),   //  0x08  8
        uint8_t(QFutureInterfaceBase::State::Suspending), //  0x10  16
        uint8_t(QFutureInterfaceBase::State::Suspended),  //  0x20  32
        uint8_t(QFutureInterfaceBase::State::Throttled),  //  0x40  64
        uint8_t(QFutureInterfaceBase::State::Pending)     //  0x80  128
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFutureInterfaceBase_TypeF(),
        "2:PySide6.QtCore.QFutureInterfaceBase.State",
        State_Initializer, State_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_State_IDX].type = EType;
    // Register converter for enum 'QFutureInterfaceBase::State'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFutureInterfaceBase_State_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFutureInterfaceBase_State,
            is_Enum_PythonToCpp_QFutureInterfaceBase_State_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFutureInterfaceBase::State");
        Shiboken::Conversions::registerConverterAlias(converter, "State");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'State' enum.

    // Initialization of enum 'CancelMode'.
    const char *CancelMode_Initializer[] = {
        "CancelOnly",
        "CancelAndFinish",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t CancelMode_InitializerValues[] = {
        int8_t(QFutureInterfaceBase::CancelMode::CancelOnly),     //  0x00  0
        int8_t(QFutureInterfaceBase::CancelMode::CancelAndFinish) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFutureInterfaceBase_TypeF(),
        "2:PySide6.QtCore.QFutureInterfaceBase.CancelMode",
        CancelMode_Initializer, CancelMode_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QFutureInterfaceBase_CancelMode_IDX].type = EType;
    // Register converter for enum 'QFutureInterfaceBase::CancelMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFutureInterfaceBase_CancelMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFutureInterfaceBase_CancelMode,
            is_Enum_PythonToCpp_QFutureInterfaceBase_CancelMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFutureInterfaceBase::CancelMode");
        Shiboken::Conversions::registerConverterAlias(converter, "CancelMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CancelMode' enum.

    qRegisterMetaType< ::QFutureInterfaceBase *>();
    qRegisterMetaType< ::QFutureInterfaceBase::State >("QFutureInterfaceBase::State");
    qRegisterMetaType< ::QFutureInterfaceBase::CancelMode >("QFutureInterfaceBase::CancelMode");

    return pyType;
}
