// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qgenericargument_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGenericArgument_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGenericArgument >()))
        return -1;

    ::QGenericArgument *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QGenericArgument", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGenericArgument::QGenericArgument(QGenericArgument)
    // 1: QGenericArgument::QGenericArgument(const char*=,const void*=)
    if (numArgs == 0) {
        overloadId = 1; // QGenericArgument(const char*,const void*)
    } else if (numArgs >= 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QGenericArgument(const char*,const void*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
            overloadId = 1; // QGenericArgument(const char*,const void*)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QGenericArgument(QGenericArgument)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGenericArgument(const QGenericArgument &QGenericArgument)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGenericArgument cppArg0_local;
            ::QGenericArgument *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGenericArgument(QGenericArgument)
                cptr = new ::QGenericArgument(*cppArg0);
            }
            break;
        }
        case 1: // QGenericArgument(const char *aName, const void *aData)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_aName = Shiboken::String::createStaticString("aName");
                if (PyDict_Contains(kwds, key_aName) != 0) {
                    value = PyDict_GetItem(kwds, key_aName);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_aName);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_aName);
                }
                static PyObject *const key_aData = Shiboken::String::createStaticString("aData");
                if (PyDict_Contains(kwds, key_aData) != 0) {
                    value = PyDict_GetItem(kwds, key_aData);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_aData);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_aData);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]);
                }
            }
            const char* cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGenericArgument(const char*,const void*)
                cptr = new ::QGenericArgument(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGenericArgument >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGenericArgumentFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGenericArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()const
        void * cppResult = const_cast<const ::QGenericArgument *>(cppSelf)->data();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGenericArgumentFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGenericArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        const char * cppResult = const_cast<const ::QGenericArgument *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGenericArgument__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGenericArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGenericArgument_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGenericArgument_methods[] = {
    {"data", reinterpret_cast<PyCFunction>(Sbk_QGenericArgumentFunc_data), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QGenericArgumentFunc_name), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGenericArgument__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QGenericArgument_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGenericArgument_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGenericArgument_Type = nullptr;
static PyTypeObject *Sbk_QGenericArgument_TypeF(void)
{
    return _Sbk_QGenericArgument_Type;
}

static PyType_Slot Sbk_QGenericArgument_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGenericArgument_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGenericArgument_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGenericArgument_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGenericArgument_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGenericArgument_spec = {
    "2:PySide6.QtCore.QGenericArgument",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGenericArgument_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGenericArgument_PythonToCpp_QGenericArgument_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGenericArgument_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGenericArgument_PythonToCpp_QGenericArgument_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGenericArgument_TypeF()))
        return QGenericArgument_PythonToCpp_QGenericArgument_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGenericArgument_PTR_CppToPython_QGenericArgument(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QGenericArgument_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QGenericArgument_COPY_CppToPython_QGenericArgument(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGenericArgument *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGenericArgument_TypeF(), new ::QGenericArgument(*source), true, true);
}

// Python to C++ copy conversion.
static void QGenericArgument_PythonToCpp_QGenericArgument_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGenericArgument *>(cppOut) = *reinterpret_cast< ::QGenericArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGenericArgument_PythonToCpp_QGenericArgument_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGenericArgument_TypeF()))
        return QGenericArgument_PythonToCpp_QGenericArgument_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGenericArgument_SignatureStrings[] = {
    "1:PySide6.QtCore.QGenericArgument(self,QGenericArgument:PySide6.QtCore.QGenericArgument)",
    "0:PySide6.QtCore.QGenericArgument(self,aName:char*=nullptr,aData:void=nullptr)",
    "PySide6.QtCore.QGenericArgument.data(self)->void",
    "PySide6.QtCore.QGenericArgument.name(self)->char*",
    "PySide6.QtCore.QGenericArgument.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QGenericArgument_SignatureByteSize = 136;
static constexpr uint8_t QGenericArgument_SignatureBytes[136] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0x74, 0x4f, 0xcd, 0x4b, 0x2d, 0xca, 0x4c, 0x76, 0x2c, 0x4a, 0x2f, 0xcd,
    0x4d, 0xcd, 0x2b, 0xd1, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0x41, 0x17, 0x25, 0xa4, 0x4b, 0x93, 0xcb,
    0x80, 0x38, 0x83, 0x13, 0xfd, 0x12, 0x73, 0x53, 0xad, 0x92, 0x33, 0x12, 0x8b, 0xb4, 0x6c, 0xf3,
    0x4a, 0x73, 0x72, 0x0a, 0x4a, 0x8a, 0x74, 0x12, 0x5d, 0x12, 0x4b, 0x12, 0xad, 0xca, 0xf2, 0x33,
    0x53, 0x60, 0x42, 0x9a, 0x5c, 0x04, 0x0c, 0xd3, 0x4b, 0x01, 0x6a, 0x01, 0x9b, 0xa8, 0xa9, 0x6b,
    0x07, 0xd2, 0x49, 0x50, 0x43, 0x1e, 0xd0, 0x5e, 0x98, 0x06, 0xb0, 0xf5, 0x04, 0x75, 0xc4, 0xc7,
    0x27, 0xe7, 0x17, 0x54, 0xc6, 0xc7, 0xc3, 0x74, 0x95, 0x54, 0x16, 0x64, 0xe6, 0xa5, 0xeb, 0x05,
    0x03, 0x79, 0x5c, 0x00, 0x5e, 0x1f, 0x75, 0x49
};
#endif

PyTypeObject *init_QGenericArgument(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX].type;

    Shiboken::AutoDecRef Sbk_QGenericArgument_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGenericArgument_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGenericArgument",
        "QGenericArgument",
        &Sbk_QGenericArgument_spec,
        &Shiboken::callCppDestructor< ::QGenericArgument >,
        Sbk_QGenericArgument_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGenericArgument_TypeF(); // references _Sbk_QGenericArgument_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGenericArgument_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGenericArgument_SignatureBytes, QGenericArgument_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGenericArgument_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGenericArgument_PythonToCpp_QGenericArgument_PTR,
        is_QGenericArgument_PythonToCpp_QGenericArgument_PTR_Convertible,
        QGenericArgument_PTR_CppToPython_QGenericArgument,
        QGenericArgument_COPY_CppToPython_QGenericArgument);

    Shiboken::Conversions::registerConverterName(converter, "QGenericArgument");
    Shiboken::Conversions::registerConverterName(converter, "QGenericArgument*");
    Shiboken::Conversions::registerConverterName(converter, "QGenericArgument&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGenericArgument).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGenericArgument_PythonToCpp_QGenericArgument_COPY,
        is_QGenericArgument_PythonToCpp_QGenericArgument_COPY_Convertible);

    qRegisterMetaType< ::QGenericArgument >("QGenericArgument");

    return pyType;
}
