// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qgenericreturnargument_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGenericReturnArgument_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGenericReturnArgument >()))
        return -1;

    ::QGenericReturnArgument *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QGenericReturnArgument", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGenericReturnArgument::QGenericReturnArgument(QGenericReturnArgument)
    // 1: QGenericReturnArgument::QGenericReturnArgument(const char*=,void*=)
    if (numArgs == 0) {
        overloadId = 1; // QGenericReturnArgument(const char*,void*)
    } else if (numArgs >= 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QGenericReturnArgument(const char*,void*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
            overloadId = 1; // QGenericReturnArgument(const char*,void*)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QGenericReturnArgument(QGenericReturnArgument)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGenericReturnArgument(const QGenericReturnArgument &QGenericReturnArgument)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGenericReturnArgument cppArg0_local;
            ::QGenericReturnArgument *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGenericReturnArgument(QGenericReturnArgument)
                cptr = new ::QGenericReturnArgument(*cppArg0);
            }
            break;
        }
        case 1: // QGenericReturnArgument(const char *aName, void *aData)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_aName = Shiboken::String::createStaticString("aName");
                if (PyDict_Contains(kwds, key_aName) != 0) {
                    value = PyDict_GetItem(kwds, key_aName);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_aName);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_aName);
                }
                static PyObject *const key_aData = Shiboken::String::createStaticString("aData");
                if (PyDict_Contains(kwds, key_aData) != 0) {
                    value = PyDict_GetItem(kwds, key_aData);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_aData);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_aData);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]);
                }
            }
            const char* cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGenericReturnArgument(const char*,void*)
                cptr = new ::QGenericReturnArgument(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGenericReturnArgument >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGenericReturnArgument__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGenericReturnArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGenericReturnArgument_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGenericReturnArgument_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGenericReturnArgument__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QGenericReturnArgument_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGenericReturnArgument_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGenericReturnArgument_Type = nullptr;
static PyTypeObject *Sbk_QGenericReturnArgument_TypeF(void)
{
    return _Sbk_QGenericReturnArgument_Type;
}

static PyType_Slot Sbk_QGenericReturnArgument_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGenericReturnArgument_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGenericReturnArgument_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGenericReturnArgument_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGenericReturnArgument_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGenericReturnArgument_spec = {
    "2:PySide6.QtCore.QGenericReturnArgument",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGenericReturnArgument_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGenericReturnArgument_PythonToCpp_QGenericReturnArgument_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGenericReturnArgument_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGenericReturnArgument_PythonToCpp_QGenericReturnArgument_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGenericReturnArgument_TypeF()))
        return QGenericReturnArgument_PythonToCpp_QGenericReturnArgument_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGenericReturnArgument_PTR_CppToPython_QGenericReturnArgument(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QGenericReturnArgument_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QGenericReturnArgument_COPY_CppToPython_QGenericReturnArgument(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGenericReturnArgument *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGenericReturnArgument_TypeF(), new ::QGenericReturnArgument(*source), true, true);
}

// Python to C++ copy conversion.
static void QGenericReturnArgument_PythonToCpp_QGenericReturnArgument_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGenericReturnArgument *>(cppOut) = *reinterpret_cast< ::QGenericReturnArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGenericReturnArgument_PythonToCpp_QGenericReturnArgument_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGenericReturnArgument_TypeF()))
        return QGenericReturnArgument_PythonToCpp_QGenericReturnArgument_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGenericReturnArgument_SignatureStrings[] = {
    "1:PySide6.QtCore.QGenericReturnArgument(self,QGenericReturnArgument:PySide6.QtCore.QGenericReturnArgument)",
    "0:PySide6.QtCore.QGenericReturnArgument(self,aName:char*=nullptr,aData:void=nullptr)",
    "PySide6.QtCore.QGenericReturnArgument.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QGenericReturnArgument_SignatureByteSize = 124;
static constexpr uint8_t QGenericReturnArgument_SignatureBytes[124] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0x74, 0x4f, 0xcd, 0x4b, 0x2d, 0xca, 0x4c, 0x0e, 0x4a, 0x2d, 0x29, 0x2d,
    0xca, 0x73, 0x2c, 0x4a, 0x2f, 0xcd, 0x4d, 0xcd, 0x2b, 0xd1, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xc1,
    0x2e, 0x47, 0x9c, 0x09, 0x9a, 0x5c, 0x06, 0xa4, 0x58, 0x95, 0xe8, 0x97, 0x98, 0x9b, 0x6a, 0x95,
    0x9c, 0x91, 0x58, 0xa4, 0x65, 0x9b, 0x57, 0x9a, 0x93, 0x53, 0x50, 0x52, 0xa4, 0x93, 0xe8, 0x92,
    0x58, 0x92, 0x68, 0x55, 0x96, 0x9f, 0x99, 0x02, 0x13, 0xd2, 0xe4, 0x22, 0xca, 0x48, 0xbd, 0xf8,
    0xf8, 0xe4, 0xfc, 0x82, 0xca, 0xf8, 0x78, 0xb0, 0xd9, 0x9a, 0xba, 0x76, 0x25, 0x95, 0x05, 0x99,
    0x79, 0xe9, 0x7a, 0xc1, 0x40, 0x1e, 0x17, 0x00, 0x0e, 0xa5, 0x5e, 0xda
};
#endif

PyTypeObject *init_QGenericReturnArgument(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX].type;

    Shiboken::AutoDecRef Sbk_QGenericReturnArgument_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]))));

    _Sbk_QGenericReturnArgument_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGenericReturnArgument",
        "QGenericReturnArgument",
        &Sbk_QGenericReturnArgument_spec,
        &Shiboken::callCppDestructor< ::QGenericReturnArgument >,
        Sbk_QGenericReturnArgument_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGenericReturnArgument_TypeF(); // references _Sbk_QGenericReturnArgument_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGenericReturnArgument_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGenericReturnArgument_SignatureBytes, QGenericReturnArgument_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGenericReturnArgument_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGenericReturnArgument_PythonToCpp_QGenericReturnArgument_PTR,
        is_QGenericReturnArgument_PythonToCpp_QGenericReturnArgument_PTR_Convertible,
        QGenericReturnArgument_PTR_CppToPython_QGenericReturnArgument,
        QGenericReturnArgument_COPY_CppToPython_QGenericReturnArgument);

    Shiboken::Conversions::registerConverterName(converter, "QGenericReturnArgument");
    Shiboken::Conversions::registerConverterName(converter, "QGenericReturnArgument*");
    Shiboken::Conversions::registerConverterName(converter, "QGenericReturnArgument&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGenericReturnArgument).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGenericReturnArgument_PythonToCpp_QGenericReturnArgument_COPY,
        is_QGenericReturnArgument_PythonToCpp_QGenericReturnArgument_COPY_Convertible);

    qRegisterMetaType< ::QGenericReturnArgument >("QGenericReturnArgument");

    return pyType;
}
