// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qiodevicebase_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QIODeviceBase_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QIODeviceBase >()))
        return -1;

    ::QIODeviceBase *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QIODeviceBase()
        cptr = new ::QIODeviceBase();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QIODeviceBase >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}


static const char *Sbk_QIODeviceBase_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QIODeviceBase_EnumFlagInfo[] = {
    "OpenModeFlag:Flag:OpenMode",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QIODeviceBase_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QIODeviceBase_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QIODeviceBase_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QIODeviceBase_Type = nullptr;
static PyTypeObject *Sbk_QIODeviceBase_TypeF(void)
{
    return _Sbk_QIODeviceBase_Type;
}

static PyType_Slot Sbk_QIODeviceBase_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QIODeviceBase_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QIODeviceBase_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QIODeviceBase_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QIODeviceBase_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QIODeviceBase_spec = {
    "2:PySide6.QtCore.QIODeviceBase",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QIODeviceBase_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QIODeviceBase_OpenModeFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QIODeviceBase::OpenModeFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QIODeviceBase::OpenModeFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QIODeviceBase_OpenModeFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_OpenModeFlag_IDX])))
        return Enum_PythonToCpp_QIODeviceBase_OpenModeFlag;
    return {};
}

static PyObject *QIODeviceBase_OpenModeFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QIODeviceBase::OpenModeFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QIODeviceBase::OpenModeFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_OpenModeFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QIODeviceBase_OpenModeFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QIODeviceBase::OpenModeFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QIODeviceBase::OpenModeFlag> *>(cppOut) = value;

}

static PyObject *QIODeviceBase_OpenModeFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QIODeviceBase::OpenModeFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_OpenModeFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QIODeviceBase_PythonToCpp_QIODeviceBase_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QIODeviceBase_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QIODeviceBase_PythonToCpp_QIODeviceBase_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QIODeviceBase_TypeF()))
        return QIODeviceBase_PythonToCpp_QIODeviceBase_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QIODeviceBase_PTR_CppToPython_QIODeviceBase(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QIODeviceBase_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QIODeviceBase_SignatureStrings[] = {
    "PySide6.QtCore.QIODeviceBase(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QIODeviceBase_SignatureByteSize = 43;
static constexpr uint8_t QIODeviceBase_SignatureBytes[43] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce, 0x2f, 0x4a,
    0xd5, 0x0b, 0xf4, 0xf4, 0x77, 0x49, 0x2d, 0xcb, 0x4c, 0x4e, 0x75, 0x4a, 0x2c, 0x4e, 0xd5, 0x28,
    0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x02, 0x00, 0xdb, 0x68, 0x0b, 0xe8
};
#endif

PyTypeObject *init_QIODeviceBase(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_IDX].type;

    Shiboken::AutoDecRef Sbk_QIODeviceBase_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QIODeviceBase_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QIODeviceBase",
        "QIODeviceBase*",
        &Sbk_QIODeviceBase_spec,
        &Shiboken::callCppDestructor< ::QIODeviceBase >,
        Sbk_QIODeviceBase_Type_bases.object(),
        0);
    auto *pyType = Sbk_QIODeviceBase_TypeF(); // references _Sbk_QIODeviceBase_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QIODeviceBase_SignatureStrings);
#else
    InitSignatureBytes(pyType, QIODeviceBase_SignatureBytes, QIODeviceBase_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QIODeviceBase_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QIODeviceBase_PythonToCpp_QIODeviceBase_PTR,
        is_QIODeviceBase_PythonToCpp_QIODeviceBase_PTR_Convertible,
        QIODeviceBase_PTR_CppToPython_QIODeviceBase);

    Shiboken::Conversions::registerConverterName(converter, "QIODeviceBase");
    Shiboken::Conversions::registerConverterName(converter, "QIODeviceBase*");
    Shiboken::Conversions::registerConverterName(converter, "QIODeviceBase&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QIODeviceBase).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QIODeviceBase_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'OpenModeFlag'.
    const char *OpenModeFlag_Initializer[] = {
        "NotOpen",
        "ReadOnly",
        "WriteOnly",
        "ReadWrite",
        "Append",
        "Truncate",
        "Text",
        "Unbuffered",
        "NewOnly",
        "ExistingOnly",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t OpenModeFlag_InitializerValues[] = {
        uint8_t(QIODeviceBase::OpenModeFlag::NotOpen),     //  0x00  0
        uint8_t(QIODeviceBase::OpenModeFlag::ReadOnly),    //  0x01  1
        uint8_t(QIODeviceBase::OpenModeFlag::WriteOnly),   //  0x02  2
        uint8_t(QIODeviceBase::OpenModeFlag::ReadWrite),   //  0x03  3
        uint8_t(QIODeviceBase::OpenModeFlag::Append),      //  0x04  4
        uint8_t(QIODeviceBase::OpenModeFlag::Truncate),    //  0x08  8
        uint8_t(QIODeviceBase::OpenModeFlag::Text),        //  0x10  16
        uint8_t(QIODeviceBase::OpenModeFlag::Unbuffered),  //  0x20  32
        uint8_t(QIODeviceBase::OpenModeFlag::NewOnly),     //  0x40  64
        uint8_t(QIODeviceBase::OpenModeFlag::ExistingOnly) //  0x80  128
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QIODeviceBase_TypeF(),
        "2:PySide6.QtCore.QIODeviceBase.OpenModeFlag",
        OpenModeFlag_Initializer, OpenModeFlag_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_OpenModeFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX].type =
        EType;
    // Register converter for enum 'QIODeviceBase::OpenModeFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QIODeviceBase_OpenModeFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QIODeviceBase_OpenModeFlag,
            is_Enum_PythonToCpp_QIODeviceBase_OpenModeFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QIODeviceBase::OpenModeFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "OpenModeFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QIODeviceBase_OpenModeFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QIODeviceBase_OpenModeFlag,
            is_Enum_PythonToCpp_QIODeviceBase_OpenModeFlag_Convertible);
        // Register converter for flag 'QFlags<QIODeviceBase::OpenModeFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QIODeviceBase::OpenModeFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QIODeviceBase::OpenMode");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'OpenModeFlag' enum/flags.

    qRegisterMetaType< ::QIODeviceBase *>();
    qRegisterMetaType< ::QIODeviceBase::OpenModeFlag >("QIODeviceBase::OpenModeFlag");

    return pyType;
}
