// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qitemselection_wrapper.h"

// Argument includes
#include <QList>
#include <qabstractitemmodel.h>
#include <qitemselectionmodel.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QItemSelection_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QItemSelection >()))
        return -1;

    ::QItemSelection *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QItemSelection", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QItemSelection::QItemSelection()
    // 1: QItemSelection::QItemSelection(QItemSelection)
    // 2: QItemSelection::QItemSelection(QModelIndex,QModelIndex)
    if (numArgs == 0) {
        overloadId = 0; // QItemSelection()
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[1])))) {
        overloadId = 2; // QItemSelection(QModelIndex,QModelIndex)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QItemSelection(QItemSelection)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QItemSelection()
        {

            // QItemSelection()
            cptr = new ::QItemSelection();
            break;
        }
        case 1: // QItemSelection(const QItemSelection &QItemSelection)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QItemSelection cppArg0_local;
            ::QItemSelection *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemSelection(QItemSelection)
                cptr = new ::QItemSelection(*cppArg0);
            }
            break;
        }
        case 2: // QItemSelection(const QModelIndex &topLeft, const QModelIndex &bottomRight)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QModelIndex cppArg0_local;
            ::QModelIndex *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QModelIndex cppArg1_local;
            ::QModelIndex *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemSelection(QModelIndex,QModelIndex)
                cptr = new ::QItemSelection(*cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QItemSelection >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QItemSelectionFunc_append(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::append(QItemSelectionRange)
    // 1: QItemSelection::append(QList<QItemSelectionRange>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), (pyArg)))) {
        overloadId = 0; // append(QItemSelectionRange)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], (pyArg)))) {
        overloadId = 1; // append(QList<QItemSelectionRange>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // append(QItemSelectionRange arg__1)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QItemSelectionRange cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QItemSelectionRange)
                cppSelf->append(cppArg0);
            }
            break;
        }
        case 1: // append(const QList<QItemSelectionRange> &l)
        {
            ::QList<QItemSelectionRange> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QList<QItemSelectionRange>)
                cppSelf->append(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_at(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::at(qsizetype)const->const QItemSelectionRange&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // at(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "at", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // at(qsizetype)const
            const QItemSelectionRange & cppResult = const_cast<const ::QItemSelection *>(cppSelf)->at(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_back(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // back()
        QItemSelectionRange & cppResult = cppSelf->back();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_capacity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // capacity()const
        qsizetype cppResult = const_cast<const ::QItemSelection *>(cppSelf)->capacity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_constData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // constData()const
        const QItemSelectionRange * cppResult = const_cast<const ::QItemSelection *>(cppSelf)->constData();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_constFirst(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // constFirst()const
        const QItemSelectionRange & cppResult = const_cast<const ::QItemSelection *>(cppSelf)->constFirst();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_constLast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // constLast()const
        const QItemSelectionRange & cppResult = const_cast<const ::QItemSelection *>(cppSelf)->constLast();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::contains(QModelIndex)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // contains(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contains", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // contains(QModelIndex)const
            bool cppResult = const_cast<const ::QItemSelection *>(cppSelf)->contains(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        qsizetype cppResult = const_cast<const ::QItemSelection *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()
        QItemSelectionRange * cppResult = cppSelf->data();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_empty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // empty()const
        bool cppResult = const_cast<const ::QItemSelection *>(cppSelf)->empty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_first(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "first", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QItemSelection::first()->QItemSelectionRange&
    // 1: QItemSelection::first(qsizetype)const->QList<QItemSelectionRange>
    if (numArgs == 0) {
        overloadId = 0; // first()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        overloadId = 1; // first(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "first", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // first()
        {

            // first()
            QItemSelectionRange & cppResult = cppSelf->first();
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), &cppResult);
            break;
        }
        case 1: // first(qsizetype n) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // first(qsizetype)const
                QList<QItemSelectionRange> cppResult = const_cast<const ::QItemSelection *>(cppSelf)->first(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_fromList(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QItemSelection::fromList(QList<QItemSelectionRange>)->QList<QItemSelectionRange>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], (pyArg)))) {
        overloadId = 0; // fromList(QList<QItemSelectionRange>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        ::QList<QItemSelectionRange> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromList(QList<QItemSelectionRange>)
            QList<QItemSelectionRange> cppResult = ::QItemSelection::fromList(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_fromVector(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QItemSelection::fromVector(QList<QItemSelectionRange>)->QList<QItemSelectionRange>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], (pyArg)))) {
        overloadId = 0; // fromVector(QList<QItemSelectionRange>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromVector", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        ::QList<QItemSelectionRange> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromVector(QList<QItemSelectionRange>)
            QList<QItemSelectionRange> cppResult = ::QItemSelection::fromVector(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_front(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // front()
        QItemSelectionRange & cppResult = cppSelf->front();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_indexes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // indexes()const
        QList<QModelIndex> cppResult = const_cast<const ::QItemSelection *>(cppSelf)->indexes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QModelIndex_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_insert(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insert", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QItemSelection::insert(qsizetype,QItemSelectionRange)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insert(qsizetype,QItemSelectionRange)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insert", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QItemSelectionRange cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insert(qsizetype,QItemSelectionRange)
            cppSelf->insert(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QItemSelection *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_isSharedWith(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::isSharedWith(QList<QItemSelectionRange>)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], (pyArg)))) {
        overloadId = 0; // isSharedWith(QList<QItemSelectionRange>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isSharedWith", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        ::QList<QItemSelectionRange> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isSharedWith(QList<QItemSelectionRange>)const
            bool cppResult = const_cast<const ::QItemSelection *>(cppSelf)->isSharedWith(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_last(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "last", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QItemSelection::last()->QItemSelectionRange&
    // 1: QItemSelection::last(qsizetype)const->QList<QItemSelectionRange>
    if (numArgs == 0) {
        overloadId = 0; // last()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        overloadId = 1; // last(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "last", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // last()
        {

            // last()
            QItemSelectionRange & cppResult = cppSelf->last();
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), &cppResult);
            break;
        }
        case 1: // last(qsizetype n) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // last(qsizetype)const
                QList<QItemSelectionRange> cppResult = const_cast<const ::QItemSelection *>(cppSelf)->last(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // length()const
        qsizetype cppResult = const_cast<const ::QItemSelection *>(cppSelf)->length();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_maxSize(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxSize()
        qsizetype cppResult = ::QItemSelection::maxSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_max_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // max_size()const
        qsizetype cppResult = const_cast<const ::QItemSelection *>(cppSelf)->max_size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_merge(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "merge", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QItemSelection::merge(QItemSelection,QFlags<QItemSelectionModel::SelectionFlag>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QItemSelectionModel_SelectionFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
        overloadId = 0; // merge(QItemSelection,QFlags<QItemSelectionModel::SelectionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "merge", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QItemSelection cppArg0_local;
        ::QItemSelection *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QFlags<QItemSelectionModel::SelectionFlag> cppArg1 = QFlags<QItemSelectionModel::SelectionFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // merge(QItemSelection,QFlags<QItemSelectionModel::SelectionFlag>)
            cppSelf->merge(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_mid(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "mid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    if (PyArg_ParseTuple(args, "|OO:mid", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QItemSelection::mid(qsizetype,qsizetype=)const->QList<QItemSelectionRange>
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // mid(qsizetype,qsizetype)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 0; // mid(qsizetype,qsizetype)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_len = Shiboken::String::createStaticString("len");
            if (PyDict_Contains(kwds, key_len) != 0) {
                value = PyDict_GetItem(kwds, key_len);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_len);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "mid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "mid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_len);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "mid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);
            }
        }
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = -1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mid(qsizetype,qsizetype)const
            QList<QItemSelectionRange> cppResult = const_cast<const ::QItemSelection *>(cppSelf)->mid(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_move(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "move", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QItemSelection::move(qsizetype,qsizetype)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // move(qsizetype,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "move", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // move(qsizetype,qsizetype)
            cppSelf->move(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_pop_back(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pop_back()
        cppSelf->pop_back();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_pop_front(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pop_front()
        cppSelf->pop_front();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_prepend(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::prepend(QItemSelectionRange)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), (pyArg)))) {
        overloadId = 0; // prepend(QItemSelectionRange)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "prepend", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QItemSelectionRange cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // prepend(QItemSelectionRange)
            cppSelf->prepend(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_push_back(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::push_back(QItemSelectionRange)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), (pyArg)))) {
        overloadId = 0; // push_back(QItemSelectionRange)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "push_back", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QItemSelectionRange cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // push_back(QItemSelectionRange)
            cppSelf->push_back(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_push_front(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::push_front(QItemSelectionRange)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), (pyArg)))) {
        overloadId = 0; // push_front(QItemSelectionRange)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "push_front", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QItemSelectionRange cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // push_front(QItemSelectionRange)
            cppSelf->push_front(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_remove(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    if (PyArg_ParseTuple(args, "|OO:remove", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QItemSelection::remove(qsizetype,qsizetype=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // remove(qsizetype,qsizetype)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 0; // remove(qsizetype,qsizetype)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_n = Shiboken::String::createStaticString("n");
            if (PyDict_Contains(kwds, key_n) != 0) {
                value = PyDict_GetItem(kwds, key_n);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_n);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_n);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);
            }
        }
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = 1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // remove(qsizetype,qsizetype)
            cppSelf->remove(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_removeAll(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::removeAll(QItemSelectionRange)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), (pyArg)))) {
        overloadId = 0; // removeAll(QItemSelectionRange)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAll", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QItemSelectionRange cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAll(QItemSelectionRange)
            cppSelf->removeAll(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_removeAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::removeAt(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // removeAt(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAt(qsizetype)
            cppSelf->removeAt(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_removeFirst(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // removeFirst()
        cppSelf->removeFirst();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_removeLast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // removeLast()
        cppSelf->removeLast();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_removeOne(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::removeOne(QItemSelectionRange)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), (pyArg)))) {
        overloadId = 0; // removeOne(QItemSelectionRange)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeOne", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QItemSelectionRange cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeOne(QItemSelectionRange)
            cppSelf->removeOne(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_reserve(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::reserve(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // reserve(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "reserve", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // reserve(qsizetype)
            cppSelf->reserve(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_resize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::resize(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // resize(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resize", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resize(qsizetype)
            cppSelf->resize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_resizeForOverwrite(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::resizeForOverwrite(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // resizeForOverwrite(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resizeForOverwrite", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeForOverwrite(qsizetype)
            cppSelf->resizeForOverwrite(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_select(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "select", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QItemSelection::select(QModelIndex,QModelIndex)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[1])))) {
        overloadId = 0; // select(QModelIndex,QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "select", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QModelIndex cppArg1_local;
        ::QModelIndex *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // select(QModelIndex,QModelIndex)
            cppSelf->select(*cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_shrink_to_fit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shrink_to_fit()
        cppSelf->shrink_to_fit();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        qsizetype cppResult = const_cast<const ::QItemSelection *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_sliced(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sliced", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QItemSelection::sliced(qsizetype)const->QList<QItemSelectionRange>
    // 1: QItemSelection::sliced(qsizetype,qsizetype)const->QList<QItemSelectionRange>
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // sliced(qsizetype)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 1; // sliced(qsizetype,qsizetype)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sliced", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // sliced(qsizetype pos) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sliced(qsizetype)const
                QList<QItemSelectionRange> cppResult = const_cast<const ::QItemSelection *>(cppSelf)->sliced(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], &cppResult);
            }
            break;
        }
        case 1: // sliced(qsizetype pos, qsizetype n) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sliced(qsizetype,qsizetype)const
                QList<QItemSelectionRange> cppResult = const_cast<const ::QItemSelection *>(cppSelf)->sliced(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_split(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "split", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QItemSelection::split(QItemSelectionRange,QItemSelectionRange,QItemSelection*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), (pyArgs[2])))) {
        overloadId = 0; // split(QItemSelectionRange,QItemSelectionRange,QItemSelection*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "split", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QItemSelectionRange cppArg0_local;
        ::QItemSelectionRange *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QItemSelectionRange cppArg1_local;
        ::QItemSelectionRange *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QItemSelection *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // split(QItemSelectionRange,QItemSelectionRange,QItemSelection*)
            ::QItemSelection::split(*cppArg0, *cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_squeeze(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // squeeze()
        cppSelf->squeeze();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::swap(QList<QItemSelectionRange>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], (pyArg)))) {
        overloadId = 0; // swap(QList<QItemSelectionRange>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        ::QList<QItemSelectionRange> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QList<QItemSelectionRange>&)
            cppSelf->swap(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_swapItemsAt(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "swapItemsAt", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QItemSelection::swapItemsAt(qsizetype,qsizetype)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // swapItemsAt(qsizetype,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "swapItemsAt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swapItemsAt(qsizetype,qsizetype)
            cppSelf->swapItemsAt(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemSelectionFunc_takeAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::takeAt(qsizetype)->QItemSelectionRange
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // takeAt(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "takeAt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // takeAt(qsizetype)
            QItemSelectionRange cppResult = cppSelf->takeAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_toList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toList()const
        QList<QItemSelectionRange> cppResult = const_cast<const ::QItemSelection *>(cppSelf)->toList();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_toVector(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toVector()const
        QList<QItemSelectionRange> cppResult = const_cast<const ::QItemSelection *>(cppSelf)->toVector();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc_value(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::value(qsizetype)const->QItemSelectionRange
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // value(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "value", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // value(qsizetype)const
            QItemSelectionRange cppResult = const_cast<const ::QItemSelection *>(cppSelf)->value(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelection__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QItemSelection_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QItemSelection_methods[] = {
    {"append", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_append), METH_O, nullptr},
    {"at", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_at), METH_O, nullptr},
    {"back", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_back), METH_NOARGS, nullptr},
    {"capacity", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_capacity), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_clear), METH_NOARGS, nullptr},
    {"constData", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_constData), METH_NOARGS, nullptr},
    {"constFirst", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_constFirst), METH_NOARGS, nullptr},
    {"constLast", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_constLast), METH_NOARGS, nullptr},
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_contains), METH_O, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_count), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_data), METH_NOARGS, nullptr},
    {"empty", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_empty), METH_NOARGS, nullptr},
    {"first", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_first), METH_VARARGS, nullptr},
    {"fromList", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_fromList), METH_O|METH_STATIC, nullptr},
    {"fromVector", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_fromVector), METH_O|METH_STATIC, nullptr},
    {"front", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_front), METH_NOARGS, nullptr},
    {"indexes", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_indexes), METH_NOARGS, nullptr},
    {"insert", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_insert), METH_VARARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_isEmpty), METH_NOARGS, nullptr},
    {"isSharedWith", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_isSharedWith), METH_O, nullptr},
    {"last", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_last), METH_VARARGS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_length), METH_NOARGS, nullptr},
    {"maxSize", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_maxSize), METH_NOARGS|METH_STATIC, nullptr},
    {"max_size", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_max_size), METH_NOARGS, nullptr},
    {"merge", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_merge), METH_VARARGS, nullptr},
    {"mid", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_mid), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"move", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_move), METH_VARARGS, nullptr},
    {"pop_back", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_pop_back), METH_NOARGS, nullptr},
    {"pop_front", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_pop_front), METH_NOARGS, nullptr},
    {"prepend", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_prepend), METH_O, nullptr},
    {"push_back", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_push_back), METH_O, nullptr},
    {"push_front", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_push_front), METH_O, nullptr},
    {"remove", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_remove), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"removeAll", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_removeAll), METH_O, nullptr},
    {"removeAt", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_removeAt), METH_O, nullptr},
    {"removeFirst", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_removeFirst), METH_NOARGS, nullptr},
    {"removeLast", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_removeLast), METH_NOARGS, nullptr},
    {"removeOne", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_removeOne), METH_O, nullptr},
    {"reserve", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_reserve), METH_O, nullptr},
    {"resize", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_resize), METH_O, nullptr},
    {"resizeForOverwrite", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_resizeForOverwrite), METH_O, nullptr},
    {"select", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_select), METH_VARARGS, nullptr},
    {"shrink_to_fit", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_shrink_to_fit), METH_NOARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_size), METH_NOARGS, nullptr},
    {"sliced", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_sliced), METH_VARARGS, nullptr},
    {"split", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_split), METH_VARARGS|METH_STATIC, nullptr},
    {"squeeze", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_squeeze), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_swap), METH_O, nullptr},
    {"swapItemsAt", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_swapItemsAt), METH_VARARGS, nullptr},
    {"takeAt", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_takeAt), METH_O, nullptr},
    {"toList", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_toList), METH_NOARGS, nullptr},
    {"toVector", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_toVector), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QItemSelectionFunc_value), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QItemSelection__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QItemSelectionFunc___add__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::operator+(QItemSelection)->QItemSelection
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), (pyArg)))) {
        overloadId = 0; // operator+(QItemSelection)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QItemSelection cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+(QItemSelection)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qitemselection-add)]
            auto res = (*cppSelf) + cppArg0;
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), &res);
            // END of custom code block [file: ../glue/qtcore.cpp (qitemselection-add)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemSelectionFunc___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemSelection::operator+=(QList<QItemSelectionRange>)->QList<QItemSelectionRange>&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], (pyArg)))) {
        overloadId = 0; // operator+=(QList<QItemSelectionRange>)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+=", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

    // Call function/method
    {
        ::QList<QItemSelectionRange> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+=(QList<QItemSelectionRange>)
            (*cppSelf) += cppArg0;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QItemSelectionFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QItemSelection::operator<<(QList<QItemSelectionRange>)->QList<QItemSelectionRange>&
        if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], (pyArg)))) {
            overloadId = 0; // operator<<(QList<QItemSelectionRange>)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]);

        // Call function/method
        {
            ::QList<QItemSelectionRange> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QList<QItemSelectionRange>)
                QList<QItemSelectionRange> & cppResult = (*cppSelf) << cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

Py_ssize_t Sbk_QItemSelection__len__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return cppSelf->size();
}
PyObject *Sbk_QItemSelection__getitem__(PyObject *self, Py_ssize_t _i)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    const Py_ssize_t size = cppSelf->size();
    if (_i < 0 || _i >= size) {
        Shiboken::Errors::setIndexOutOfBounds(_i, 0, size);
        return nullptr;
    }
    QItemSelection::const_iterator _item = cppSelf->begin();
    std::advance(_item, _i);
    return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), &*_item);
}
int Sbk_QItemSelection__setitem__(PyObject *self, Py_ssize_t _i, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    const Py_ssize_t size = cppSelf->size();
    if (_i < 0 || _i >= size) {
        Shiboken::Errors::setIndexOutOfBounds(_i, 0, size);
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), (pyArg)))) {
        Shiboken::Errors::setSequenceTypeError("QItemSelectionRange");
        return -1;
    }
    if (!Shiboken::Object::isValid(pyArg))
        return -1;
    ::QItemSelectionRange cppValue;
    pythonToCpp(pyArg, &cppValue);
    QItemSelection::iterator _item = cppSelf->begin();
    std::advance(_item, _i);
    *_item = cppValue;
    return {};
}
// Rich comparison
static PyObject * Sbk_QItemSelection_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), (pyArg)))) {
                // operator!=(const QItemSelection &arg__1)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QItemSelection cppArg0_local;
                ::QItemSelection *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                SBK_UNUSED(cppArg0)
                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), (pyArg)))) {
                // operator==(const QItemSelection &arg__1)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QItemSelection cppArg0_local;
                ::QItemSelection *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                SBK_UNUSED(cppArg0)
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QItemSelection_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QItemSelection_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QItemSelection_Type = nullptr;
static PyTypeObject *Sbk_QItemSelection_TypeF(void)
{
    return _Sbk_QItemSelection_Type;
}

static PyType_Slot Sbk_QItemSelection_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QItemSelection_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QItemSelection_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QItemSelection_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QItemSelection_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QItemSelection_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports sequence protocol
    {Py_sq_ass_item,    reinterpret_cast<void *>(Sbk_QItemSelection__setitem__)},
    {Py_sq_length,      reinterpret_cast<void *>(Sbk_QItemSelection__len__)},
    {Py_sq_item,        reinterpret_cast<void *>(Sbk_QItemSelection__getitem__)},
    // type supports number protocol
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QItemSelectionFunc___iadd__)},
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QItemSelectionFunc___lshift__)},
    {Py_nb_add,         reinterpret_cast<void *>(Sbk_QItemSelectionFunc___add__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QItemSelection_spec = {
    "2:PySide6.QtCore.QItemSelection",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QItemSelection_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QItemSelection_PythonToCpp_QItemSelection_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QItemSelection_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QItemSelection_PythonToCpp_QItemSelection_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QItemSelection_TypeF()))
        return QItemSelection_PythonToCpp_QItemSelection_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QItemSelection_PTR_CppToPython_QItemSelection(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QItemSelection_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QItemSelection_COPY_CppToPython_QItemSelection(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QItemSelection *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QItemSelection_TypeF(), new ::QItemSelection(*source), true, true);
}

// Python to C++ copy conversion.
static void QItemSelection_PythonToCpp_QItemSelection_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QItemSelection *>(cppOut) = *reinterpret_cast< ::QItemSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QItemSelection_PythonToCpp_QItemSelection_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QItemSelection_TypeF()))
        return QItemSelection_PythonToCpp_QItemSelection_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QItemSelection_SignatureStrings[] = {
    "2:PySide6.QtCore.QItemSelection(self)",
    "1:PySide6.QtCore.QItemSelection(self,QItemSelection:PySide6.QtCore.QItemSelection)",
    "0:PySide6.QtCore.QItemSelection(self,topLeft:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],bottomRight:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "1:PySide6.QtCore.QItemSelection.append(self,arg__1:PySide6.QtCore.QItemSelectionRange)",
    "0:PySide6.QtCore.QItemSelection.append(self,l:QList[PySide6.QtCore.QItemSelectionRange])",
    "PySide6.QtCore.QItemSelection.at(self,i:qsizetype)->PySide6.QtCore.QItemSelectionRange",
    "PySide6.QtCore.QItemSelection.back(self)->PySide6.QtCore.QItemSelectionRange",
    "PySide6.QtCore.QItemSelection.capacity(self)->qsizetype",
    "PySide6.QtCore.QItemSelection.clear(self)",
    "PySide6.QtCore.QItemSelection.constData(self)->PySide6.QtCore.QItemSelectionRange",
    "PySide6.QtCore.QItemSelection.constFirst(self)->PySide6.QtCore.QItemSelectionRange",
    "PySide6.QtCore.QItemSelection.constLast(self)->PySide6.QtCore.QItemSelectionRange",
    "PySide6.QtCore.QItemSelection.contains(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "PySide6.QtCore.QItemSelection.count(self)->qsizetype",
    "PySide6.QtCore.QItemSelection.data(self)->PySide6.QtCore.QItemSelectionRange",
    "PySide6.QtCore.QItemSelection.empty(self)->bool",
    "1:PySide6.QtCore.QItemSelection.first(self)->PySide6.QtCore.QItemSelectionRange",
    "0:PySide6.QtCore.QItemSelection.first(self,n:qsizetype)->QList[PySide6.QtCore.QItemSelectionRange]",
    "PySide6.QtCore.QItemSelection.fromList(list:QList[PySide6.QtCore.QItemSelectionRange])->QList[PySide6.QtCore.QItemSelectionRange]",
    "PySide6.QtCore.QItemSelection.fromVector(vector:QList[PySide6.QtCore.QItemSelectionRange])->QList[PySide6.QtCore.QItemSelectionRange]",
    "PySide6.QtCore.QItemSelection.front(self)->PySide6.QtCore.QItemSelectionRange",
    "PySide6.QtCore.QItemSelection.indexes(self)->QList[PySide6.QtCore.QModelIndex]",
    "PySide6.QtCore.QItemSelection.insert(self,arg__1:qsizetype,arg__2:PySide6.QtCore.QItemSelectionRange)",
    "PySide6.QtCore.QItemSelection.isEmpty(self)->bool",
    "PySide6.QtCore.QItemSelection.isSharedWith(self,other:QList[PySide6.QtCore.QItemSelectionRange])->bool",
    "1:PySide6.QtCore.QItemSelection.last(self)->PySide6.QtCore.QItemSelectionRange",
    "0:PySide6.QtCore.QItemSelection.last(self,n:qsizetype)->QList[PySide6.QtCore.QItemSelectionRange]",
    "PySide6.QtCore.QItemSelection.length(self)->qsizetype",
    "PySide6.QtCore.QItemSelection.maxSize()->qsizetype",
    "PySide6.QtCore.QItemSelection.max_size(self)->qsizetype",
    "PySide6.QtCore.QItemSelection.merge(self,other:PySide6.QtCore.QItemSelection,command:PySide6.QtCore.QItemSelectionModel.SelectionFlag)",
    "PySide6.QtCore.QItemSelection.mid(self,pos:qsizetype,len:qsizetype=-1)->QList[PySide6.QtCore.QItemSelectionRange]",
    "PySide6.QtCore.QItemSelection.move(self,from:qsizetype,to:qsizetype)",
    "PySide6.QtCore.QItemSelection.pop_back(self)",
    "PySide6.QtCore.QItemSelection.pop_front(self)",
    "PySide6.QtCore.QItemSelection.prepend(self,arg__1:PySide6.QtCore.QItemSelectionRange)",
    "PySide6.QtCore.QItemSelection.push_back(self,arg__1:PySide6.QtCore.QItemSelectionRange)",
    "PySide6.QtCore.QItemSelection.push_front(self,arg__1:PySide6.QtCore.QItemSelectionRange)",
    "PySide6.QtCore.QItemSelection.remove(self,i:qsizetype,n:qsizetype=1)",
    "PySide6.QtCore.QItemSelection.removeAll(self,arg__1:PySide6.QtCore.QItemSelectionRange)",
    "PySide6.QtCore.QItemSelection.removeAt(self,i:qsizetype)",
    "PySide6.QtCore.QItemSelection.removeFirst(self)",
    "PySide6.QtCore.QItemSelection.removeLast(self)",
    "PySide6.QtCore.QItemSelection.removeOne(self,arg__1:PySide6.QtCore.QItemSelectionRange)",
    "PySide6.QtCore.QItemSelection.reserve(self,size:qsizetype)",
    "PySide6.QtCore.QItemSelection.resize(self,size:qsizetype)",
    "PySide6.QtCore.QItemSelection.resizeForOverwrite(self,size:qsizetype)",
    "PySide6.QtCore.QItemSelection.select(self,topLeft:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],bottomRight:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "PySide6.QtCore.QItemSelection.shrink_to_fit(self)",
    "PySide6.QtCore.QItemSelection.size(self)->qsizetype",
    "1:PySide6.QtCore.QItemSelection.sliced(self,pos:qsizetype)->QList[PySide6.QtCore.QItemSelectionRange]",
    "0:PySide6.QtCore.QItemSelection.sliced(self,pos:qsizetype,n:qsizetype)->QList[PySide6.QtCore.QItemSelectionRange]",
    "PySide6.QtCore.QItemSelection.split(range:PySide6.QtCore.QItemSelectionRange,other:PySide6.QtCore.QItemSelectionRange,result:PySide6.QtCore.QItemSelection)",
    "PySide6.QtCore.QItemSelection.squeeze(self)",
    "PySide6.QtCore.QItemSelection.swap(self,other:QList[PySide6.QtCore.QItemSelectionRange])",
    "PySide6.QtCore.QItemSelection.swapItemsAt(self,i:qsizetype,j:qsizetype)",
    "PySide6.QtCore.QItemSelection.takeAt(self,i:qsizetype)->PySide6.QtCore.QItemSelectionRange",
    "PySide6.QtCore.QItemSelection.toList(self)->QList[PySide6.QtCore.QItemSelectionRange]",
    "PySide6.QtCore.QItemSelection.toVector(self)->QList[PySide6.QtCore.QItemSelectionRange]",
    "PySide6.QtCore.QItemSelection.value(self,i:qsizetype)->PySide6.QtCore.QItemSelectionRange",
    "PySide6.QtCore.QItemSelection.__copy__(self)->typing.Self",
    "PySide6.QtCore.QItemSelection.__add__(self,arg__1:PySide6.QtCore.QItemSelection)->PySide6.QtCore.QItemSelection",
    "PySide6.QtCore.QItemSelection.__iadd__(self,l:QList[PySide6.QtCore.QItemSelectionRange])->QList[PySide6.QtCore.QItemSelectionRange]",
    "PySide6.QtCore.QItemSelection.__lshift__(self,l:QList[PySide6.QtCore.QItemSelectionRange])->QList[PySide6.QtCore.QItemSelectionRange]",
    "PySide6.QtCore.QItemSelection.__ne__(self,arg__1:PySide6.QtCore.QItemSelection)->bool",
    "PySide6.QtCore.QItemSelection.__eq__(self,arg__1:PySide6.QtCore.QItemSelection)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QItemSelection_SignatureByteSize = 710;
static constexpr uint8_t QItemSelection_SignatureBytes[710] = {
    0x78, 0xda, 0xd5, 0x58, 0x4b, 0x6f, 0xda, 0x40, 0x10, 0xbe, 0xe7, 0x57, 0xf4, 0x08, 0x12, 0x41,
    0x90, 0x43, 0x0f, 0x48, 0x89, 0x14, 0xb5, 0x45, 0x8a, 0x44, 0x95, 0x10, 0xd4, 0xf6, 0x10, 0x45,
    0xab, 0xc5, 0x1e, 0xdb, 0x5b, 0xd6, 0xbb, 0x66, 0x77, 0x20, 0xa1, 0xbf, 0xbe, 0x36, 0x18, 0x6c,
    0x52, 0xc4, 0xac, 0xd1, 0x22, 0xd4, 0x0b, 0x0f, 0x33, 0xf3, 0xed, 0x37, 0xef, 0x59, 0x6e, 0x06,
    0x4f, 0xab, 0x89, 0x08, 0xe1, 0x73, 0x77, 0x8c, 0x5f, 0xb4, 0x81, 0xee, 0xf8, 0x01, 0x21, 0x9d,
    0x80, 0x84, 0x00, 0x85, 0x56, 0x2d, 0x0b, 0x32, 0x6a, 0x5f, 0xf5, 0x1d, 0xa4, 0x3a, 0xfb, 0xcf,
    0x8e, 0x6b, 0xb4, 0xaf, 0x7a, 0x2e, 0x90, 0xa8, 0xb3, 0x11, 0x44, 0x38, 0xc0, 0x55, 0x26, 0x54,
    0xdc, 0xfd, 0xa1, 0xf2, 0x5f, 0x5e, 0x3e, 0xea, 0x7d, 0xd7, 0x21, 0xc8, 0x07, 0x15, 0xc2, 0x7b,
    0xe7, 0xd3, 0xc7, 0xdf, 0x9e, 0xc0, 0x58, 0x61, 0x11, 0x14, 0x56, 0x52, 0xaf, 0x9d, 0xa9, 0x46,
    0xd4, 0xe9, 0xb3, 0x88, 0x13, 0xdf, 0xd0, 0xa4, 0xab, 0xba, 0x3c, 0xcb, 0x40, 0x85, 0x1b, 0xf3,
    0xb8, 0x89, 0x19, 0x23, 0x14, 0x9e, 0xb9, 0x8a, 0x81, 0x74, 0xd7, 0x1e, 0xac, 0x1c, 0x8c, 0x47,
    0x39, 0xb3, 0x17, 0x1a, 0x37, 0xe7, 0x4b, 0xc0, 0xe2, 0x06, 0x52, 0x0c, 0xe6, 0x56, 0xfc, 0x81,
    0xdc, 0x59, 0xd0, 0xbe, 0xbe, 0xa3, 0x81, 0x09, 0xd8, 0x29, 0x0f, 0x66, 0x9b, 0xd4, 0xf2, 0x00,
    0x16, 0xf0, 0x8c, 0x07, 0x02, 0x57, 0x5b, 0xc0, 0x1d, 0x53, 0x4a, 0x4f, 0x02, 0x37, 0x65, 0x82,
    0x13, 0x92, 0x5a, 0x59, 0xfc, 0xca, 0x91, 0xfb, 0xe3, 0x5c, 0x20, 0x0e, 0x85, 0xb1, 0xe8, 0x17,
    0x72, 0xc4, 0xfd, 0x22, 0x22, 0x17, 0xca, 0x96, 0x29, 0x50, 0x24, 0xb8, 0xef, 0x72, 0xb9, 0xbe,
    0x9b, 0x6a, 0x2d, 0x49, 0x1e, 0x0b, 0x85, 0x4d, 0xa3, 0x1b, 0xfa, 0x0c, 0x17, 0xa4, 0x59, 0x95,
    0x5f, 0x6b, 0xc6, 0x54, 0x99, 0x47, 0x0d, 0x63, 0xdb, 0x73, 0xc6, 0xeb, 0xa8, 0xbd, 0x5a, 0x74,
    0x2e, 0x75, 0xc2, 0xc4, 0xc8, 0xe8, 0xb4, 0x80, 0x6a, 0xc9, 0xfc, 0xa5, 0x41, 0x03, 0xf1, 0xcb,
    0xe0, 0x67, 0xfe, 0x59, 0x9b, 0xd6, 0x72, 0xfd, 0x76, 0x29, 0x16, 0xca, 0x5f, 0x09, 0xad, 0x8b,
    0x06, 0xec, 0x16, 0xef, 0x30, 0xc9, 0x5a, 0x41, 0x90, 0x70, 0x16, 0x0c, 0xee, 0x0d, 0x8f, 0x5d,
    0x2e, 0x6c, 0x1e, 0xdc, 0x38, 0x4d, 0x13, 0xe2, 0x14, 0xfb, 0xed, 0x9f, 0x7c, 0xa7, 0x34, 0x26,
    0x09, 0x37, 0x10, 0xfe, 0x12, 0x98, 0x6c, 0xd8, 0x69, 0x4c, 0xa0, 0x59, 0x00, 0x9d, 0xca, 0x4a,
    0x72, 0xaf, 0x55, 0xb5, 0x83, 0x3b, 0x53, 0x51, 0x49, 0x50, 0x71, 0xe9, 0x91, 0x06, 0xad, 0x2b,
    0xe5, 0xef, 0x93, 0x5c, 0xb2, 0xd5, 0x4c, 0x85, 0x15, 0xa2, 0x8d, 0x8f, 0x02, 0x13, 0x43, 0x3d,
    0x62, 0x47, 0xc5, 0x3b, 0x81, 0x4e, 0x53, 0xae, 0xc2, 0xe3, 0x52, 0xeb, 0x74, 0xee, 0xee, 0xbe,
    0x0e, 0x25, 0x8f, 0xa9, 0x8c, 0x4b, 0x45, 0xb9, 0xba, 0x64, 0xda, 0xd6, 0x32, 0x3a, 0x77, 0x5f,
    0xf5, 0xed, 0xf6, 0xba, 0xef, 0x31, 0x32, 0xa9, 0x5e, 0x96, 0x76, 0x17, 0x6d, 0xa7, 0x76, 0x26,
    0xea, 0x5a, 0x26, 0x10, 0x20, 0x99, 0xce, 0x58, 0xb5, 0xca, 0x38, 0x08, 0xd7, 0x9a, 0x0b, 0x25,
    0x6d, 0xe0, 0xa4, 0x3d, 0x91, 0x40, 0x5d, 0xd8, 0xa4, 0x62, 0xec, 0x19, 0xb7, 0x32, 0xce, 0x1f,
    0xb0, 0x81, 0x2a, 0x50, 0xb5, 0x1d, 0xb4, 0x5e, 0xae, 0xb7, 0x7d, 0x37, 0x90, 0x7b, 0x29, 0xcf,
    0x42, 0xee, 0xfe, 0xc0, 0x8a, 0xec, 0xa4, 0x58, 0x5b, 0xff, 0x9c, 0xe4, 0xab, 0xdd, 0xce, 0x49,
    0xfc, 0x51, 0x81, 0x77, 0x7b, 0xf3, 0xe9, 0xb3, 0x8d, 0x46, 0x61, 0x6b, 0x13, 0x8b, 0x77, 0xdd,
    0xe9, 0x24, 0xcd, 0xa1, 0x36, 0x8f, 0x4b, 0x30, 0x6f, 0x46, 0xe0, 0x49, 0x28, 0x76, 0xfd, 0xe9,
    0xbf, 0xbd, 0x54, 0x12, 0xc6, 0x25, 0x46, 0xa8, 0x19, 0x43, 0xcd, 0x22, 0xe1, 0x96, 0x21, 0x87,
    0x47, 0x05, 0x35, 0x7c, 0xad, 0x14, 0x01, 0x1c, 0x6a, 0xd4, 0x8d, 0xfa, 0x72, 0xef, 0xd4, 0x53,
    0xce, 0x34, 0xa3, 0x6d, 0x26, 0x73, 0xaf, 0x99, 0x42, 0xd4, 0xa1, 0x46, 0x5c, 0xc6, 0xe4, 0x46,
    0x30, 0x4f, 0xdc, 0x85, 0x44, 0xea, 0x6f, 0x10, 0x82, 0xdb, 0x7c, 0x01, 0xb0, 0x0d, 0x15, 0x25,
    0xfb, 0xc6, 0xb3, 0xd3, 0x76, 0x2f, 0x07, 0xe0, 0xe2, 0x89, 0x3d, 0xd0, 0xe9, 0x3a, 0xbf, 0xdd,
    0x6b, 0x10, 0xf9, 0xec, 0x60, 0xb3, 0xf4, 0xb0, 0x66, 0xa3, 0x5e, 0x5f, 0x5d, 0x8e, 0x6e, 0xd9,
    0xcd, 0x33, 0x03, 0x75, 0x79, 0x1d, 0xf1, 0x8c, 0xbb, 0xe4, 0x72, 0x01, 0x67, 0xf1, 0x03, 0x63,
    0x81, 0xce, 0x56, 0x8c, 0x6d, 0x19, 0x97, 0x7d, 0x28, 0x17, 0x88, 0x48, 0x4d, 0x1e, 0x86, 0xa5,
    0xa2, 0xd3, 0xc4, 0xa0, 0xe8, 0x92, 0xe7, 0x89, 0xda, 0x81, 0xf2, 0x22, 0x57, 0x3d, 0xc6, 0xa4,
    0x4d, 0x44, 0x84, 0x97, 0x66, 0xa1, 0xa0, 0xa1, 0xe3, 0x1d, 0x6e, 0x64, 0x8c, 0xc1, 0xfc, 0x14,
    0xd4, 0xbf, 0x0d, 0x4a, 0x04, 0x19
};
#endif

PyTypeObject *init_QItemSelection(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX].type;

    Shiboken::AutoDecRef Sbk_QItemSelection_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QItemSelection_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QItemSelection",
        "QItemSelection",
        &Sbk_QItemSelection_spec,
        &Shiboken::callCppDestructor< ::QItemSelection >,
        Sbk_QItemSelection_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QItemSelection_TypeF(); // references _Sbk_QItemSelection_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QItemSelection_SignatureStrings);
#else
    InitSignatureBytes(pyType, QItemSelection_SignatureBytes, QItemSelection_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QItemSelection_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QItemSelection_PythonToCpp_QItemSelection_PTR,
        is_QItemSelection_PythonToCpp_QItemSelection_PTR_Convertible,
        QItemSelection_PTR_CppToPython_QItemSelection,
        QItemSelection_COPY_CppToPython_QItemSelection);

    Shiboken::Conversions::registerConverterName(converter, "QItemSelection");
    Shiboken::Conversions::registerConverterName(converter, "QItemSelection*");
    Shiboken::Conversions::registerConverterName(converter, "QItemSelection&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QItemSelection).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QItemSelection_PythonToCpp_QItemSelection_COPY,
        is_QItemSelection_PythonToCpp_QItemSelection_COPY_Convertible);

    qRegisterMetaType< ::QItemSelection >("QItemSelection");

    return pyType;
}
