// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qjsondocument_wrapper.h"

// Argument includes
#include <QString>
#include <QStringView>
#include <QtCore/qlatin1stringview.h>
#include <qbytearray.h>
#include <qjsonarray.h>
#include <qjsondocument.h>
#include <qjsonobject.h>
#include <qjsonvalue.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QJsonDocument_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QJsonDocument >()))
        return -1;

    ::QJsonDocument *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QJsonDocument", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QJsonDocument::QJsonDocument()
    // 1: QJsonDocument::QJsonDocument(QJsonArray)
    // 2: QJsonDocument::QJsonDocument(QJsonDocument)
    // 3: QJsonDocument::QJsonDocument(QJsonObject)
    if (numArgs == 0) {
        overloadId = 0; // QJsonDocument()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], (pyArgs[0])))) {
        overloadId = 3; // QJsonDocument(QJsonObject)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QJsonDocument(QJsonDocument)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QJsonDocument(QJsonArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QJsonDocument()
        {

            // QJsonDocument()
            cptr = new ::QJsonDocument();
            break;
        }
        case 1: // QJsonDocument(const QJsonArray &array)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QJsonArray cppArg0_local;
            ::QJsonArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonDocument(QJsonArray)
                cptr = new ::QJsonDocument(*cppArg0);
            }
            break;
        }
        case 2: // QJsonDocument(const QJsonDocument &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QJsonDocument cppArg0_local;
            ::QJsonDocument *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonDocument(QJsonDocument)
                cptr = new ::QJsonDocument(*cppArg0);
            }
            break;
        }
        case 3: // QJsonDocument(const QJsonObject &object)
        {
            ::QJsonObject cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonDocument(QJsonObject)
                cptr = new ::QJsonDocument(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QJsonDocument >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QJsonDocumentFunc_array(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // array()const
        QJsonArray cppResult = const_cast<const ::QJsonDocument *>(cppSelf)->array();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonDocumentFunc_fromJson(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fromJson", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QJsonDocument::fromJson(QByteArray,QJsonParseError*=)->QJsonDocument
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromJson(QByteArray,QJsonParseError*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]), (pyArgs[1])))) {
            overloadId = 0; // fromJson(QByteArray,QJsonParseError*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_error = Shiboken::String::createStaticString("error");
            if (PyDict_Contains(kwds, key_error) != 0) {
                value = PyDict_GetItem(kwds, key_error);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_error);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "fromJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_error);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QJsonParseError *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromJson(QByteArray,QJsonParseError*)
            QJsonDocument cppResult = ::QJsonDocument::fromJson(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonDocumentFunc_fromVariant(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QJsonDocument::fromVariant(QVariant)->QJsonDocument
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // fromVariant(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromVariant", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromVariant(QVariant)
            QJsonDocument cppResult = ::QJsonDocument::fromVariant(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonDocumentFunc_isArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isArray()const
        bool cppResult = const_cast<const ::QJsonDocument *>(cppSelf)->isArray();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonDocumentFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QJsonDocument *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonDocumentFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QJsonDocument *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonDocumentFunc_isObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isObject()const
        bool cppResult = const_cast<const ::QJsonDocument *>(cppSelf)->isObject();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonDocumentFunc_object(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // object()const
        QJsonObject cppResult = const_cast<const ::QJsonDocument *>(cppSelf)->object();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonDocumentFunc_setArray(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJsonDocument::setArray(QJsonArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), (pyArg)))) {
        overloadId = 0; // setArray(QJsonArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setArray", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJsonArray cppArg0_local;
        ::QJsonArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setArray(QJsonArray)
            cppSelf->setArray(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QJsonDocumentFunc_setObject(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJsonDocument::setObject(QJsonObject)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], (pyArg)))) {
        overloadId = 0; // setObject(QJsonObject)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setObject", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);

    // Call function/method
    {
        ::QJsonObject cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setObject(QJsonObject)
            cppSelf->setObject(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QJsonDocumentFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJsonDocument::swap(QJsonDocument&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QJsonDocument&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJsonDocument cppArg0_local;
        ::QJsonDocument *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QJsonDocument&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QJsonDocumentFunc_toJson(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);

    if (PyArg_ParseTuple(args, "|O:toJson", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonDocument::toJson(QJsonDocument::JsonFormat=)const->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // toJson(QJsonDocument::JsonFormat)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_JsonFormat_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // toJson(QJsonDocument::JsonFormat)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_JsonFormat_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "toJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "toJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]);
            }
        }
        ::QJsonDocument::JsonFormat cppArg0(QJsonDocument::JsonFormat::Indented);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toJson(QJsonDocument::JsonFormat)const
            QByteArray cppResult = const_cast<const ::QJsonDocument *>(cppSelf)->toJson(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonDocumentFunc_toVariant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toVariant()const
        QVariant cppResult = const_cast<const ::QJsonDocument *>(cppSelf)->toVariant();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonDocument__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QJsonDocument_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QJsonDocument_EnumFlagInfo[] = {
    "JsonFormat:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QJsonDocument_methods[] = {
    {"array", reinterpret_cast<PyCFunction>(Sbk_QJsonDocumentFunc_array), METH_NOARGS, nullptr},
    {"fromJson", reinterpret_cast<PyCFunction>(Sbk_QJsonDocumentFunc_fromJson), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromVariant", reinterpret_cast<PyCFunction>(Sbk_QJsonDocumentFunc_fromVariant), METH_O|METH_STATIC, nullptr},
    {"isArray", reinterpret_cast<PyCFunction>(Sbk_QJsonDocumentFunc_isArray), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QJsonDocumentFunc_isEmpty), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QJsonDocumentFunc_isNull), METH_NOARGS, nullptr},
    {"isObject", reinterpret_cast<PyCFunction>(Sbk_QJsonDocumentFunc_isObject), METH_NOARGS, nullptr},
    {"object", reinterpret_cast<PyCFunction>(Sbk_QJsonDocumentFunc_object), METH_NOARGS, nullptr},
    {"setArray", reinterpret_cast<PyCFunction>(Sbk_QJsonDocumentFunc_setArray), METH_O, nullptr},
    {"setObject", reinterpret_cast<PyCFunction>(Sbk_QJsonDocumentFunc_setObject), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QJsonDocumentFunc_swap), METH_O, nullptr},
    {"toJson", reinterpret_cast<PyCFunction>(Sbk_QJsonDocumentFunc_toJson), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toVariant", reinterpret_cast<PyCFunction>(Sbk_QJsonDocumentFunc_toVariant), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QJsonDocument__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QJsonDocument___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QJsonDocument_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), (pyArg)))) {
                // operator!=(const QJsonDocument &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJsonDocument cppArg0_local;
                ::QJsonDocument *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), (pyArg)))) {
                // operator==(const QJsonDocument &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJsonDocument cppArg0_local;
                ::QJsonDocument *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QJsonDocument_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QJsonDocument_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QJsonDocument__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QJsonDocument_Type = nullptr;
static PyTypeObject *Sbk_QJsonDocument_TypeF(void)
{
    return _Sbk_QJsonDocument_Type;
}

static PyType_Slot Sbk_QJsonDocument_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QJsonDocument__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QJsonDocument_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QJsonDocument_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QJsonDocument_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QJsonDocument_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QJsonDocument_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QJsonDocument___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QJsonDocument_spec = {
    "2:PySide6.QtCore.QJsonDocument",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QJsonDocument_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QJsonDocument_JsonFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QJsonDocument::JsonFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QJsonDocument::JsonFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QJsonDocument_JsonFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_JsonFormat_IDX])))
        return Enum_PythonToCpp_QJsonDocument_JsonFormat;
    return {};
}

static PyObject *QJsonDocument_JsonFormat_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QJsonDocument::JsonFormat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QJsonDocument::JsonFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_JsonFormat_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QJsonDocument_PythonToCpp_QJsonDocument_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QJsonDocument_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QJsonDocument_PythonToCpp_QJsonDocument_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QJsonDocument_TypeF()))
        return QJsonDocument_PythonToCpp_QJsonDocument_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QJsonDocument_PTR_CppToPython_QJsonDocument(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QJsonDocument_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QJsonDocument_COPY_CppToPython_QJsonDocument(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QJsonDocument *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QJsonDocument_TypeF(), new ::QJsonDocument(*source), true, true);
}

// Python to C++ copy conversion.
static void QJsonDocument_PythonToCpp_QJsonDocument_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QJsonDocument *>(cppOut) = *reinterpret_cast< ::QJsonDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QJsonDocument_PythonToCpp_QJsonDocument_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QJsonDocument_TypeF()))
        return QJsonDocument_PythonToCpp_QJsonDocument_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QJsonDocument_SignatureStrings[] = {
    "3:PySide6.QtCore.QJsonDocument(self)",
    "2:PySide6.QtCore.QJsonDocument(self,array:PySide6.QtCore.QJsonArray)",
    "1:PySide6.QtCore.QJsonDocument(self,other:PySide6.QtCore.QJsonDocument)",
    "0:PySide6.QtCore.QJsonDocument(self,object:QJsonObject)",
    "PySide6.QtCore.QJsonDocument.array(self)->PySide6.QtCore.QJsonArray",
    "PySide6.QtCore.QJsonDocument.fromJson(json:typing.Union[PySide6.QtCore.QByteArray, char*],error:PySide6.QtCore.QJsonParseError=nullptr)->PySide6.QtCore.QJsonDocument",
    "PySide6.QtCore.QJsonDocument.fromVariant(variant:QVariant)->PySide6.QtCore.QJsonDocument",
    "PySide6.QtCore.QJsonDocument.isArray(self)->bool",
    "PySide6.QtCore.QJsonDocument.isEmpty(self)->bool",
    "PySide6.QtCore.QJsonDocument.isNull(self)->bool",
    "PySide6.QtCore.QJsonDocument.isObject(self)->bool",
    "PySide6.QtCore.QJsonDocument.object(self)->QJsonObject",
    "PySide6.QtCore.QJsonDocument.setArray(self,array:PySide6.QtCore.QJsonArray)",
    "PySide6.QtCore.QJsonDocument.setObject(self,object:QJsonObject)",
    "PySide6.QtCore.QJsonDocument.swap(self,other:PySide6.QtCore.QJsonDocument)",
    "PySide6.QtCore.QJsonDocument.toJson(self,format:PySide6.QtCore.QJsonDocument.JsonFormat=QJsonDocument.JsonFormat.Indented)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QJsonDocument.toVariant(self)->QVariant",
    "PySide6.QtCore.QJsonDocument.__copy__(self)->typing.Self",
    "PySide6.QtCore.QJsonDocument.__ne__(self,rhs:PySide6.QtCore.QJsonDocument)->bool",
    "PySide6.QtCore.QJsonDocument.__eq__(self,rhs:PySide6.QtCore.QJsonDocument)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QJsonDocument_SignatureByteSize = 321;
static constexpr uint8_t QJsonDocument_SignatureBytes[321] = {
    0x78, 0xda, 0xa5, 0x53, 0x4d, 0x4f, 0x83, 0x40, 0x10, 0xbd, 0xf3, 0x2b, 0x3c, 0x16, 0x83, 0xc4,
    0x8f, 0xc4, 0x03, 0x49, 0x4d, 0xaa, 0xd6, 0x44, 0x0f, 0x5a, 0xd2, 0xe8, 0xa5, 0x31, 0x64, 0x0b,
    0x83, 0xd0, 0xc0, 0x0e, 0xce, 0x6e, 0x35, 0xfc, 0x7b, 0x61, 0x0b, 0x8a, 0x06, 0x76, 0x21, 0x5e,
    0x58, 0x66, 0xe7, 0xbd, 0x97, 0x37, 0xb3, 0x33, 0x17, 0xde, 0xaa, 0x5c, 0xa7, 0x11, 0x5c, 0xba,
    0xbe, 0xbc, 0x41, 0x02, 0xd7, 0x7f, 0x10, 0xc8, 0x6f, 0x31, 0xdc, 0xe7, 0xc0, 0xe5, 0x4c, 0x40,
    0x16, 0xdb, 0xd6, 0xb9, 0x19, 0xe4, 0x30, 0x22, 0x56, 0xf6, 0xe2, 0x16, 0x75, 0xc6, 0xb6, 0xce,
    0x46, 0x88, 0xa0, 0x4c, 0x80, 0xb4, 0x38, 0xdb, 0x3a, 0x1d, 0xa3, 0xb3, 0xdd, 0x41, 0x28, 0x3d,
    0x95, 0x79, 0x52, 0xff, 0xb6, 0xa5, 0x63, 0xb9, 0xca, 0xfd, 0xa1, 0xda, 0x93, 0xab, 0xc1, 0x22,
    0xf4, 0x1a, 0x31, 0x61, 0x5e, 0x5f, 0xcc, 0x76, 0xd5, 0xc7, 0x93, 0x65, 0x91, 0xf2, 0x37, 0xf7,
    0x99, 0xa7, 0xc8, 0x37, 0x7f, 0x79, 0xd7, 0xa5, 0x04, 0xa5, 0xe8, 0x1c, 0x85, 0x09, 0xa3, 0xe3,
    0x57, 0x07, 0x88, 0xb0, 0xbf, 0xf2, 0x15, 0x23, 0x01, 0xcb, 0x3a, 0x3d, 0xe7, 0xfb, 0x2c, 0x2b,
    0x24, 0x0d, 0x58, 0x6c, 0x8d, 0x98, 0x5d, 0xbe, 0x30, 0x4a, 0x59, 0xd5, 0xab, 0x8f, 0xc3, 0xe9,
    0xf9, 0xcd, 0xc5, 0xbf, 0x84, 0x53, 0xb1, 0xe8, 0x36, 0x71, 0x8b, 0x98, 0x99, 0x08, 0xcb, 0xbc,
    0x90, 0x93, 0x08, 0x8f, 0x55, 0x03, 0xa6, 0xe0, 0x0f, 0x6f, 0x3f, 0x9e, 0x81, 0xbf, 0xf0, 0x9d,
    0xf1, 0xd1, 0xd3, 0x04, 0xc8, 0x9f, 0xda, 0xcd, 0x9b, 0x60, 0xd2, 0xea, 0xb8, 0x9e, 0x3e, 0xc9,
    0xe2, 0x93, 0x15, 0xe3, 0x97, 0x49, 0x2b, 0x25, 0x51, 0x8d, 0xb3, 0x12, 0x8b, 0x91, 0x72, 0x26,
    0xb5, 0x6a, 0x6e, 0x1d, 0xdc, 0x29, 0xdc, 0x7c, 0x28, 0xe1, 0xde, 0xf3, 0xa8, 0xba, 0x81, 0xa8,
    0x67, 0xd4, 0xbe, 0x97, 0xc2, 0xe4, 0xaa, 0x1d, 0xdf, 0xf6, 0x99, 0x9a, 0x58, 0x4f, 0x0b, 0x82,
    0x10, 0x8b, 0x32, 0x08, 0x5a, 0x56, 0xb3, 0x9f, 0xeb, 0x2a, 0x32, 0x11, 0x39, 0x34, 0x34, 0x87,
    0x12, 0xa1, 0x6f, 0xe8, 0x98, 0x21, 0x0b, 0x02, 0x78, 0x9f, 0x2a, 0xf8, 0x05, 0xf6, 0xf9, 0x08,
    0xe8
};
#endif

PyTypeObject *init_QJsonDocument(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX].type;

    Shiboken::AutoDecRef Sbk_QJsonDocument_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QJsonDocument_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QJsonDocument",
        "QJsonDocument",
        &Sbk_QJsonDocument_spec,
        &Shiboken::callCppDestructor< ::QJsonDocument >,
        Sbk_QJsonDocument_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QJsonDocument_TypeF(); // references _Sbk_QJsonDocument_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QJsonDocument_SignatureStrings);
#else
    InitSignatureBytes(pyType, QJsonDocument_SignatureBytes, QJsonDocument_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QJsonDocument_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QJsonDocument_PythonToCpp_QJsonDocument_PTR,
        is_QJsonDocument_PythonToCpp_QJsonDocument_PTR_Convertible,
        QJsonDocument_PTR_CppToPython_QJsonDocument,
        QJsonDocument_COPY_CppToPython_QJsonDocument);

    Shiboken::Conversions::registerConverterName(converter, "QJsonDocument");
    Shiboken::Conversions::registerConverterName(converter, "QJsonDocument*");
    Shiboken::Conversions::registerConverterName(converter, "QJsonDocument&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QJsonDocument).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QJsonDocument_PythonToCpp_QJsonDocument_COPY,
        is_QJsonDocument_PythonToCpp_QJsonDocument_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QJsonDocument_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'JsonFormat'.
    const char *JsonFormat_Initializer[] = {
        "Indented",
        "Compact",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t JsonFormat_InitializerValues[] = {
        uint8_t(QJsonDocument::JsonFormat::Indented), //  0x00  0
        uint8_t(QJsonDocument::JsonFormat::Compact)   //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QJsonDocument_TypeF(),
        "2:PySide6.QtCore.QJsonDocument.JsonFormat",
        JsonFormat_Initializer, JsonFormat_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_JsonFormat_IDX].type = EType;
    // Register converter for enum 'QJsonDocument::JsonFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QJsonDocument_JsonFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QJsonDocument_JsonFormat,
            is_Enum_PythonToCpp_QJsonDocument_JsonFormat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QJsonDocument::JsonFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "JsonFormat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'JsonFormat' enum.

    qRegisterMetaType< ::QJsonDocument::JsonFormat >("QJsonDocument::JsonFormat");

    return pyType;
}
