// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qjsonparseerror_wrapper.h"

// Argument includes
#include <QString>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QJsonParseError_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QJsonParseError >()))
        return -1;

    ::QJsonParseError *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QJsonParseError", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QJsonParseError::QJsonParseError()
    // 1: QJsonParseError::QJsonParseError(QJsonParseError)
    if (numArgs == 0) {
        overloadId = 0; // QJsonParseError()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QJsonParseError(QJsonParseError)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QJsonParseError()
        {

            // QJsonParseError()
            cptr = new ::QJsonParseError();
            break;
        }
        case 1: // QJsonParseError(const QJsonParseError &QJsonParseError)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QJsonParseError cppArg0_local;
            ::QJsonParseError *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonParseError(QJsonParseError)
                cptr = new ::QJsonParseError(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QJsonParseError >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QJsonParseErrorFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonParseError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QJsonParseError *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonParseError__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QJsonParseError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QJsonParseError_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QJsonParseError_EnumFlagInfo[] = {
    "ParseError:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QJsonParseError_methods[] = {
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QJsonParseErrorFunc_errorString), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QJsonParseError__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QJsonParseError_get_offset(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonParseError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->offset;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QJsonParseError_set_offset(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QJsonParseError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("offset");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("offset", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->offset;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->offset = cppOut_local;

    return 0;
}

static PyObject *Sbk_QJsonParseError_get_error(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonParseError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QJsonParseError::ParseError cppOut_local = cppSelf->error;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_ParseError_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QJsonParseError_set_error(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QJsonParseError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("error");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_ParseError_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("error", "ParseError");
        return -1;
    }

    auto cppOut_local = cppSelf->error;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->error = cppOut_local;

    return 0;
}

// Getters and Setters for QJsonParseError
static PyGetSetDef Sbk_QJsonParseError_getsetlist[] = {
    {const_cast<char *>("offset"), Sbk_QJsonParseError_get_offset, Sbk_QJsonParseError_set_offset, nullptr, nullptr},
    {const_cast<char *>("error"), Sbk_QJsonParseError_get_error, Sbk_QJsonParseError_set_error, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QJsonParseError_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QJsonParseError_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QJsonParseError_Type = nullptr;
static PyTypeObject *Sbk_QJsonParseError_TypeF(void)
{
    return _Sbk_QJsonParseError_Type;
}

static PyType_Slot Sbk_QJsonParseError_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QJsonParseError_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QJsonParseError_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QJsonParseError_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QJsonParseError_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QJsonParseError_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QJsonParseError_spec = {
    "2:PySide6.QtCore.QJsonParseError",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QJsonParseError_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QJsonParseError_ParseError(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QJsonParseError::ParseError>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QJsonParseError::ParseError *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QJsonParseError_ParseError_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_ParseError_IDX])))
        return Enum_PythonToCpp_QJsonParseError_ParseError;
    return {};
}

static PyObject *QJsonParseError_ParseError_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QJsonParseError::ParseError>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QJsonParseError::ParseError *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_ParseError_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QJsonParseError_PythonToCpp_QJsonParseError_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QJsonParseError_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QJsonParseError_PythonToCpp_QJsonParseError_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QJsonParseError_TypeF()))
        return QJsonParseError_PythonToCpp_QJsonParseError_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QJsonParseError_PTR_CppToPython_QJsonParseError(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QJsonParseError_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QJsonParseError_COPY_CppToPython_QJsonParseError(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QJsonParseError *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QJsonParseError_TypeF(), new ::QJsonParseError(*source), true, true);
}

// Python to C++ copy conversion.
static void QJsonParseError_PythonToCpp_QJsonParseError_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QJsonParseError *>(cppOut) = *reinterpret_cast< ::QJsonParseError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QJsonParseError_PythonToCpp_QJsonParseError_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QJsonParseError_TypeF()))
        return QJsonParseError_PythonToCpp_QJsonParseError_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QJsonParseError_SignatureStrings[] = {
    "1:PySide6.QtCore.QJsonParseError(self)",
    "0:PySide6.QtCore.QJsonParseError(self,QJsonParseError:PySide6.QtCore.QJsonParseError)",
    "PySide6.QtCore.QJsonParseError.errorString(self)->QString",
    "PySide6.QtCore.QJsonParseError.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QJsonParseError_SignatureByteSize = 98;
static constexpr uint8_t QJsonParseError_SignatureBytes[98] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0xf4, 0x2a, 0xce, 0xcf, 0x0b, 0x48, 0x2c, 0x2a, 0x4e, 0x75, 0x2d, 0x2a,
    0xca, 0x2f, 0xd2, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x20, 0x46, 0x99, 0x0e, 0x9a, 0x20,
    0x01, 0x3d, 0x9a, 0x5c, 0xf8, 0xe5, 0xf5, 0x52, 0x41, 0x64, 0x70, 0x49, 0x51, 0x66, 0x5e, 0x3a,
    0xc4, 0x19, 0xba, 0x76, 0x81, 0x10, 0x2e, 0x21, 0x9d, 0xf1, 0xf1, 0xc9, 0xf9, 0x05, 0x95, 0xf1,
    0xf1, 0x30, 0x6d, 0x25, 0x95, 0x05, 0x40, 0x5d, 0x7a, 0xc1, 0x40, 0x1e, 0x17, 0x00, 0x11, 0x3d,
    0x56, 0xfb
};
#endif

PyTypeObject *init_QJsonParseError(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX].type;

    Shiboken::AutoDecRef Sbk_QJsonParseError_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QJsonParseError_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QJsonParseError",
        "QJsonParseError",
        &Sbk_QJsonParseError_spec,
        &Shiboken::callCppDestructor< ::QJsonParseError >,
        Sbk_QJsonParseError_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QJsonParseError_TypeF(); // references _Sbk_QJsonParseError_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QJsonParseError_SignatureStrings);
#else
    InitSignatureBytes(pyType, QJsonParseError_SignatureBytes, QJsonParseError_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QJsonParseError_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QJsonParseError_PythonToCpp_QJsonParseError_PTR,
        is_QJsonParseError_PythonToCpp_QJsonParseError_PTR_Convertible,
        QJsonParseError_PTR_CppToPython_QJsonParseError,
        QJsonParseError_COPY_CppToPython_QJsonParseError);

    Shiboken::Conversions::registerConverterName(converter, "QJsonParseError");
    Shiboken::Conversions::registerConverterName(converter, "QJsonParseError*");
    Shiboken::Conversions::registerConverterName(converter, "QJsonParseError&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QJsonParseError).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QJsonParseError_PythonToCpp_QJsonParseError_COPY,
        is_QJsonParseError_PythonToCpp_QJsonParseError_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QJsonParseError_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ParseError'.
    const char *ParseError_Initializer[] = {
        "NoError",
        "UnterminatedObject",
        "MissingNameSeparator",
        "UnterminatedArray",
        "MissingValueSeparator",
        "IllegalValue",
        "TerminationByNumber",
        "IllegalNumber",
        "IllegalEscapeSequence",
        "IllegalUTF8String",
        "UnterminatedString",
        "MissingObject",
        "DeepNesting",
        "DocumentTooLarge",
        "GarbageAtEnd",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ParseError_InitializerValues[] = {
        uint8_t(QJsonParseError::ParseError::NoError),               //  0x00  0
        uint8_t(QJsonParseError::ParseError::UnterminatedObject),    //  0x01  1
        uint8_t(QJsonParseError::ParseError::MissingNameSeparator),  //  0x02  2
        uint8_t(QJsonParseError::ParseError::UnterminatedArray),     //  0x03  3
        uint8_t(QJsonParseError::ParseError::MissingValueSeparator), //  0x04  4
        uint8_t(QJsonParseError::ParseError::IllegalValue),          //  0x05  5
        uint8_t(QJsonParseError::ParseError::TerminationByNumber),   //  0x06  6
        uint8_t(QJsonParseError::ParseError::IllegalNumber),         //  0x07  7
        uint8_t(QJsonParseError::ParseError::IllegalEscapeSequence), //  0x08  8
        uint8_t(QJsonParseError::ParseError::IllegalUTF8String),     //  0x09  9
        uint8_t(QJsonParseError::ParseError::UnterminatedString),    //  0x0a  10
        uint8_t(QJsonParseError::ParseError::MissingObject),         //  0x0b  11
        uint8_t(QJsonParseError::ParseError::DeepNesting),           //  0x0c  12
        uint8_t(QJsonParseError::ParseError::DocumentTooLarge),      //  0x0d  13
        uint8_t(QJsonParseError::ParseError::GarbageAtEnd)           //  0x0e  14
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QJsonParseError_TypeF(),
        "2:PySide6.QtCore.QJsonParseError.ParseError",
        ParseError_Initializer, ParseError_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_ParseError_IDX].type = EType;
    // Register converter for enum 'QJsonParseError::ParseError'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QJsonParseError_ParseError_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QJsonParseError_ParseError,
            is_Enum_PythonToCpp_QJsonParseError_ParseError_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QJsonParseError::ParseError");
        Shiboken::Conversions::registerConverterAlias(converter, "ParseError");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ParseError' enum.

    qRegisterMetaType< ::QJsonParseError >("QJsonParseError");
    qRegisterMetaType< ::QJsonParseError::ParseError >("QJsonParseError::ParseError");

    return pyType;
}
