// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qlibraryinfo_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <qlibraryinfo.h>
#include <qversionnumber.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QLibraryInfoFunc_build(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // build()
        const char * cppResult = ::QLibraryInfo::build();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtcore.cpp (qlibraryinfo_build)]
        auto oldResult = pyResult;
        const auto version = _PepRuntimeVersion();
        pyResult = PyUnicode_FromFormat(
#ifdef Py_LIMITED_API
                                        "%U [Python limited API %d.%d.%d]",
#else
                                        "%U [Python %d.%d.%d]",
#endif
                                        oldResult, (version >> 16) & 0xFF,
                                        (version >> 8) & 0xFF, version & 0xFF);
        Py_DECREF(oldResult);
        // END of custom code block [file: ../glue/qtcore.cpp (qlibraryinfo_build)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLibraryInfoFunc_isDebugBuild(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDebugBuild()
        bool cppResult = ::QLibraryInfo::isDebugBuild();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLibraryInfoFunc_isSharedBuild(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSharedBuild()
        bool cppResult = ::QLibraryInfo::isSharedBuild();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLibraryInfoFunc_location(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLibraryInfo::location(QLibraryInfo::LibraryPath)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLibraryInfo_LibraryPath_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // location(QLibraryInfo::LibraryPath)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "location", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLibraryInfo_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QLibraryInfo", "location(QLibraryInfo.LibraryPath location)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        ::QLibraryInfo::LibraryPath cppArg0{QLibraryInfo::PrefixPath};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // location(QLibraryInfo::LibraryPath)
            QString cppResult = ::QLibraryInfo::location(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLibraryInfoFunc_path(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLibraryInfo::path(QLibraryInfo::LibraryPath)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLibraryInfo_LibraryPath_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // path(QLibraryInfo::LibraryPath)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "path", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLibraryInfo_IDX]);

    // Call function/method
    {
        ::QLibraryInfo::LibraryPath cppArg0{QLibraryInfo::PrefixPath};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // path(QLibraryInfo::LibraryPath)
            QString cppResult = ::QLibraryInfo::path(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLibraryInfoFunc_paths(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLibraryInfo::paths(QLibraryInfo::LibraryPath)->QStringList
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLibraryInfo_LibraryPath_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // paths(QLibraryInfo::LibraryPath)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "paths", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLibraryInfo_IDX]);

    // Call function/method
    {
        ::QLibraryInfo::LibraryPath cppArg0{QLibraryInfo::PrefixPath};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paths(QLibraryInfo::LibraryPath)
            QStringList cppResult = ::QLibraryInfo::paths(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLibraryInfoFunc_platformPluginArguments(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLibraryInfo::platformPluginArguments(QString)->QStringList
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // platformPluginArguments(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "platformPluginArguments", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLibraryInfo_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // platformPluginArguments(QString)
            QStringList cppResult = ::QLibraryInfo::platformPluginArguments(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLibraryInfoFunc_version(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // version()
        QVersionNumber cppResult = ::QLibraryInfo::version();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QLibraryInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QLibraryInfo_EnumFlagInfo[] = {
    "LibraryPath:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLibraryInfo_methods[] = {
    {"build", reinterpret_cast<PyCFunction>(Sbk_QLibraryInfoFunc_build), METH_NOARGS|METH_STATIC, nullptr},
    {"isDebugBuild", reinterpret_cast<PyCFunction>(Sbk_QLibraryInfoFunc_isDebugBuild), METH_NOARGS|METH_STATIC, nullptr},
    {"isSharedBuild", reinterpret_cast<PyCFunction>(Sbk_QLibraryInfoFunc_isSharedBuild), METH_NOARGS|METH_STATIC, nullptr},
    {"location", reinterpret_cast<PyCFunction>(Sbk_QLibraryInfoFunc_location), METH_O|METH_STATIC, nullptr},
    {"path", reinterpret_cast<PyCFunction>(Sbk_QLibraryInfoFunc_path), METH_O|METH_STATIC, nullptr},
    {"paths", reinterpret_cast<PyCFunction>(Sbk_QLibraryInfoFunc_paths), METH_O|METH_STATIC, nullptr},
    {"platformPluginArguments", reinterpret_cast<PyCFunction>(Sbk_QLibraryInfoFunc_platformPluginArguments), METH_O|METH_STATIC, nullptr},
    {"version", reinterpret_cast<PyCFunction>(Sbk_QLibraryInfoFunc_version), METH_NOARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QLibraryInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLibraryInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLibraryInfo_Type = nullptr;
static PyTypeObject *Sbk_QLibraryInfo_TypeF(void)
{
    return _Sbk_QLibraryInfo_Type;
}

static PyType_Slot Sbk_QLibraryInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLibraryInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLibraryInfo_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLibraryInfo_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLibraryInfo_spec = {
    "2:PySide6.QtCore.QLibraryInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLibraryInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QLibraryInfo_LibraryPath(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLibraryInfo::LibraryPath>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLibraryInfo::LibraryPath *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLibraryInfo_LibraryPath_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLibraryInfo_LibraryPath_IDX])))
        return Enum_PythonToCpp_QLibraryInfo_LibraryPath;
    return {};
}

static PyObject *QLibraryInfo_LibraryPath_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLibraryInfo::LibraryPath>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLibraryInfo::LibraryPath *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLibraryInfo_LibraryPath_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLibraryInfo_PythonToCpp_QLibraryInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLibraryInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLibraryInfo_PythonToCpp_QLibraryInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLibraryInfo_TypeF()))
        return QLibraryInfo_PythonToCpp_QLibraryInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLibraryInfo_PTR_CppToPython_QLibraryInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QLibraryInfo_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QLibraryInfo_SignatureStrings[] = {
    "PySide6.QtCore.QLibraryInfo.build()->char*",
    "PySide6.QtCore.QLibraryInfo.isDebugBuild()->bool",
    "PySide6.QtCore.QLibraryInfo.isSharedBuild()->bool",
    "PySide6.QtCore.QLibraryInfo.location(location:PySide6.QtCore.QLibraryInfo.LibraryPath)->QString",
    "PySide6.QtCore.QLibraryInfo.path(p:PySide6.QtCore.QLibraryInfo.LibraryPath)->QString",
    "PySide6.QtCore.QLibraryInfo.paths(p:PySide6.QtCore.QLibraryInfo.LibraryPath)->QStringList",
    "PySide6.QtCore.QLibraryInfo.platformPluginArguments(platformName:QString)->QStringList",
    "PySide6.QtCore.QLibraryInfo.version()->PySide6.QtCore.QVersionNumber",
    nullptr}; // Sentinel
#else
static constexpr size_t QLibraryInfo_SignatureByteSize = 175;
static constexpr uint8_t QLibraryInfo_SignatureBytes[175] = {
    0x78, 0xda, 0xb5, 0x90, 0xbb, 0x0a, 0xc3, 0x30, 0x0c, 0x45, 0xf7, 0x7c, 0x49, 0x5a, 0x68, 0xc6,
    0x0e, 0x19, 0x0a, 0x7d, 0x2c, 0x85, 0x10, 0x1c, 0x02, 0xdd, 0xed, 0x44, 0x75, 0x04, 0x7e, 0x04,
    0xd9, 0x2e, 0xe4, 0xef, 0xeb, 0xd2, 0x64, 0xe9, 0xe0, 0x3e, 0xa0, 0xdb, 0x45, 0x3a, 0xf7, 0x08,
    0xc4, 0xa6, 0x16, 0x7b, 0xd8, 0x16, 0x8d, 0x3f, 0x5a, 0x82, 0xa2, 0xa9, 0x50, 0x10, 0xa7, 0xe9,
    0x6c, 0xae, 0xb6, 0x10, 0x01, 0x55, 0x9f, 0xaf, 0x36, 0xbb, 0x6e, 0xe0, 0xb4, 0xce, 0x58, 0x02,
    0x45, 0x77, 0x02, 0x11, 0xe4, 0x61, 0x69, 0x08, 0x6b, 0xd5, 0x9b, 0x42, 0x1b, 0xa5, 0xd0, 0x7f,
    0xde, 0x50, 0xb6, 0xe3, 0x1e, 0xad, 0xc9, 0x97, 0x50, 0xa6, 0xe8, 0x39, 0x33, 0xee, 0x87, 0x28,
    0x6f, 0x5a, 0x4f, 0x68, 0x64, 0xd2, 0x3f, 0x46, 0x34, 0x1f, 0xff, 0x20, 0x75, 0xbf, 0x58, 0x2b,
    0x74, 0x3e, 0x6d, 0x56, 0xdc, 0x5f, 0x2d, 0x69, 0xa6, 0x82, 0x44, 0xb3, 0x27, 0x19, 0x34, 0x18,
    0x1f, 0x6f, 0xcd, 0xf3, 0x9a, 0x6b, 0x28, 0x67, 0xd9, 0x17, 0xda, 0x1b, 0x90, 0x7b, 0x3c, 0x39,
    0x56, 0x5e, 0xb1, 0xcb, 0x73, 0x55, 0x07, 0x2d, 0x80, 0xb2, 0x3b, 0x08, 0x60, 0xcc, 0xa2
};
#endif

PyTypeObject *init_QLibraryInfo(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QLibraryInfo_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QLibraryInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QLibraryInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QLibraryInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLibraryInfo",
        "QLibraryInfo*",
        &Sbk_QLibraryInfo_spec,
        &Shiboken::callCppDestructor< ::QLibraryInfo >,
        Sbk_QLibraryInfo_Type_bases.object(),
        0);
    auto *pyType = Sbk_QLibraryInfo_TypeF(); // references _Sbk_QLibraryInfo_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QLibraryInfo_SignatureStrings);
#else
    InitSignatureBytes(pyType, QLibraryInfo_SignatureBytes, QLibraryInfo_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLibraryInfo_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QLibraryInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLibraryInfo_PythonToCpp_QLibraryInfo_PTR,
        is_QLibraryInfo_PythonToCpp_QLibraryInfo_PTR_Convertible,
        QLibraryInfo_PTR_CppToPython_QLibraryInfo);

    Shiboken::Conversions::registerConverterName(converter, "QLibraryInfo");
    Shiboken::Conversions::registerConverterName(converter, "QLibraryInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QLibraryInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLibraryInfo).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QLibraryInfo_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'LibraryPath'.
    const char *LibraryPath_Initializer[] = {
        "PrefixPath",
        "DocumentationPath",
        "HeadersPath",
        "LibrariesPath",
        "LibraryExecutablesPath",
        "BinariesPath",
        "PluginsPath",
        "QmlImportsPath",
        "Qml2ImportsPath",
        "ArchDataPath",
        "DataPath",
        "TranslationsPath",
        "ExamplesPath",
        "TestsPath",
        "SettingsPath",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t LibraryPath_InitializerValues[] = {
        uint8_t(QLibraryInfo::LibraryPath::PrefixPath),             //  0x00  0
        uint8_t(QLibraryInfo::LibraryPath::DocumentationPath),      //  0x01  1
        uint8_t(QLibraryInfo::LibraryPath::HeadersPath),            //  0x02  2
        uint8_t(QLibraryInfo::LibraryPath::LibrariesPath),          //  0x03  3
        uint8_t(QLibraryInfo::LibraryPath::LibraryExecutablesPath), //  0x04  4
        uint8_t(QLibraryInfo::LibraryPath::BinariesPath),           //  0x05  5
        uint8_t(QLibraryInfo::LibraryPath::PluginsPath),            //  0x06  6
        uint8_t(QLibraryInfo::LibraryPath::QmlImportsPath),         //  0x07  7
        uint8_t(QLibraryInfo::LibraryPath::Qml2ImportsPath),        //  0x07  7
        uint8_t(QLibraryInfo::LibraryPath::ArchDataPath),           //  0x08  8
        uint8_t(QLibraryInfo::LibraryPath::DataPath),               //  0x09  9
        uint8_t(QLibraryInfo::LibraryPath::TranslationsPath),       //  0x0a  10
        uint8_t(QLibraryInfo::LibraryPath::ExamplesPath),           //  0x0b  11
        uint8_t(QLibraryInfo::LibraryPath::TestsPath),              //  0x0c  12
        uint8_t(QLibraryInfo::LibraryPath::SettingsPath)            //  0x64  100
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLibraryInfo_TypeF(),
        "2:PySide6.QtCore.QLibraryInfo.LibraryPath",
        LibraryPath_Initializer, LibraryPath_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLibraryInfo_LibraryPath_IDX].type = EType;
    // Register converter for enum 'QLibraryInfo::LibraryPath'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLibraryInfo_LibraryPath_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLibraryInfo_LibraryPath,
            is_Enum_PythonToCpp_QLibraryInfo_LibraryPath_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLibraryInfo::LibraryPath");
        Shiboken::Conversions::registerConverterAlias(converter, "LibraryPath");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'LibraryPath' enum.

    qRegisterMetaType< ::QLibraryInfo *>();
    qRegisterMetaType< ::QLibraryInfo::LibraryPath >("QLibraryInfo::LibraryPath");

    return pyType;
}
