// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qlinef_wrapper.h"

// Argument includes
#include <qline.h>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLineF_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLineF >()))
        return -1;

    ::QLineF *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 3)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);

    if (PyArg_UnpackTuple(args, "QLineF", 0, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLineF::QLineF()
    // 1: QLineF::QLineF(QLine)
    // 2: QLineF::QLineF(QLineF)
    // 3: QLineF::QLineF(QPointF,QPointF)
    // 4: QLineF::QLineF(qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // QLineF()
    } else if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        overloadId = 4; // QLineF(qreal,qreal,qreal,qreal)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))) {
        overloadId = 3; // QLineF(QPointF,QPointF)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QLineF(QLine)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QLineF(QLineF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QLineF()
        {

            // QLineF()
            cptr = new ::QLineF();
            break;
        }
        case 1: // QLineF(const QLine &line)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QLine cppArg0_local;
            ::QLine *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLineF(QLine)
                cptr = new ::QLineF(*cppArg0);
            }
            break;
        }
        case 2: // QLineF(const QLineF &QLineF)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QLineF cppArg0_local;
            ::QLineF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLineF(QLineF)
                cptr = new ::QLineF(*cppArg0);
            }
            break;
        }
        case 3: // QLineF(const QPointF &pt1, const QPointF &pt2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLineF(QPointF,QPointF)
                cptr = new ::QLineF(*cppArg0, *cppArg1);
            }
            break;
        }
        case 4: // QLineF(qreal x1, qreal y1, qreal x2, qreal y2)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QLineF(qreal,qreal,qreal,qreal)
                cptr = new ::QLineF(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QLineF >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QLineFFunc___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __reduce__()
        // Begin code injection
        // TEMPLATE - reduce_code - START
        pyResult = Py_BuildValue("(N(dddd))", PyObject_Type(self), cppSelf->x1(), cppSelf->y1(), cppSelf->x2(), cppSelf->y2());
        // TEMPLATE - reduce_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - repr_code - START
        QString format = QString::asprintf("%s(%f, %f, %f, %f)",
            Py_TYPE(self)->tp_name, cppSelf->x1(), cppSelf->y1(), cppSelf->x2(), cppSelf->y2());
        pyResult = Shiboken::String::fromCString(qPrintable(format));
        // TEMPLATE - repr_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_angle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // angle()const
        qreal cppResult = const_cast<const ::QLineF *>(cppSelf)->angle();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_angleTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLineF::angleTo(QLineF)const->qreal
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), (pyArg)))) {
        overloadId = 0; // angleTo(QLineF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "angleTo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLineF cppArg0_local;
        ::QLineF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // angleTo(QLineF)const
            qreal cppResult = const_cast<const ::QLineF *>(cppSelf)->angleTo(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_center(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // center()const
        QPointF cppResult = const_cast<const ::QLineF *>(cppSelf)->center();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_dx(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dx()const
        qreal cppResult = const_cast<const ::QLineF *>(cppSelf)->dx();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_dy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dy()const
        qreal cppResult = const_cast<const ::QLineF *>(cppSelf)->dy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_fromPolar(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "fromPolar", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QLineF::fromPolar(qreal,qreal)->QLineF
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 0; // fromPolar(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromPolar", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromPolar(qreal,qreal)
            QLineF cppResult = ::QLineF::fromPolar(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_intersects(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLineF::intersects(QLineF,QPointF*=)const->(intersectType, intersectionPoint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), (pyArg)))) {
        overloadId = 0; // intersects(QLineF,QPointF*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "intersects", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLineF cppArg0_local;
        ::QLineF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);

        ::QPointF* removed_cppArg1 = nullptr;
        SBK_UNUSED(removed_cppArg1)

        if (Shiboken::Errors::occurred() == nullptr) {
            // intersects(QLineF,QPointF*)const
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qlinef-intersect)]
            QPointF p;
            ::QLineF::IntersectionType retval = cppSelf->intersects((*cppArg0), &p);
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IntersectionType_IDX])))->converter, &retval));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &p));
            // END of custom code block [file: ../glue/qtcore.cpp (qlinef-intersect)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QLineF *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // length()const
        qreal cppResult = const_cast<const ::QLineF *>(cppSelf)->length();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_normalVector(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // normalVector()const
        QLineF cppResult = const_cast<const ::QLineF *>(cppSelf)->normalVector();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_p1(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // p1()const
        QPointF cppResult = const_cast<const ::QLineF *>(cppSelf)->p1();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_p2(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // p2()const
        QPointF cppResult = const_cast<const ::QLineF *>(cppSelf)->p2();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_pointAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLineF::pointAt(qreal)const->QPointF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // pointAt(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "pointAt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // pointAt(qreal)const
            QPointF cppResult = const_cast<const ::QLineF *>(cppSelf)->pointAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_setAngle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLineF::setAngle(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setAngle(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAngle", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAngle(qreal)
            cppSelf->setAngle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLineFFunc_setLength(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLineF::setLength(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setLength(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLength", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLength(qreal)
            cppSelf->setLength(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLineFFunc_setLine(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setLine", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLineF::setLine(qreal,qreal,qreal,qreal)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        overloadId = 0; // setLine(qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setLine", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        qreal cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        qreal cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLine(qreal,qreal,qreal,qreal)
            cppSelf->setLine(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLineFFunc_setP1(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLineF::setP1(QPointF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 0; // setP1(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setP1", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setP1(QPointF)
            cppSelf->setP1(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLineFFunc_setP2(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLineF::setP2(QPointF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 0; // setP2(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setP2", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setP2(QPointF)
            cppSelf->setP2(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLineFFunc_setPoints(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setPoints", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLineF::setPoints(QPointF,QPointF)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setPoints(QPointF,QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPoints", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPointF cppArg1_local;
        ::QPointF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPoints(QPointF,QPointF)
            cppSelf->setPoints(*cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLineFFunc_toLine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toLine()const
        QLine cppResult = const_cast<const ::QLineF *>(cppSelf)->toLine();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_toTuple(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toTuple()
        // Begin code injection
        // TEMPLATE - to_tuple - START
        pyResult = Py_BuildValue("dddd", cppSelf->x1(), cppSelf->y1(), cppSelf->x2(), cppSelf->y2());
        // TEMPLATE - to_tuple - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_translate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "translate", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLineF::translate(QPointF)
    // 1: QLineF::translate(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 1; // translate(qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // translate(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "translate", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // translate(const QPointF &p)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // translate(QPointF)
                cppSelf->translate(*cppArg0);
            }
            break;
        }
        case 1: // translate(qreal dx, qreal dy)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // translate(qreal,qreal)
                cppSelf->translate(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLineFFunc_translated(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "translated", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLineF::translated(QPointF)const->QLineF
    // 1: QLineF::translated(qreal,qreal)const->QLineF
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 1; // translated(qreal,qreal)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // translated(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "translated", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // translated(const QPointF &p) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // translated(QPointF)const
                QLineF cppResult = const_cast<const ::QLineF *>(cppSelf)->translated(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), &cppResult);
            }
            break;
        }
        case 1: // translated(qreal dx, qreal dy) const
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // translated(qreal,qreal)const
                QLineF cppResult = const_cast<const ::QLineF *>(cppSelf)->translated(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_unitVector(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unitVector()const
        QLineF cppResult = const_cast<const ::QLineF *>(cppSelf)->unitVector();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_x1(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // x1()const
        qreal cppResult = const_cast<const ::QLineF *>(cppSelf)->x1();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_x2(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // x2()const
        qreal cppResult = const_cast<const ::QLineF *>(cppSelf)->x2();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_y1(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // y1()const
        qreal cppResult = const_cast<const ::QLineF *>(cppSelf)->y1();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineFFunc_y2(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // y2()const
        qreal cppResult = const_cast<const ::QLineF *>(cppSelf)->y2();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLineF__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QLineF_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QLineF_EnumFlagInfo[] = {
    "IntersectionType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLineF_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc___reduce__), METH_NOARGS, nullptr},
    {"angle", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_angle), METH_NOARGS, nullptr},
    {"angleTo", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_angleTo), METH_O, nullptr},
    {"center", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_center), METH_NOARGS, nullptr},
    {"dx", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_dx), METH_NOARGS, nullptr},
    {"dy", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_dy), METH_NOARGS, nullptr},
    {"fromPolar", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_fromPolar), METH_VARARGS|METH_STATIC, nullptr},
    {"intersects", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_intersects), METH_O, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_isNull), METH_NOARGS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_length), METH_NOARGS, nullptr},
    {"normalVector", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_normalVector), METH_NOARGS, nullptr},
    {"p1", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_p1), METH_NOARGS, nullptr},
    {"p2", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_p2), METH_NOARGS, nullptr},
    {"pointAt", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_pointAt), METH_O, nullptr},
    {"setAngle", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_setAngle), METH_O, nullptr},
    {"setLength", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_setLength), METH_O, nullptr},
    {"setLine", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_setLine), METH_VARARGS, nullptr},
    {"setP1", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_setP1), METH_O, nullptr},
    {"setP2", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_setP2), METH_O, nullptr},
    {"setPoints", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_setPoints), METH_VARARGS, nullptr},
    {"toLine", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_toLine), METH_NOARGS, nullptr},
    {"toTuple", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_toTuple), METH_NOARGS, nullptr},
    {"translate", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_translate), METH_VARARGS, nullptr},
    {"translated", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_translated), METH_VARARGS, nullptr},
    {"unitVector", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_unitVector), METH_NOARGS, nullptr},
    {"x1", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_x1), METH_NOARGS, nullptr},
    {"x2", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_x2), METH_NOARGS, nullptr},
    {"y1", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_y1), METH_NOARGS, nullptr},
    {"y2", reinterpret_cast<PyCFunction>(Sbk_QLineFFunc_y2), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QLineF__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QLineF___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QLineF_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), (pyArg)))) {
                // operator!=(const QLine &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLine cppArg0_local;
                ::QLine *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), (pyArg)))) {
                // operator!=(const QLineF &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLineF cppArg0_local;
                ::QLineF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), (pyArg)))) {
                // operator==(const QLine &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLine cppArg0_local;
                ::QLine *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), (pyArg)))) {
                // operator==(const QLineF &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLineF cppArg0_local;
                ::QLineF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QLineF_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLineF_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLineF_Type = nullptr;
static PyTypeObject *Sbk_QLineF_TypeF(void)
{
    return _Sbk_QLineF_Type;
}

static PyType_Slot Sbk_QLineF_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QLineFFunc___repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLineF_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLineF_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QLineF_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLineF_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLineF_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QLineF___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLineF_spec = {
    "2:PySide6.QtCore.QLineF",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLineF_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QLineF_IntersectionType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLineF::IntersectionType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLineF::IntersectionType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLineF_IntersectionType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IntersectionType_IDX])))
        return Enum_PythonToCpp_QLineF_IntersectionType;
    return {};
}

static PyObject *QLineF_IntersectionType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLineF::IntersectionType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLineF::IntersectionType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IntersectionType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLineF_PythonToCpp_QLineF_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLineF_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLineF_PythonToCpp_QLineF_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLineF_TypeF()))
        return QLineF_PythonToCpp_QLineF_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLineF_PTR_CppToPython_QLineF(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QLineF_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QLineF_COPY_CppToPython_QLineF(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QLineF *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QLineF_TypeF(), new ::QLineF(*source), true, true);
}

// Python to C++ copy conversion.
static void QLineF_PythonToCpp_QLineF_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QLineF *>(cppOut) = *reinterpret_cast< ::QLineF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QLineF_PythonToCpp_QLineF_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QLineF_TypeF()))
        return QLineF_PythonToCpp_QLineF_COPY;
    return {};
}

// Implicit conversions.
static void constQLineREF_PythonToCpp_QLineF(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QLineF *>(cppOut) = ::QLineF( *reinterpret_cast< ::QLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQLineREF_PythonToCpp_QLineF_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), pyIn))
        return constQLineREF_PythonToCpp_QLineF;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QLineF_SignatureStrings[] = {
    "4:PySide6.QtCore.QLineF(self)",
    "3:PySide6.QtCore.QLineF(self,line:PySide6.QtCore.QLine)",
    "2:PySide6.QtCore.QLineF(self,QLineF:PySide6.QtCore.QLineF)",
    "1:PySide6.QtCore.QLineF(self,pt1:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint],pt2:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint])",
    "0:PySide6.QtCore.QLineF(self,x1:qreal,y1:qreal,x2:qreal,y2:qreal)",
    "PySide6.QtCore.QLineF.__reduce__(self)->str",
    "PySide6.QtCore.QLineF.__repr__(self)->str",
    "PySide6.QtCore.QLineF.angle(self)->qreal",
    "PySide6.QtCore.QLineF.angleTo(self,l:typing.Union[PySide6.QtCore.QLineF, PySide6.QtCore.QLine])->qreal",
    "PySide6.QtCore.QLineF.center(self)->PySide6.QtCore.QPointF",
    "PySide6.QtCore.QLineF.dx(self)->qreal",
    "PySide6.QtCore.QLineF.dy(self)->qreal",
    "PySide6.QtCore.QLineF.fromPolar(length:qreal,angle:qreal)->PySide6.QtCore.QLineF",
    "PySide6.QtCore.QLineF.intersects(self,l:typing.Union[PySide6.QtCore.QLineF, PySide6.QtCore.QLine])->Tuple[PySide6.QtCore.QLineF.IntersectionType, PySide6.QtCore.QPointF]",
    "PySide6.QtCore.QLineF.isNull(self)->bool",
    "PySide6.QtCore.QLineF.length(self)->qreal",
    "PySide6.QtCore.QLineF.normalVector(self)->PySide6.QtCore.QLineF",
    "PySide6.QtCore.QLineF.p1(self)->PySide6.QtCore.QPointF",
    "PySide6.QtCore.QLineF.p2(self)->PySide6.QtCore.QPointF",
    "PySide6.QtCore.QLineF.pointAt(self,t:qreal)->PySide6.QtCore.QPointF",
    "PySide6.QtCore.QLineF.setAngle(self,angle:qreal)",
    "PySide6.QtCore.QLineF.setLength(self,len:qreal)",
    "PySide6.QtCore.QLineF.setLine(self,x1:qreal,y1:qreal,x2:qreal,y2:qreal)",
    "PySide6.QtCore.QLineF.setP1(self,p1:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint])",
    "PySide6.QtCore.QLineF.setP2(self,p2:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint])",
    "PySide6.QtCore.QLineF.setPoints(self,p1:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint],p2:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint])",
    "PySide6.QtCore.QLineF.toLine(self)->PySide6.QtCore.QLine",
    "PySide6.QtCore.QLineF.toTuple(self)->PyObject",
    "1:PySide6.QtCore.QLineF.translate(self,p:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint])",
    "0:PySide6.QtCore.QLineF.translate(self,dx:qreal,dy:qreal)",
    "1:PySide6.QtCore.QLineF.translated(self,p:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint])->PySide6.QtCore.QLineF",
    "0:PySide6.QtCore.QLineF.translated(self,dx:qreal,dy:qreal)->PySide6.QtCore.QLineF",
    "PySide6.QtCore.QLineF.unitVector(self)->PySide6.QtCore.QLineF",
    "PySide6.QtCore.QLineF.x1(self)->qreal",
    "PySide6.QtCore.QLineF.x2(self)->qreal",
    "PySide6.QtCore.QLineF.y1(self)->qreal",
    "PySide6.QtCore.QLineF.y2(self)->qreal",
    "PySide6.QtCore.QLineF.__copy__(self)->typing.Self",
    "1:PySide6.QtCore.QLineF.__ne__(self,rhs:PySide6.QtCore.QLine)->bool",
    "0:PySide6.QtCore.QLineF.__ne__(self,rhs:typing.Union[PySide6.QtCore.QLineF, PySide6.QtCore.QLine])->bool",
    "1:PySide6.QtCore.QLineF.__eq__(self,rhs:PySide6.QtCore.QLine)->bool",
    "0:PySide6.QtCore.QLineF.__eq__(self,rhs:typing.Union[PySide6.QtCore.QLineF, PySide6.QtCore.QLine])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QLineF_SignatureByteSize = 475;
static constexpr uint8_t QLineF_SignatureBytes[475] = {
    0x78, 0xda, 0xb5, 0x56, 0x51, 0x6b, 0xc2, 0x30, 0x10, 0x7e, 0xef, 0xaf, 0xd8, 0xa3, 0x85, 0xae,
    0xd8, 0x6e, 0xec, 0xc1, 0x87, 0x81, 0x0c, 0x84, 0x81, 0x6c, 0x15, 0xdd, 0x5e, 0x86, 0x94, 0xda,
    0x46, 0xed, 0x88, 0x49, 0x4c, 0x52, 0x68, 0xfe, 0xfd, 0xd2, 0x9a, 0x2a, 0x6a, 0x13, 0x33, 0xab,
    0x6f, 0xd7, 0xe6, 0xbe, 0xbb, 0x2f, 0xdf, 0x5d, 0x2e, 0x79, 0x1e, 0x44, 0x62, 0x9a, 0x67, 0xe0,
    0xc5, 0x9f, 0xf0, 0x37, 0x4c, 0x81, 0x3f, 0x19, 0xe7, 0x08, 0x8c, 0x7a, 0x0c, 0xc0, 0xa5, 0xeb,
    0x3c, 0x19, 0x56, 0x3d, 0x28, 0xcd, 0xd6, 0x75, 0xd7, 0x09, 0x4d, 0xb8, 0x9d, 0xdd, 0xee, 0xe1,
    0x3a, 0x81, 0x09, 0x4a, 0x78, 0x30, 0xe0, 0x82, 0xe4, 0x68, 0xe5, 0x7f, 0xa1, 0x1c, 0xa3, 0x9f,
    0x53, 0xdf, 0x08, 0xe7, 0x88, 0x8f, 0xbc, 0x87, 0xd6, 0xff, 0x73, 0x89, 0x0f, 0xbb, 0xe0, 0x5d,
    0xa7, 0x6f, 0x62, 0x57, 0x06, 0x83, 0x2d, 0x05, 0x09, 0xf4, 0x44, 0x63, 0x94, 0x61, 0xf3, 0x47,
    0x19, 0xae, 0xd3, 0x8a, 0xf7, 0xe3, 0x98, 0x82, 0xac, 0x48, 0x41, 0x1c, 0xef, 0x94, 0x7f, 0x7c,
    0x65, 0x9c, 0x1a, 0x7c, 0x09, 0xb5, 0xf1, 0x4c, 0xd0, 0x0a, 0x82, 0xc6, 0xad, 0xce, 0x6f, 0x72,
    0x9c, 0x61, 0x55, 0x57, 0xb3, 0x44, 0x35, 0xe2, 0x5c, 0xa1, 0xea, 0xf7, 0xfc, 0x42, 0x9a, 0x14,
    0x20, 0x0e, 0x68, 0x43, 0xa8, 0x5d, 0x7b, 0x0d, 0x34, 0x2b, 0x6d, 0xf6, 0x91, 0x09, 0x1b, 0xaf,
    0x25, 0xc5, 0x9b, 0x08, 0xc3, 0x84, 0xf6, 0x20, 0x40, 0x2b, 0xbe, 0x56, 0x35, 0xaa, 0x45, 0x50,
    0x65, 0x3a, 0x67, 0x57, 0x43, 0x35, 0x01, 0xf3, 0x6a, 0x5b, 0x0c, 0xa4, 0x9c, 0xdd, 0x42, 0xc1,
    0x59, 0x41, 0x20, 0x68, 0x07, 0xf9, 0xef, 0x4d, 0x26, 0x19, 0x77, 0x26, 0x08, 0xd0, 0x74, 0xea,
    0x68, 0xae, 0x63, 0xca, 0x3e, 0x0a, 0x08, 0x1b, 0x91, 0x16, 0x18, 0xeb, 0x34, 0xda, 0x29, 0x63,
    0xa3, 0x26, 0xc2, 0x74, 0x93, 0xc0, 0x6f, 0xc9, 0x09, 0x6b, 0x4b, 0x6b, 0x12, 0x8f, 0x04, 0x57,
    0x35, 0x04, 0x09, 0xaf, 0x83, 0x55, 0x8b, 0x43, 0xbe, 0xab, 0x13, 0xd7, 0x56, 0xdb, 0x18, 0x83,
    0x01, 0x3e, 0xdc, 0x9f, 0xac, 0xa3, 0xb6, 0xd1, 0x03, 0xc6, 0x07, 0x3d, 0x3d, 0xa9, 0xed, 0x65,
    0x7f, 0x69, 0x74, 0x9e, 0x2a, 0x32, 0x4e, 0x14, 0xa8, 0xc9, 0x19, 0x74, 0x1b, 0x7c, 0xfa, 0x04,
    0xa1, 0x4a, 0x10, 0xde, 0x2b, 0x41, 0xe5, 0xc0, 0x6e, 0xb1, 0x8b, 0x3b, 0x71, 0xe4, 0x78, 0x5f,
    0x2c, 0x4d, 0xeb, 0x6b, 0x81, 0xf5, 0x51, 0x3f, 0x20, 0x3f, 0x17, 0xbf, 0xf2, 0x18, 0xe9, 0xae,
    0x40, 0x9f, 0xd3, 0x04, 0x31, 0x98, 0x70, 0xd5, 0x18, 0xe4, 0x2e, 0x57, 0xd9, 0x69, 0x96, 0xac,
    0x54, 0xcd, 0x96, 0x89, 0xa6, 0xd9, 0x2e, 0xf2, 0xcb, 0x6e, 0x41, 0x50, 0x37, 0x45, 0xfa, 0x96,
    0xd9, 0xcf, 0x89, 0xff, 0x6f, 0x2e, 0x15, 0x28, 0xe7, 0xd7, 0x4f, 0xb5, 0x32, 0xb0, 0x99, 0x9d,
    0x65, 0x68, 0xe3, 0x25, 0xac, 0x62, 0x09, 0xab, 0x58, 0x71, 0x9c, 0x62, 0x22, 0x0e, 0x8f, 0x07,
    0x55, 0xa1, 0xa9, 0xfc, 0xd2, 0xd6, 0x35, 0x8e, 0x51, 0xf3, 0x30, 0xf1, 0xe8, 0x9a, 0xb5, 0xbf,
    0xf9, 0xd4, 0x6d, 0xd2, 0xb7, 0x8c, 0xd1, 0xe5, 0x82, 0xac, 0x13, 0xe9, 0xc9, 0x82, 0x6d, 0x77,
    0xb2, 0xc7, 0x31, 0x3a, 0x93, 0xfd, 0x03, 0x57, 0x8b, 0xee, 0x68
};
#endif

PyTypeObject *init_QLineF(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX].type;

    Shiboken::AutoDecRef Sbk_QLineF_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QLineF_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLineF",
        "QLineF",
        &Sbk_QLineF_spec,
        &Shiboken::callCppDestructor< ::QLineF >,
        Sbk_QLineF_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QLineF_TypeF(); // references _Sbk_QLineF_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QLineF_SignatureStrings);
#else
    InitSignatureBytes(pyType, QLineF_SignatureBytes, QLineF_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLineF_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLineF_PythonToCpp_QLineF_PTR,
        is_QLineF_PythonToCpp_QLineF_PTR_Convertible,
        QLineF_PTR_CppToPython_QLineF,
        QLineF_COPY_CppToPython_QLineF);

    Shiboken::Conversions::registerConverterName(converter, "QLineF");
    Shiboken::Conversions::registerConverterName(converter, "QLineF*");
    Shiboken::Conversions::registerConverterName(converter, "QLineF&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLineF).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLineF_PythonToCpp_QLineF_COPY,
        is_QLineF_PythonToCpp_QLineF_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQLineREF_PythonToCpp_QLineF,
        is_constQLineREF_PythonToCpp_QLineF_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QLineF_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'IntersectionType'.
    const char *IntersectionType_Initializer[] = {
        "NoIntersection",
        "BoundedIntersection",
        "UnboundedIntersection",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t IntersectionType_InitializerValues[] = {
        uint8_t(QLineF::IntersectionType::NoIntersection),       //  0x00  0
        uint8_t(QLineF::IntersectionType::BoundedIntersection),  //  0x01  1
        uint8_t(QLineF::IntersectionType::UnboundedIntersection) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLineF_TypeF(),
        "2:PySide6.QtCore.QLineF.IntersectionType",
        IntersectionType_Initializer, IntersectionType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IntersectionType_IDX].type = EType;
    // Register converter for enum 'QLineF::IntersectionType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLineF_IntersectionType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLineF_IntersectionType,
            is_Enum_PythonToCpp_QLineF_IntersectionType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLineF::IntersectionType");
        Shiboken::Conversions::registerConverterAlias(converter, "IntersectionType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'IntersectionType' enum.

    qRegisterMetaType< ::QLineF >("QLineF");
    qRegisterMetaType< ::QLineF::IntersectionType >("QLineF::IntersectionType");

    return pyType;
}
