// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qlocationpermission_wrapper.h"

// Argument includes
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpermissions.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLocationPermission_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLocationPermission >()))
        return -1;

    ::QLocationPermission *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QLocationPermission", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLocationPermission::QLocationPermission()
    // 1: QLocationPermission::QLocationPermission(QLocationPermission)
    if (numArgs == 0) {
        overloadId = 0; // QLocationPermission()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QLocationPermission(QLocationPermission)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QLocationPermission()
        {

            // QLocationPermission()
            cptr = new ::QLocationPermission();
            break;
        }
        case 1: // QLocationPermission(const QLocationPermission &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QLocationPermission cppArg0_local;
            ::QLocationPermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLocationPermission(QLocationPermission)
                cptr = new ::QLocationPermission(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QLocationPermission >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QLocationPermissionFunc_accuracy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocationPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // accuracy()const
        QLocationPermission::Accuracy cppResult = const_cast<const ::QLocationPermission *>(cppSelf)->accuracy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_Accuracy_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocationPermissionFunc_availability(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocationPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // availability()const
        QLocationPermission::Availability cppResult = const_cast<const ::QLocationPermission *>(cppSelf)->availability();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_Availability_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocationPermissionFunc_setAccuracy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocationPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocationPermission::setAccuracy(QLocationPermission::Accuracy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_Accuracy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAccuracy(QLocationPermission::Accuracy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAccuracy", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]);

    // Call function/method
    {
        ::QLocationPermission::Accuracy cppArg0{QLocationPermission::Approximate};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAccuracy(QLocationPermission::Accuracy)
            cppSelf->setAccuracy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLocationPermissionFunc_setAvailability(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocationPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocationPermission::setAvailability(QLocationPermission::Availability)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_Availability_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAvailability(QLocationPermission::Availability)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAvailability", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]);

    // Call function/method
    {
        ::QLocationPermission::Availability cppArg0{QLocationPermission::WhenInUse};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAvailability(QLocationPermission::Availability)
            cppSelf->setAvailability(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLocationPermissionFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocationPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocationPermission::swap(QLocationPermission&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QLocationPermission&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLocationPermission cppArg0_local;
        ::QLocationPermission *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QLocationPermission&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLocationPermission__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLocationPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QLocationPermission_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QLocationPermission_EnumFlagInfo[] = {
    "Accuracy:Enum",
    "Availability:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLocationPermission_methods[] = {
    {"accuracy", reinterpret_cast<PyCFunction>(Sbk_QLocationPermissionFunc_accuracy), METH_NOARGS, nullptr},
    {"availability", reinterpret_cast<PyCFunction>(Sbk_QLocationPermissionFunc_availability), METH_NOARGS, nullptr},
    {"setAccuracy", reinterpret_cast<PyCFunction>(Sbk_QLocationPermissionFunc_setAccuracy), METH_O, nullptr},
    {"setAvailability", reinterpret_cast<PyCFunction>(Sbk_QLocationPermissionFunc_setAvailability), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QLocationPermissionFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QLocationPermission__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QLocationPermission_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLocationPermission_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLocationPermission_Type = nullptr;
static PyTypeObject *Sbk_QLocationPermission_TypeF(void)
{
    return _Sbk_QLocationPermission_Type;
}

static PyType_Slot Sbk_QLocationPermission_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLocationPermission_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLocationPermission_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLocationPermission_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLocationPermission_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLocationPermission_spec = {
    "2:PySide6.QtCore.QLocationPermission",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLocationPermission_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QLocationPermission_Accuracy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLocationPermission::Accuracy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLocationPermission::Accuracy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLocationPermission_Accuracy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_Accuracy_IDX])))
        return Enum_PythonToCpp_QLocationPermission_Accuracy;
    return {};
}

static PyObject *QLocationPermission_Accuracy_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLocationPermission::Accuracy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLocationPermission::Accuracy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_Accuracy_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QLocationPermission_Availability(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLocationPermission::Availability>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLocationPermission::Availability *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLocationPermission_Availability_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_Availability_IDX])))
        return Enum_PythonToCpp_QLocationPermission_Availability;
    return {};
}

static PyObject *QLocationPermission_Availability_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLocationPermission::Availability>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLocationPermission::Availability *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_Availability_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLocationPermission_PythonToCpp_QLocationPermission_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLocationPermission_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLocationPermission_PythonToCpp_QLocationPermission_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLocationPermission_TypeF()))
        return QLocationPermission_PythonToCpp_QLocationPermission_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLocationPermission_PTR_CppToPython_QLocationPermission(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QLocationPermission_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QLocationPermission_COPY_CppToPython_QLocationPermission(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QLocationPermission *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QLocationPermission_TypeF(), new ::QLocationPermission(*source), true, true);
}

// Python to C++ copy conversion.
static void QLocationPermission_PythonToCpp_QLocationPermission_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QLocationPermission *>(cppOut) = *reinterpret_cast< ::QLocationPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QLocationPermission_PythonToCpp_QLocationPermission_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QLocationPermission_TypeF()))
        return QLocationPermission_PythonToCpp_QLocationPermission_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QLocationPermission_SignatureStrings[] = {
    "1:PySide6.QtCore.QLocationPermission(self)",
    "0:PySide6.QtCore.QLocationPermission(self,other:PySide6.QtCore.QLocationPermission)",
    "PySide6.QtCore.QLocationPermission.accuracy(self)->PySide6.QtCore.QLocationPermission.Accuracy",
    "PySide6.QtCore.QLocationPermission.availability(self)->PySide6.QtCore.QLocationPermission.Availability",
    "PySide6.QtCore.QLocationPermission.setAccuracy(self,accuracy:PySide6.QtCore.QLocationPermission.Accuracy)",
    "PySide6.QtCore.QLocationPermission.setAvailability(self,availability:PySide6.QtCore.QLocationPermission.Availability)",
    "PySide6.QtCore.QLocationPermission.swap(self,other:PySide6.QtCore.QLocationPermission)",
    "PySide6.QtCore.QLocationPermission.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QLocationPermission_SignatureByteSize = 159;
static constexpr uint8_t QLocationPermission_SignatureBytes[159] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0xf4, 0xc9, 0x4f, 0x4e, 0x2c, 0xc9, 0xcc, 0xcf, 0x0b, 0x48, 0x2d, 0xca,
    0xcd, 0x2c, 0x2e, 0x06, 0xb2, 0x34, 0x8a, 0x53, 0x73, 0xd2, 0x34, 0xb9, 0x0c, 0x88, 0x55, 0xaa,
    0x93, 0x5f, 0x92, 0x91, 0x5a, 0x44, 0x84, 0x6a, 0x4d, 0x2e, 0xc2, 0x6a, 0xf4, 0x12, 0x93, 0x93,
    0x4b, 0x8b, 0x12, 0x93, 0x2b, 0x21, 0xae, 0xd0, 0xb5, 0x23, 0x42, 0x8b, 0x23, 0x54, 0x0b, 0x51,
    0xc6, 0x97, 0x25, 0x66, 0xe6, 0x24, 0x26, 0x65, 0xe6, 0x64, 0x96, 0x90, 0x64, 0x05, 0x92, 0x36,
    0x62, 0xac, 0x29, 0x4e, 0x2d, 0x71, 0x44, 0xf6, 0x88, 0x0e, 0xcc, 0x5b, 0x56, 0x24, 0xf8, 0x47,
    0x93, 0x58, 0x9b, 0xd0, 0xfd, 0xa4, 0x83, 0xec, 0x4b, 0x2b, 0x12, 0xbd, 0x47, 0x9c, 0xad, 0xe5,
    0x89, 0x05, 0x34, 0x88, 0xfc, 0xf8, 0xf8, 0xe4, 0xfc, 0x82, 0xca, 0xf8, 0x78, 0x58, 0xcc, 0x94,
    0x54, 0x16, 0x64, 0xe6, 0xa5, 0xeb, 0x05, 0x03, 0x79, 0x5c, 0x00, 0x67, 0x3e, 0x02, 0xbf
};
#endif

PyTypeObject *init_QLocationPermission(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX].type;

    Shiboken::AutoDecRef Sbk_QLocationPermission_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QLocationPermission_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLocationPermission",
        "QLocationPermission",
        &Sbk_QLocationPermission_spec,
        &Shiboken::callCppDestructor< ::QLocationPermission >,
        Sbk_QLocationPermission_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QLocationPermission_TypeF(); // references _Sbk_QLocationPermission_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QLocationPermission_SignatureStrings);
#else
    InitSignatureBytes(pyType, QLocationPermission_SignatureBytes, QLocationPermission_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLocationPermission_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLocationPermission_PythonToCpp_QLocationPermission_PTR,
        is_QLocationPermission_PythonToCpp_QLocationPermission_PTR_Convertible,
        QLocationPermission_PTR_CppToPython_QLocationPermission,
        QLocationPermission_COPY_CppToPython_QLocationPermission);

    Shiboken::Conversions::registerConverterName(converter, "QLocationPermission");
    Shiboken::Conversions::registerConverterName(converter, "QLocationPermission*");
    Shiboken::Conversions::registerConverterName(converter, "QLocationPermission&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLocationPermission).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLocationPermission_PythonToCpp_QLocationPermission_COPY,
        is_QLocationPermission_PythonToCpp_QLocationPermission_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QLocationPermission_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Accuracy'.
    const char *Accuracy_Initializer[] = {
        "Approximate",
        "Precise",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t Accuracy_InitializerValues[] = {
        uint8_t(QLocationPermission::Accuracy::Approximate), //  0x00  0
        uint8_t(QLocationPermission::Accuracy::Precise)      //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLocationPermission_TypeF(),
        "2:PySide6.QtCore.QLocationPermission.Accuracy",
        Accuracy_Initializer, Accuracy_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_Accuracy_IDX].type = EType;
    // Register converter for enum 'QLocationPermission::Accuracy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLocationPermission_Accuracy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLocationPermission_Accuracy,
            is_Enum_PythonToCpp_QLocationPermission_Accuracy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLocationPermission::Accuracy");
        Shiboken::Conversions::registerConverterAlias(converter, "Accuracy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Accuracy' enum.

    // Initialization of enum 'Availability'.
    const char *Availability_Initializer[] = {
        "WhenInUse",
        "Always",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t Availability_InitializerValues[] = {
        uint8_t(QLocationPermission::Availability::WhenInUse), //  0x00  0
        uint8_t(QLocationPermission::Availability::Always)     //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLocationPermission_TypeF(),
        "2:PySide6.QtCore.QLocationPermission.Availability",
        Availability_Initializer, Availability_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_Availability_IDX].type = EType;
    // Register converter for enum 'QLocationPermission::Availability'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLocationPermission_Availability_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLocationPermission_Availability,
            is_Enum_PythonToCpp_QLocationPermission_Availability_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLocationPermission::Availability");
        Shiboken::Conversions::registerConverterAlias(converter, "Availability");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Availability' enum.

    qRegisterMetaType< ::QLocationPermission >("QLocationPermission");
    qRegisterMetaType< ::QLocationPermission::Accuracy >("QLocationPermission::Accuracy");
    qRegisterMetaType< ::QLocationPermission::Availability >("QLocationPermission::Availability");

    return pyType;
}
