// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qmessageauthenticationcode_wrapper.h"

// Argument includes
#include <qbytearray.h>
#include <qbytearrayview.h>
#include <qcryptographichash.h>
#include <qiodevice.h>
#include <qmessageauthenticationcode.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMessageAuthenticationCode_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMessageAuthenticationCode >()))
        return -1;

    ::QMessageAuthenticationCode *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QMessageAuthenticationCode", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMessageAuthenticationCode::QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArrayView=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_Algorithm_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArrayView)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArrayView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_key = Shiboken::String::createStaticString("key");
            if (PyDict_Contains(kwds, key_key) != 0) {
                value = PyDict_GetItem(kwds, key_key);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_key);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QByteArrayView_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_key);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]);
            }
        }
        ::QCryptographicHash::Algorithm cppArg0{QCryptographicHash::Md4};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QByteArray cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArrayView)
            cptr = new ::QMessageAuthenticationCode(cppArg0, QByteArrayView(cppArg1));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMessageAuthenticationCode >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMessageAuthenticationCodeFunc_addData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageAuthenticationCode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addData", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMessageAuthenticationCode::addData(QByteArrayView)
    // 1: QMessageAuthenticationCode::addData(QIODevice*)->bool
    // 2: QMessageAuthenticationCode::addData(const char*,qsizetype)
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 2; // addData(const char*,qsizetype)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        overloadId = 1; // addData(QIODevice*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 0; // addData(QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addData(QByteArrayView data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addData(QByteArrayView)
                cppSelf->addData(QByteArrayView(cppArg0));
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 1: // addData(QIODevice *device)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addData(QIODevice*)
                bool cppResult = cppSelf->addData(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // addData(const char *data, qsizetype length)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addData(const char*,qsizetype)
                cppSelf->addData(cppArg0, cppArg1);
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMessageAuthenticationCodeFunc_hash(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "hash", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMessageAuthenticationCode::hash(QByteArrayView,QByteArrayView,QCryptographicHash::Algorithm)->QByteArray
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_Algorithm_IDX])))->converter, (pyArgs[2])))) {
        overloadId = 0; // hash(QByteArrayView,QByteArrayView,QCryptographicHash::Algorithm)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "hash", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QCryptographicHash::Algorithm cppArg2{QCryptographicHash::Md4};
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hash(QByteArrayView,QByteArrayView,QCryptographicHash::Algorithm)
            QByteArray cppResult = ::QMessageAuthenticationCode::hash(QByteArrayView(cppArg0), QByteArrayView(cppArg1), cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMessageAuthenticationCodeFunc_reset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageAuthenticationCode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reset()
        cppSelf->reset();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMessageAuthenticationCodeFunc_result(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageAuthenticationCode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // result()const
        QByteArray cppResult = const_cast<const ::QMessageAuthenticationCode *>(cppSelf)->result();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMessageAuthenticationCodeFunc_resultView(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageAuthenticationCode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resultView()const
        QByteArrayView cppResult = const_cast<const ::QMessageAuthenticationCode *>(cppSelf)->resultView();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QByteArrayView_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMessageAuthenticationCodeFunc_setKey(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageAuthenticationCode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMessageAuthenticationCode::setKey(QByteArrayView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setKey(QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setKey", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setKey(QByteArrayView)
            cppSelf->setKey(QByteArrayView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMessageAuthenticationCodeFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageAuthenticationCode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMessageAuthenticationCode::swap(QMessageAuthenticationCode&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QMessageAuthenticationCode&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMessageAuthenticationCode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QMessageAuthenticationCode&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QMessageAuthenticationCode_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMessageAuthenticationCode_methods[] = {
    {"addData", reinterpret_cast<PyCFunction>(Sbk_QMessageAuthenticationCodeFunc_addData), METH_VARARGS, nullptr},
    {"hash", reinterpret_cast<PyCFunction>(Sbk_QMessageAuthenticationCodeFunc_hash), METH_VARARGS|METH_STATIC, nullptr},
    {"reset", reinterpret_cast<PyCFunction>(Sbk_QMessageAuthenticationCodeFunc_reset), METH_NOARGS, nullptr},
    {"result", reinterpret_cast<PyCFunction>(Sbk_QMessageAuthenticationCodeFunc_result), METH_NOARGS, nullptr},
    {"resultView", reinterpret_cast<PyCFunction>(Sbk_QMessageAuthenticationCodeFunc_resultView), METH_NOARGS, nullptr},
    {"setKey", reinterpret_cast<PyCFunction>(Sbk_QMessageAuthenticationCodeFunc_setKey), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QMessageAuthenticationCodeFunc_swap), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QMessageAuthenticationCode_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMessageAuthenticationCode_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMessageAuthenticationCode_Type = nullptr;
static PyTypeObject *Sbk_QMessageAuthenticationCode_TypeF(void)
{
    return _Sbk_QMessageAuthenticationCode_Type;
}

static PyType_Slot Sbk_QMessageAuthenticationCode_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMessageAuthenticationCode_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMessageAuthenticationCode_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMessageAuthenticationCode_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMessageAuthenticationCode_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMessageAuthenticationCode_spec = {
    "2:PySide6.QtCore.QMessageAuthenticationCode",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMessageAuthenticationCode_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMessageAuthenticationCode_PythonToCpp_QMessageAuthenticationCode_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMessageAuthenticationCode_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMessageAuthenticationCode_PythonToCpp_QMessageAuthenticationCode_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMessageAuthenticationCode_TypeF()))
        return QMessageAuthenticationCode_PythonToCpp_QMessageAuthenticationCode_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMessageAuthenticationCode_PTR_CppToPython_QMessageAuthenticationCode(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QMessageAuthenticationCode_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMessageAuthenticationCode_SignatureStrings[] = {
    "PySide6.QtCore.QMessageAuthenticationCode(self,method:PySide6.QtCore.QCryptographicHash.Algorithm,key:typing.Union[PySide6.QtCore.QByteArray, char*]={})",
    "2:PySide6.QtCore.QMessageAuthenticationCode.addData(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "1:PySide6.QtCore.QMessageAuthenticationCode.addData(self,device:PySide6.QtCore.QIODevice)->bool",
    "0:PySide6.QtCore.QMessageAuthenticationCode.addData(self,data:char*,length:qsizetype)",
    "PySide6.QtCore.QMessageAuthenticationCode.hash(message:typing.Union[PySide6.QtCore.QByteArray, char*],key:typing.Union[PySide6.QtCore.QByteArray, char*],method:PySide6.QtCore.QCryptographicHash.Algorithm)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QMessageAuthenticationCode.reset(self)",
    "PySide6.QtCore.QMessageAuthenticationCode.result(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QMessageAuthenticationCode.resultView(self)->QByteArrayView",
    "PySide6.QtCore.QMessageAuthenticationCode.setKey(self,key:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtCore.QMessageAuthenticationCode.swap(self,other:PySide6.QtCore.QMessageAuthenticationCode)",
    nullptr}; // Sentinel
#else
static constexpr size_t QMessageAuthenticationCode_SignatureByteSize = 270;
static constexpr uint8_t QMessageAuthenticationCode_SignatureBytes[270] = {
    0x78, 0xda, 0xad, 0x52, 0x4f, 0x4b, 0xc3, 0x30, 0x14, 0xbf, 0xe7, 0x53, 0x78, 0x5c, 0xa4, 0x06,
    0xf5, 0xe0, 0xa1, 0xa0, 0x50, 0xbb, 0x83, 0x22, 0xe2, 0x86, 0xe8, 0x45, 0x3c, 0xc4, 0xe6, 0x99,
    0x04, 0xd3, 0xa4, 0x26, 0x6f, 0x8e, 0x28, 0x7e, 0x77, 0x63, 0xab, 0x0c, 0x36, 0x06, 0x4b, 0xf5,
    0x16, 0xf2, 0xf8, 0xfd, 0x7d, 0x6f, 0x16, 0x6f, 0xb5, 0x80, 0x13, 0x36, 0xc7, 0xda, 0x79, 0x60,
    0xf3, 0x6b, 0x08, 0x81, 0x4b, 0xa8, 0x16, 0xa8, 0xc0, 0xa2, 0x6e, 0x38, 0x6a, 0x67, 0x6b, 0x27,
    0x60, 0x12, 0xc0, 0x3c, 0x17, 0x2d, 0xa0, 0x72, 0xa2, 0x9c, 0xad, 0xa1, 0x6a, 0x1f, 0x3b, 0x74,
    0xd2, 0xf3, 0x4e, 0xe9, 0xe6, 0x82, 0x07, 0xc5, 0x2a, 0x23, 0x9d, 0xd7, 0xa8, 0xda, 0xe2, 0x05,
    0x62, 0x89, 0xb1, 0xd3, 0x56, 0xb2, 0x3b, 0x9b, 0xc8, 0x1e, 0xd6, 0xc1, 0xe7, 0x11, 0xa1, 0xf2,
    0x9e, 0xc7, 0x62, 0xaf, 0x51, 0xdc, 0xef, 0x3f, 0x9e, 0x7e, 0x7c, 0x52, 0x72, 0xbc, 0x21, 0xb2,
    0xd5, 0x1a, 0xe3, 0x42, 0x4c, 0x39, 0xf2, 0xc1, 0xa2, 0x48, 0xaf, 0x4c, 0x41, 0x4a, 0x8e, 0x46,
    0xab, 0xc1, 0x9b, 0x6e, 0x60, 0x03, 0x7d, 0x79, 0x33, 0xed, 0x07, 0xf4, 0xe0, 0xec, 0xc9, 0x39,
    0x43, 0x0e, 0xff, 0x94, 0xa6, 0x77, 0x59, 0x18, 0xb0, 0x12, 0x55, 0xf9, 0x1a, 0xf4, 0x3b, 0xa4,
    0x7c, 0x40, 0xc9, 0xee, 0x9c, 0x2a, 0xed, 0x64, 0xd2, 0x0e, 0xe3, 0xcc, 0x72, 0x46, 0x2c, 0x70,
    0xc4, 0x99, 0xa4, 0xa2, 0xb6, 0xd2, 0x66, 0xe4, 0xf4, 0x10, 0x00, 0xfb, 0xe6, 0x68, 0x1e, 0x6a,
    0x61, 0x7e, 0x60, 0xff, 0xe6, 0x23, 0x31, 0xde, 0x6b, 0x58, 0xfe, 0xb2, 0xae, 0x68, 0xbe, 0x7f,
    0x33, 0xa8, 0x52, 0xa0, 0x2b, 0x88, 0xc3, 0x35, 0xe4, 0xaf, 0x22, 0xa7, 0x86, 0xb0, 0xe4, 0xdd,
    0xa0, 0xe3, 0xd2, 0xcc, 0xef, 0x7e, 0xb2, 0x94, 0x7c, 0x01, 0xe4, 0xa2, 0x8f, 0x10
};
#endif

PyTypeObject *init_QMessageAuthenticationCode(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX].type;

    Shiboken::AutoDecRef Sbk_QMessageAuthenticationCode_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QMessageAuthenticationCode_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMessageAuthenticationCode",
        "QMessageAuthenticationCode*",
        &Sbk_QMessageAuthenticationCode_spec,
        &Shiboken::callCppDestructor< ::QMessageAuthenticationCode >,
        Sbk_QMessageAuthenticationCode_Type_bases.object(),
        0);
    auto *pyType = Sbk_QMessageAuthenticationCode_TypeF(); // references _Sbk_QMessageAuthenticationCode_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMessageAuthenticationCode_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMessageAuthenticationCode_SignatureBytes, QMessageAuthenticationCode_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMessageAuthenticationCode_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QMessageAuthenticationCode_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMessageAuthenticationCode_PythonToCpp_QMessageAuthenticationCode_PTR,
        is_QMessageAuthenticationCode_PythonToCpp_QMessageAuthenticationCode_PTR_Convertible,
        QMessageAuthenticationCode_PTR_CppToPython_QMessageAuthenticationCode);

    Shiboken::Conversions::registerConverterName(converter, "QMessageAuthenticationCode");
    Shiboken::Conversions::registerConverterName(converter, "QMessageAuthenticationCode*");
    Shiboken::Conversions::registerConverterName(converter, "QMessageAuthenticationCode&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMessageAuthenticationCode).name());

    qRegisterMetaType< ::QMessageAuthenticationCode *>();

    return pyType;
}
