// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qmetatype_wrapper.h"

// Extra includes
#include <pysidemetatype.h>

// Argument includes
#include <qbytearray.h>
#include <qbytearrayview.h>
#include <qdatastream.h>
#include <qmetatype.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMetaType_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMetaType >()))
        return -1;

    ::QMetaType *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QMetaType", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMetaType::QMetaType()
    // 1: QMetaType::QMetaType(PyTypeObject*)
    // 2: QMetaType::QMetaType(QMetaType::Type)
    // 3: QMetaType::QMetaType(int)
    if (numArgs == 0) {
        overloadId = 0; // QMetaType()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_Type_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 2; // QMetaType(QMetaType::Type)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 3; // QMetaType(int)
    } else if (numArgs == 1
        && PyType_Check(pyArgs[0])) {
        overloadId = 1; // QMetaType(PyTypeObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QMetaType()
        {

            // QMetaType()
            cptr = new ::QMetaType();
            break;
        }
        case 1: // QMetaType(PyTypeObject *py_type)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMetaType(PyTypeObject*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (metatype-from-type)]
                cptr = new QMetaType(PySide::qMetaTypeFromPyType(reinterpret_cast<PyTypeObject *>(pyArgs[0])));
                // END of custom code block [file: ../glue/qtcore.cpp (metatype-from-type)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 2: // QMetaType(QMetaType::Type type)
        {
            ::QMetaType::Type cppArg0{QMetaType::UnknownType};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMetaType(QMetaType::Type)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (metatype-from-metatype-type)]
                Shiboken::AutoDecRef intArg(PyObject_GetAttrString(pyArgs[1-1], "value"));
                cptr = new QMetaType(PyLong_AsLong(intArg));
                // END of custom code block [file: ../glue/qtcore.cpp (metatype-from-metatype-type)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 3: // QMetaType(int type)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMetaType(int)
                cptr = new ::QMetaType(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMetaType >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMetaTypeFunc_alignOf(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // alignOf()const
        qsizetype cppResult = const_cast<const ::QMetaType *>(cppSelf)->alignOf();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_canConvert(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "canConvert", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaType::canConvert(QMetaType,QMetaType)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[1])))) {
        overloadId = 0; // canConvert(QMetaType,QMetaType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "canConvert", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QMetaType cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QMetaType cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // canConvert(QMetaType,QMetaType)
            bool cppResult = ::QMetaType::canConvert(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_canView(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "canView", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaType::canView(QMetaType,QMetaType)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[1])))) {
        overloadId = 0; // canView(QMetaType,QMetaType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "canView", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QMetaType cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QMetaType cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // canView(QMetaType,QMetaType)
            bool cppResult = ::QMetaType::canView(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_compare(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "compare", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaType::compare(const void*,const void*,int,int*)->bool
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // compare(const void*,const void*,int,int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "compare", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QMetaType", "compare(const void *lhs, const void *rhs, int typeId, int *result)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        void* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        void* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int *cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // compare(const void*,const void*,int,int*)
            bool cppResult = ::QMetaType::compare(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_construct(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QMetaType *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "construct", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:construct", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaType::construct(int,void*,const void*)->void*
    // 1: QMetaType::construct(void*,const void*=)const->void*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // construct(void*,const void*)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
            overloadId = 1; // construct(void*,const void*)const
        }
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[2])))) {
        overloadId = 0; // construct(int,void*,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "construct", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // construct(int type, void *where, const void *copy)
        {
            Shiboken::Warnings::warnDeprecated("QMetaType", "construct(int type, void *where, const void *copy)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "construct", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            void* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // construct(int,void*,const void*)
                void * cppResult = ::QMetaType::construct(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
            }
            break;
        }
        case 1: // construct(void *where, const void *copy) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_copy = Shiboken::String::createStaticString("copy");
                if (PyDict_Contains(kwds, key_copy) != 0) {
                    value = PyDict_GetItem(kwds, key_copy);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_copy);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "construct", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "construct", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_copy);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "construct", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);
                }
            }
            void* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // construct(void*,const void*)const
                void * cppResult = const_cast<const ::QMetaType *>(cppSelf)->construct(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_convert(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "convert", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaType::convert(QMetaType,const void*,QMetaType,void*)->bool
    // 1: static QMetaType::convert(const void*,int,void*,int)->bool
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 1; // convert(const void*,int,void*,int)
    } else if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[3])))) {
        overloadId = 0; // convert(QMetaType,const void*,QMetaType,void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "convert", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // convert(QMetaType fromType, const void *from, QMetaType toType, void *to)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QMetaType cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QMetaType cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            void* cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // convert(QMetaType,const void*,QMetaType,void*)
                bool cppResult = ::QMetaType::convert(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // convert(const void *from, int fromTypeId, void *to, int toTypeId)
        {
            Shiboken::Warnings::warnDeprecated("QMetaType", "convert(const void *from, int fromTypeId, void *to, int toTypeId)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            void* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            void* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // convert(const void*,int,void*,int)
                bool cppResult = ::QMetaType::convert(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_create(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QMetaType *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    if (PyArg_ParseTuple(args, "|OO:create", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMetaType::create(const void*=)const->void*
    // 1: static QMetaType::create(int,const void*=)->void*
    if (numArgs == 0) {
        overloadId = 0; // create(const void*)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // create(int,const void*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
            overloadId = 1; // create(int,const void*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[0])))) {
        overloadId = 0; // create(const void*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // create(const void *copy) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_copy = Shiboken::String::createStaticString("copy");
                if (PyDict_Contains(kwds, key_copy) != 0) {
                    value = PyDict_GetItem(kwds, key_copy);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_copy);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_copy);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);
                }
            }
            void* cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // create(const void*)const
                void * cppResult = const_cast<const ::QMetaType *>(cppSelf)->create(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
            }
            break;
        }
        case 1: // create(int type, const void *copy)
        {
            Shiboken::Warnings::warnDeprecated("QMetaType", "create(int type, const void *copy)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_copy = Shiboken::String::createStaticString("copy");
                if (PyDict_Contains(kwds, key_copy) != 0) {
                    value = PyDict_GetItem(kwds, key_copy);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_copy);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_copy);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "create", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // create(int,const void*)
                void * cppResult = ::QMetaType::create(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_destroy(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QMetaType *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "destroy", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaType::destroy(int,void*)
    // 1: QMetaType::destroy(void*)const
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[0])))) {
        overloadId = 1; // destroy(void*)const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
        overloadId = 0; // destroy(int,void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "destroy", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // destroy(int type, void *data)
        {
            Shiboken::Warnings::warnDeprecated("QMetaType", "destroy(int type, void *data)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // destroy(int,void*)
                ::QMetaType::destroy(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // destroy(void *data) const
        {
            void* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // destroy(void*)const
                const_cast<const ::QMetaType *>(cppSelf)->destroy(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMetaTypeFunc_destruct(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QMetaType *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "destruct", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaType::destruct(int,void*)
    // 1: QMetaType::destruct(void*)const
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[0])))) {
        overloadId = 1; // destruct(void*)const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
        overloadId = 0; // destruct(int,void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "destruct", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // destruct(int type, void *where)
        {
            Shiboken::Warnings::warnDeprecated("QMetaType", "destruct(int type, void *where)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // destruct(int,void*)
                ::QMetaType::destruct(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // destruct(void *data) const
        {
            void* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // destruct(void*)const
                const_cast<const ::QMetaType *>(cppSelf)->destruct(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMetaTypeFunc_equals(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QMetaType *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 3)
        return Shiboken::returnWrongArguments(args, "equals", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    if (PyArg_UnpackTuple(args, "equals", 2, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMetaType::equals(const void*,const void*)const->bool
    // 1: static QMetaType::equals(const void*,const void*,int,int*)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // equals(const void*,const void*)const
        } else if (numArgs == 4
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 1; // equals(const void*,const void*,int,int*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "equals", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // equals(const void *lhs, const void *rhs) const
        {
            void* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // equals(const void*,const void*)const
                bool cppResult = const_cast<const ::QMetaType *>(cppSelf)->equals(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // equals(const void *lhs, const void *rhs, int typeId, int *result)
        {
            Shiboken::Warnings::warnDeprecated("QMetaType", "equals(const void *lhs, const void *rhs, int typeId, int *result)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            void* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int *cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // equals(const void*,const void*,int,int*)
                bool cppResult = ::QMetaType::equals(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QMetaType::TypeFlag> cppResult = const_cast<const ::QMetaType *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QMetaType_TypeFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_fromName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMetaType::fromName(QByteArrayView)->QMetaType
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // fromName(QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromName(QByteArrayView)
            QMetaType cppResult = ::QMetaType::fromName(QByteArrayView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_hasRegisteredConverterFunction(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "hasRegisteredConverterFunction", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaType::hasRegisteredConverterFunction(QMetaType,QMetaType)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[1])))) {
        overloadId = 0; // hasRegisteredConverterFunction(QMetaType,QMetaType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "hasRegisteredConverterFunction", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QMetaType cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QMetaType cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasRegisteredConverterFunction(QMetaType,QMetaType)
            bool cppResult = ::QMetaType::hasRegisteredConverterFunction(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_hasRegisteredDataStreamOperators(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasRegisteredDataStreamOperators()const
        bool cppResult = const_cast<const ::QMetaType *>(cppSelf)->hasRegisteredDataStreamOperators();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_hasRegisteredDebugStreamOperator(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QMetaType *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "hasRegisteredDebugStreamOperator", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMetaType::hasRegisteredDebugStreamOperator()const->bool
    // 1: static QMetaType::hasRegisteredDebugStreamOperator(int)->bool
    if (numArgs == 0) {
        overloadId = 0; // hasRegisteredDebugStreamOperator()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 1; // hasRegisteredDebugStreamOperator(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "hasRegisteredDebugStreamOperator", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // hasRegisteredDebugStreamOperator() const
        {

            // hasRegisteredDebugStreamOperator()const
            bool cppResult = const_cast<const ::QMetaType *>(cppSelf)->hasRegisteredDebugStreamOperator();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            break;
        }
        case 1: // hasRegisteredDebugStreamOperator(int typeId)
        {
            Shiboken::Warnings::warnDeprecated("QMetaType", "hasRegisteredDebugStreamOperator(int typeId)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // hasRegisteredDebugStreamOperator(int)
                bool cppResult = ::QMetaType::hasRegisteredDebugStreamOperator(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_hasRegisteredMutableViewFunction(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "hasRegisteredMutableViewFunction", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaType::hasRegisteredMutableViewFunction(QMetaType,QMetaType)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[1])))) {
        overloadId = 0; // hasRegisteredMutableViewFunction(QMetaType,QMetaType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "hasRegisteredMutableViewFunction", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QMetaType cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QMetaType cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasRegisteredMutableViewFunction(QMetaType,QMetaType)
            bool cppResult = ::QMetaType::hasRegisteredMutableViewFunction(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_id(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "id", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    if (PyArg_ParseTuple(args, "|O:id", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMetaType::id(int=)const->int
    if (numArgs == 0) {
        overloadId = 0; // id(int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // id(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "id", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_arg__1 = Shiboken::String::createStaticString("arg__1");
            if (PyDict_Contains(kwds, key_arg__1) != 0) {
                value = PyDict_GetItem(kwds, key_arg__1);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_arg__1);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "id", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "id", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_arg__1);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "id", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);
            }
        }
        int cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // id(int)const
            int cppResult = const_cast<const ::QMetaType *>(cppSelf)->id(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_isCopyConstructible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isCopyConstructible()const
        bool cppResult = const_cast<const ::QMetaType *>(cppSelf)->isCopyConstructible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_isDefaultConstructible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDefaultConstructible()const
        bool cppResult = const_cast<const ::QMetaType *>(cppSelf)->isDefaultConstructible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_isDestructible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDestructible()const
        bool cppResult = const_cast<const ::QMetaType *>(cppSelf)->isDestructible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_isEqualityComparable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEqualityComparable()const
        bool cppResult = const_cast<const ::QMetaType *>(cppSelf)->isEqualityComparable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_isMoveConstructible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isMoveConstructible()const
        bool cppResult = const_cast<const ::QMetaType *>(cppSelf)->isMoveConstructible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_isOrdered(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isOrdered()const
        bool cppResult = const_cast<const ::QMetaType *>(cppSelf)->isOrdered();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_isRegistered(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QMetaType *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "isRegistered", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMetaType::isRegistered()const->bool
    // 1: static QMetaType::isRegistered(int)->bool
    if (numArgs == 0) {
        overloadId = 0; // isRegistered()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 1; // isRegistered(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isRegistered", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // isRegistered() const
        {

            // isRegistered()const
            bool cppResult = const_cast<const ::QMetaType *>(cppSelf)->isRegistered();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            break;
        }
        case 1: // isRegistered(int type)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isRegistered(int)
                bool cppResult = ::QMetaType::isRegistered(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QMetaType *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_load(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QMetaType *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "load", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaType::load(QDataStream&,int,void*)->bool
    // 1: QMetaType::load(QDataStream&,void*)const->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
            overloadId = 1; // load(QDataStream&,void*)const
        } else if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[2])))) {
            overloadId = 0; // load(QDataStream&,int,void*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "load", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // load(QDataStream &stream, int type, void *data)
        {
            Shiboken::Warnings::warnDeprecated("QMetaType", "load(QDataStream &stream, int type, void *data)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            void* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // load(QDataStream&,int,void*)
                bool cppResult = ::QMetaType::load(*cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // load(QDataStream &stream, void *data) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // load(QDataStream&,void*)const
                bool cppResult = const_cast<const ::QMetaType *>(cppSelf)->load(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_metaObjectForType(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMetaType::metaObjectForType(int)->const QMetaObject*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // metaObjectForType(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "metaObjectForType", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QMetaType", "metaObjectForType(int type)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // metaObjectForType(int)
            const QMetaObject * cppResult = ::QMetaType::metaObjectForType(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        const char * cppResult = const_cast<const ::QMetaType *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_registerNormalizedTypedef(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "registerNormalizedTypedef", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaType::registerNormalizedTypedef(QByteArray,QMetaType)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[1])))) {
        overloadId = 0; // registerNormalizedTypedef(QByteArray,QMetaType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "registerNormalizedTypedef", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QMetaType cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // registerNormalizedTypedef(QByteArray,QMetaType)
            ::QMetaType::registerNormalizedTypedef(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMetaTypeFunc_registerType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // registerType()const
        const_cast<const ::QMetaType *>(cppSelf)->registerType();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMetaTypeFunc_save(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QMetaType *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "save", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMetaType::save(QDataStream&,const void*)const->bool
    // 1: static QMetaType::save(QDataStream&,int,const void*)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArgs[0])))) {
        if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[2])))) {
            overloadId = 1; // save(QDataStream&,int,const void*)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
            overloadId = 0; // save(QDataStream&,const void*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "save", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // save(QDataStream &stream, const void *data) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // save(QDataStream&,const void*)const
                bool cppResult = const_cast<const ::QMetaType *>(cppSelf)->save(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // save(QDataStream &stream, int type, const void *data)
        {
            Shiboken::Warnings::warnDeprecated("QMetaType", "save(QDataStream &stream, int type, const void *data)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            void* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // save(QDataStream&,int,const void*)
                bool cppResult = ::QMetaType::save(*cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_sizeOf(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QMetaType *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sizeOf", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMetaType::sizeOf()const->qsizetype
    // 1: static QMetaType::sizeOf(int)->int
    if (numArgs == 0) {
        overloadId = 0; // sizeOf()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 1; // sizeOf(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sizeOf", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // sizeOf() const
        {

            // sizeOf()const
            qsizetype cppResult = const_cast<const ::QMetaType *>(cppSelf)->sizeOf();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            break;
        }
        case 1: // sizeOf(int type)
        {
            Shiboken::Warnings::warnDeprecated("QMetaType", "sizeOf(int type)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sizeOf(int)
                int cppResult = ::QMetaType::sizeOf(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_type(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMetaType::type(QByteArray)->int
    // 1: static QMetaType::type(const char*)->int
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 1; // type(const char*)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // type(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "type", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // type(const QByteArray &typeName)
        {
            Shiboken::Warnings::warnDeprecated("QMetaType", "type(const QByteArray &typeName)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // type(QByteArray)
                int cppResult = ::QMetaType::type(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
        case 1: // type(const char *typeName)
        {
            Shiboken::Warnings::warnDeprecated("QMetaType", "type(const char *typeName)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            const char* cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // type(const char*)
                int cppResult = ::QMetaType::type(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_typeFlags(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMetaType::typeFlags(int)->QFlags<QMetaType::TypeFlag>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // typeFlags(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "typeFlags", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QMetaType", "typeFlags(int type)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // typeFlags(int)
            QFlags<QMetaType::TypeFlag> cppResult = ::QMetaType::typeFlags(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QMetaType_TypeFlag_IDX])))->flagsConverter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_typeName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMetaType::typeName(int)->const char*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // typeName(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "typeName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QMetaType", "typeName(int type)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // typeName(int)
            const char * cppResult = ::QMetaType::typeName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_underlyingType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // underlyingType()const
        QMetaType cppResult = const_cast<const ::QMetaType *>(cppSelf)->underlyingType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaTypeFunc_unregisterConverterFunction(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "unregisterConverterFunction", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaType::unregisterConverterFunction(QMetaType,QMetaType)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[1])))) {
        overloadId = 0; // unregisterConverterFunction(QMetaType,QMetaType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "unregisterConverterFunction", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QMetaType cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QMetaType cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // unregisterConverterFunction(QMetaType,QMetaType)
            ::QMetaType::unregisterConverterFunction(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMetaTypeFunc_unregisterMetaType(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMetaType::unregisterMetaType(QMetaType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArg)))) {
        overloadId = 0; // unregisterMetaType(QMetaType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "unregisterMetaType", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMetaType cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // unregisterMetaType(QMetaType)
            ::QMetaType::unregisterMetaType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMetaTypeFunc_unregisterMutableViewFunction(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "unregisterMutableViewFunction", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaType::unregisterMutableViewFunction(QMetaType,QMetaType)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[1])))) {
        overloadId = 0; // unregisterMutableViewFunction(QMetaType,QMetaType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "unregisterMutableViewFunction", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QMetaType cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QMetaType cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // unregisterMutableViewFunction(QMetaType,QMetaType)
            ::QMetaType::unregisterMutableViewFunction(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMetaTypeFunc_view(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "view", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaType::view(QMetaType,void*,QMetaType,void*)->bool
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[3])))) {
        overloadId = 0; // view(QMetaType,void*,QMetaType,void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "view", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QMetaType cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        void* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QMetaType cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        void* cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // view(QMetaType,void*,QMetaType,void*)
            bool cppResult = ::QMetaType::view(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaType__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QMetaTypeMethod_construct = {"construct", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_construct), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QMetaTypeMethod_create = {"create", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_create), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QMetaTypeMethod_destroy = {"destroy", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_destroy), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QMetaTypeMethod_destruct = {"destruct", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_destruct), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QMetaTypeMethod_equals = {"equals", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_equals), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QMetaTypeMethod_hasRegisteredDebugStreamOperator = {"hasRegisteredDebugStreamOperator", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_hasRegisteredDebugStreamOperator), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QMetaTypeMethod_isRegistered = {"isRegistered", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_isRegistered), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QMetaTypeMethod_load = {"load", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_load), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QMetaTypeMethod_save = {"save", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_save), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QMetaTypeMethod_sizeOf = {"sizeOf", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_sizeOf), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_QMetaType_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QMetaType_EnumFlagInfo[] = {
    "Type:IntEnum",
    "TypeFlag:Flag:TypeFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMetaType_methods[] = {
    {"alignOf", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_alignOf), METH_NOARGS, nullptr},
    {"canConvert", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_canConvert), METH_VARARGS|METH_STATIC, nullptr},
    {"canView", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_canView), METH_VARARGS|METH_STATIC, nullptr},
    {"compare", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_compare), METH_VARARGS|METH_STATIC, nullptr},
    {"construct", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_construct), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"convert", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_convert), METH_VARARGS|METH_STATIC, nullptr},
    {"create", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_create), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"destroy", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_destroy), METH_VARARGS|METH_STATIC, nullptr},
    {"destruct", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_destruct), METH_VARARGS|METH_STATIC, nullptr},
    {"equals", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_equals), METH_VARARGS|METH_STATIC, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_flags), METH_NOARGS, nullptr},
    {"fromName", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_fromName), METH_O|METH_STATIC, nullptr},
    {"hasRegisteredConverterFunction", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_hasRegisteredConverterFunction), METH_VARARGS|METH_STATIC, nullptr},
    {"hasRegisteredDataStreamOperators", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_hasRegisteredDataStreamOperators), METH_NOARGS, nullptr},
    {"hasRegisteredDebugStreamOperator", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_hasRegisteredDebugStreamOperator), METH_VARARGS|METH_STATIC, nullptr},
    {"hasRegisteredMutableViewFunction", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_hasRegisteredMutableViewFunction), METH_VARARGS|METH_STATIC, nullptr},
    {"id", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_id), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"isCopyConstructible", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_isCopyConstructible), METH_NOARGS, nullptr},
    {"isDefaultConstructible", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_isDefaultConstructible), METH_NOARGS, nullptr},
    {"isDestructible", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_isDestructible), METH_NOARGS, nullptr},
    {"isEqualityComparable", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_isEqualityComparable), METH_NOARGS, nullptr},
    {"isMoveConstructible", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_isMoveConstructible), METH_NOARGS, nullptr},
    {"isOrdered", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_isOrdered), METH_NOARGS, nullptr},
    {"isRegistered", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_isRegistered), METH_VARARGS|METH_STATIC, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_isValid), METH_NOARGS, nullptr},
    {"load", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_load), METH_VARARGS|METH_STATIC, nullptr},
    {"metaObjectForType", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_metaObjectForType), METH_O|METH_STATIC, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_name), METH_NOARGS, nullptr},
    {"registerNormalizedTypedef", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_registerNormalizedTypedef), METH_VARARGS|METH_STATIC, nullptr},
    {"registerType", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_registerType), METH_NOARGS, nullptr},
    {"save", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_save), METH_VARARGS|METH_STATIC, nullptr},
    {"sizeOf", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_sizeOf), METH_VARARGS|METH_STATIC, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_type), METH_O|METH_STATIC, nullptr},
    {"typeFlags", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_typeFlags), METH_O|METH_STATIC, nullptr},
    {"typeName", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_typeName), METH_O|METH_STATIC, nullptr},
    {"underlyingType", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_underlyingType), METH_NOARGS, nullptr},
    {"unregisterConverterFunction", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_unregisterConverterFunction), METH_VARARGS|METH_STATIC, nullptr},
    {"unregisterMetaType", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_unregisterMetaType), METH_O|METH_STATIC, nullptr},
    {"unregisterMutableViewFunction", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_unregisterMutableViewFunction), METH_VARARGS|METH_STATIC, nullptr},
    {"view", reinterpret_cast<PyCFunction>(Sbk_QMetaTypeFunc_view), METH_VARARGS|METH_STATIC, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QMetaType__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QMetaType_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QMetaTypeMethod_construct = {
        Sbk_QMetaTypeMethod_construct.ml_name,
        Sbk_QMetaTypeMethod_construct.ml_meth,
        Sbk_QMetaTypeMethod_construct.ml_flags & (~METH_STATIC),
        Sbk_QMetaTypeMethod_construct.ml_doc,
    };
    if (Shiboken::String::compare(name, "construct") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QMetaTypeMethod_construct, self, 0);
    static PyMethodDef non_static_Sbk_QMetaTypeMethod_create = {
        Sbk_QMetaTypeMethod_create.ml_name,
        Sbk_QMetaTypeMethod_create.ml_meth,
        Sbk_QMetaTypeMethod_create.ml_flags & (~METH_STATIC),
        Sbk_QMetaTypeMethod_create.ml_doc,
    };
    if (Shiboken::String::compare(name, "create") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QMetaTypeMethod_create, self, 0);
    static PyMethodDef non_static_Sbk_QMetaTypeMethod_destroy = {
        Sbk_QMetaTypeMethod_destroy.ml_name,
        Sbk_QMetaTypeMethod_destroy.ml_meth,
        Sbk_QMetaTypeMethod_destroy.ml_flags & (~METH_STATIC),
        Sbk_QMetaTypeMethod_destroy.ml_doc,
    };
    if (Shiboken::String::compare(name, "destroy") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QMetaTypeMethod_destroy, self, 0);
    static PyMethodDef non_static_Sbk_QMetaTypeMethod_destruct = {
        Sbk_QMetaTypeMethod_destruct.ml_name,
        Sbk_QMetaTypeMethod_destruct.ml_meth,
        Sbk_QMetaTypeMethod_destruct.ml_flags & (~METH_STATIC),
        Sbk_QMetaTypeMethod_destruct.ml_doc,
    };
    if (Shiboken::String::compare(name, "destruct") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QMetaTypeMethod_destruct, self, 0);
    static PyMethodDef non_static_Sbk_QMetaTypeMethod_equals = {
        Sbk_QMetaTypeMethod_equals.ml_name,
        Sbk_QMetaTypeMethod_equals.ml_meth,
        Sbk_QMetaTypeMethod_equals.ml_flags & (~METH_STATIC),
        Sbk_QMetaTypeMethod_equals.ml_doc,
    };
    if (Shiboken::String::compare(name, "equals") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QMetaTypeMethod_equals, self, 0);
    static PyMethodDef non_static_Sbk_QMetaTypeMethod_hasRegisteredDebugStreamOperator = {
        Sbk_QMetaTypeMethod_hasRegisteredDebugStreamOperator.ml_name,
        Sbk_QMetaTypeMethod_hasRegisteredDebugStreamOperator.ml_meth,
        Sbk_QMetaTypeMethod_hasRegisteredDebugStreamOperator.ml_flags & (~METH_STATIC),
        Sbk_QMetaTypeMethod_hasRegisteredDebugStreamOperator.ml_doc,
    };
    if (Shiboken::String::compare(name, "hasRegisteredDebugStreamOperator") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QMetaTypeMethod_hasRegisteredDebugStreamOperator, self, 0);
    static PyMethodDef non_static_Sbk_QMetaTypeMethod_isRegistered = {
        Sbk_QMetaTypeMethod_isRegistered.ml_name,
        Sbk_QMetaTypeMethod_isRegistered.ml_meth,
        Sbk_QMetaTypeMethod_isRegistered.ml_flags & (~METH_STATIC),
        Sbk_QMetaTypeMethod_isRegistered.ml_doc,
    };
    if (Shiboken::String::compare(name, "isRegistered") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QMetaTypeMethod_isRegistered, self, 0);
    static PyMethodDef non_static_Sbk_QMetaTypeMethod_load = {
        Sbk_QMetaTypeMethod_load.ml_name,
        Sbk_QMetaTypeMethod_load.ml_meth,
        Sbk_QMetaTypeMethod_load.ml_flags & (~METH_STATIC),
        Sbk_QMetaTypeMethod_load.ml_doc,
    };
    if (Shiboken::String::compare(name, "load") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QMetaTypeMethod_load, self, 0);
    static PyMethodDef non_static_Sbk_QMetaTypeMethod_save = {
        Sbk_QMetaTypeMethod_save.ml_name,
        Sbk_QMetaTypeMethod_save.ml_meth,
        Sbk_QMetaTypeMethod_save.ml_flags & (~METH_STATIC),
        Sbk_QMetaTypeMethod_save.ml_doc,
    };
    if (Shiboken::String::compare(name, "save") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QMetaTypeMethod_save, self, 0);
    static PyMethodDef non_static_Sbk_QMetaTypeMethod_sizeOf = {
        Sbk_QMetaTypeMethod_sizeOf.ml_name,
        Sbk_QMetaTypeMethod_sizeOf.ml_meth,
        Sbk_QMetaTypeMethod_sizeOf.ml_flags & (~METH_STATIC),
        Sbk_QMetaTypeMethod_sizeOf.ml_doc,
    };
    if (Shiboken::String::compare(name, "sizeOf") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QMetaTypeMethod_sizeOf, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

// Rich comparison
static PyObject * Sbk_QMetaType_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArg)))) {
                // operator!=(const QMetaType &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMetaType cppArg0_local;
                ::QMetaType *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArg)))) {
                // operator==(const QMetaType &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMetaType cppArg0_local;
                ::QMetaType *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QMetaType_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QMetaType_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMetaType_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMetaType_Type = nullptr;
static PyTypeObject *Sbk_QMetaType_TypeF(void)
{
    return _Sbk_QMetaType_Type;
}

static PyType_Slot Sbk_QMetaType_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QMetaType_HashFunc)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QMetaType_getattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMetaType_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMetaType_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QMetaType_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMetaType_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMetaType_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMetaType_spec = {
    "2:PySide6.QtCore.QMetaType",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMetaType_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QMetaType_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMetaType::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMetaType::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMetaType_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_Type_IDX])))
        return Enum_PythonToCpp_QMetaType_Type;
    return {};
}

static PyObject *QMetaType_Type_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMetaType::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMetaType::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_Type_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QMetaType_TypeFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMetaType::TypeFlag>(Shiboken::Enum::getValue(pyIn));
    switch (value) {
    case QMetaType::TypeFlag::MovableType:
        Shiboken::Warnings::warnDeprecatedEnumValue("QMetaType::TypeFlag", "MovableType");
        break;
    default:
        break;
    }
    *reinterpret_cast<::QMetaType::TypeFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMetaType_TypeFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_TypeFlag_IDX])))
        return Enum_PythonToCpp_QMetaType_TypeFlag;
    return {};
}

static PyObject *QMetaType_TypeFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMetaType::TypeFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMetaType::TypeFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_TypeFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QMetaType_TypeFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QMetaType::TypeFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QMetaType::TypeFlag> *>(cppOut) = value;

}

static PyObject *QMetaType_TypeFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QMetaType::TypeFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_TypeFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMetaType_PythonToCpp_QMetaType_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMetaType_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMetaType_PythonToCpp_QMetaType_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMetaType_TypeF()))
        return QMetaType_PythonToCpp_QMetaType_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMetaType_PTR_CppToPython_QMetaType(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QMetaType_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QMetaType_COPY_CppToPython_QMetaType(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QMetaType *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QMetaType_TypeF(), new ::QMetaType(*source), true, true);
}

// Python to C++ copy conversion.
static void QMetaType_PythonToCpp_QMetaType_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QMetaType *>(cppOut) = *reinterpret_cast< ::QMetaType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QMetaType_PythonToCpp_QMetaType_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QMetaType_TypeF()))
        return QMetaType_PythonToCpp_QMetaType_COPY;
    return {};
}

// Python to C++ conversions for type 'QMetaType'.
static void PyTypeObject_PythonToCpp_QMetaType(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pytypeobject-qmetatype)]
    auto *pyType = reinterpret_cast<PyTypeObject *>(pyIn);
    *reinterpret_cast<::QMetaType *>(cppOut) = PySide::qMetaTypeFromPyType(pyType);
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pytypeobject-qmetatype)]
    // ========================================================================

}
static PythonToCppFunc is_PyTypeObject_PythonToCpp_QMetaType_Convertible(PyObject *pyIn)
{
    if (PyType_Check(pyIn))
        return PyTypeObject_PythonToCpp_QMetaType;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMetaType_SignatureStrings[] = {
    "3:PySide6.QtCore.QMetaType(self)",
    "2:PySide6.QtCore.QMetaType(self,py_type:PyTypeObject)",
    "1:PySide6.QtCore.QMetaType(self,type:PySide6.QtCore.QMetaType.Type)",
    "0:PySide6.QtCore.QMetaType(self,type:int)",
    "PySide6.QtCore.QMetaType.alignOf(self)->qsizetype",
    "PySide6.QtCore.QMetaType.canConvert(fromType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type],toType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])->bool",
    "PySide6.QtCore.QMetaType.canView(fromType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type],toType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])->bool",
    "PySide6.QtCore.QMetaType.compare(lhs:void,rhs:void,typeId:int,result:int*)->bool",
    "1:PySide6.QtCore.QMetaType.construct(type:int,where:void,copy:void)->void",
    "0:PySide6.QtCore.QMetaType.construct(self,where:void,copy:void=nullptr)->void",
    "1:PySide6.QtCore.QMetaType.convert(fromType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type],from:void,toType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type],to:void)->bool",
    "0:PySide6.QtCore.QMetaType.convert(from:void,fromTypeId:int,to:void,toTypeId:int)->bool",
    "1:PySide6.QtCore.QMetaType.create(self,copy:void=nullptr)->void",
    "0:PySide6.QtCore.QMetaType.create(type:int,copy:void=nullptr)->void",
    "1:PySide6.QtCore.QMetaType.destroy(type:int,data:void)",
    "0:PySide6.QtCore.QMetaType.destroy(self,data:void)",
    "1:PySide6.QtCore.QMetaType.destruct(type:int,where:void)",
    "0:PySide6.QtCore.QMetaType.destruct(self,data:void)",
    "1:PySide6.QtCore.QMetaType.equals(self,lhs:void,rhs:void)->bool",
    "0:PySide6.QtCore.QMetaType.equals(lhs:void,rhs:void,typeId:int,result:int*)->bool",
    "PySide6.QtCore.QMetaType.flags(self)->PySide6.QtCore.QMetaType.TypeFlag",
    "PySide6.QtCore.QMetaType.fromName(name:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QMetaType",
    "PySide6.QtCore.QMetaType.hasRegisteredConverterFunction(fromType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type],toType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])->bool",
    "PySide6.QtCore.QMetaType.hasRegisteredDataStreamOperators(self)->bool",
    "1:PySide6.QtCore.QMetaType.hasRegisteredDebugStreamOperator(self)->bool",
    "0:PySide6.QtCore.QMetaType.hasRegisteredDebugStreamOperator(typeId:int)->bool",
    "PySide6.QtCore.QMetaType.hasRegisteredMutableViewFunction(fromType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type],toType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])->bool",
    "PySide6.QtCore.QMetaType.id(self,arg__1:int=0)->int",
    "PySide6.QtCore.QMetaType.isCopyConstructible(self)->bool",
    "PySide6.QtCore.QMetaType.isDefaultConstructible(self)->bool",
    "PySide6.QtCore.QMetaType.isDestructible(self)->bool",
    "PySide6.QtCore.QMetaType.isEqualityComparable(self)->bool",
    "PySide6.QtCore.QMetaType.isMoveConstructible(self)->bool",
    "PySide6.QtCore.QMetaType.isOrdered(self)->bool",
    "1:PySide6.QtCore.QMetaType.isRegistered(self)->bool",
    "0:PySide6.QtCore.QMetaType.isRegistered(type:int)->bool",
    "PySide6.QtCore.QMetaType.isValid(self)->bool",
    "1:PySide6.QtCore.QMetaType.load(stream:PySide6.QtCore.QDataStream,type:int,data:void)->bool",
    "0:PySide6.QtCore.QMetaType.load(self,stream:PySide6.QtCore.QDataStream,data:void)->bool",
    "PySide6.QtCore.QMetaType.metaObjectForType(type:int)->PySide6.QtCore.QMetaObject",
    "PySide6.QtCore.QMetaType.name(self)->char*",
    "PySide6.QtCore.QMetaType.registerNormalizedTypedef(normalizedTypeName:typing.Union[PySide6.QtCore.QByteArray, char*],type:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])",
    "PySide6.QtCore.QMetaType.registerType(self)",
    "1:PySide6.QtCore.QMetaType.save(self,stream:PySide6.QtCore.QDataStream,data:void)->bool",
    "0:PySide6.QtCore.QMetaType.save(stream:PySide6.QtCore.QDataStream,type:int,data:void)->bool",
    "1:PySide6.QtCore.QMetaType.sizeOf(self)->qsizetype",
    "0:PySide6.QtCore.QMetaType.sizeOf(type:int)->int",
    "1:PySide6.QtCore.QMetaType.type(typeName:typing.Union[PySide6.QtCore.QByteArray, char*])->int",
    "0:PySide6.QtCore.QMetaType.type(typeName:char*)->int",
    "PySide6.QtCore.QMetaType.typeFlags(type:int)->PySide6.QtCore.QMetaType.TypeFlag",
    "PySide6.QtCore.QMetaType.typeName(type:int)->char*",
    "PySide6.QtCore.QMetaType.underlyingType(self)->PySide6.QtCore.QMetaType",
    "PySide6.QtCore.QMetaType.unregisterConverterFunction(from:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type],to:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])",
    "PySide6.QtCore.QMetaType.unregisterMetaType(type:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])",
    "PySide6.QtCore.QMetaType.unregisterMutableViewFunction(from:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type],to:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])",
    "PySide6.QtCore.QMetaType.view(fromType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type],from:void,toType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type],to:void)->bool",
    "PySide6.QtCore.QMetaType.__copy__(self)->typing.Self",
    "PySide6.QtCore.QMetaType.__ne__(self,rhs:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])->bool",
    "PySide6.QtCore.QMetaType.__eq__(self,rhs:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])->bool",
    "PySide6.QtCore.QMetaType.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QMetaType_SignatureByteSize = 777;
static constexpr uint8_t QMetaType_SignatureBytes[777] = {
    0x78, 0xda, 0xdd, 0x58, 0xc1, 0x8e, 0xda, 0x30, 0x10, 0xbd, 0xf3, 0x15, 0x7b, 0x84, 0x55, 0x8a,
    0xb2, 0xad, 0xd4, 0x03, 0xd2, 0x56, 0x6a, 0xd9, 0x22, 0xf5, 0x00, 0x74, 0x4b, 0xbb, 0x97, 0x6a,
    0x15, 0x19, 0x32, 0x80, 0xab, 0x60, 0x83, 0xe3, 0xb0, 0xca, 0x7e, 0x7d, 0xc7, 0x49, 0x0c, 0x89,
    0xc0, 0x76, 0x60, 0x81, 0x8a, 0x5e, 0x20, 0x44, 0x7e, 0x6f, 0x3c, 0x33, 0x6f, 0xc6, 0x63, 0x3e,
    0x74, 0xbe, 0xa7, 0x23, 0x1a, 0xc2, 0xc7, 0xf6, 0xa3, 0xec, 0x72, 0x01, 0xed, 0xc7, 0x3e, 0x48,
    0xf2, 0x33, 0x5d, 0x42, 0x33, 0x86, 0x68, 0xda, 0x6a, 0xbc, 0xb7, 0x2f, 0xf0, 0x96, 0x69, 0x20,
    0xf1, 0x07, 0xae, 0x52, 0xef, 0x86, 0xe3, 0x3f, 0x30, 0x91, 0xad, 0xc6, 0x9d, 0x03, 0x55, 0x40,
    0xf6, 0x2f, 0x69, 0xab, 0x8f, 0x56, 0xc3, 0xaf, 0xc3, 0x41, 0x19, 0x5a, 0x33, 0x12, 0x91, 0x88,
    0xce, 0xd8, 0x70, 0x9a, 0xbb, 0xf2, 0xee, 0xd3, 0x2a, 0xa6, 0xaf, 0xa0, 0x60, 0x66, 0xc4, 0x84,
    0xb0, 0x2e, 0x67, 0x6b, 0x10, 0xb2, 0x39, 0x15, 0x7c, 0xa1, 0xde, 0x75, 0x10, 0x41, 0xd9, 0xac,
    0xfd, 0x8b, 0x51, 0xce, 0x7e, 0x9b, 0x90, 0xde, 0x8d, 0xd5, 0x9d, 0x67, 0x4f, 0xf2, 0xd3, 0x91,
    0xa1, 0x2f, 0x63, 0xce, 0x23, 0xab, 0x1b, 0x4f, 0x14, 0x5e, 0xae, 0xdb, 0x07, 0xbe, 0x58, 0x12,
    0x01, 0xcd, 0x68, 0x1e, 0x77, 0xd6, 0x9c, 0x86, 0x9e, 0xd0, 0x0f, 0x2a, 0x85, 0xdf, 0x42, 0x95,
    0x7b, 0x4f, 0x40, 0x9c, 0x44, 0x52, 0x3d, 0xde, 0x6a, 0x42, 0xb3, 0xf6, 0x90, 0x92, 0xc5, 0x52,
    0x24, 0x13, 0xd9, 0xd4, 0xe2, 0xf1, 0x5e, 0xe6, 0x20, 0x20, 0xa7, 0x9d, 0xf0, 0x65, 0x9a, 0x3d,
    0x21, 0x93, 0xfa, 0xb2, 0x28, 0xb0, 0xc4, 0x94, 0x69, 0x71, 0x1f, 0xcb, 0x3d, 0x4b, 0xa2, 0x68,
    0x29, 0x85, 0x66, 0xb3, 0xef, 0xeb, 0x1c, 0x92, 0x53, 0x74, 0x45, 0xc4, 0xf8, 0x49, 0x55, 0xa0,
    0xa3, 0x94, 0xc5, 0xdb, 0xaf, 0xe7, 0x57, 0xbe, 0x11, 0xed, 0x61, 0x91, 0xbe, 0x82, 0xaa, 0xd8,
    0x5f, 0xfe, 0xb2, 0x4e, 0x1e, 0x05, 0x10, 0x59, 0xb4, 0x01, 0x63, 0xbc, 0x7d, 0x27, 0x7e, 0x23,
    0x82, 0x63, 0x72, 0x16, 0x02, 0x0a, 0x80, 0xa7, 0x5b, 0x92, 0x90, 0x48, 0x92, 0x07, 0xc6, 0x66,
    0x5a, 0xc3, 0xb2, 0xbd, 0x97, 0x20, 0x2e, 0x4b, 0x06, 0xd1, 0xba, 0x6d, 0x6d, 0x34, 0x5a, 0xcf,
    0x18, 0xac, 0x12, 0x12, 0xc5, 0x39, 0x62, 0xa7, 0xf2, 0x6a, 0xa4, 0xbc, 0xc0, 0x1f, 0x5a, 0xb4,
    0x46, 0xbe, 0x69, 0x44, 0x66, 0xb1, 0x6e, 0xe0, 0x56, 0x61, 0xf6, 0x70, 0xa5, 0x85, 0x07, 0x85,
    0x37, 0x20, 0x0b, 0x68, 0x32, 0xfc, 0xb0, 0x17, 0xc2, 0x97, 0x54, 0xc2, 0x67, 0x21, 0x48, 0xea,
    0xdd, 0x4c, 0xe6, 0x44, 0xdc, 0x3e, 0x5b, 0x2c, 0x9b, 0x0d, 0xce, 0x49, 0xfc, 0x03, 0x66, 0x34,
    0x96, 0x98, 0xaa, 0xb0, 0x38, 0x53, 0x40, 0xf4, 0x12, 0x36, 0x91, 0x68, 0xf4, 0xaa, 0x3b, 0x73,
    0xc5, 0xb5, 0x07, 0x94, 0xd5, 0x48, 0x62, 0x41, 0x2d, 0x86, 0x4b, 0x10, 0x44, 0x72, 0xb1, 0x49,
    0x97, 0xab, 0x8c, 0xab, 0x3c, 0x30, 0x4e, 0x66, 0x55, 0xa2, 0x0a, 0x8f, 0xff, 0x06, 0x1e, 0xb9,
    0xd3, 0x5c, 0xea, 0x71, 0xf5, 0x13, 0x49, 0xc6, 0x11, 0xa8, 0xa3, 0xf4, 0xbf, 0x48, 0x1c, 0x0d,
    0xf3, 0xc2, 0x26, 0x62, 0x16, 0x04, 0x77, 0x2a, 0x1e, 0xf7, 0x3e, 0x82, 0xf0, 0xdb, 0x82, 0x89,
    0xbb, 0xd8, 0x1d, 0xbb, 0xfa, 0xbc, 0xa3, 0x18, 0x8f, 0x4a, 0x5e, 0x2c, 0xc0, 0x07, 0x98, 0x12,
    0x2c, 0xf4, 0x23, 0xb1, 0x87, 0x63, 0xbe, 0xaa, 0xde, 0x43, 0x25, 0x6e, 0x56, 0x4d, 0x0e, 0xe4,
    0x00, 0x64, 0x9f, 0xaf, 0xe1, 0xa8, 0x6d, 0x0e, 0x45, 0xa8, 0x84, 0x52, 0x57, 0xf1, 0xb4, 0x24,
    0xae, 0xba, 0xea, 0xae, 0x60, 0x36, 0x43, 0xaf, 0x7b, 0x6b, 0x4f, 0x18, 0x8b, 0xda, 0x1b, 0x8b,
    0x38, 0xc1, 0xb5, 0x59, 0xd5, 0xec, 0x2c, 0xda, 0x56, 0xb8, 0xb7, 0xe7, 0xb0, 0x73, 0x3b, 0x90,
    0x73, 0x2b, 0xdd, 0xb9, 0x0d, 0xec, 0xf0, 0x1a, 0x59, 0x17, 0xf8, 0x90, 0x5f, 0x37, 0x7a, 0x5c,
    0x64, 0xb7, 0x82, 0x52, 0x6c, 0xf6, 0xa1, 0xf2, 0xc5, 0x66, 0x42, 0x75, 0x30, 0xe8, 0x70, 0x65,
    0x7d, 0xdf, 0xbc, 0x54, 0x14, 0x09, 0x19, 0x70, 0xb1, 0xc0, 0x28, 0xbf, 0x42, 0xa8, 0x5e, 0x87,
    0x30, 0x6d, 0xb2, 0xca, 0x9b, 0xc1, 0xe1, 0x67, 0x4d, 0x1e, 0xe2, 0xd3, 0xb4, 0x03, 0xb7, 0x03,
    0xa5, 0x8b, 0x9e, 0x45, 0x1c, 0x31, 0x59, 0xc3, 0xd1, 0x09, 0xf4, 0x5d, 0xbc, 0x6f, 0x10, 0x9d,
    0x6d, 0xcf, 0x98, 0x83, 0x7d, 0x37, 0x3f, 0xdf, 0x09, 0x29, 0xc9, 0x48, 0x35, 0x46, 0x8b, 0x0d,
    0xa9, 0x55, 0x37, 0x38, 0x6a, 0xa6, 0x50, 0xec, 0x7e, 0x5d, 0xf6, 0x0c, 0xe5, 0xea, 0xd5, 0xb2,
    0x18, 0x83, 0x62, 0x57, 0x2d, 0xd4, 0x1c, 0x9a, 0xb4, 0xf5, 0x32, 0x9d, 0xa3, 0x34, 0x12, 0x86,
    0x0d, 0x31, 0x4a, 0x31, 0x12, 0x5b, 0x6d, 0x1d, 0x33, 0x3e, 0x25, 0x4c, 0x6b, 0x74, 0xff, 0xec,
    0x74, 0xba, 0xbb, 0xcc, 0xb9, 0x6b, 0x6d, 0xeb, 0xc9, 0xe6, 0xff, 0x8b, 0x8b, 0xd4, 0x78, 0xc9,
    0xae, 0x61, 0x8c, 0xb9, 0x9e, 0x18, 0xae, 0xcf, 0xf0, 0x67, 0xc6, 0x65, 0x6e, 0xc7, 0xc6, 0xd5,
    0x41, 0xa0, 0x6e, 0x9d, 0x41, 0xa0, 0x4b, 0xa4, 0xb0, 0x3e, 0xc2, 0x5f, 0x36, 0x10, 0x83, 0x02,
    0x92, 0xdd, 0xac, 0x2e, 0x33, 0x36, 0x06, 0x01, 0xac, 0xfe, 0x85, 0x55, 0x9c, 0xc5, 0xe7, 0xdb,
    0x00, 0xa9, 0xce, 0xf7, 0x17, 0x84, 0x70, 0x6c, 0xfc
};
#endif

PyTypeObject *init_QMetaType(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX].type;

    Shiboken::AutoDecRef Sbk_QMetaType_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QMetaType_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMetaType",
        "QMetaType",
        &Sbk_QMetaType_spec,
        &Shiboken::callCppDestructor< ::QMetaType >,
        Sbk_QMetaType_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QMetaType_TypeF(); // references _Sbk_QMetaType_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMetaType_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMetaType_SignatureBytes, QMetaType_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMetaType_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMetaType_PythonToCpp_QMetaType_PTR,
        is_QMetaType_PythonToCpp_QMetaType_PTR_Convertible,
        QMetaType_PTR_CppToPython_QMetaType,
        QMetaType_COPY_CppToPython_QMetaType);

    Shiboken::Conversions::registerConverterName(converter, "QMetaType");
    Shiboken::Conversions::registerConverterName(converter, "QMetaType*");
    Shiboken::Conversions::registerConverterName(converter, "QMetaType&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMetaType).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QMetaType_PythonToCpp_QMetaType_COPY,
        is_QMetaType_PythonToCpp_QMetaType_COPY_Convertible);
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PyTypeObject_PythonToCpp_QMetaType,
        is_PyTypeObject_PythonToCpp_QMetaType_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QMetaType_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "Bool",
        "Int",
        "UInt",
        "LongLong",
        "ULongLong",
        "Double",
        "Long",
        "Short",
        "Char",
        "Char16",
        "Char32",
        "ULong",
        "UShort",
        "UChar",
        "Float",
        "SChar",
        "Nullptr",
        "QCborSimpleType",
        "Void",
        "VoidStar",
        "QChar",
        "QString",
        "QByteArray",
        "QBitArray",
        "QDate",
        "QTime",
        "QDateTime",
        "QUrl",
        "QLocale",
        "QRect",
        "QRectF",
        "QSize",
        "QSizeF",
        "QLine",
        "QLineF",
        "QPoint",
        "QPointF",
        "QEasingCurve",
        "QUuid",
        "QVariant",
        "QRegularExpression",
        "QJsonValue",
        "QJsonObject",
        "QJsonArray",
        "QJsonDocument",
        "QCborValue",
        "QCborArray",
        "QCborMap",
        "Float16",
        "QModelIndex",
        "QPersistentModelIndex",
        "QObjectStar",
        "QVariantMap",
        "QVariantList",
        "QVariantHash",
        "QVariantPair",
        "QByteArrayList",
        "QStringList",
        "QFont",
        "QPixmap",
        "QBrush",
        "QColor",
        "QPalette",
        "QIcon",
        "QImage",
        "QPolygon",
        "QRegion",
        "QBitmap",
        "QCursor",
        "QKeySequence",
        "QPen",
        "QTextLength",
        "QTextFormat",
        "QTransform",
        "QMatrix4x4",
        "QVector2D",
        "QVector3D",
        "QVector4D",
        "QQuaternion",
        "QPolygonF",
        "QColorSpace",
        "QSizePolicy",
        "FirstCoreType",
        "LastCoreType",
        "FirstGuiType",
        "LastGuiType",
        "FirstWidgetsType",
        "LastWidgetsType",
        "HighestInternalId",
        "QReal",
        "UnknownType",
        "User",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t Type_InitializerValues[] = {
        uint32_t(QMetaType::Type::Bool),                  //  0x00000001  1
        uint32_t(QMetaType::Type::Int),                   //  0x00000002  2
        uint32_t(QMetaType::Type::UInt),                  //  0x00000003  3
        uint32_t(QMetaType::Type::LongLong),              //  0x00000004  4
        uint32_t(QMetaType::Type::ULongLong),             //  0x00000005  5
        uint32_t(QMetaType::Type::Double),                //  0x00000006  6
        uint32_t(QMetaType::Type::Long),                  //  0x00000020  32
        uint32_t(QMetaType::Type::Short),                 //  0x00000021  33
        uint32_t(QMetaType::Type::Char),                  //  0x00000022  34
        uint32_t(QMetaType::Type::Char16),                //  0x00000038  56
        uint32_t(QMetaType::Type::Char32),                //  0x00000039  57
        uint32_t(QMetaType::Type::ULong),                 //  0x00000023  35
        uint32_t(QMetaType::Type::UShort),                //  0x00000024  36
        uint32_t(QMetaType::Type::UChar),                 //  0x00000025  37
        uint32_t(QMetaType::Type::Float),                 //  0x00000026  38
        uint32_t(QMetaType::Type::SChar),                 //  0x00000028  40
        uint32_t(QMetaType::Type::Nullptr),               //  0x00000033  51
        uint32_t(QMetaType::Type::QCborSimpleType),       //  0x00000034  52
        uint32_t(QMetaType::Type::Void),                  //  0x0000002b  43
        uint32_t(QMetaType::Type::VoidStar),              //  0x0000001f  31
        uint32_t(QMetaType::Type::QChar),                 //  0x00000007  7
        uint32_t(QMetaType::Type::QString),               //  0x0000000a  10
        uint32_t(QMetaType::Type::QByteArray),            //  0x0000000c  12
        uint32_t(QMetaType::Type::QBitArray),             //  0x0000000d  13
        uint32_t(QMetaType::Type::QDate),                 //  0x0000000e  14
        uint32_t(QMetaType::Type::QTime),                 //  0x0000000f  15
        uint32_t(QMetaType::Type::QDateTime),             //  0x00000010  16
        uint32_t(QMetaType::Type::QUrl),                  //  0x00000011  17
        uint32_t(QMetaType::Type::QLocale),               //  0x00000012  18
        uint32_t(QMetaType::Type::QRect),                 //  0x00000013  19
        uint32_t(QMetaType::Type::QRectF),                //  0x00000014  20
        uint32_t(QMetaType::Type::QSize),                 //  0x00000015  21
        uint32_t(QMetaType::Type::QSizeF),                //  0x00000016  22
        uint32_t(QMetaType::Type::QLine),                 //  0x00000017  23
        uint32_t(QMetaType::Type::QLineF),                //  0x00000018  24
        uint32_t(QMetaType::Type::QPoint),                //  0x00000019  25
        uint32_t(QMetaType::Type::QPointF),               //  0x0000001a  26
        uint32_t(QMetaType::Type::QEasingCurve),          //  0x0000001d  29
        uint32_t(QMetaType::Type::QUuid),                 //  0x0000001e  30
        uint32_t(QMetaType::Type::QVariant),              //  0x00000029  41
        uint32_t(QMetaType::Type::QRegularExpression),    //  0x0000002c  44
        uint32_t(QMetaType::Type::QJsonValue),            //  0x0000002d  45
        uint32_t(QMetaType::Type::QJsonObject),           //  0x0000002e  46
        uint32_t(QMetaType::Type::QJsonArray),            //  0x0000002f  47
        uint32_t(QMetaType::Type::QJsonDocument),         //  0x00000030  48
        uint32_t(QMetaType::Type::QCborValue),            //  0x00000035  53
        uint32_t(QMetaType::Type::QCborArray),            //  0x00000036  54
        uint32_t(QMetaType::Type::QCborMap),              //  0x00000037  55
        uint32_t(QMetaType::Type::Float16),               //  0x0000003f  63
        uint32_t(QMetaType::Type::QModelIndex),           //  0x0000002a  42
        uint32_t(QMetaType::Type::QPersistentModelIndex), //  0x00000032  50
        uint32_t(QMetaType::Type::QObjectStar),           //  0x00000027  39
        uint32_t(QMetaType::Type::QVariantMap),           //  0x00000008  8
        uint32_t(QMetaType::Type::QVariantList),          //  0x00000009  9
        uint32_t(QMetaType::Type::QVariantHash),          //  0x0000001c  28
        uint32_t(QMetaType::Type::QVariantPair),          //  0x0000003a  58
        uint32_t(QMetaType::Type::QByteArrayList),        //  0x00000031  49
        uint32_t(QMetaType::Type::QStringList),           //  0x0000000b  11
        uint32_t(QMetaType::Type::QFont),                 //  0x00001000  4096
        uint32_t(QMetaType::Type::QPixmap),               //  0x00001001  4097
        uint32_t(QMetaType::Type::QBrush),                //  0x00001002  4098
        uint32_t(QMetaType::Type::QColor),                //  0x00001003  4099
        uint32_t(QMetaType::Type::QPalette),              //  0x00001004  4100
        uint32_t(QMetaType::Type::QIcon),                 //  0x00001005  4101
        uint32_t(QMetaType::Type::QImage),                //  0x00001006  4102
        uint32_t(QMetaType::Type::QPolygon),              //  0x00001007  4103
        uint32_t(QMetaType::Type::QRegion),               //  0x00001008  4104
        uint32_t(QMetaType::Type::QBitmap),               //  0x00001009  4105
        uint32_t(QMetaType::Type::QCursor),               //  0x0000100a  4106
        uint32_t(QMetaType::Type::QKeySequence),          //  0x0000100b  4107
        uint32_t(QMetaType::Type::QPen),                  //  0x0000100c  4108
        uint32_t(QMetaType::Type::QTextLength),           //  0x0000100d  4109
        uint32_t(QMetaType::Type::QTextFormat),           //  0x0000100e  4110
        uint32_t(QMetaType::Type::QTransform),            //  0x00001010  4112
        uint32_t(QMetaType::Type::QMatrix4x4),            //  0x00001011  4113
        uint32_t(QMetaType::Type::QVector2D),             //  0x00001012  4114
        uint32_t(QMetaType::Type::QVector3D),             //  0x00001013  4115
        uint32_t(QMetaType::Type::QVector4D),             //  0x00001014  4116
        uint32_t(QMetaType::Type::QQuaternion),           //  0x00001015  4117
        uint32_t(QMetaType::Type::QPolygonF),             //  0x00001016  4118
        uint32_t(QMetaType::Type::QColorSpace),           //  0x00001017  4119
        uint32_t(QMetaType::Type::QSizePolicy),           //  0x00002000  8192
        uint32_t(QMetaType::Type::FirstCoreType),         //  0x00000001  1
        uint32_t(QMetaType::Type::LastCoreType),          //  0x0000003f  63
        uint32_t(QMetaType::Type::FirstGuiType),          //  0x00001000  4096
        uint32_t(QMetaType::Type::LastGuiType),           //  0x00001017  4119
        uint32_t(QMetaType::Type::FirstWidgetsType),      //  0x00002000  8192
        uint32_t(QMetaType::Type::LastWidgetsType),       //  0x00002000  8192
        uint32_t(QMetaType::Type::HighestInternalId),     //  0x00002000  8192
        uint32_t(QMetaType::Type::QReal),                 //  0x00000006  6
        uint32_t(QMetaType::Type::UnknownType),           //  0x00000000  0
        uint32_t(QMetaType::Type::User)                   //  0x00010000  65536
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMetaType_TypeF(),
        "2:PySide6.QtCore.QMetaType.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_Type_IDX].type = EType;
    // Register converter for enum 'QMetaType::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMetaType_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMetaType_Type,
            is_Enum_PythonToCpp_QMetaType_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMetaType::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    // Initialization of enum 'TypeFlag'.
    const char *TypeFlag_Initializer[] = {
        "NeedsConstruction",
        "NeedsDestruction",
        "RelocatableType",
        "MovableType",
        "PointerToQObject",
        "IsEnumeration",
        "SharedPointerToQObject",
        "WeakPointerToQObject",
        "TrackingPointerToQObject",
        "IsUnsignedEnumeration",
        "IsGadget",
        "PointerToGadget",
        "IsPointer",
        "IsQmlList",
        "IsConst",
        "NeedsCopyConstruction",
        "NeedsMoveConstruction",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t TypeFlag_InitializerValues[] = {
        uint16_t(QMetaType::TypeFlag::NeedsConstruction),        //  0x0001  1
        uint16_t(QMetaType::TypeFlag::NeedsDestruction),         //  0x0002  2
        uint16_t(QMetaType::TypeFlag::RelocatableType),          //  0x0004  4
        uint16_t(QMetaType::TypeFlag::MovableType),              //  0x0004  4
        uint16_t(QMetaType::TypeFlag::PointerToQObject),         //  0x0008  8
        uint16_t(QMetaType::TypeFlag::IsEnumeration),            //  0x0010  16
        uint16_t(QMetaType::TypeFlag::SharedPointerToQObject),   //  0x0020  32
        uint16_t(QMetaType::TypeFlag::WeakPointerToQObject),     //  0x0040  64
        uint16_t(QMetaType::TypeFlag::TrackingPointerToQObject), //  0x0080  128
        uint16_t(QMetaType::TypeFlag::IsUnsignedEnumeration),    //  0x0100  256
        uint16_t(QMetaType::TypeFlag::IsGadget),                 //  0x0200  512
        uint16_t(QMetaType::TypeFlag::PointerToGadget),          //  0x0400  1024
        uint16_t(QMetaType::TypeFlag::IsPointer),                //  0x0800  2048
        uint16_t(QMetaType::TypeFlag::IsQmlList),                //  0x1000  4096
        uint16_t(QMetaType::TypeFlag::IsConst),                  //  0x2000  8192
        uint16_t(QMetaType::TypeFlag::NeedsCopyConstruction),    //  0x4000  16384
        uint16_t(QMetaType::TypeFlag::NeedsMoveConstruction)     //  0x8000  32768
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMetaType_TypeF(),
        "2:PySide6.QtCore.QMetaType.TypeFlag",
        TypeFlag_Initializer, TypeFlag_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_TypeFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QMetaType_TypeFlag_IDX].type =
        EType;
    // Register converter for enum 'QMetaType::TypeFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMetaType_TypeFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMetaType_TypeFlag,
            is_Enum_PythonToCpp_QMetaType_TypeFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMetaType::TypeFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "TypeFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QMetaType_TypeFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QMetaType_TypeFlag,
            is_Enum_PythonToCpp_QMetaType_TypeFlag_Convertible);
        // Register converter for flag 'QFlags<QMetaType::TypeFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QMetaType::TypeFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QMetaType::TypeFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'TypeFlag' enum/flags.

    qRegisterMetaType< ::QMetaType >("QMetaType");
    qRegisterMetaType< ::QMetaType::Type >("QMetaType::Type");
    qRegisterMetaType< ::QMetaType::TypeFlag >("QMetaType::TypeFlag");

    return pyType;
}
