// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qmicrophonepermission_wrapper.h"

// Argument includes
#include <qpermissions.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMicrophonePermission_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMicrophonePermission >()))
        return -1;

    ::QMicrophonePermission *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QMicrophonePermission", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMicrophonePermission::QMicrophonePermission()
    // 1: QMicrophonePermission::QMicrophonePermission(QMicrophonePermission)
    if (numArgs == 0) {
        overloadId = 0; // QMicrophonePermission()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMicrophonePermission_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QMicrophonePermission(QMicrophonePermission)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMicrophonePermission_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QMicrophonePermission_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QMicrophonePermission()
        {

            // QMicrophonePermission()
            cptr = new ::QMicrophonePermission();
            break;
        }
        case 1: // QMicrophonePermission(const QMicrophonePermission &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QMicrophonePermission cppArg0_local;
            ::QMicrophonePermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QMicrophonePermission(QMicrophonePermission)
                cptr = new ::QMicrophonePermission(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMicrophonePermission >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMicrophonePermission_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMicrophonePermissionFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMicrophonePermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMicrophonePermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMicrophonePermission::swap(QMicrophonePermission&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMicrophonePermission_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QMicrophonePermission&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMicrophonePermission_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMicrophonePermission cppArg0_local;
        ::QMicrophonePermission *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QMicrophonePermission&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMicrophonePermission__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMicrophonePermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMicrophonePermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMicrophonePermission_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QMicrophonePermission_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMicrophonePermission_methods[] = {
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QMicrophonePermissionFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QMicrophonePermission__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QMicrophonePermission_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMicrophonePermission_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMicrophonePermission_Type = nullptr;
static PyTypeObject *Sbk_QMicrophonePermission_TypeF(void)
{
    return _Sbk_QMicrophonePermission_Type;
}

static PyType_Slot Sbk_QMicrophonePermission_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMicrophonePermission_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMicrophonePermission_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMicrophonePermission_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMicrophonePermission_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMicrophonePermission_spec = {
    "2:PySide6.QtCore.QMicrophonePermission",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMicrophonePermission_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMicrophonePermission_PythonToCpp_QMicrophonePermission_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMicrophonePermission_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMicrophonePermission_PythonToCpp_QMicrophonePermission_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMicrophonePermission_TypeF()))
        return QMicrophonePermission_PythonToCpp_QMicrophonePermission_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMicrophonePermission_PTR_CppToPython_QMicrophonePermission(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QMicrophonePermission_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QMicrophonePermission_COPY_CppToPython_QMicrophonePermission(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QMicrophonePermission *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QMicrophonePermission_TypeF(), new ::QMicrophonePermission(*source), true, true);
}

// Python to C++ copy conversion.
static void QMicrophonePermission_PythonToCpp_QMicrophonePermission_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QMicrophonePermission *>(cppOut) = *reinterpret_cast< ::QMicrophonePermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMicrophonePermission_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QMicrophonePermission_PythonToCpp_QMicrophonePermission_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QMicrophonePermission_TypeF()))
        return QMicrophonePermission_PythonToCpp_QMicrophonePermission_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMicrophonePermission_SignatureStrings[] = {
    "1:PySide6.QtCore.QMicrophonePermission(self)",
    "0:PySide6.QtCore.QMicrophonePermission(self,other:PySide6.QtCore.QMicrophonePermission)",
    "PySide6.QtCore.QMicrophonePermission.swap(self,other:PySide6.QtCore.QMicrophonePermission)",
    "PySide6.QtCore.QMicrophonePermission.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QMicrophonePermission_SignatureByteSize = 99;
static constexpr uint8_t QMicrophonePermission_SignatureBytes[99] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0xf4, 0xcd, 0x4c, 0x2e, 0xca, 0x2f, 0xc8, 0xc8, 0xcf, 0x4b, 0x0d, 0x48,
    0x2d, 0xca, 0xcd, 0x2c, 0x2e, 0xce, 0xcc, 0xcf, 0xd3, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32,
    0x20, 0x5e, 0xb1, 0x4e, 0x7e, 0x49, 0x46, 0x6a, 0x11, 0x51, 0xea, 0x35, 0xb9, 0x88, 0x51, 0xa5,
    0x57, 0x5c, 0x9e, 0x58, 0x40, 0x23, 0xa3, 0xe3, 0xe3, 0x93, 0xf3, 0x0b, 0x2a, 0xe3, 0xe3, 0x21,
    0xde, 0xd4, 0xb5, 0x2b, 0xa9, 0x2c, 0xc8, 0xcc, 0x4b, 0xd7, 0x0b, 0x06, 0xf2, 0xb8, 0x00, 0x09,
    0xec, 0x6a, 0x6e
};
#endif

PyTypeObject *init_QMicrophonePermission(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QMicrophonePermission_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QMicrophonePermission_IDX].type;

    Shiboken::AutoDecRef Sbk_QMicrophonePermission_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QMicrophonePermission_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMicrophonePermission",
        "QMicrophonePermission",
        &Sbk_QMicrophonePermission_spec,
        &Shiboken::callCppDestructor< ::QMicrophonePermission >,
        Sbk_QMicrophonePermission_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QMicrophonePermission_TypeF(); // references _Sbk_QMicrophonePermission_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMicrophonePermission_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMicrophonePermission_SignatureBytes, QMicrophonePermission_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMicrophonePermission_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QMicrophonePermission_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMicrophonePermission_PythonToCpp_QMicrophonePermission_PTR,
        is_QMicrophonePermission_PythonToCpp_QMicrophonePermission_PTR_Convertible,
        QMicrophonePermission_PTR_CppToPython_QMicrophonePermission,
        QMicrophonePermission_COPY_CppToPython_QMicrophonePermission);

    Shiboken::Conversions::registerConverterName(converter, "QMicrophonePermission");
    Shiboken::Conversions::registerConverterName(converter, "QMicrophonePermission*");
    Shiboken::Conversions::registerConverterName(converter, "QMicrophonePermission&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMicrophonePermission).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QMicrophonePermission_PythonToCpp_QMicrophonePermission_COPY,
        is_QMicrophonePermission_PythonToCpp_QMicrophonePermission_COPY_Convertible);

    qRegisterMetaType< ::QMicrophonePermission >("QMicrophonePermission");

    return pyType;
}
