// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qmimetype_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <qmimetype.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMimeType_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMimeType >()))
        return -1;

    ::QMimeType *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QMimeType", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMimeType::QMimeType()
    // 1: QMimeType::QMimeType(QMimeType)
    if (numArgs == 0) {
        overloadId = 0; // QMimeType()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QMimeType(QMimeType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QMimeType()
        {

            // QMimeType()
            cptr = new ::QMimeType();
            break;
        }
        case 1: // QMimeType(const QMimeType &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QMimeType cppArg0_local;
            ::QMimeType *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QMimeType(QMimeType)
                cptr = new ::QMimeType(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMimeType >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMimeTypeFunc_aliases(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // aliases()const
        QStringList cppResult = const_cast<const ::QMimeType *>(cppSelf)->aliases();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeTypeFunc_allAncestors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // allAncestors()const
        QStringList cppResult = const_cast<const ::QMimeType *>(cppSelf)->allAncestors();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeTypeFunc_comment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // comment()const
        QString cppResult = const_cast<const ::QMimeType *>(cppSelf)->comment();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeTypeFunc_filterString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // filterString()const
        QString cppResult = const_cast<const ::QMimeType *>(cppSelf)->filterString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeTypeFunc_genericIconName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // genericIconName()const
        QString cppResult = const_cast<const ::QMimeType *>(cppSelf)->genericIconName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeTypeFunc_globPatterns(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // globPatterns()const
        QStringList cppResult = const_cast<const ::QMimeType *>(cppSelf)->globPatterns();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeTypeFunc_iconName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // iconName()const
        QString cppResult = const_cast<const ::QMimeType *>(cppSelf)->iconName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeTypeFunc_inherits(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMimeType::inherits(QString)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // inherits(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "inherits", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // inherits(QString)const
            bool cppResult = const_cast<const ::QMimeType *>(cppSelf)->inherits(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeTypeFunc_isDefault(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDefault()const
        bool cppResult = const_cast<const ::QMimeType *>(cppSelf)->isDefault();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeTypeFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QMimeType *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeTypeFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QMimeType *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeTypeFunc_parentMimeTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parentMimeTypes()const
        QStringList cppResult = const_cast<const ::QMimeType *>(cppSelf)->parentMimeTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeTypeFunc_preferredSuffix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // preferredSuffix()const
        QString cppResult = const_cast<const ::QMimeType *>(cppSelf)->preferredSuffix();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeTypeFunc_suffixes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // suffixes()const
        QStringList cppResult = const_cast<const ::QMimeType *>(cppSelf)->suffixes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeTypeFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMimeType::swap(QMimeType&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QMimeType&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMimeType cppArg0_local;
        ::QMimeType *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QMimeType&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMimeType__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QMimeType_PropertyStrings[] = {
    "aliases:",
    "allAncestors:",
    "comment:",
    "filterString:",
    "genericIconName:",
    "globPatterns:",
    "iconName:",
    "isDefault:",
    "name:",
    "parentMimeTypes:",
    "preferredSuffix:",
    "suffixes:",
    "valid:isValid",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMimeType_methods[] = {
    {"aliases", reinterpret_cast<PyCFunction>(Sbk_QMimeTypeFunc_aliases), METH_NOARGS, nullptr},
    {"allAncestors", reinterpret_cast<PyCFunction>(Sbk_QMimeTypeFunc_allAncestors), METH_NOARGS, nullptr},
    {"comment", reinterpret_cast<PyCFunction>(Sbk_QMimeTypeFunc_comment), METH_NOARGS, nullptr},
    {"filterString", reinterpret_cast<PyCFunction>(Sbk_QMimeTypeFunc_filterString), METH_NOARGS, nullptr},
    {"genericIconName", reinterpret_cast<PyCFunction>(Sbk_QMimeTypeFunc_genericIconName), METH_NOARGS, nullptr},
    {"globPatterns", reinterpret_cast<PyCFunction>(Sbk_QMimeTypeFunc_globPatterns), METH_NOARGS, nullptr},
    {"iconName", reinterpret_cast<PyCFunction>(Sbk_QMimeTypeFunc_iconName), METH_NOARGS, nullptr},
    {"inherits", reinterpret_cast<PyCFunction>(Sbk_QMimeTypeFunc_inherits), METH_O, nullptr},
    {"isDefault", reinterpret_cast<PyCFunction>(Sbk_QMimeTypeFunc_isDefault), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QMimeTypeFunc_isValid), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QMimeTypeFunc_name), METH_NOARGS, nullptr},
    {"parentMimeTypes", reinterpret_cast<PyCFunction>(Sbk_QMimeTypeFunc_parentMimeTypes), METH_NOARGS, nullptr},
    {"preferredSuffix", reinterpret_cast<PyCFunction>(Sbk_QMimeTypeFunc_preferredSuffix), METH_NOARGS, nullptr},
    {"suffixes", reinterpret_cast<PyCFunction>(Sbk_QMimeTypeFunc_suffixes), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QMimeTypeFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QMimeType__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QMimeType_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), (pyArg)))) {
                // operator!=(const QMimeType &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMimeType cppArg0_local;
                ::QMimeType *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), (pyArg)))) {
                // operator==(const QMimeType &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMimeType cppArg0_local;
                ::QMimeType *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QMimeType_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QMimeType_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMimeType_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QMimeType__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMimeType_Type = nullptr;
static PyTypeObject *Sbk_QMimeType_TypeF(void)
{
    return _Sbk_QMimeType_Type;
}

static PyType_Slot Sbk_QMimeType_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QMimeType__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QMimeType_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMimeType_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMimeType_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QMimeType_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMimeType_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMimeType_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMimeType_spec = {
    "2:PySide6.QtCore.QMimeType",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMimeType_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMimeType_PythonToCpp_QMimeType_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMimeType_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMimeType_PythonToCpp_QMimeType_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMimeType_TypeF()))
        return QMimeType_PythonToCpp_QMimeType_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMimeType_PTR_CppToPython_QMimeType(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QMimeType_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QMimeType_COPY_CppToPython_QMimeType(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QMimeType *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QMimeType_TypeF(), new ::QMimeType(*source), true, true);
}

// Python to C++ copy conversion.
static void QMimeType_PythonToCpp_QMimeType_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QMimeType *>(cppOut) = *reinterpret_cast< ::QMimeType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QMimeType_PythonToCpp_QMimeType_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QMimeType_TypeF()))
        return QMimeType_PythonToCpp_QMimeType_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMimeType_SignatureStrings[] = {
    "1:PySide6.QtCore.QMimeType(self,*:KeywordOnly=None,valid:bool=None,isDefault:bool=None,name:QString=None,comment:QString=None,genericIconName:QString=None,iconName:QString=None,globPatterns:QStringList=None,parentMimeTypes:QStringList=None,allAncestors:QStringList=None,aliases:QStringList=None,suffixes:QStringList=None,preferredSuffix:QString=None,filterString:QString=None)",
    "0:PySide6.QtCore.QMimeType(self,other:PySide6.QtCore.QMimeType,*:KeywordOnly=None,valid:bool=None,isDefault:bool=None,name:QString=None,comment:QString=None,genericIconName:QString=None,iconName:QString=None,globPatterns:QStringList=None,parentMimeTypes:QStringList=None,allAncestors:QStringList=None,aliases:QStringList=None,suffixes:QStringList=None,preferredSuffix:QString=None,filterString:QString=None)",
    "PySide6.QtCore.QMimeType.aliases(self)->QStringList",
    "PySide6.QtCore.QMimeType.allAncestors(self)->QStringList",
    "PySide6.QtCore.QMimeType.comment(self)->QString",
    "PySide6.QtCore.QMimeType.filterString(self)->QString",
    "PySide6.QtCore.QMimeType.genericIconName(self)->QString",
    "PySide6.QtCore.QMimeType.globPatterns(self)->QStringList",
    "PySide6.QtCore.QMimeType.iconName(self)->QString",
    "PySide6.QtCore.QMimeType.inherits(self,mimeTypeName:QString)->bool",
    "PySide6.QtCore.QMimeType.isDefault(self)->bool",
    "PySide6.QtCore.QMimeType.isValid(self)->bool",
    "PySide6.QtCore.QMimeType.name(self)->QString",
    "PySide6.QtCore.QMimeType.parentMimeTypes(self)->QStringList",
    "PySide6.QtCore.QMimeType.preferredSuffix(self)->QString",
    "PySide6.QtCore.QMimeType.suffixes(self)->QStringList",
    "PySide6.QtCore.QMimeType.swap(self,other:PySide6.QtCore.QMimeType)",
    "PySide6.QtCore.QMimeType.__copy__(self)->typing.Self",
    "PySide6.QtCore.QMimeType.__ne__(self,rhs:PySide6.QtCore.QMimeType)->bool",
    "PySide6.QtCore.QMimeType.__eq__(self,rhs:PySide6.QtCore.QMimeType)->bool",
    "PySide6.QtCore.QMimeType.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QMimeType_SignatureByteSize = 346;
static constexpr uint8_t QMimeType_SignatureBytes[346] = {
    0x78, 0xda, 0xed, 0x54, 0x4d, 0x4f, 0xc3, 0x30, 0x0c, 0xbd, 0xef, 0x97, 0x30, 0x54, 0x2a, 0xb8,
    0x70, 0xa8, 0x04, 0x12, 0x82, 0x0b, 0x02, 0xc6, 0xaa, 0x22, 0xae, 0x55, 0xd6, 0xba, 0xad, 0xa5,
    0xd4, 0x09, 0x49, 0xc6, 0xc8, 0xbf, 0xa7, 0x5b, 0x5b, 0xad, 0x2b, 0xfd, 0x94, 0xe0, 0xc6, 0x31,
    0xb6, 0x9f, 0x9f, 0xed, 0x67, 0xe7, 0xca, 0x5b, 0xdb, 0x00, 0x63, 0xb8, 0x76, 0x7d, 0x73, 0x2f,
    0x14, 0xb8, 0xfe, 0x0b, 0xe6, 0xf0, 0x66, 0x25, 0x9c, 0x69, 0xe0, 0x89, 0x73, 0xee, 0x3d, 0x81,
    0xdd, 0x09, 0x15, 0xbf, 0x12, 0xb7, 0x37, 0x2b, 0x41, 0xe0, 0x7c, 0x32, 0x8e, 0xb1, 0xb7, 0x11,
    0x82, 0x97, 0x6f, 0xd4, 0x0f, 0x90, 0xb0, 0x2d, 0x37, 0x0d, 0x1b, 0xb1, 0x1c, 0x3c, 0x3f, 0x30,
    0x0a, 0x29, 0x2d, 0x2d, 0x91, 0xc8, 0x73, 0x20, 0x73, 0x6a, 0x4c, 0x81, 0x40, 0x61, 0xf4, 0x18,
    0x09, 0x5a, 0xfd, 0x40, 0x60, 0xa7, 0x35, 0xe5, 0x62, 0xb3, 0x66, 0xc6, 0x80, 0x22, 0x5d, 0x7b,
    0x9e, 0x51, 0x9b, 0xd2, 0x2b, 0x99, 0x2a, 0x48, 0xea, 0x16, 0x3a, 0x02, 0x18, 0xe7, 0x77, 0x14,
    0x81, 0x36, 0x42, 0x75, 0x7a, 0x91, 0xe9, 0x2e, 0x98, 0xde, 0x26, 0x09, 0x7e, 0x75, 0x79, 0xa4,
    0x82, 0x04, 0x94, 0x82, 0x38, 0x38, 0x84, 0x9c, 0x16, 0x9b, 0x20, 0x2f, 0x0a, 0x2d, 0x2d, 0x27,
    0x9e, 0xe5, 0xe2, 0x72, 0x64, 0xf0, 0xc2, 0x64, 0xa0, 0x7a, 0x63, 0xfe, 0x75, 0xf9, 0x2b, 0x5d,
    0xfa, 0x26, 0xee, 0x56, 0x35, 0x1c, 0xd4, 0x59, 0x5e, 0xdc, 0x36, 0x08, 0x87, 0x30, 0xc7, 0xae,
    0x66, 0x01, 0x2b, 0x55, 0x5a, 0x98, 0xfe, 0xf8, 0x66, 0x43, 0x93, 0x41, 0x2d, 0x95, 0xa7, 0xe3,
    0x1a, 0x52, 0xcf, 0xea, 0x0a, 0xe7, 0x32, 0x21, 0x15, 0x47, 0x80, 0xa6, 0x64, 0x71, 0xf2, 0xca,
    0xdc, 0x5c, 0xbe, 0x22, 0xcb, 0x7e, 0xbb, 0x07, 0x52, 0xd4, 0x57, 0x50, 0x93, 0x8e, 0x85, 0xbf,
    0xef, 0xcf, 0x68, 0x5a, 0x30, 0xcd, 0xe9, 0xa5, 0x75, 0x02, 0xb3, 0x06, 0xd7, 0x5a, 0xe6, 0xc9,
    0x9c, 0xf5, 0x79, 0xcc, 0x22, 0xd3, 0x3b, 0x26, 0xa7, 0xfc, 0x41, 0x03, 0xb7, 0x12, 0x86, 0x91,
    0x90, 0x36, 0x0c, 0x6b, 0x5e, 0x63, 0x65, 0x41, 0xeb, 0x06, 0xc5, 0x6b, 0x08, 0x44, 0x50, 0x41,
    0x1c, 0x95, 0xe9, 0x7e, 0xde, 0x31, 0x59, 0xc2, 0x10, 0x3e, 0x7e, 0x29, 0x51, 0xc6, 0x74, 0x76,
    0x6c, 0x03, 0xc9, 0x2c, 0xbe, 0x01, 0x0f, 0xcd, 0x9e, 0x35
};
#endif

PyTypeObject *init_QMimeType(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX].type;

    Shiboken::AutoDecRef Sbk_QMimeType_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QMimeType_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMimeType",
        "QMimeType",
        &Sbk_QMimeType_spec,
        &Shiboken::callCppDestructor< ::QMimeType >,
        Sbk_QMimeType_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QMimeType_TypeF(); // references _Sbk_QMimeType_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMimeType_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMimeType_SignatureBytes, QMimeType_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMimeType_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMimeType_PythonToCpp_QMimeType_PTR,
        is_QMimeType_PythonToCpp_QMimeType_PTR_Convertible,
        QMimeType_PTR_CppToPython_QMimeType,
        QMimeType_COPY_CppToPython_QMimeType);

    Shiboken::Conversions::registerConverterName(converter, "QMimeType");
    Shiboken::Conversions::registerConverterName(converter, "QMimeType*");
    Shiboken::Conversions::registerConverterName(converter, "QMimeType&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMimeType).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QMimeType_PythonToCpp_QMimeType_COPY,
        is_QMimeType_PythonToCpp_QMimeType_COPY_Convertible);

    qRegisterMetaType< ::QMimeType >("QMimeType");

    return pyType;
}
