// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qmodelindex_wrapper.h"

// Argument includes
#include <qabstractitemmodel.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QModelIndex_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QModelIndex >()))
        return -1;

    ::QModelIndex *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QModelIndex", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QModelIndex::QModelIndex()
    // 1: QModelIndex::QModelIndex(QModelIndex)
    if (numArgs == 0) {
        overloadId = 0; // QModelIndex()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QModelIndex(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QModelIndex()
        {

            // QModelIndex()
            cptr = new ::QModelIndex();
            break;
        }
        case 1: // QModelIndex(const QModelIndex &QModelIndex)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QModelIndex cppArg0_local;
            ::QModelIndex *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QModelIndex(QModelIndex)
                cptr = new ::QModelIndex(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QModelIndex >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QModelIndexFunc_column(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // column()const
        int cppResult = const_cast<const ::QModelIndex *>(cppSelf)->column();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelIndexFunc_constInternalPointer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // constInternalPointer()const
        const void * cppResult = const_cast<const ::QModelIndex *>(cppSelf)->constInternalPointer();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelIndexFunc_data(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]);

    if (PyArg_ParseTuple(args, "|O:data", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QModelIndex::data(int=)const->QVariant
    if (numArgs == 0) {
        overloadId = 0; // data(int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // data(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_role = Shiboken::String::createStaticString("role");
            if (PyDict_Contains(kwds, key_role) != 0) {
                value = PyDict_GetItem(kwds, key_role);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_role);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_role);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]);
            }
        }
        int cppArg0 = Qt::DisplayRole;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // data(int)const
            QVariant cppResult = const_cast<const ::QModelIndex *>(cppSelf)->data(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelIndexFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<Qt::ItemFlag> cppResult = const_cast<const ::QModelIndex *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ItemFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelIndexFunc_internalId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // internalId()const
        quintptr cppResult = const_cast<const ::QModelIndex *>(cppSelf)->internalId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_quintptr_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelIndexFunc_internalPointer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // internalPointer()const
        // Begin code injection
        // TEMPLATE - return_internal_pointer - START
        pyResult = reinterpret_cast<PyObject*>(cppSelf->internalPointer());
        if (!pyResult)
            pyResult = Py_None;
        Py_INCREF(pyResult);
        // TEMPLATE - return_internal_pointer - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelIndexFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QModelIndex *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelIndexFunc_model(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // model()const
        const QAbstractItemModel * cppResult = const_cast<const ::QModelIndex *>(cppSelf)->model();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), cppResult);

        // Ownership transferences.
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelIndexFunc_multiData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModelIndex::multiData(QModelRoleDataSpan)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]), (pyArg)))) {
        overloadId = 0; // multiData(QModelRoleDataSpan)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "multiData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelRoleDataSpan cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // multiData(QModelRoleDataSpan)const
            const_cast<const ::QModelIndex *>(cppSelf)->multiData(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModelIndexFunc_parent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parent()const
        QModelIndex cppResult = const_cast<const ::QModelIndex *>(cppSelf)->parent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelIndexFunc_row(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // row()const
        int cppResult = const_cast<const ::QModelIndex *>(cppSelf)->row();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelIndexFunc_sibling(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sibling", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QModelIndex::sibling(int,int)const->QModelIndex
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // sibling(int,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sibling", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sibling(int,int)const
            QModelIndex cppResult = const_cast<const ::QModelIndex *>(cppSelf)->sibling(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelIndexFunc_siblingAtColumn(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModelIndex::siblingAtColumn(int)const->QModelIndex
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // siblingAtColumn(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "siblingAtColumn", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // siblingAtColumn(int)const
            QModelIndex cppResult = const_cast<const ::QModelIndex *>(cppSelf)->siblingAtColumn(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelIndexFunc_siblingAtRow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModelIndex::siblingAtRow(int)const->QModelIndex
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // siblingAtRow(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "siblingAtRow", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // siblingAtRow(int)const
            QModelIndex cppResult = const_cast<const ::QModelIndex *>(cppSelf)->siblingAtRow(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelIndex__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QModelIndex_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QModelIndex_methods[] = {
    {"column", reinterpret_cast<PyCFunction>(Sbk_QModelIndexFunc_column), METH_NOARGS, nullptr},
    {"constInternalPointer", reinterpret_cast<PyCFunction>(Sbk_QModelIndexFunc_constInternalPointer), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QModelIndexFunc_data), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QModelIndexFunc_flags), METH_NOARGS, nullptr},
    {"internalId", reinterpret_cast<PyCFunction>(Sbk_QModelIndexFunc_internalId), METH_NOARGS, nullptr},
    {"internalPointer", reinterpret_cast<PyCFunction>(Sbk_QModelIndexFunc_internalPointer), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QModelIndexFunc_isValid), METH_NOARGS, nullptr},
    {"model", reinterpret_cast<PyCFunction>(Sbk_QModelIndexFunc_model), METH_NOARGS, nullptr},
    {"multiData", reinterpret_cast<PyCFunction>(Sbk_QModelIndexFunc_multiData), METH_O, nullptr},
    {"parent", reinterpret_cast<PyCFunction>(Sbk_QModelIndexFunc_parent), METH_NOARGS, nullptr},
    {"row", reinterpret_cast<PyCFunction>(Sbk_QModelIndexFunc_row), METH_NOARGS, nullptr},
    {"sibling", reinterpret_cast<PyCFunction>(Sbk_QModelIndexFunc_sibling), METH_VARARGS, nullptr},
    {"siblingAtColumn", reinterpret_cast<PyCFunction>(Sbk_QModelIndexFunc_siblingAtColumn), METH_O, nullptr},
    {"siblingAtRow", reinterpret_cast<PyCFunction>(Sbk_QModelIndexFunc_siblingAtRow), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QModelIndex__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QModelIndex_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
                // operator!=(const QModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QModelIndex cppArg0_local;
                ::QModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), (pyArg)))) {
                // operator!=(const QPersistentModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPersistentModelIndex cppArg0_local;
                ::QPersistentModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
                // operator<(const QModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QModelIndex cppArg0_local;
                ::QModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), (pyArg)))) {
                // operator<(const QPersistentModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPersistentModelIndex cppArg0_local;
                ::QPersistentModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
                // operator<=(const QModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QModelIndex cppArg0_local;
                ::QModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), (pyArg)))) {
                // operator<=(const QPersistentModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPersistentModelIndex cppArg0_local;
                ::QPersistentModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
                // operator==(const QModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QModelIndex cppArg0_local;
                ::QModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), (pyArg)))) {
                // operator==(const QPersistentModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPersistentModelIndex cppArg0_local;
                ::QPersistentModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
                // operator>(const QModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QModelIndex cppArg0_local;
                ::QModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), (pyArg)))) {
                // operator>(const QPersistentModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPersistentModelIndex cppArg0_local;
                ::QPersistentModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
                // operator>=(const QModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QModelIndex cppArg0_local;
                ::QModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), (pyArg)))) {
                // operator>=(const QPersistentModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPersistentModelIndex cppArg0_local;
                ::QPersistentModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QModelIndex_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QModelIndex_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QModelIndex_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QModelIndex__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QModelIndex_Type = nullptr;
static PyTypeObject *Sbk_QModelIndex_TypeF(void)
{
    return _Sbk_QModelIndex_Type;
}

static PyType_Slot Sbk_QModelIndex_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QModelIndex__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QModelIndex_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QModelIndex_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QModelIndex_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QModelIndex_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QModelIndex_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QModelIndex_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QModelIndex_spec = {
    "2:PySide6.QtCore.QModelIndex",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QModelIndex_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QModelIndex_PythonToCpp_QModelIndex_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QModelIndex_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QModelIndex_PythonToCpp_QModelIndex_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QModelIndex_TypeF()))
        return QModelIndex_PythonToCpp_QModelIndex_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QModelIndex_PTR_CppToPython_QModelIndex(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QModelIndex_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QModelIndex_COPY_CppToPython_QModelIndex(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QModelIndex *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QModelIndex_TypeF(), new ::QModelIndex(*source), true, true);
}

// Python to C++ copy conversion.
static void QModelIndex_PythonToCpp_QModelIndex_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QModelIndex *>(cppOut) = *reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QModelIndex_PythonToCpp_QModelIndex_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QModelIndex_TypeF()))
        return QModelIndex_PythonToCpp_QModelIndex_COPY;
    return {};
}

// Implicit conversions.
static void QPersistentModelIndex_PythonToCpp_QModelIndex(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QModelIndex *>(cppOut) = ::QModelIndex(*reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_QPersistentModelIndex_PythonToCpp_QModelIndex_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX])))
        return QPersistentModelIndex_PythonToCpp_QModelIndex;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QModelIndex_SignatureStrings[] = {
    "1:PySide6.QtCore.QModelIndex(self)",
    "0:PySide6.QtCore.QModelIndex(self,QModelIndex:PySide6.QtCore.QModelIndex)",
    "PySide6.QtCore.QModelIndex.column(self)->int",
    "PySide6.QtCore.QModelIndex.constInternalPointer(self)->void",
    "PySide6.QtCore.QModelIndex.data(self,role:int=Qt.DisplayRole)->QVariant",
    "PySide6.QtCore.QModelIndex.flags(self)->PySide6.QtCore.Qt.ItemFlag",
    "PySide6.QtCore.QModelIndex.internalId(self)->quintptr",
    "PySide6.QtCore.QModelIndex.internalPointer(self)->Any",
    "PySide6.QtCore.QModelIndex.isValid(self)->bool",
    "PySide6.QtCore.QModelIndex.model(self)->PySide6.QtCore.QAbstractItemModel",
    "PySide6.QtCore.QModelIndex.multiData(self,roleDataSpan:typing.Union[PySide6.QtCore.QModelRoleDataSpan, PySide6.QtCore.QModelRoleData])",
    "PySide6.QtCore.QModelIndex.parent(self)->PySide6.QtCore.QModelIndex",
    "PySide6.QtCore.QModelIndex.row(self)->int",
    "PySide6.QtCore.QModelIndex.sibling(self,row:int,column:int)->PySide6.QtCore.QModelIndex",
    "PySide6.QtCore.QModelIndex.siblingAtColumn(self,column:int)->PySide6.QtCore.QModelIndex",
    "PySide6.QtCore.QModelIndex.siblingAtRow(self,row:int)->PySide6.QtCore.QModelIndex",
    "PySide6.QtCore.QModelIndex.__copy__(self)->typing.Self",
    "1:PySide6.QtCore.QModelIndex.__ne__(self,rhs:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "0:PySide6.QtCore.QModelIndex.__ne__(self,rhs:typing.Union[PySide6.QtCore.QPersistentModelIndex, PySide6.QtCore.QModelIndex])->bool",
    "1:PySide6.QtCore.QModelIndex.__lt__(self,rhs:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "0:PySide6.QtCore.QModelIndex.__lt__(self,rhs:typing.Union[PySide6.QtCore.QPersistentModelIndex, PySide6.QtCore.QModelIndex])->bool",
    "1:PySide6.QtCore.QModelIndex.__le__(self,rhs:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "0:PySide6.QtCore.QModelIndex.__le__(self,rhs:typing.Union[PySide6.QtCore.QPersistentModelIndex, PySide6.QtCore.QModelIndex])->bool",
    "1:PySide6.QtCore.QModelIndex.__eq__(self,rhs:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "0:PySide6.QtCore.QModelIndex.__eq__(self,rhs:typing.Union[PySide6.QtCore.QPersistentModelIndex, PySide6.QtCore.QModelIndex])->bool",
    "1:PySide6.QtCore.QModelIndex.__gt__(self,rhs:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "0:PySide6.QtCore.QModelIndex.__gt__(self,rhs:typing.Union[PySide6.QtCore.QPersistentModelIndex, PySide6.QtCore.QModelIndex])->bool",
    "1:PySide6.QtCore.QModelIndex.__ge__(self,rhs:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "0:PySide6.QtCore.QModelIndex.__ge__(self,rhs:typing.Union[PySide6.QtCore.QPersistentModelIndex, PySide6.QtCore.QModelIndex])->bool",
    "PySide6.QtCore.QModelIndex.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QModelIndex_SignatureByteSize = 396;
static constexpr uint8_t QModelIndex_SignatureBytes[396] = {
    0x78, 0xda, 0xc5, 0x55, 0x5d, 0x6b, 0xc2, 0x30, 0x14, 0x7d, 0xf7, 0x57, 0xec, 0x71, 0x42, 0x57,
    0xf4, 0x65, 0x0f, 0x85, 0x0d, 0x64, 0x32, 0xe8, 0xc3, 0xa0, 0xad, 0xcc, 0x97, 0x21, 0x25, 0xda,
    0x58, 0x03, 0x31, 0xa9, 0xc9, 0x75, 0xae, 0xff, 0x7e, 0x89, 0x36, 0x56, 0x9d, 0x8d, 0x1f, 0xe8,
    0xf2, 0x96, 0xa6, 0xe7, 0x9c, 0x9c, 0x7b, 0x73, 0x2e, 0xe9, 0x06, 0x51, 0x39, 0x20, 0x19, 0x7e,
    0xf6, 0x63, 0x78, 0xe3, 0x02, 0xfb, 0xf1, 0x07, 0xcf, 0x30, 0x0d, 0x59, 0x86, 0x7f, 0x1e, 0x25,
    0xa6, 0xd3, 0x76, 0xab, 0x73, 0x0a, 0xe2, 0xed, 0x6c, 0x58, 0xb0, 0xed, 0x56, 0xf3, 0x3f, 0x7f,
    0xc2, 0xe9, 0x72, 0xce, 0x36, 0x27, 0x3e, 0xbd, 0x12, 0x06, 0x76, 0x30, 0x93, 0x10, 0x32, 0xc0,
    0x82, 0x21, 0x1a, 0x71, 0xa2, 0x57, 0x86, 0xfa, 0xcd, 0x49, 0x66, 0xe3, 0x66, 0x08, 0xd0, 0xc6,
    0xb5, 0xe0, 0x14, 0x07, 0x8a, 0xfb, 0x12, 0x83, 0xdf, 0x27, 0xb2, 0xa0, 0xa8, 0x4c, 0xd4, 0x96,
    0xd2, 0x88, 0x87, 0x48, 0x10, 0x64, 0xf7, 0x30, 0xa5, 0x28, 0x97, 0xe6, 0xd0, 0x43, 0x1c, 0xf8,
    0x21, 0xe0, 0xf9, 0xbb, 0x82, 0xd8, 0x24, 0x48, 0x55, 0x41, 0x98, 0x19, 0x9d, 0xc5, 0x52, 0xed,
    0x15, 0x20, 0xce, 0x61, 0x1d, 0xd4, 0xdd, 0x63, 0xa5, 0x95, 0x25, 0x87, 0x88, 0x92, 0xed, 0x41,
    0x63, 0xce, 0xa9, 0x0d, 0x3e, 0xd7, 0xcb, 0xa6, 0xea, 0x7a, 0x63, 0x09, 0x02, 0x4d, 0x40, 0xd7,
    0xb8, 0xe6, 0x58, 0x95, 0x96, 0x14, 0x48, 0x7f, 0xaf, 0xe9, 0xfa, 0x6b, 0x50, 0x20, 0x16, 0x40,
    0x59, 0x10, 0x96, 0xfb, 0x9f, 0x8c, 0x70, 0xf6, 0x75, 0x54, 0x23, 0xd9, 0x81, 0x7b, 0x0f, 0x56,
    0xc8, 0xc8, 0x9a, 0xaf, 0x02, 0x09, 0xcc, 0xa0, 0xa9, 0xa2, 0x1a, 0x68, 0xd3, 0x10, 0x7c, 0x75,
    0x66, 0x40, 0x25, 0x19, 0x53, 0x55, 0x99, 0x29, 0x79, 0xa5, 0x63, 0xe6, 0x6d, 0x22, 0xae, 0x97,
    0x57, 0x3b, 0xa8, 0x74, 0x7b, 0xea, 0xcf, 0x76, 0x5c, 0x6e, 0xaa, 0x9b, 0x54, 0x25, 0x1a, 0xd3,
    0x57, 0x2b, 0xa6, 0xe9, 0x84, 0x17, 0x65, 0x9a, 0x9a, 0x86, 0x55, 0x57, 0x3d, 0x50, 0x5f, 0xad,
    0x6e, 0x60, 0x25, 0x32, 0x5c, 0xd1, 0x3c, 0x31, 0x93, 0x67, 0x64, 0x64, 0xcd, 0xfb, 0x1b, 0x8e,
    0x08, 0x0b, 0x49, 0x24, 0xa8, 0x5b, 0xaf, 0x51, 0x23, 0x13, 0xfd, 0xce, 0xcd, 0x2c, 0x1c, 0x3b,
    0xa6, 0x21, 0xa9, 0xfb, 0x16, 0x4e, 0x74, 0x81, 0x82, 0xf3, 0x2e, 0x5c, 0x60, 0xe1, 0x6e, 0x5d,
    0x70, 0x9f, 0x05, 0xea, 0x3e, 0x0b, 0x78, 0xe1, 0xbc, 0x0b, 0x17, 0x58, 0xb8, 0x57, 0x17, 0x72,
    0xf7, 0x13, 0x91, 0xbb, 0x9f, 0x88, 0xdc, 0xfd, 0x44, 0xe4, 0xff, 0x30, 0x11, 0x56, 0x03, 0x33,
    0x24, 0x67, 0xf5, 0xd3, 0xa2, 0xdf, 0xe2, 0x5f, 0x0d, 0x5b, 0xda, 0x32
};
#endif

PyTypeObject *init_QModelIndex(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX].type;

    Shiboken::AutoDecRef Sbk_QModelIndex_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QModelIndex_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QModelIndex",
        "QModelIndex",
        &Sbk_QModelIndex_spec,
        &Shiboken::callCppDestructor< ::QModelIndex >,
        Sbk_QModelIndex_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QModelIndex_TypeF(); // references _Sbk_QModelIndex_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QModelIndex_SignatureStrings);
#else
    InitSignatureBytes(pyType, QModelIndex_SignatureBytes, QModelIndex_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QModelIndex_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QModelIndex_PythonToCpp_QModelIndex_PTR,
        is_QModelIndex_PythonToCpp_QModelIndex_PTR_Convertible,
        QModelIndex_PTR_CppToPython_QModelIndex,
        QModelIndex_COPY_CppToPython_QModelIndex);

    Shiboken::Conversions::registerConverterName(converter, "QModelIndex");
    Shiboken::Conversions::registerConverterName(converter, "QModelIndex*");
    Shiboken::Conversions::registerConverterName(converter, "QModelIndex&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QModelIndex).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QModelIndex_PythonToCpp_QModelIndex_COPY,
        is_QModelIndex_PythonToCpp_QModelIndex_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QPersistentModelIndex_PythonToCpp_QModelIndex,
        is_QPersistentModelIndex_PythonToCpp_QModelIndex_Convertible);


    return pyType;
}
