// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qmodelroledata_wrapper.h"

// Argument includes
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QModelRoleData_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QModelRoleData >()))
        return -1;

    ::QModelRoleData *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QModelRoleData", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QModelRoleData::QModelRoleData(QModelRoleData)
    // 1: QModelRoleData::QModelRoleData(int)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 1; // QModelRoleData(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QModelRoleData(QModelRoleData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QModelRoleData(const QModelRoleData &QModelRoleData)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QModelRoleData cppArg0_local = ::QModelRoleData(int(0));
            ::QModelRoleData *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QModelRoleData(QModelRoleData)
                cptr = new ::QModelRoleData(*cppArg0);
            }
            break;
        }
        case 1: // QModelRoleData(int role)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QModelRoleData(int)
                cptr = new ::QModelRoleData(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QModelRoleData >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QModelRoleDataFunc_clearData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelRoleData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearData()
        cppSelf->clearData();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModelRoleDataFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelRoleData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()
        QVariant & cppResult = cppSelf->data();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelRoleDataFunc_role(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelRoleData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // role()const
        int cppResult = const_cast<const ::QModelRoleData *>(cppSelf)->role();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelRoleDataFunc_setData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelRoleData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModelRoleData::setData(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setData(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // setData(QVariant)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qmodelroledata-setdata)]
            // Call template <typename T> void QModelRoleData::setData(T &&value)
            cppSelf->setData(cppArg0);
            // END of custom code block [file: ../glue/qtcore.cpp (qmodelroledata-setdata)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModelRoleData__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QModelRoleData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QModelRoleData_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QModelRoleData_methods[] = {
    {"clearData", reinterpret_cast<PyCFunction>(Sbk_QModelRoleDataFunc_clearData), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QModelRoleDataFunc_data), METH_NOARGS, nullptr},
    {"role", reinterpret_cast<PyCFunction>(Sbk_QModelRoleDataFunc_role), METH_NOARGS, nullptr},
    {"setData", reinterpret_cast<PyCFunction>(Sbk_QModelRoleDataFunc_setData), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QModelRoleData__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QModelRoleData_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QModelRoleData_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QModelRoleData_Type = nullptr;
static PyTypeObject *Sbk_QModelRoleData_TypeF(void)
{
    return _Sbk_QModelRoleData_Type;
}

static PyType_Slot Sbk_QModelRoleData_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QModelRoleData_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QModelRoleData_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QModelRoleData_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QModelRoleData_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QModelRoleData_spec = {
    "2:PySide6.QtCore.QModelRoleData",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QModelRoleData_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QModelRoleData_PythonToCpp_QModelRoleData_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QModelRoleData_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QModelRoleData_PythonToCpp_QModelRoleData_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QModelRoleData_TypeF()))
        return QModelRoleData_PythonToCpp_QModelRoleData_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QModelRoleData_PTR_CppToPython_QModelRoleData(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QModelRoleData_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QModelRoleData_COPY_CppToPython_QModelRoleData(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QModelRoleData *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QModelRoleData_TypeF(), new ::QModelRoleData(*source), true, true);
}

// Python to C++ copy conversion.
static void QModelRoleData_PythonToCpp_QModelRoleData_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QModelRoleData *>(cppOut) = *reinterpret_cast< ::QModelRoleData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QModelRoleData_PythonToCpp_QModelRoleData_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QModelRoleData_TypeF()))
        return QModelRoleData_PythonToCpp_QModelRoleData_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QModelRoleData_SignatureStrings[] = {
    "1:PySide6.QtCore.QModelRoleData(self,QModelRoleData:PySide6.QtCore.QModelRoleData)",
    "0:PySide6.QtCore.QModelRoleData(self,role:int)",
    "PySide6.QtCore.QModelRoleData.clearData(self)",
    "PySide6.QtCore.QModelRoleData.data(self)->QVariant",
    "PySide6.QtCore.QModelRoleData.role(self)->int",
    "PySide6.QtCore.QModelRoleData.setData(self,data:QVariant)",
    "PySide6.QtCore.QModelRoleData.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QModelRoleData_SignatureByteSize = 132;
static constexpr uint8_t QModelRoleData_SignatureBytes[132] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0xf4, 0xcd, 0x4f, 0x49, 0xcd, 0x09, 0xca, 0xcf, 0x49, 0x75, 0x49, 0x2c,
    0x49, 0xd4, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0x41, 0x15, 0xc3, 0xaf, 0x43, 0x93, 0xcb, 0x80, 0x18,
    0x23, 0x8b, 0x80, 0x3c, 0xab, 0xcc, 0xbc, 0x12, 0x4d, 0x2e, 0xbc, 0x8a, 0xf5, 0x92, 0x73, 0x52,
    0x13, 0x8b, 0xe0, 0xda, 0x08, 0xa9, 0x4e, 0x81, 0x2b, 0xd4, 0xb5, 0x0b, 0x0c, 0x4b, 0x2c, 0xca,
    0x4c, 0xcc, 0x2b, 0x21, 0xa0, 0x05, 0xe4, 0x10, 0x98, 0x96, 0x4c, 0x82, 0xaa, 0x8b, 0x53, 0x4b,
    0x10, 0x7e, 0x00, 0xd9, 0x66, 0x05, 0xb3, 0x86, 0x90, 0xd3, 0xe2, 0xe3, 0x93, 0xf3, 0x0b, 0x2a,
    0xe3, 0xe3, 0x61, 0x76, 0x95, 0x54, 0x16, 0x64, 0xe6, 0xa5, 0xeb, 0x05, 0x03, 0x79, 0x5c, 0x00,
    0xfc, 0xab, 0x88, 0xcb
};
#endif

PyTypeObject *init_QModelRoleData(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX].type;

    Shiboken::AutoDecRef Sbk_QModelRoleData_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QModelRoleData_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QModelRoleData",
        "QModelRoleData",
        &Sbk_QModelRoleData_spec,
        &Shiboken::callCppDestructor< ::QModelRoleData >,
        Sbk_QModelRoleData_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QModelRoleData_TypeF(); // references _Sbk_QModelRoleData_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QModelRoleData_SignatureStrings);
#else
    InitSignatureBytes(pyType, QModelRoleData_SignatureBytes, QModelRoleData_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QModelRoleData_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QModelRoleData_PythonToCpp_QModelRoleData_PTR,
        is_QModelRoleData_PythonToCpp_QModelRoleData_PTR_Convertible,
        QModelRoleData_PTR_CppToPython_QModelRoleData,
        QModelRoleData_COPY_CppToPython_QModelRoleData);

    Shiboken::Conversions::registerConverterName(converter, "QModelRoleData");
    Shiboken::Conversions::registerConverterName(converter, "QModelRoleData*");
    Shiboken::Conversions::registerConverterName(converter, "QModelRoleData&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QModelRoleData).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QModelRoleData_PythonToCpp_QModelRoleData_COPY,
        is_QModelRoleData_PythonToCpp_QModelRoleData_COPY_Convertible);


    return pyType;
}
