// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qmodelroledataspan_wrapper.h"

// Argument includes
#include <qabstractitemmodel.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QModelRoleDataSpan_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QModelRoleDataSpan >()))
        return -1;

    ::QModelRoleDataSpan *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QModelRoleDataSpan", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QModelRoleDataSpan::QModelRoleDataSpan()
    // 1: QModelRoleDataSpan::QModelRoleDataSpan(QModelRoleData&)
    // 2: QModelRoleDataSpan::QModelRoleDataSpan(QModelRoleData*,qsizetype)
    // 3: QModelRoleDataSpan::QModelRoleDataSpan(QModelRoleDataSpan)
    if (numArgs == 0) {
        overloadId = 0; // QModelRoleDataSpan()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QModelRoleDataSpan(QModelRoleData&)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 2; // QModelRoleDataSpan(QModelRoleData*,qsizetype)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QModelRoleDataSpan(QModelRoleDataSpan)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QModelRoleDataSpan()
        {

            // QModelRoleDataSpan()
            cptr = new ::QModelRoleDataSpan();
            break;
        }
        case 1: // QModelRoleDataSpan(QModelRoleData &modelRoleData)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QModelRoleData cppArg0_local = ::QModelRoleData(int(0));
            ::QModelRoleData *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QModelRoleDataSpan(QModelRoleData&)
                cptr = new ::QModelRoleDataSpan(*cppArg0);
            }
            break;
        }
        case 2: // QModelRoleDataSpan(QModelRoleData *modelRoleData, qsizetype len)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QModelRoleData *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QModelRoleDataSpan(QModelRoleData*,qsizetype)
                cptr = new ::QModelRoleDataSpan(cppArg0, cppArg1);
            }
            break;
        }
        case 3: // QModelRoleDataSpan(const QModelRoleDataSpan &QModelRoleDataSpan)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QModelRoleDataSpan cppArg0_local;
            ::QModelRoleDataSpan *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QModelRoleDataSpan(QModelRoleDataSpan)
                cptr = new ::QModelRoleDataSpan(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QModelRoleDataSpan >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QModelRoleDataSpanFunc_begin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelRoleDataSpan *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // begin()const
        QModelRoleData * cppResult = const_cast<const ::QModelRoleDataSpan *>(cppSelf)->begin();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelRoleDataSpanFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelRoleDataSpan *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()const
        QModelRoleData * cppResult = const_cast<const ::QModelRoleDataSpan *>(cppSelf)->data();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelRoleDataSpanFunc_end(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelRoleDataSpan *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // end()const
        QModelRoleData * cppResult = const_cast<const ::QModelRoleDataSpan *>(cppSelf)->end();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelRoleDataSpanFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelRoleDataSpan *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // length()const
        qsizetype cppResult = const_cast<const ::QModelRoleDataSpan *>(cppSelf)->length();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelRoleDataSpanFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelRoleDataSpan *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        qsizetype cppResult = const_cast<const ::QModelRoleDataSpan *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModelRoleDataSpan__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QModelRoleDataSpan *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QModelRoleDataSpan_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QModelRoleDataSpan_methods[] = {
    {"begin", reinterpret_cast<PyCFunction>(Sbk_QModelRoleDataSpanFunc_begin), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QModelRoleDataSpanFunc_data), METH_NOARGS, nullptr},
    {"end", reinterpret_cast<PyCFunction>(Sbk_QModelRoleDataSpanFunc_end), METH_NOARGS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QModelRoleDataSpanFunc_length), METH_NOARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QModelRoleDataSpanFunc_size), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QModelRoleDataSpan__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

Py_ssize_t Sbk_QModelRoleDataSpanFunc___len__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelRoleDataSpan *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (qmodelroledataspan-len)]
    return cppSelf->size();
    // END of custom code block [file: ../glue/qtcore.cpp (qmodelroledataspan-len)]
    // ========================================================================
    // End of code injection

}

PyObject* Sbk_QModelRoleDataSpanFunc___getitem__(PyObject *self, Py_ssize_t _i)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModelRoleDataSpan *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (qmodelroledataspan-getitem)]
    const Py_ssize_t size = cppSelf->size();
    if (_i < 0 || _i >= size) {
        Shiboken::Errors::setIndexOutOfBounds(_i, 0, size);
        return nullptr;
    }
    // Return a pointer to allow for modification using  QModelRoleData::setData()
    QModelRoleData *item = &((*cppSelf)[_i]);
    return Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]), item);
    // END of custom code block [file: ../glue/qtcore.cpp (qmodelroledataspan-getitem)]
    // ========================================================================
    // End of code injection

}

} // extern "C"

static int Sbk_QModelRoleDataSpan_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QModelRoleDataSpan_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QModelRoleDataSpan_Type = nullptr;
static PyTypeObject *Sbk_QModelRoleDataSpan_TypeF(void)
{
    return _Sbk_QModelRoleDataSpan_Type;
}

static PyType_Slot Sbk_QModelRoleDataSpan_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QModelRoleDataSpan_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QModelRoleDataSpan_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QModelRoleDataSpan_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QModelRoleDataSpan_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports sequence protocol
    {Py_sq_length,      reinterpret_cast<void *>(&Sbk_QModelRoleDataSpanFunc___len__)},
    {Py_sq_item,        reinterpret_cast<void *>(&Sbk_QModelRoleDataSpanFunc___getitem__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QModelRoleDataSpan_spec = {
    "2:PySide6.QtCore.QModelRoleDataSpan",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QModelRoleDataSpan_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QModelRoleDataSpan_PythonToCpp_QModelRoleDataSpan_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QModelRoleDataSpan_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QModelRoleDataSpan_PythonToCpp_QModelRoleDataSpan_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QModelRoleDataSpan_TypeF()))
        return QModelRoleDataSpan_PythonToCpp_QModelRoleDataSpan_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QModelRoleDataSpan_PTR_CppToPython_QModelRoleDataSpan(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QModelRoleDataSpan_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QModelRoleDataSpan_COPY_CppToPython_QModelRoleDataSpan(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QModelRoleDataSpan *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QModelRoleDataSpan_TypeF(), new ::QModelRoleDataSpan(*source), true, true);
}

// Python to C++ copy conversion.
static void QModelRoleDataSpan_PythonToCpp_QModelRoleDataSpan_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QModelRoleDataSpan *>(cppOut) = *reinterpret_cast< ::QModelRoleDataSpan *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QModelRoleDataSpan_PythonToCpp_QModelRoleDataSpan_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QModelRoleDataSpan_TypeF()))
        return QModelRoleDataSpan_PythonToCpp_QModelRoleDataSpan_COPY;
    return {};
}

// Implicit conversions.
static void QModelRoleDataREF_PythonToCpp_QModelRoleDataSpan(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QModelRoleDataSpan *>(cppOut) = ::QModelRoleDataSpan( *reinterpret_cast< ::QModelRoleData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_QModelRoleDataREF_PythonToCpp_QModelRoleDataSpan_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleData_IDX]), pyIn))
        return QModelRoleDataREF_PythonToCpp_QModelRoleDataSpan;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QModelRoleDataSpan_SignatureStrings[] = {
    "3:PySide6.QtCore.QModelRoleDataSpan(self)",
    "2:PySide6.QtCore.QModelRoleDataSpan(self,modelRoleData:PySide6.QtCore.QModelRoleData)",
    "1:PySide6.QtCore.QModelRoleDataSpan(self,modelRoleData:PySide6.QtCore.QModelRoleData,len:qsizetype)",
    "0:PySide6.QtCore.QModelRoleDataSpan(self,QModelRoleDataSpan:PySide6.QtCore.QModelRoleDataSpan)",
    "PySide6.QtCore.QModelRoleDataSpan.begin(self)->PySide6.QtCore.QModelRoleData",
    "PySide6.QtCore.QModelRoleDataSpan.data(self)->PySide6.QtCore.QModelRoleData",
    "PySide6.QtCore.QModelRoleDataSpan.end(self)->PySide6.QtCore.QModelRoleData",
    "PySide6.QtCore.QModelRoleDataSpan.length(self)->qsizetype",
    "PySide6.QtCore.QModelRoleDataSpan.size(self)->qsizetype",
    "PySide6.QtCore.QModelRoleDataSpan.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QModelRoleDataSpan_SignatureByteSize = 154;
static constexpr uint8_t QModelRoleDataSpan_SignatureBytes[154] = {
    0x78, 0xda, 0x33, 0xb6, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0xf4, 0xcd, 0x4f, 0x49, 0xcd, 0x09, 0xca, 0xcf, 0x49, 0x75, 0x49, 0x2c,
    0x49, 0x0c, 0x2e, 0x48, 0xcc, 0xd3, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x22, 0x52, 0xa5,
    0x4e, 0x2e, 0xb2, 0x30, 0x7e, 0x4d, 0x9a, 0x5c, 0x86, 0x34, 0x30, 0x55, 0x27, 0x27, 0x35, 0xcf,
    0xaa, 0xb0, 0x38, 0xb3, 0x2a, 0xb5, 0xa4, 0xb2, 0x20, 0x55, 0x93, 0xcb, 0x80, 0x58, 0x3b, 0x30,
    0xc5, 0x09, 0xeb, 0xd4, 0xe4, 0x22, 0xa8, 0x44, 0x2f, 0x29, 0x35, 0x3d, 0x13, 0x1a, 0x8c, 0xba,
    0x76, 0x78, 0x95, 0x13, 0x61, 0x58, 0x0a, 0x90, 0x41, 0x2d, 0xb3, 0x52, 0xf3, 0x52, 0xa8, 0x65,
    0x14, 0x30, 0xcc, 0xd3, 0x4b, 0x32, 0x60, 0xa6, 0xc1, 0x43, 0x9f, 0x08, 0x9d, 0x20, 0xa5, 0xe4,
    0xe8, 0x8b, 0x8f, 0x4f, 0xce, 0x2f, 0xa8, 0x8c, 0x8f, 0x87, 0xe9, 0x05, 0x6a, 0xcb, 0xcc, 0x4b,
    0xd7, 0x0b, 0x06, 0xf2, 0xb8, 0x00, 0x04, 0x5b, 0x02, 0xe4
};
#endif

PyTypeObject *init_QModelRoleDataSpan(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX].type;

    Shiboken::AutoDecRef Sbk_QModelRoleDataSpan_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QModelRoleDataSpan_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QModelRoleDataSpan",
        "QModelRoleDataSpan",
        &Sbk_QModelRoleDataSpan_spec,
        &Shiboken::callCppDestructor< ::QModelRoleDataSpan >,
        Sbk_QModelRoleDataSpan_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QModelRoleDataSpan_TypeF(); // references _Sbk_QModelRoleDataSpan_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QModelRoleDataSpan_SignatureStrings);
#else
    InitSignatureBytes(pyType, QModelRoleDataSpan_SignatureBytes, QModelRoleDataSpan_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QModelRoleDataSpan_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QModelRoleDataSpan_PythonToCpp_QModelRoleDataSpan_PTR,
        is_QModelRoleDataSpan_PythonToCpp_QModelRoleDataSpan_PTR_Convertible,
        QModelRoleDataSpan_PTR_CppToPython_QModelRoleDataSpan,
        QModelRoleDataSpan_COPY_CppToPython_QModelRoleDataSpan);

    Shiboken::Conversions::registerConverterName(converter, "QModelRoleDataSpan");
    Shiboken::Conversions::registerConverterName(converter, "QModelRoleDataSpan*");
    Shiboken::Conversions::registerConverterName(converter, "QModelRoleDataSpan&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QModelRoleDataSpan).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QModelRoleDataSpan_PythonToCpp_QModelRoleDataSpan_COPY,
        is_QModelRoleDataSpan_PythonToCpp_QModelRoleDataSpan_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QModelRoleDataREF_PythonToCpp_QModelRoleDataSpan,
        is_QModelRoleDataREF_PythonToCpp_QModelRoleDataSpan_Convertible);

    qRegisterMetaType< ::QModelRoleDataSpan >("QModelRoleDataSpan");

    return pyType;
}
