// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qmutex_wrapper.h"

// Argument includes
#include <qdeadlinetimer.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMutex_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMutex >()))
        return -1;

    ::QMutex *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QMutex_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QMutex()
        cptr = new ::QMutex();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMutex >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMutexFunc_tryLock(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMutex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMutex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "tryLock", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMutex::tryLock(QDeadlineTimer)->bool
    // 1: QBasicMutex::tryLock()->bool
    // 2: QMutex::tryLock(int)->bool
    if (numArgs == 0) {
        overloadId = 1; // tryLock()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 2; // tryLock(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0])))) {
        overloadId = 0; // tryLock(QDeadlineTimer)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "tryLock", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMutex_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // tryLock(QDeadlineTimer timeout)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDeadlineTimer cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // tryLock(QDeadlineTimer)
                bool cppResult = cppSelf->tryLock(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // tryLock()
        {

            // tryLock()
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = reinterpret_cast<QBasicMutex *>(cppSelf)->tryLock();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            break;
        }
        case 2: // tryLock(int timeout)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // tryLock(int)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->tryLock(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMutexFunc_try_lock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMutex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMutex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // try_lock()
        bool cppResult = cppSelf->try_lock();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QMutex_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMutex_methods[] = {
    {"tryLock", reinterpret_cast<PyCFunction>(Sbk_QMutexFunc_tryLock), METH_VARARGS, nullptr},
    {"try_lock", reinterpret_cast<PyCFunction>(Sbk_QMutexFunc_try_lock), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QMutex_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMutex_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMutex_Type = nullptr;
static PyTypeObject *Sbk_QMutex_TypeF(void)
{
    return _Sbk_QMutex_Type;
}

static PyType_Slot Sbk_QMutex_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMutex_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMutex_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMutex_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMutex_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMutex_spec = {
    "2:PySide6.QtCore.QMutex",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMutex_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMutex_PythonToCpp_QMutex_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMutex_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMutex_PythonToCpp_QMutex_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMutex_TypeF()))
        return QMutex_PythonToCpp_QMutex_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMutex_PTR_CppToPython_QMutex(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QMutex_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMutex_SignatureStrings[] = {
    "PySide6.QtCore.QMutex(self)",
    "2:PySide6.QtCore.QMutex.tryLock(self,timeout:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64])->bool",
    "1:PySide6.QtCore.QMutex.tryLock(self)->bool",
    "0:PySide6.QtCore.QMutex.tryLock(self,timeout:int)->bool",
    "PySide6.QtCore.QMutex.try_lock(self)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QMutex_SignatureByteSize = 143;
static constexpr uint8_t QMutex_SignatureBytes[143] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce, 0x2f, 0x4a,
    0xd5, 0x0b, 0xf4, 0x2d, 0x2d, 0x49, 0xad, 0xd0, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0xb2,
    0x0a, 0xc0, 0x26, 0xab, 0x57, 0x52, 0x54, 0xe9, 0x93, 0x9f, 0x9c, 0x0d, 0x56, 0xa5, 0x53, 0x92,
    0x99, 0x9b, 0x9a, 0x5f, 0x5a, 0x62, 0x55, 0x52, 0x59, 0x90, 0x99, 0x97, 0xae, 0x17, 0x9a, 0x97,
    0x99, 0x9f, 0x17, 0x8d, 0xae, 0xcf, 0x25, 0x35, 0x31, 0x25, 0x27, 0x33, 0x2f, 0x35, 0x04, 0xa8,
    0xb8, 0x48, 0x47, 0x01, 0xaf, 0xb4, 0x9e, 0x1b, 0x50, 0xac, 0x2c, 0xb5, 0xc8, 0x39, 0x3f, 0xaf,
    0xb8, 0x24, 0x31, 0xaf, 0x44, 0x47, 0xa1, 0x30, 0x33, 0xaf, 0xc4, 0xcc, 0x24, 0x56, 0x53, 0xd7,
    0x2e, 0x29, 0x3f, 0x3f, 0x87, 0xcb, 0x90, 0x08, 0x67, 0xc1, 0xd4, 0x1a, 0x90, 0xe2, 0x05, 0xa0,
    0x35, 0x30, 0x7d, 0x38, 0x75, 0xc5, 0xe7, 0xa0, 0x5b, 0x01, 0x00, 0x54, 0x0e, 0x72, 0x52
};
#endif

PyTypeObject *init_QMutex(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QMutex_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QMutex_IDX].type;

    Shiboken::AutoDecRef Sbk_QMutex_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBasicMutex_IDX]))));

    _Sbk_QMutex_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMutex",
        "QMutex*",
        &Sbk_QMutex_spec,
        &Shiboken::callCppDestructor< ::QMutex >,
        Sbk_QMutex_Type_bases.object(),
        0);
    auto *pyType = Sbk_QMutex_TypeF(); // references _Sbk_QMutex_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMutex_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMutex_SignatureBytes, QMutex_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMutex_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QMutex_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMutex_PythonToCpp_QMutex_PTR,
        is_QMutex_PythonToCpp_QMutex_PTR_Convertible,
        QMutex_PTR_CppToPython_QMutex);

    Shiboken::Conversions::registerConverterName(converter, "QMutex");
    Shiboken::Conversions::registerConverterName(converter, "QMutex*");
    Shiboken::Conversions::registerConverterName(converter, "QMutex&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMutex).name());

    qRegisterMetaType< ::QMutex *>();

    return pyType;
}
