// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qnativeipckey_wrapper.h"

// Argument includes
#include <QString>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qtipccommon.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNativeIpcKey_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNativeIpcKey >()))
        return -1;

    ::QNativeIpcKey *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QNativeIpcKey", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNativeIpcKey::QNativeIpcKey()
    // 1: QNativeIpcKey::QNativeIpcKey(QNativeIpcKey::Type)
    // 2: QNativeIpcKey::QNativeIpcKey(QNativeIpcKey)
    // 3: QNativeIpcKey::QNativeIpcKey(QString,QNativeIpcKey::Type=)
    if (numArgs == 0) {
        overloadId = 0; // QNativeIpcKey()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // QNativeIpcKey(QString,QNativeIpcKey::Type)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_Type_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 3; // QNativeIpcKey(QString,QNativeIpcKey::Type)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QNativeIpcKey(QNativeIpcKey)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_Type_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // QNativeIpcKey(QNativeIpcKey::Type)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QNativeIpcKey()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]);
            }

            // QNativeIpcKey()
            cptr = new ::QNativeIpcKey();
            break;
        }
        case 1: // QNativeIpcKey(QNativeIpcKey::Type type)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]);
            }
            ::QNativeIpcKey::Type cppArg0 = static_cast< ::QNativeIpcKey::Type>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNativeIpcKey(QNativeIpcKey::Type)
                cptr = new ::QNativeIpcKey(cppArg0);
            }
            break;
        }
        case 2: // QNativeIpcKey(const QNativeIpcKey &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNativeIpcKey cppArg0_local;
            ::QNativeIpcKey *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNativeIpcKey(QNativeIpcKey)
                cptr = new ::QNativeIpcKey(*cppArg0);
            }
            break;
        }
        case 3: // QNativeIpcKey(const QString &k, QNativeIpcKey::Type type)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_type = Shiboken::String::createStaticString("type");
                if (PyDict_Contains(kwds, key_type) != 0) {
                    value = PyDict_GetItem(kwds, key_type);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_type);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_Type_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_type);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QNativeIpcKey::Type cppArg1(QNativeIpcKey::DefaultTypeForOs);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNativeIpcKey(QString,QNativeIpcKey::Type)
                cptr = new ::QNativeIpcKey(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QNativeIpcKey >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QNativeIpcKeyFunc_fromString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNativeIpcKey::fromString(QString)->QNativeIpcKey
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // fromString(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromString(QString)
            QNativeIpcKey cppResult = ::QNativeIpcKey::fromString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeIpcKeyFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeIpcKey *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QNativeIpcKey *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeIpcKeyFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeIpcKey *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QNativeIpcKey *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeIpcKeyFunc_legacyDefaultTypeForOs(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // legacyDefaultTypeForOs()
        QNativeIpcKey::Type cppResult = ::QNativeIpcKey::legacyDefaultTypeForOs();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeIpcKeyFunc_nativeKey(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeIpcKey *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nativeKey()const
        QString cppResult = const_cast<const ::QNativeIpcKey *>(cppSelf)->nativeKey();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeIpcKeyFunc_setNativeKey(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeIpcKey *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNativeIpcKey::setNativeKey(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setNativeKey(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNativeKey", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNativeKey(QString)
            cppSelf->setNativeKey(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNativeIpcKeyFunc_setType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeIpcKey *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNativeIpcKey::setType(QNativeIpcKey::Type)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_Type_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setType(QNativeIpcKey::Type)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setType", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]);

    // Call function/method
    {
        ::QNativeIpcKey::Type cppArg0 = static_cast< ::QNativeIpcKey::Type>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setType(QNativeIpcKey::Type)
            cppSelf->setType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNativeIpcKeyFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeIpcKey *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNativeIpcKey::swap(QNativeIpcKey&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QNativeIpcKey&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNativeIpcKey cppArg0_local;
        ::QNativeIpcKey *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QNativeIpcKey&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNativeIpcKeyFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeIpcKey *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toString()const
        QString cppResult = const_cast<const ::QNativeIpcKey *>(cppSelf)->toString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeIpcKeyFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeIpcKey *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QNativeIpcKey::Type cppResult = const_cast<const ::QNativeIpcKey *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeIpcKey__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNativeIpcKey *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNativeIpcKey_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QNativeIpcKey_EnumFlagInfo[] = {
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNativeIpcKey_methods[] = {
    {"fromString", reinterpret_cast<PyCFunction>(Sbk_QNativeIpcKeyFunc_fromString), METH_O|METH_STATIC, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QNativeIpcKeyFunc_isEmpty), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QNativeIpcKeyFunc_isValid), METH_NOARGS, nullptr},
    {"legacyDefaultTypeForOs", reinterpret_cast<PyCFunction>(Sbk_QNativeIpcKeyFunc_legacyDefaultTypeForOs), METH_NOARGS|METH_STATIC, nullptr},
    {"nativeKey", reinterpret_cast<PyCFunction>(Sbk_QNativeIpcKeyFunc_nativeKey), METH_NOARGS, nullptr},
    {"setNativeKey", reinterpret_cast<PyCFunction>(Sbk_QNativeIpcKeyFunc_setNativeKey), METH_O, nullptr},
    {"setType", reinterpret_cast<PyCFunction>(Sbk_QNativeIpcKeyFunc_setType), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QNativeIpcKeyFunc_swap), METH_O, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QNativeIpcKeyFunc_toString), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QNativeIpcKeyFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QNativeIpcKey__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QNativeIpcKey_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNativeIpcKey *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), (pyArg)))) {
                // operator!=(const QNativeIpcKey &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QNativeIpcKey cppArg0_local;
                ::QNativeIpcKey *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), (pyArg)))) {
                // operator==(const QNativeIpcKey &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QNativeIpcKey cppArg0_local;
                ::QNativeIpcKey *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QNativeIpcKey_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeIpcKey *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QNativeIpcKey_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNativeIpcKey_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNativeIpcKey_Type = nullptr;
static PyTypeObject *Sbk_QNativeIpcKey_TypeF(void)
{
    return _Sbk_QNativeIpcKey_Type;
}

static PyType_Slot Sbk_QNativeIpcKey_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QNativeIpcKey_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNativeIpcKey_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNativeIpcKey_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QNativeIpcKey_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNativeIpcKey_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNativeIpcKey_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNativeIpcKey_spec = {
    "2:PySide6.QtCore.QNativeIpcKey",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNativeIpcKey_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QNativeIpcKey_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNativeIpcKey::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNativeIpcKey::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNativeIpcKey_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_Type_IDX])))
        return Enum_PythonToCpp_QNativeIpcKey_Type;
    return {};
}

static PyObject *QNativeIpcKey_Type_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QNativeIpcKey::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QNativeIpcKey::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_Type_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNativeIpcKey_PythonToCpp_QNativeIpcKey_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNativeIpcKey_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNativeIpcKey_PythonToCpp_QNativeIpcKey_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNativeIpcKey_TypeF()))
        return QNativeIpcKey_PythonToCpp_QNativeIpcKey_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNativeIpcKey_PTR_CppToPython_QNativeIpcKey(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QNativeIpcKey_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QNativeIpcKey_COPY_CppToPython_QNativeIpcKey(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QNativeIpcKey *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QNativeIpcKey_TypeF(), new ::QNativeIpcKey(*source), true, true);
}

// Python to C++ copy conversion.
static void QNativeIpcKey_PythonToCpp_QNativeIpcKey_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNativeIpcKey *>(cppOut) = *reinterpret_cast< ::QNativeIpcKey *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QNativeIpcKey_PythonToCpp_QNativeIpcKey_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QNativeIpcKey_TypeF()))
        return QNativeIpcKey_PythonToCpp_QNativeIpcKey_COPY;
    return {};
}

// Implicit conversions.
static void constQStringREF_PythonToCpp_QNativeIpcKey(PyObject *pyIn, void *cppOut)
{
    ::QString cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QNativeIpcKey *>(cppOut) = ::QNativeIpcKey(cppIn);
}
static PythonToCppFunc is_constQStringREF_PythonToCpp_QNativeIpcKey_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return constQStringREF_PythonToCpp_QNativeIpcKey;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QNativeIpcKey_SignatureStrings[] = {
    "3:PySide6.QtCore.QNativeIpcKey(self)",
    "2:PySide6.QtCore.QNativeIpcKey(self,type:PySide6.QtCore.QNativeIpcKey.Type)",
    "1:PySide6.QtCore.QNativeIpcKey(self,other:PySide6.QtCore.QNativeIpcKey)",
    "0:PySide6.QtCore.QNativeIpcKey(self,k:QString,type:PySide6.QtCore.QNativeIpcKey.Type=QNativeIpcKey.DefaultTypeForOs)",
    "PySide6.QtCore.QNativeIpcKey.fromString(string:QString)->PySide6.QtCore.QNativeIpcKey",
    "PySide6.QtCore.QNativeIpcKey.isEmpty(self)->bool",
    "PySide6.QtCore.QNativeIpcKey.isValid(self)->bool",
    "PySide6.QtCore.QNativeIpcKey.legacyDefaultTypeForOs()->PySide6.QtCore.QNativeIpcKey.Type",
    "PySide6.QtCore.QNativeIpcKey.nativeKey(self)->QString",
    "PySide6.QtCore.QNativeIpcKey.setNativeKey(self,newKey:QString)",
    "PySide6.QtCore.QNativeIpcKey.setType(self,type:PySide6.QtCore.QNativeIpcKey.Type)",
    "PySide6.QtCore.QNativeIpcKey.swap(self,other:typing.Union[PySide6.QtCore.QNativeIpcKey, QString])",
    "PySide6.QtCore.QNativeIpcKey.toString(self)->QString",
    "PySide6.QtCore.QNativeIpcKey.type(self)->PySide6.QtCore.QNativeIpcKey.Type",
    "PySide6.QtCore.QNativeIpcKey.__copy__(self)->typing.Self",
    "PySide6.QtCore.QNativeIpcKey.__ne__(self,rhs:typing.Union[PySide6.QtCore.QNativeIpcKey, QString])->bool",
    "PySide6.QtCore.QNativeIpcKey.__eq__(self,rhs:typing.Union[PySide6.QtCore.QNativeIpcKey, QString])->bool",
    "PySide6.QtCore.QNativeIpcKey.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QNativeIpcKey_SignatureByteSize = 284;
static constexpr uint8_t QNativeIpcKey_SignatureBytes[284] = {
    0x78, 0xda, 0xbd, 0x52, 0xcb, 0x4e, 0xc3, 0x30, 0x10, 0xbc, 0xe7, 0x2b, 0x38, 0x26, 0x52, 0x12,
    0x15, 0x90, 0x38, 0x54, 0x22, 0x17, 0x1e, 0x12, 0x42, 0x2a, 0x44, 0x01, 0x2e, 0x08, 0x59, 0x26,
    0xdd, 0x34, 0x16, 0xae, 0x6d, 0xec, 0x85, 0x2a, 0x7f, 0x8f, 0x1b, 0x92, 0xd2, 0x72, 0xb0, 0x5d,
    0x2a, 0x71, 0xf2, 0x6b, 0x67, 0x76, 0x76, 0x3c, 0xa7, 0xd3, 0xfb, 0xae, 0x62, 0x73, 0x38, 0xcb,
    0x4b, 0xbc, 0x90, 0x1a, 0xf2, 0x72, 0x46, 0x91, 0x7d, 0xc2, 0x8d, 0xaa, 0x6f, 0xa1, 0x8b, 0x0d,
    0xf0, 0x26, 0x89, 0x4e, 0xfc, 0x45, 0x29, 0x76, 0x0a, 0x9c, 0x65, 0xf9, 0x83, 0xad, 0x48, 0xa2,
    0xe3, 0x00, 0x2e, 0x89, 0x2d, 0x68, 0x67, 0x5d, 0x12, 0x4d, 0x02, 0x78, 0xde, 0xa6, 0x65, 0x85,
    0x9a, 0x89, 0x45, 0xa0, 0xba, 0xf3, 0xdd, 0xab, 0x4b, 0x68, 0xe8, 0x07, 0xc7, 0xf5, 0xcb, 0xb5,
    0xd4, 0x77, 0x26, 0x89, 0x9c, 0x0c, 0x8d, 0x96, 0xcb, 0xef, 0x76, 0xb1, 0xe9, 0x97, 0xb1, 0x7b,
    0x92, 0x15, 0x2e, 0xa0, 0x9b, 0x95, 0x99, 0xab, 0xa5, 0xc2, 0xe1, 0x27, 0xb2, 0xe2, 0x55, 0x4a,
    0xee, 0x03, 0x3c, 0x51, 0xce, 0xe6, 0xe1, 0x00, 0x0e, 0x0b, 0x5a, 0x77, 0xbf, 0x87, 0x8d, 0x3d,
    0xaa, 0x7b, 0xc3, 0xdc, 0xc4, 0xa2, 0x3f, 0x6c, 0x62, 0x94, 0x15, 0x83, 0x1f, 0x6e, 0x94, 0x01,
    0x9c, 0xed, 0x00, 0x53, 0x01, 0x2b, 0xbb, 0xdf, 0xb8, 0xe9, 0x85, 0xaf, 0x95, 0xed, 0x17, 0x4a,
    0x37, 0xe3, 0x8a, 0xaa, 0xed, 0x5c, 0x5a, 0x52, 0x2b, 0x23, 0x7f, 0x14, 0x4c, 0x8a, 0x67, 0x17,
    0x32, 0x3d, 0x1a, 0x24, 0xbf, 0x78, 0x3a, 0xa0, 0x1c, 0x73, 0xb3, 0x87, 0x4f, 0x38, 0x4e, 0x79,
    0xf8, 0x47, 0x11, 0x52, 0x4b, 0xd5, 0x11, 0x32, 0xd2, 0x0d, 0x13, 0x56, 0xf6, 0xe4, 0x03, 0x0a,
    0x18, 0x60, 0xa9, 0x6e, 0xcd, 0x9f, 0xac, 0x09, 0x89, 0x28, 0x21, 0xf0, 0xfe, 0x3f, 0x7d, 0x5a,
    0x6a, 0xda, 0x1f, 0x23, 0x98, 0xc0, 0xe8, 0x0b, 0x58, 0xc8, 0xd4, 0xc6
};
#endif

PyTypeObject *init_QNativeIpcKey(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX].type;

    Shiboken::AutoDecRef Sbk_QNativeIpcKey_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QNativeIpcKey_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNativeIpcKey",
        "QNativeIpcKey",
        &Sbk_QNativeIpcKey_spec,
        &Shiboken::callCppDestructor< ::QNativeIpcKey >,
        Sbk_QNativeIpcKey_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QNativeIpcKey_TypeF(); // references _Sbk_QNativeIpcKey_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QNativeIpcKey_SignatureStrings);
#else
    InitSignatureBytes(pyType, QNativeIpcKey_SignatureBytes, QNativeIpcKey_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNativeIpcKey_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNativeIpcKey_PythonToCpp_QNativeIpcKey_PTR,
        is_QNativeIpcKey_PythonToCpp_QNativeIpcKey_PTR_Convertible,
        QNativeIpcKey_PTR_CppToPython_QNativeIpcKey,
        QNativeIpcKey_COPY_CppToPython_QNativeIpcKey);

    Shiboken::Conversions::registerConverterName(converter, "QNativeIpcKey");
    Shiboken::Conversions::registerConverterName(converter, "QNativeIpcKey*");
    Shiboken::Conversions::registerConverterName(converter, "QNativeIpcKey&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNativeIpcKey).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QNativeIpcKey_PythonToCpp_QNativeIpcKey_COPY,
        is_QNativeIpcKey_PythonToCpp_QNativeIpcKey_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQStringREF_PythonToCpp_QNativeIpcKey,
        is_constQStringREF_PythonToCpp_QNativeIpcKey_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QNativeIpcKey_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "SystemV",
        "PosixRealtime",
        "Windows",
        nullptr};
    // "uint16_t" used instead of "unsigned short"
    constexpr uint16_t Type_InitializerValues[] = {
        uint16_t(QNativeIpcKey::Type::SystemV),       //  0x0051  81
        uint16_t(QNativeIpcKey::Type::PosixRealtime), //  0x0100  256
        uint16_t(QNativeIpcKey::Type::Windows)        //  0x0101  257
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNativeIpcKey_TypeF(),
        "2:PySide6.QtCore.QNativeIpcKey.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_Type_IDX].type = EType;
    // Register converter for enum 'QNativeIpcKey::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNativeIpcKey_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNativeIpcKey_Type,
            is_Enum_PythonToCpp_QNativeIpcKey_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QNativeIpcKey::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    qRegisterMetaType< ::QNativeIpcKey >("QNativeIpcKey");
    qRegisterMetaType< ::QNativeIpcKey::Type >("QNativeIpcKey::Type");

    return pyType;
}

PyTypeObject *init_QNativeIpcKeyStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QNativeIpcKey");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "DefaultTypeForOs",
                         Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QNativeIpcKey_Type_IDX])))->converter, &QNativeIpcKey::DefaultTypeForOs));
    return type;
}
