// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qoperatingsystemversionbase_wrapper.h"

// Argument includes
#include <QString>
#include <qoperatingsystemversion.h>
#include <qversionnumber.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOperatingSystemVersionBase_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOperatingSystemVersionBase >()))
        return -1;

    ::QOperatingSystemVersionBase *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:QOperatingSystemVersionBase", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOperatingSystemVersionBase::QOperatingSystemVersionBase()
    // 1: QOperatingSystemVersionBase::QOperatingSystemVersionBase(QOperatingSystemVersionBase::OSType,int,int=,int=)
    // 2: QOperatingSystemVersionBase::QOperatingSystemVersionBase(QOperatingSystemVersionBase)
    if (numArgs == 0) {
        overloadId = 0; // QOperatingSystemVersionBase()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QOperatingSystemVersionBase(QOperatingSystemVersionBase)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_OSType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // QOperatingSystemVersionBase(QOperatingSystemVersionBase::OSType,int,int,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // QOperatingSystemVersionBase(QOperatingSystemVersionBase::OSType,int,int,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                overloadId = 1; // QOperatingSystemVersionBase(QOperatingSystemVersionBase::OSType,int,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOperatingSystemVersionBase()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);
            }

            // QOperatingSystemVersionBase()
            cptr = new ::QOperatingSystemVersionBase();
            break;
        }
        case 1: // QOperatingSystemVersionBase(QOperatingSystemVersionBase::OSType osType, int vmajor, int vminor, int vmicro)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_vminor = Shiboken::String::createStaticString("vminor");
                if (PyDict_Contains(kwds, key_vminor) != 0) {
                    value = PyDict_GetItem(kwds, key_vminor);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_vminor);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_vminor);
                }
                static PyObject *const key_vmicro = Shiboken::String::createStaticString("vmicro");
                if (PyDict_Contains(kwds, key_vmicro) != 0) {
                    value = PyDict_GetItem(kwds, key_vmicro);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_vmicro);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_vmicro);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);
                }
            }
            ::QOperatingSystemVersionBase::OSType cppArg0{QOperatingSystemVersionBase::Unknown};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = -1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOperatingSystemVersionBase(QOperatingSystemVersionBase::OSType,int,int,int)
                cptr = new ::QOperatingSystemVersionBase(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 2: // QOperatingSystemVersionBase(const QOperatingSystemVersionBase &QOperatingSystemVersionBase)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QOperatingSystemVersionBase cppArg0_local;
            ::QOperatingSystemVersionBase *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QOperatingSystemVersionBase(QOperatingSystemVersionBase)
                cptr = new ::QOperatingSystemVersionBase(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QOperatingSystemVersionBase >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_compare(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "compare", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QOperatingSystemVersionBase::compare(QOperatingSystemVersionBase,QOperatingSystemVersionBase)->int
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArgs[1])))) {
        overloadId = 0; // compare(QOperatingSystemVersionBase,QOperatingSystemVersionBase)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "compare", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QOperatingSystemVersionBase cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QOperatingSystemVersionBase cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // compare(QOperatingSystemVersionBase,QOperatingSystemVersionBase)
            int cppResult = ::QOperatingSystemVersionBase::compare(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_current(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // current()
        QOperatingSystemVersionBase cppResult = ::QOperatingSystemVersionBase::current();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_currentType(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentType()
        QOperatingSystemVersionBase::OSType cppResult = ::QOperatingSystemVersionBase::currentType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_OSType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_majorVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // majorVersion()const
        int cppResult = const_cast<const ::QOperatingSystemVersionBase *>(cppSelf)->majorVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_microVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // microVersion()const
        int cppResult = const_cast<const ::QOperatingSystemVersionBase *>(cppSelf)->microVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_minorVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minorVersion()const
        int cppResult = const_cast<const ::QOperatingSystemVersionBase *>(cppSelf)->minorVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_name(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QOperatingSystemVersionBase *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "name", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOperatingSystemVersionBase::name()const->QString
    // 1: static QOperatingSystemVersionBase::name(QOperatingSystemVersionBase)->QString
    if (numArgs == 0) {
        overloadId = 0; // name()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArgs[0])))) {
        overloadId = 1; // name(QOperatingSystemVersionBase)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "name", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // name() const
        {

            // name()const
            QString cppResult = const_cast<const ::QOperatingSystemVersionBase *>(cppSelf)->name();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            break;
        }
        case 1: // name(QOperatingSystemVersionBase osversion)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QOperatingSystemVersionBase cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // name(QOperatingSystemVersionBase)
                QString cppResult = ::QOperatingSystemVersionBase::name(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_segmentCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // segmentCount()const
        int cppResult = const_cast<const ::QOperatingSystemVersionBase *>(cppSelf)->segmentCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QOperatingSystemVersionBase::OSType cppResult = const_cast<const ::QOperatingSystemVersionBase *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_OSType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_version(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // version()const
        QVersionNumber cppResult = const_cast<const ::QOperatingSystemVersionBase *>(cppSelf)->version();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOperatingSystemVersionBase__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QOperatingSystemVersionBaseMethod_name = {"name", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_name), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_QOperatingSystemVersionBase_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QOperatingSystemVersionBase_EnumFlagInfo[] = {
    "OSType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOperatingSystemVersionBase_methods[] = {
    {"compare", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_compare), METH_VARARGS|METH_STATIC, nullptr},
    {"current", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_current), METH_NOARGS|METH_STATIC, nullptr},
    {"currentType", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_currentType), METH_NOARGS|METH_STATIC, nullptr},
    {"majorVersion", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_majorVersion), METH_NOARGS, nullptr},
    {"microVersion", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_microVersion), METH_NOARGS, nullptr},
    {"minorVersion", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_minorVersion), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_name), METH_VARARGS|METH_STATIC, nullptr},
    {"segmentCount", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_segmentCount), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_type), METH_NOARGS, nullptr},
    {"version", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_version), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBase__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QOperatingSystemVersionBase_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QOperatingSystemVersionBaseMethod_name = {
        Sbk_QOperatingSystemVersionBaseMethod_name.ml_name,
        Sbk_QOperatingSystemVersionBaseMethod_name.ml_meth,
        Sbk_QOperatingSystemVersionBaseMethod_name.ml_flags & (~METH_STATIC),
        Sbk_QOperatingSystemVersionBaseMethod_name.ml_doc,
    };
    if (Shiboken::String::compare(name, "name") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QOperatingSystemVersionBaseMethod_name, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

// Rich comparison
static PyObject * Sbk_QOperatingSystemVersionBase_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArg)))) {
                // operator<(QOperatingSystemVersionBase rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QOperatingSystemVersionBase cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf < (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArg)))) {
                // operator<=(QOperatingSystemVersionBase rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QOperatingSystemVersionBase cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf <= (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArg)))) {
                // operator>(QOperatingSystemVersionBase rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QOperatingSystemVersionBase cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf > (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArg)))) {
                // operator>=(QOperatingSystemVersionBase rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QOperatingSystemVersionBase cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf >= (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QOperatingSystemVersionBase_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOperatingSystemVersionBase_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOperatingSystemVersionBase_Type = nullptr;
static PyTypeObject *Sbk_QOperatingSystemVersionBase_TypeF(void)
{
    return _Sbk_QOperatingSystemVersionBase_Type;
}

static PyType_Slot Sbk_QOperatingSystemVersionBase_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QOperatingSystemVersionBase_getattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOperatingSystemVersionBase_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOperatingSystemVersionBase_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QOperatingSystemVersionBase_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOperatingSystemVersionBase_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOperatingSystemVersionBase_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOperatingSystemVersionBase_spec = {
    "2:PySide6.QtCore.QOperatingSystemVersionBase",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOperatingSystemVersionBase_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QOperatingSystemVersionBase_OSType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOperatingSystemVersionBase::OSType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOperatingSystemVersionBase::OSType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QOperatingSystemVersionBase_OSType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_OSType_IDX])))
        return Enum_PythonToCpp_QOperatingSystemVersionBase_OSType;
    return {};
}

static PyObject *QOperatingSystemVersionBase_OSType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QOperatingSystemVersionBase::OSType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QOperatingSystemVersionBase::OSType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_OSType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOperatingSystemVersionBase_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOperatingSystemVersionBase_TypeF()))
        return QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOperatingSystemVersionBase_PTR_CppToPython_QOperatingSystemVersionBase(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QOperatingSystemVersionBase_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QOperatingSystemVersionBase_COPY_CppToPython_QOperatingSystemVersionBase(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QOperatingSystemVersionBase *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QOperatingSystemVersionBase_TypeF(), new ::QOperatingSystemVersionBase(*source), true, true);
}

// Python to C++ copy conversion.
static void QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QOperatingSystemVersionBase *>(cppOut) = *reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QOperatingSystemVersionBase_TypeF()))
        return QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOperatingSystemVersionBase_SignatureStrings[] = {
    "2:PySide6.QtCore.QOperatingSystemVersionBase(self)",
    "1:PySide6.QtCore.QOperatingSystemVersionBase(self,osType:PySide6.QtCore.QOperatingSystemVersionBase.OSType,vmajor:int,vminor:int=-1,vmicro:int=-1)",
    "0:PySide6.QtCore.QOperatingSystemVersionBase(self,QOperatingSystemVersionBase:PySide6.QtCore.QOperatingSystemVersionBase)",
    "PySide6.QtCore.QOperatingSystemVersionBase.compare(v1:PySide6.QtCore.QOperatingSystemVersionBase,v2:PySide6.QtCore.QOperatingSystemVersionBase)->int",
    "PySide6.QtCore.QOperatingSystemVersionBase.current()->PySide6.QtCore.QOperatingSystemVersionBase",
    "PySide6.QtCore.QOperatingSystemVersionBase.currentType()->PySide6.QtCore.QOperatingSystemVersionBase.OSType",
    "PySide6.QtCore.QOperatingSystemVersionBase.majorVersion(self)->int",
    "PySide6.QtCore.QOperatingSystemVersionBase.microVersion(self)->int",
    "PySide6.QtCore.QOperatingSystemVersionBase.minorVersion(self)->int",
    "1:PySide6.QtCore.QOperatingSystemVersionBase.name(self)->QString",
    "0:PySide6.QtCore.QOperatingSystemVersionBase.name(osversion:PySide6.QtCore.QOperatingSystemVersionBase)->QString",
    "PySide6.QtCore.QOperatingSystemVersionBase.segmentCount(self)->int",
    "PySide6.QtCore.QOperatingSystemVersionBase.type(self)->PySide6.QtCore.QOperatingSystemVersionBase.OSType",
    "PySide6.QtCore.QOperatingSystemVersionBase.version(self)->PySide6.QtCore.QVersionNumber",
    "PySide6.QtCore.QOperatingSystemVersionBase.__copy__(self)->typing.Self",
    "PySide6.QtCore.QOperatingSystemVersionBase.__lt__(self,rhs:PySide6.QtCore.QOperatingSystemVersionBase)->bool",
    "PySide6.QtCore.QOperatingSystemVersionBase.__le__(self,rhs:PySide6.QtCore.QOperatingSystemVersionBase)->bool",
    "PySide6.QtCore.QOperatingSystemVersionBase.__gt__(self,rhs:PySide6.QtCore.QOperatingSystemVersionBase)->bool",
    "PySide6.QtCore.QOperatingSystemVersionBase.__ge__(self,rhs:PySide6.QtCore.QOperatingSystemVersionBase)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QOperatingSystemVersionBase_SignatureByteSize = 282;
static constexpr uint8_t QOperatingSystemVersionBase_SignatureBytes[282] = {
    0x78, 0xda, 0xbd, 0x52, 0xc1, 0x4e, 0xc3, 0x30, 0x0c, 0xbd, 0xf7, 0x4b, 0x5a, 0xa9, 0x8b, 0xd8,
    0x0e, 0x3b, 0x4c, 0x82, 0x03, 0xbb, 0x33, 0xaa, 0x20, 0xae, 0x55, 0x56, 0x4c, 0x09, 0x6a, 0xe2,
    0xca, 0x49, 0x23, 0xf5, 0xef, 0x97, 0xae, 0xe9, 0x01, 0x84, 0x10, 0xde, 0xc4, 0x6e, 0x71, 0xe4,
    0xf7, 0x9e, 0xed, 0xf7, 0x36, 0xbb, 0xe7, 0x51, 0xea, 0x37, 0xd8, 0x8a, 0xca, 0xef, 0x91, 0x40,
    0x54, 0x87, 0x1e, 0x48, 0x79, 0x6d, 0x5b, 0x39, 0x3a, 0x0f, 0xe6, 0x15, 0xc8, 0x69, 0xb4, 0x8f,
    0xca, 0x41, 0xee, 0xa0, 0x7b, 0x2f, 0xb2, 0x35, 0x17, 0x52, 0xa2, 0x7b, 0x19, 0x7b, 0x60, 0xc0,
    0xc4, 0x41, 0x4e, 0x88, 0x32, 0x18, 0xf5, 0x89, 0xb4, 0xd3, 0xd6, 0xc7, 0xa7, 0xb6, 0xf3, 0xf3,
    0x7e, 0xb5, 0x9e, 0xaa, 0x86, 0x30, 0x55, 0x45, 0x76, 0xc7, 0x1e, 0xe9, 0x97, 0x06, 0x06, 0x57,
    0x91, 0x31, 0x76, 0x6a, 0xd0, 0xf4, 0x8a, 0x20, 0x0f, 0x9c, 0x03, 0x96, 0x61, 0xc3, 0x99, 0x67,
    0xf5, 0x10, 0x4f, 0xc2, 0x1a, 0x6a, 0x20, 0x02, 0xeb, 0xf3, 0x88, 0xfc, 0x3b, 0xea, 0x02, 0x81,
    0xc9, 0x4e, 0x9e, 0x48, 0xca, 0x00, 0x47, 0xeb, 0x9c, 0x96, 0xf4, 0x31, 0x87, 0x95, 0x7d, 0x8f,
    0x73, 0xae, 0xae, 0xa5, 0xb0, 0x3f, 0x4e, 0xc1, 0xb1, 0x5d, 0x58, 0x65, 0x60, 0x01, 0x57, 0xd2,
    0x53, 0x6c, 0x62, 0xa5, 0x7c, 0x26, 0x40, 0x17, 0xe6, 0x2f, 0x5e, 0x86, 0x16, 0x41, 0x86, 0x9c,
    0x83, 0xd6, 0x44, 0x9b, 0xf7, 0x38, 0xc4, 0x30, 0x5d, 0x76, 0x37, 0x3f, 0x45, 0x24, 0x41, 0xff,
    0x35, 0x26, 0xe1, 0xab, 0x37, 0xdf, 0x91, 0xa9, 0xf5, 0x69, 0x30, 0x47, 0x20, 0x0e, 0x6f, 0x5d,
    0x37, 0xd8, 0x8f, 0x75, 0xbd, 0x10, 0xc7, 0x85, 0x62, 0x9f, 0x90, 0xb1, 0xe2, 0xd1, 0x74, 0x3e,
    0x91, 0x94, 0xf4, 0xe1, 0x78, 0xd6, 0x1d, 0x11, 0x3b, 0xa6, 0x18, 0xdc, 0x50, 0xac, 0xbd, 0xe5,
    0x66, 0xed, 0x95, 0x9b, 0x9d, 0x00, 0xd9, 0xfa, 0xa2, 0x8a
};
#endif

PyTypeObject *init_QOperatingSystemVersionBase(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX].type;

    Shiboken::AutoDecRef Sbk_QOperatingSystemVersionBase_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QOperatingSystemVersionBase_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOperatingSystemVersionBase",
        "QOperatingSystemVersionBase",
        &Sbk_QOperatingSystemVersionBase_spec,
        &Shiboken::callCppDestructor< ::QOperatingSystemVersionBase >,
        Sbk_QOperatingSystemVersionBase_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QOperatingSystemVersionBase_TypeF(); // references _Sbk_QOperatingSystemVersionBase_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOperatingSystemVersionBase_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOperatingSystemVersionBase_SignatureBytes, QOperatingSystemVersionBase_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOperatingSystemVersionBase_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_PTR,
        is_QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_PTR_Convertible,
        QOperatingSystemVersionBase_PTR_CppToPython_QOperatingSystemVersionBase,
        QOperatingSystemVersionBase_COPY_CppToPython_QOperatingSystemVersionBase);

    Shiboken::Conversions::registerConverterName(converter, "QOperatingSystemVersionBase");
    Shiboken::Conversions::registerConverterName(converter, "QOperatingSystemVersionBase*");
    Shiboken::Conversions::registerConverterName(converter, "QOperatingSystemVersionBase&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOperatingSystemVersionBase).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_COPY,
        is_QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QOperatingSystemVersionBase_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'OSType'.
    const char *OSType_Initializer[] = {
        "Unknown",
        "Windows",
        "MacOS",
        "IOS",
        "TvOS",
        "WatchOS",
        "Android",
        "VisionOS",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t OSType_InitializerValues[] = {
        uint8_t(QOperatingSystemVersionBase::OSType::Unknown), //  0x00  0
        uint8_t(QOperatingSystemVersionBase::OSType::Windows), //  0x01  1
        uint8_t(QOperatingSystemVersionBase::OSType::MacOS),   //  0x02  2
        uint8_t(QOperatingSystemVersionBase::OSType::IOS),     //  0x03  3
        uint8_t(QOperatingSystemVersionBase::OSType::TvOS),    //  0x04  4
        uint8_t(QOperatingSystemVersionBase::OSType::WatchOS), //  0x05  5
        uint8_t(QOperatingSystemVersionBase::OSType::Android), //  0x06  6
        uint8_t(QOperatingSystemVersionBase::OSType::VisionOS) //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOperatingSystemVersionBase_TypeF(),
        "2:PySide6.QtCore.QOperatingSystemVersionBase.OSType",
        OSType_Initializer, OSType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_OSType_IDX].type = EType;
    // Register converter for enum 'QOperatingSystemVersionBase::OSType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOperatingSystemVersionBase_OSType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QOperatingSystemVersionBase_OSType,
            is_Enum_PythonToCpp_QOperatingSystemVersionBase_OSType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QOperatingSystemVersionBase::OSType");
        Shiboken::Conversions::registerConverterAlias(converter, "OSType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'OSType' enum.

    qRegisterMetaType< ::QOperatingSystemVersionBase::OSType >("QOperatingSystemVersionBase::OSType");

    return pyType;
}
