// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qpermission_wrapper.h"

// Argument includes
#include <qmetatype.h>
#include <qnamespace.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPermission_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPermission >()))
        return -1;

    ::QPermission *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPermission", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPermission::QPermission()
    // 1: QPermission::QPermission(QPermission)
    if (numArgs == 0) {
        overloadId = 0; // QPermission()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPermission(QPermission)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPermission()
        {

            // QPermission()
            cptr = new ::QPermission();
            break;
        }
        case 1: // QPermission(const QPermission &QPermission)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPermission cppArg0_local;
            ::QPermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QPermission(QPermission)
                cptr = new ::QPermission(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPermission >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPermissionFunc_status(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // status()const
        Qt::PermissionStatus cppResult = const_cast<const ::QPermission *>(cppSelf)->status();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_PermissionStatus_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPermissionFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QMetaType cppResult = const_cast<const ::QPermission *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPermission__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPermission_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPermission_methods[] = {
    {"status", reinterpret_cast<PyCFunction>(Sbk_QPermissionFunc_status), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QPermissionFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QPermission__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QPermission_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPermission_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPermission_Type = nullptr;
static PyTypeObject *Sbk_QPermission_TypeF(void)
{
    return _Sbk_QPermission_Type;
}

static PyType_Slot Sbk_QPermission_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPermission_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPermission_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPermission_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPermission_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPermission_spec = {
    "2:PySide6.QtCore.QPermission",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPermission_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPermission_PythonToCpp_QPermission_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPermission_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPermission_PythonToCpp_QPermission_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPermission_TypeF()))
        return QPermission_PythonToCpp_QPermission_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPermission_PTR_CppToPython_QPermission(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QPermission_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QPermission_COPY_CppToPython_QPermission(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QPermission *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QPermission_TypeF(), new ::QPermission(*source), true, true);
}

// Python to C++ copy conversion.
static void QPermission_PythonToCpp_QPermission_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPermission *>(cppOut) = *reinterpret_cast< ::QPermission *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QPermission_PythonToCpp_QPermission_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QPermission_TypeF()))
        return QPermission_PythonToCpp_QPermission_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPermission_SignatureStrings[] = {
    "1:PySide6.QtCore.QPermission(self)",
    "0:PySide6.QtCore.QPermission(self,QPermission:PySide6.QtCore.QPermission)",
    "PySide6.QtCore.QPermission.status(self)->PySide6.QtCore.Qt.PermissionStatus",
    "PySide6.QtCore.QPermission.type(self)->PySide6.QtCore.QMetaType",
    "PySide6.QtCore.QPermission.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QPermission_SignatureByteSize = 113;
static constexpr uint8_t QPermission_SignatureBytes[113] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0x0c, 0x48, 0x2d, 0xca, 0xcd, 0x2c, 0x2e, 0xce, 0xcc, 0xcf, 0xd3, 0x28,
    0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x20, 0xa4, 0x44, 0x07, 0x49, 0x00, 0x8f, 0x5a, 0x4d, 0x2e,
    0xdc, 0x72, 0x7a, 0xc5, 0x25, 0x89, 0x25, 0xa5, 0xc5, 0x10, 0x1b, 0x75, 0xed, 0xd0, 0x15, 0x96,
    0xe8, 0x21, 0x94, 0x06, 0x83, 0x55, 0xe2, 0x33, 0xab, 0xa4, 0xb2, 0x20, 0x15, 0x97, 0x49, 0xbe,
    0xa9, 0x25, 0x89, 0x21, 0x40, 0x79, 0x7c, 0xfa, 0xe3, 0xe3, 0x93, 0xf3, 0x0b, 0x2a, 0xe3, 0xe3,
    0x61, 0x66, 0x00, 0xcd, 0xcb, 0xcc, 0x4b, 0xd7, 0x0b, 0x06, 0xf2, 0xb8, 0x00, 0xbd, 0xc1, 0x6c,
    0xf0
};
#endif

PyTypeObject *init_QPermission(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX].type;

    Shiboken::AutoDecRef Sbk_QPermission_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPermission_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPermission",
        "QPermission",
        &Sbk_QPermission_spec,
        &Shiboken::callCppDestructor< ::QPermission >,
        Sbk_QPermission_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QPermission_TypeF(); // references _Sbk_QPermission_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPermission_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPermission_SignatureBytes, QPermission_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPermission_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPermission_PythonToCpp_QPermission_PTR,
        is_QPermission_PythonToCpp_QPermission_PTR_Convertible,
        QPermission_PTR_CppToPython_QPermission,
        QPermission_COPY_CppToPython_QPermission);

    Shiboken::Conversions::registerConverterName(converter, "QPermission");
    Shiboken::Conversions::registerConverterName(converter, "QPermission*");
    Shiboken::Conversions::registerConverterName(converter, "QPermission&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPermission).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QPermission_PythonToCpp_QPermission_COPY,
        is_QPermission_PythonToCpp_QPermission_COPY_Convertible);

    qRegisterMetaType< ::QPermission >("QPermission");

    return pyType;
}
