// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qpersistentmodelindex_wrapper.h"

// Extra includes
#include <QtCore/QList>

// Argument includes
#include <qabstractitemmodel.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPersistentModelIndex_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPersistentModelIndex >()))
        return -1;

    ::QPersistentModelIndex *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPersistentModelIndex", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPersistentModelIndex::QPersistentModelIndex()
    // 1: QPersistentModelIndex::QPersistentModelIndex(QModelIndex)
    // 2: QPersistentModelIndex::QPersistentModelIndex(QPersistentModelIndex)
    if (numArgs == 0) {
        overloadId = 0; // QPersistentModelIndex()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPersistentModelIndex(QModelIndex)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QPersistentModelIndex(QPersistentModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPersistentModelIndex()
        {

            // QPersistentModelIndex()
            cptr = new ::QPersistentModelIndex();
            break;
        }
        case 1: // QPersistentModelIndex(const QModelIndex &index)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QModelIndex cppArg0_local;
            ::QModelIndex *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QPersistentModelIndex(QModelIndex)
                cptr = new ::QPersistentModelIndex(*cppArg0);
            }
            break;
        }
        case 2: // QPersistentModelIndex(const QPersistentModelIndex &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPersistentModelIndex cppArg0_local;
            ::QPersistentModelIndex *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QPersistentModelIndex(QPersistentModelIndex)
                cptr = new ::QPersistentModelIndex(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPersistentModelIndex >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPersistentModelIndexFunc_column(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // column()const
        int cppResult = const_cast<const ::QPersistentModelIndex *>(cppSelf)->column();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPersistentModelIndexFunc_constInternalPointer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // constInternalPointer()const
        const void * cppResult = const_cast<const ::QPersistentModelIndex *>(cppSelf)->constInternalPointer();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPersistentModelIndexFunc_data(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]);

    if (PyArg_ParseTuple(args, "|O:data", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPersistentModelIndex::data(int=)const->QVariant
    if (numArgs == 0) {
        overloadId = 0; // data(int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // data(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_role = Shiboken::String::createStaticString("role");
            if (PyDict_Contains(kwds, key_role) != 0) {
                value = PyDict_GetItem(kwds, key_role);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_role);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_role);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]);
            }
        }
        int cppArg0 = Qt::DisplayRole;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // data(int)const
            QVariant cppResult = const_cast<const ::QPersistentModelIndex *>(cppSelf)->data(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPersistentModelIndexFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<Qt::ItemFlag> cppResult = const_cast<const ::QPersistentModelIndex *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ItemFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPersistentModelIndexFunc_internalId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // internalId()const
        quintptr cppResult = const_cast<const ::QPersistentModelIndex *>(cppSelf)->internalId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_quintptr_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPersistentModelIndexFunc_internalPointer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // internalPointer()const
        // Begin code injection
        // TEMPLATE - return_internal_pointer - START
        pyResult = reinterpret_cast<PyObject*>(cppSelf->internalPointer());
        if (!pyResult)
            pyResult = Py_None;
        Py_INCREF(pyResult);
        // TEMPLATE - return_internal_pointer - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPersistentModelIndexFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QPersistentModelIndex *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPersistentModelIndexFunc_model(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // model()const
        const QAbstractItemModel * cppResult = const_cast<const ::QPersistentModelIndex *>(cppSelf)->model();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPersistentModelIndexFunc_multiData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPersistentModelIndex::multiData(QModelRoleDataSpan)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelRoleDataSpan_IDX]), (pyArg)))) {
        overloadId = 0; // multiData(QModelRoleDataSpan)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "multiData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelRoleDataSpan cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // multiData(QModelRoleDataSpan)const
            const_cast<const ::QPersistentModelIndex *>(cppSelf)->multiData(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPersistentModelIndexFunc_parent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parent()const
        QModelIndex cppResult = const_cast<const ::QPersistentModelIndex *>(cppSelf)->parent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPersistentModelIndexFunc_row(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // row()const
        int cppResult = const_cast<const ::QPersistentModelIndex *>(cppSelf)->row();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPersistentModelIndexFunc_sibling(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sibling", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPersistentModelIndex::sibling(int,int)const->QModelIndex
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // sibling(int,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sibling", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sibling(int,int)const
            QModelIndex cppResult = const_cast<const ::QPersistentModelIndex *>(cppSelf)->sibling(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPersistentModelIndexFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPersistentModelIndex::swap(QPersistentModelIndex&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QPersistentModelIndex&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPersistentModelIndex cppArg0_local;
        ::QPersistentModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QPersistentModelIndex&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPersistentModelIndex__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPersistentModelIndex_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPersistentModelIndex_methods[] = {
    {"column", reinterpret_cast<PyCFunction>(Sbk_QPersistentModelIndexFunc_column), METH_NOARGS, nullptr},
    {"constInternalPointer", reinterpret_cast<PyCFunction>(Sbk_QPersistentModelIndexFunc_constInternalPointer), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QPersistentModelIndexFunc_data), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QPersistentModelIndexFunc_flags), METH_NOARGS, nullptr},
    {"internalId", reinterpret_cast<PyCFunction>(Sbk_QPersistentModelIndexFunc_internalId), METH_NOARGS, nullptr},
    {"internalPointer", reinterpret_cast<PyCFunction>(Sbk_QPersistentModelIndexFunc_internalPointer), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QPersistentModelIndexFunc_isValid), METH_NOARGS, nullptr},
    {"model", reinterpret_cast<PyCFunction>(Sbk_QPersistentModelIndexFunc_model), METH_NOARGS, nullptr},
    {"multiData", reinterpret_cast<PyCFunction>(Sbk_QPersistentModelIndexFunc_multiData), METH_O, nullptr},
    {"parent", reinterpret_cast<PyCFunction>(Sbk_QPersistentModelIndexFunc_parent), METH_NOARGS, nullptr},
    {"row", reinterpret_cast<PyCFunction>(Sbk_QPersistentModelIndexFunc_row), METH_NOARGS, nullptr},
    {"sibling", reinterpret_cast<PyCFunction>(Sbk_QPersistentModelIndexFunc_sibling), METH_VARARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QPersistentModelIndexFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QPersistentModelIndex__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QPersistentModelIndex_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
                // operator!=(const QModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QModelIndex cppArg0_local;
                ::QModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), (pyArg)))) {
                // operator!=(const QPersistentModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPersistentModelIndex cppArg0_local;
                ::QPersistentModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
                // operator<(const QModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QModelIndex cppArg0_local;
                ::QModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), (pyArg)))) {
                // operator<(const QPersistentModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPersistentModelIndex cppArg0_local;
                ::QPersistentModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
                // operator<=(const QModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QModelIndex cppArg0_local;
                ::QModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), (pyArg)))) {
                // operator<=(const QPersistentModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPersistentModelIndex cppArg0_local;
                ::QPersistentModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
                // operator==(const QModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QModelIndex cppArg0_local;
                ::QModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), (pyArg)))) {
                // operator==(const QPersistentModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPersistentModelIndex cppArg0_local;
                ::QPersistentModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
                // operator>(const QModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QModelIndex cppArg0_local;
                ::QModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), (pyArg)))) {
                // operator>(const QPersistentModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPersistentModelIndex cppArg0_local;
                ::QPersistentModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
                // operator>=(const QModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QModelIndex cppArg0_local;
                ::QModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), (pyArg)))) {
                // operator>=(const QPersistentModelIndex &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPersistentModelIndex cppArg0_local;
                ::QPersistentModelIndex *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QPersistentModelIndex_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QPersistentModelIndex_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPersistentModelIndex_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QPersistentModelIndex__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPersistentModelIndex_Type = nullptr;
static PyTypeObject *Sbk_QPersistentModelIndex_TypeF(void)
{
    return _Sbk_QPersistentModelIndex_Type;
}

static PyType_Slot Sbk_QPersistentModelIndex_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QPersistentModelIndex__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QPersistentModelIndex_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPersistentModelIndex_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPersistentModelIndex_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QPersistentModelIndex_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPersistentModelIndex_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPersistentModelIndex_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPersistentModelIndex_spec = {
    "2:PySide6.QtCore.QPersistentModelIndex",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPersistentModelIndex_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPersistentModelIndex_PythonToCpp_QPersistentModelIndex_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPersistentModelIndex_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPersistentModelIndex_PythonToCpp_QPersistentModelIndex_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPersistentModelIndex_TypeF()))
        return QPersistentModelIndex_PythonToCpp_QPersistentModelIndex_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPersistentModelIndex_PTR_CppToPython_QPersistentModelIndex(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QPersistentModelIndex_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QPersistentModelIndex_COPY_CppToPython_QPersistentModelIndex(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QPersistentModelIndex *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QPersistentModelIndex_TypeF(), new ::QPersistentModelIndex(*source), true, true);
}

// Python to C++ copy conversion.
static void QPersistentModelIndex_PythonToCpp_QPersistentModelIndex_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPersistentModelIndex *>(cppOut) = *reinterpret_cast< ::QPersistentModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QPersistentModelIndex_PythonToCpp_QPersistentModelIndex_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QPersistentModelIndex_TypeF()))
        return QPersistentModelIndex_PythonToCpp_QPersistentModelIndex_COPY;
    return {};
}

// Implicit conversions.
static void constQModelIndexREF_PythonToCpp_QPersistentModelIndex(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPersistentModelIndex *>(cppOut) = ::QPersistentModelIndex( *reinterpret_cast< ::QModelIndex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQModelIndexREF_PythonToCpp_QPersistentModelIndex_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), pyIn))
        return constQModelIndexREF_PythonToCpp_QPersistentModelIndex;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPersistentModelIndex_SignatureStrings[] = {
    "2:PySide6.QtCore.QPersistentModelIndex(self)",
    "1:PySide6.QtCore.QPersistentModelIndex(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "0:PySide6.QtCore.QPersistentModelIndex(self,other:PySide6.QtCore.QPersistentModelIndex)",
    "PySide6.QtCore.QPersistentModelIndex.column(self)->int",
    "PySide6.QtCore.QPersistentModelIndex.constInternalPointer(self)->void",
    "PySide6.QtCore.QPersistentModelIndex.data(self,role:int=Qt.DisplayRole)->QVariant",
    "PySide6.QtCore.QPersistentModelIndex.flags(self)->PySide6.QtCore.Qt.ItemFlag",
    "PySide6.QtCore.QPersistentModelIndex.internalId(self)->quintptr",
    "PySide6.QtCore.QPersistentModelIndex.internalPointer(self)->Any",
    "PySide6.QtCore.QPersistentModelIndex.isValid(self)->bool",
    "PySide6.QtCore.QPersistentModelIndex.model(self)->PySide6.QtCore.QAbstractItemModel",
    "PySide6.QtCore.QPersistentModelIndex.multiData(self,roleDataSpan:typing.Union[PySide6.QtCore.QModelRoleDataSpan, PySide6.QtCore.QModelRoleData])",
    "PySide6.QtCore.QPersistentModelIndex.parent(self)->PySide6.QtCore.QModelIndex",
    "PySide6.QtCore.QPersistentModelIndex.row(self)->int",
    "PySide6.QtCore.QPersistentModelIndex.sibling(self,row:int,column:int)->PySide6.QtCore.QModelIndex",
    "PySide6.QtCore.QPersistentModelIndex.swap(self,other:typing.Union[PySide6.QtCore.QPersistentModelIndex, PySide6.QtCore.QModelIndex])",
    "PySide6.QtCore.QPersistentModelIndex.__copy__(self)->typing.Self",
    "1:PySide6.QtCore.QPersistentModelIndex.__ne__(self,rhs:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "0:PySide6.QtCore.QPersistentModelIndex.__ne__(self,rhs:typing.Union[PySide6.QtCore.QPersistentModelIndex, PySide6.QtCore.QModelIndex])->bool",
    "1:PySide6.QtCore.QPersistentModelIndex.__lt__(self,rhs:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "0:PySide6.QtCore.QPersistentModelIndex.__lt__(self,rhs:typing.Union[PySide6.QtCore.QPersistentModelIndex, PySide6.QtCore.QModelIndex])->bool",
    "1:PySide6.QtCore.QPersistentModelIndex.__le__(self,rhs:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "0:PySide6.QtCore.QPersistentModelIndex.__le__(self,rhs:typing.Union[PySide6.QtCore.QPersistentModelIndex, PySide6.QtCore.QModelIndex])->bool",
    "1:PySide6.QtCore.QPersistentModelIndex.__eq__(self,rhs:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "0:PySide6.QtCore.QPersistentModelIndex.__eq__(self,rhs:typing.Union[PySide6.QtCore.QPersistentModelIndex, PySide6.QtCore.QModelIndex])->bool",
    "1:PySide6.QtCore.QPersistentModelIndex.__gt__(self,rhs:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "0:PySide6.QtCore.QPersistentModelIndex.__gt__(self,rhs:typing.Union[PySide6.QtCore.QPersistentModelIndex, PySide6.QtCore.QModelIndex])->bool",
    "1:PySide6.QtCore.QPersistentModelIndex.__ge__(self,rhs:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "0:PySide6.QtCore.QPersistentModelIndex.__ge__(self,rhs:typing.Union[PySide6.QtCore.QPersistentModelIndex, PySide6.QtCore.QModelIndex])->bool",
    "PySide6.QtCore.QPersistentModelIndex.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QPersistentModelIndex_SignatureByteSize = 406;
static constexpr uint8_t QPersistentModelIndex_SignatureBytes[406] = {
    0x78, 0xda, 0xcd, 0x55, 0x5d, 0x6b, 0xc2, 0x30, 0x14, 0x7d, 0xf7, 0x57, 0xec, 0x71, 0x42, 0x57,
    0xdc, 0x1e, 0xf6, 0x20, 0x6c, 0x20, 0x93, 0x41, 0x1f, 0x06, 0x56, 0x99, 0x2f, 0x43, 0x4a, 0xb4,
    0xb1, 0xbd, 0x10, 0x93, 0x98, 0x5c, 0xe7, 0xfa, 0xef, 0x97, 0xcc, 0x76, 0x7e, 0xcd, 0x71, 0x0b,
    0x2a, 0x7d, 0xbb, 0x09, 0xf7, 0x9c, 0x9e, 0x7b, 0x9a, 0x93, 0x3c, 0x74, 0x07, 0xc5, 0x08, 0x52,
    0xfe, 0x18, 0xc6, 0xf8, 0xa2, 0x0c, 0x0f, 0xe3, 0x01, 0x37, 0x16, 0x2c, 0x72, 0x89, 0x6f, 0x2a,
    0xe5, 0x22, 0x92, 0x29, 0xff, 0xba, 0xb5, 0x5c, 0xcc, 0xdb, 0xad, 0x7b, 0x7a, 0x73, 0x00, 0xbe,
    0xec, 0x62, 0xa1, 0x41, 0x66, 0xe1, 0xbb, 0x04, 0x25, 0x3f, 0x0e, 0xc1, 0x5b, 0x48, 0x70, 0x43,
    0x21, 0x9e, 0xb4, 0x5b, 0x9d, 0x1a, 0x0a, 0x14, 0xe6, 0xdc, 0x90, 0xfa, 0xdb, 0x2d, 0x4a, 0x57,
    0x38, 0x53, 0x62, 0xb5, 0x90, 0x1b, 0x2f, 0xee, 0x9e, 0x41, 0x22, 0x15, 0x26, 0x2d, 0x46, 0x12,
    0xb9, 0x91, 0x4c, 0x0c, 0x14, 0xf8, 0xaa, 0x22, 0xf9, 0x54, 0x90, 0xd2, 0x58, 0x52, 0x86, 0x6c,
    0x33, 0x97, 0x51, 0x82, 0x77, 0x1d, 0xcb, 0x53, 0x8c, 0x61, 0x1f, 0xac, 0x16, 0xac, 0x18, 0xba,
    0x2d, 0xc7, 0x16, 0x8f, 0x99, 0x01, 0x46, 0xd5, 0x35, 0x17, 0x2c, 0xb3, 0x95, 0x90, 0x43, 0x04,
    0x86, 0x11, 0xf2, 0xc5, 0xab, 0x6b, 0xa1, 0x91, 0x41, 0x39, 0x5f, 0x94, 0x56, 0x8c, 0xcb, 0x95,
    0xdb, 0xd3, 0x68, 0xea, 0xe1, 0x0f, 0xfc, 0xe9, 0xc9, 0x82, 0x88, 0xb7, 0x63, 0x26, 0xe0, 0xf7,
    0xe3, 0x53, 0xa5, 0x04, 0x0d, 0xb8, 0xf0, 0xe5, 0x29, 0x17, 0x7a, 0x53, 0x8b, 0x86, 0xcd, 0xd0,
    0x7b, 0xf1, 0x83, 0x21, 0x72, 0xae, 0x04, 0x42, 0x7f, 0xef, 0x87, 0xf9, 0xd5, 0x48, 0x33, 0x49,
    0x48, 0xc4, 0x70, 0xa7, 0xfd, 0x38, 0x18, 0x7b, 0x2d, 0x13, 0xe2, 0xc9, 0xd5, 0xcc, 0xb8, 0x8d,
    0x53, 0x53, 0x6e, 0x1b, 0x69, 0x6c, 0x46, 0xad, 0x6b, 0x87, 0xc0, 0xc2, 0x54, 0xb8, 0xb9, 0x2b,
    0x43, 0xd6, 0xfe, 0x00, 0x07, 0x9b, 0x40, 0xf9, 0xf2, 0x0c, 0xaa, 0xec, 0x9a, 0xe9, 0xdd, 0xe0,
    0xff, 0x6b, 0xf4, 0x5f, 0x0c, 0x27, 0xbc, 0xae, 0xae, 0x1e, 0x92, 0x88, 0x24, 0x99, 0x29, 0x5d,
    0x24, 0x49, 0xe5, 0x4f, 0x29, 0x62, 0xe4, 0x56, 0xc4, 0xdb, 0xd3, 0x51, 0x48, 0x5e, 0x12, 0x04,
    0x26, 0xb7, 0xe7, 0xbe, 0x42, 0xcb, 0x6c, 0x74, 0x2e, 0x20, 0xa6, 0xbe, 0xa9, 0xa5, 0x18, 0xb2,
    0x33, 0x02, 0x1b, 0xe4, 0x4c, 0x0d, 0x31, 0x57, 0x70, 0xa6, 0x49, 0x67, 0x46, 0x34, 0xe9, 0xcc,
    0xf0, 0x65, 0x83, 0x9c, 0xa9, 0x21, 0xe6, 0xf2, 0xce, 0x64, 0x4d, 0x4a, 0x53, 0xd6, 0xa4, 0x34,
    0x65, 0x4d, 0x4a, 0x53, 0x76, 0x85, 0x34, 0x11, 0xa5, 0xe4, 0xcc, 0xe6, 0xdb, 0xc7, 0xcd, 0x3f,
    0xfe, 0xdf, 0x96, 0xb0, 0x74, 0xf7
};
#endif

PyTypeObject *init_QPersistentModelIndex(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX].type;

    Shiboken::AutoDecRef Sbk_QPersistentModelIndex_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPersistentModelIndex_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPersistentModelIndex",
        "QPersistentModelIndex",
        &Sbk_QPersistentModelIndex_spec,
        &Shiboken::callCppDestructor< ::QPersistentModelIndex >,
        Sbk_QPersistentModelIndex_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QPersistentModelIndex_TypeF(); // references _Sbk_QPersistentModelIndex_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPersistentModelIndex_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPersistentModelIndex_SignatureBytes, QPersistentModelIndex_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPersistentModelIndex_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPersistentModelIndex_PythonToCpp_QPersistentModelIndex_PTR,
        is_QPersistentModelIndex_PythonToCpp_QPersistentModelIndex_PTR_Convertible,
        QPersistentModelIndex_PTR_CppToPython_QPersistentModelIndex,
        QPersistentModelIndex_COPY_CppToPython_QPersistentModelIndex);

    Shiboken::Conversions::registerConverterName(converter, "QPersistentModelIndex");
    Shiboken::Conversions::registerConverterName(converter, "QPersistentModelIndex*");
    Shiboken::Conversions::registerConverterName(converter, "QPersistentModelIndex&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPersistentModelIndex).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QPersistentModelIndex_PythonToCpp_QPersistentModelIndex_COPY,
        is_QPersistentModelIndex_PythonToCpp_QPersistentModelIndex_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQModelIndexREF_PythonToCpp_QPersistentModelIndex,
        is_constQModelIndexREF_PythonToCpp_QPersistentModelIndex_Convertible);



    // Begin code injection
    qRegisterMetaType<QList<QPersistentModelIndex> >("QList_QPersistentModelIndex");
    // End of code injection

    qRegisterMetaType< ::QPersistentModelIndex >("QPersistentModelIndex");

    return pyType;
}

