// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qprocess_unixprocessparameters_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QProcess_UnixProcessParameters_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QProcess::UnixProcessParameters >()))
        return -1;

    ::QProcess::UnixProcessParameters *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "UnixProcessParameters", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: UnixProcessParameters::UnixProcessParameters()
    // 1: UnixProcessParameters::UnixProcessParameters(QProcess::UnixProcessParameters)
    if (numArgs == 0) {
        overloadId = 0; // UnixProcessParameters()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX]), (pyArgs[0])))) {
        overloadId = 1; // UnixProcessParameters(QProcess::UnixProcessParameters)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // UnixProcessParameters()
        {

            // UnixProcessParameters()
            cptr = new ::QProcess::UnixProcessParameters();
            break;
        }
        case 1: // UnixProcessParameters(const QProcess::UnixProcessParameters &UnixProcessParameters)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QProcess::UnixProcessParameters cppArg0_local;
            ::QProcess::UnixProcessParameters *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // UnixProcessParameters(QProcess::UnixProcessParameters)
                cptr = new ::QProcess::UnixProcessParameters(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QProcess::UnixProcessParameters >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QProcess_UnixProcessParameters__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QProcess::UnixProcessParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QProcess_UnixProcessParameters_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QProcess_UnixProcessParameters_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QProcess_UnixProcessParameters__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QProcess_UnixProcessParameters_get_flags(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess::UnixProcessParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QProcess_UnixProcessFlag_IDX])))->flagsConverter, &cppSelf->flags);
    return pyOut;
}
static int Sbk_QProcess_UnixProcessParameters_set_flags(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QProcess::UnixProcessParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("flags");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QProcess_UnixProcessFlag_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("flags", "UnixProcessFlags");
        return -1;
    }

    auto cppOut_local = cppSelf->flags;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->flags = cppOut_local;

    return 0;
}

static PyObject *Sbk_QProcess_UnixProcessParameters_get_lowestFileDescriptorToClose(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcess::UnixProcessParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->lowestFileDescriptorToClose;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QProcess_UnixProcessParameters_set_lowestFileDescriptorToClose(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QProcess::UnixProcessParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("lowestFileDescriptorToClose");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("lowestFileDescriptorToClose", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->lowestFileDescriptorToClose;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->lowestFileDescriptorToClose = cppOut_local;

    return 0;
}


// Getters and Setters for UnixProcessParameters
static PyGetSetDef Sbk_QProcess_UnixProcessParameters_getsetlist[] = {
    {const_cast<char *>("flags"), Sbk_QProcess_UnixProcessParameters_get_flags, Sbk_QProcess_UnixProcessParameters_set_flags, nullptr, nullptr},
    {const_cast<char *>("lowestFileDescriptorToClose"), Sbk_QProcess_UnixProcessParameters_get_lowestFileDescriptorToClose, Sbk_QProcess_UnixProcessParameters_set_lowestFileDescriptorToClose, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QProcess_UnixProcessParameters_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QProcess_UnixProcessParameters_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QProcess_UnixProcessParameters_Type = nullptr;
static PyTypeObject *Sbk_QProcess_UnixProcessParameters_TypeF(void)
{
    return _Sbk_QProcess_UnixProcessParameters_Type;
}

static PyType_Slot Sbk_QProcess_UnixProcessParameters_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QProcess_UnixProcessParameters_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QProcess_UnixProcessParameters_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QProcess_UnixProcessParameters_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QProcess_UnixProcessParameters_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QProcess_UnixProcessParameters_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QProcess_UnixProcessParameters_spec = {
    "2:PySide6.QtCore.QProcess.UnixProcessParameters",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QProcess_UnixProcessParameters_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void UnixProcessParameters_PythonToCpp_UnixProcessParameters_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QProcess_UnixProcessParameters_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_UnixProcessParameters_PythonToCpp_UnixProcessParameters_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QProcess_UnixProcessParameters_TypeF()))
        return UnixProcessParameters_PythonToCpp_UnixProcessParameters_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *UnixProcessParameters_PTR_CppToPython_UnixProcessParameters(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QProcess_UnixProcessParameters_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *UnixProcessParameters_COPY_CppToPython_UnixProcessParameters(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QProcess::UnixProcessParameters *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QProcess_UnixProcessParameters_TypeF(), new ::QProcess::UnixProcessParameters(*source), true, true);
}

// Python to C++ copy conversion.
static void UnixProcessParameters_PythonToCpp_UnixProcessParameters_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QProcess::UnixProcessParameters *>(cppOut) = *reinterpret_cast< ::QProcess::UnixProcessParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_UnixProcessParameters_PythonToCpp_UnixProcessParameters_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QProcess_UnixProcessParameters_TypeF()))
        return UnixProcessParameters_PythonToCpp_UnixProcessParameters_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QProcess_UnixProcessParameters_SignatureStrings[] = {
    "1:PySide6.QtCore.QProcess.UnixProcessParameters(self)",
    "0:PySide6.QtCore.QProcess.UnixProcessParameters(self,UnixProcessParameters:PySide6.QtCore.QProcess.UnixProcessParameters)",
    "PySide6.QtCore.QProcess.UnixProcessParameters.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QProcess_UnixProcessParameters_SignatureByteSize = 94;
static constexpr uint8_t QProcess_UnixProcessParameters_SignatureBytes[94] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0x0c, 0x28, 0xca, 0x4f, 0x4e, 0x2d, 0x2e, 0xd6, 0x0b, 0xcd, 0xcb, 0xac,
    0x80, 0xb2, 0x03, 0x12, 0x8b, 0x12, 0x73, 0x53, 0x4b, 0x52, 0x8b, 0x8a, 0x35, 0x8a, 0x53, 0x73,
    0xd2, 0x34, 0xb9, 0x0c, 0xc8, 0xd0, 0xa5, 0x83, 0x55, 0x8a, 0x34, 0x83, 0x34, 0xb9, 0x48, 0x52,
    0xae, 0x17, 0x1f, 0x9f, 0x9c, 0x5f, 0x50, 0x19, 0x1f, 0x0f, 0x71, 0xb6, 0xae, 0x5d, 0x49, 0x65,
    0x41, 0x66, 0x5e, 0xba, 0x5e, 0x30, 0x90, 0xc7, 0x05, 0x00, 0x32, 0xf6, 0x5c, 0x91
};
#endif

PyTypeObject *init_QProcess_UnixProcessParameters(PyObject *enclosingClass)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX].type;

    Shiboken::AutoDecRef Sbk_QProcess_UnixProcessParameters_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QProcess_UnixProcessParameters_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "UnixProcessParameters",
        "QProcess::UnixProcessParameters",
        &Sbk_QProcess_UnixProcessParameters_spec,
        &Shiboken::callCppDestructor< ::QProcess::UnixProcessParameters >,
        Sbk_QProcess_UnixProcessParameters_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QProcess_UnixProcessParameters_TypeF(); // references _Sbk_QProcess_UnixProcessParameters_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QProcess_UnixProcessParameters_SignatureStrings);
#else
    InitSignatureBytes(pyType, QProcess_UnixProcessParameters_SignatureBytes, QProcess_UnixProcessParameters_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QProcess_UnixProcessParameters_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QProcess_UnixProcessParameters_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        UnixProcessParameters_PythonToCpp_UnixProcessParameters_PTR,
        is_UnixProcessParameters_PythonToCpp_UnixProcessParameters_PTR_Convertible,
        UnixProcessParameters_PTR_CppToPython_UnixProcessParameters,
        UnixProcessParameters_COPY_CppToPython_UnixProcessParameters);

    Shiboken::Conversions::registerConverterName(converter, "QProcess::UnixProcessParameters");
    Shiboken::Conversions::registerConverterName(converter, "QProcess::UnixProcessParameters*");
    Shiboken::Conversions::registerConverterName(converter, "QProcess::UnixProcessParameters&");
    Shiboken::Conversions::registerConverterAlias(converter, "UnixProcessParameters");
    Shiboken::Conversions::registerConverterAlias(converter, "UnixProcessParameters*");
    Shiboken::Conversions::registerConverterAlias(converter, "UnixProcessParameters&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QProcess::UnixProcessParameters).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        UnixProcessParameters_PythonToCpp_UnixProcessParameters_COPY,
        is_UnixProcessParameters_PythonToCpp_UnixProcessParameters_COPY_Convertible);

    qRegisterMetaType< ::QProcess::UnixProcessParameters >("UnixProcessParameters");
    qRegisterMetaType< ::QProcess::UnixProcessParameters >("QProcess::UnixProcessParameters");

    return pyType;
}
