// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qrandomgenerator64_wrapper.h"

// Argument includes
#include <qrandom.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRandomGenerator64_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRandomGenerator64 >()))
        return -1;

    ::QRandomGenerator64 *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QRandomGenerator64", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRandomGenerator64::QRandomGenerator64(QRandomGenerator)
    // 1: QRandomGenerator64::QRandomGenerator64(const quint32*,const quint32*)
    // 2: QRandomGenerator64::QRandomGenerator64(const quint32*,qsizetype)
    // 3: QRandomGenerator64::QRandomGenerator64(quint32=)
    if (numArgs == 0) {
        overloadId = 3; // QRandomGenerator64(quint32)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // QRandomGenerator64(quint32)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 2; // QRandomGenerator64(const quint32*,qsizetype)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[1])))) {
            overloadId = 1; // QRandomGenerator64(const quint32*,const quint32*)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QRandomGenerator64(QRandomGenerator)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRandomGenerator64(const QRandomGenerator &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRandomGenerator *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRandomGenerator64(QRandomGenerator)
                cptr = new ::QRandomGenerator64(*cppArg0);
            }
            break;
        }
        case 1: // QRandomGenerator64(const quint32 *begin, const quint32 *end)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]);
            }
            quint32 *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            quint32 *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRandomGenerator64(const quint32*,const quint32*)
                cptr = new ::QRandomGenerator64(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QRandomGenerator64(const quint32 *seedBuffer, qsizetype len)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]);
            }
            quint32 *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRandomGenerator64(const quint32*,qsizetype)
                cptr = new ::QRandomGenerator64(cppArg0, cppArg1);
            }
            break;
        }
        case 3: // QRandomGenerator64(quint32 seedValue)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_seedValue = Shiboken::String::createStaticString("seedValue");
                if (PyDict_Contains(kwds, key_seedValue) != 0) {
                    value = PyDict_GetItem(kwds, key_seedValue);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_seedValue);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_seedValue);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]);
                }
            }
            quint32 cppArg0 = 1;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRandomGenerator64(quint32)
                cptr = new ::QRandomGenerator64(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRandomGenerator64 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRandomGenerator64Func_discard(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRandomGenerator64 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRandomGenerator::discard(qulonglong)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long long>(), (pyArg)))) {
        overloadId = 0; // discard(qulonglong)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "discard", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]);

    // Call function/method
    {
        unsigned long long cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // discard(qulonglong)
            cppSelf->discard(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRandomGenerator64Func_generate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRandomGenerator64 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // generate()
        quint64 cppResult = cppSelf->generate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRandomGenerator64Func_global_(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // global()
        QRandomGenerator64 * cppResult = ::QRandomGenerator64::global();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRandomGenerator64Func_max(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // max()
        unsigned long long cppResult = ::QRandomGenerator64::max();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long long>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRandomGenerator64Func_min(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // min()
        unsigned long long cppResult = ::QRandomGenerator64::min();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long long>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRandomGenerator64Func_securelySeeded(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // securelySeeded()
        QRandomGenerator64* cppResult = new QRandomGenerator64(::QRandomGenerator64::securelySeeded());
        pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]), cppResult, true, true);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRandomGenerator64Func_system(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // system()
        QRandomGenerator64 * cppResult = ::QRandomGenerator64::system();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRandomGenerator64_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRandomGenerator64_methods[] = {
    {"discard", reinterpret_cast<PyCFunction>(Sbk_QRandomGenerator64Func_discard), METH_O, nullptr},
    {"generate", reinterpret_cast<PyCFunction>(Sbk_QRandomGenerator64Func_generate), METH_NOARGS, nullptr},
    {"global_", reinterpret_cast<PyCFunction>(Sbk_QRandomGenerator64Func_global_), METH_NOARGS|METH_STATIC, nullptr},
    {"max", reinterpret_cast<PyCFunction>(Sbk_QRandomGenerator64Func_max), METH_NOARGS|METH_STATIC, nullptr},
    {"min", reinterpret_cast<PyCFunction>(Sbk_QRandomGenerator64Func_min), METH_NOARGS|METH_STATIC, nullptr},
    {"securelySeeded", reinterpret_cast<PyCFunction>(Sbk_QRandomGenerator64Func_securelySeeded), METH_NOARGS|METH_STATIC, nullptr},
    {"system", reinterpret_cast<PyCFunction>(Sbk_QRandomGenerator64Func_system), METH_NOARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRandomGenerator64_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRandomGenerator64_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRandomGenerator64_Type = nullptr;
static PyTypeObject *Sbk_QRandomGenerator64_TypeF(void)
{
    return _Sbk_QRandomGenerator64_Type;
}

static PyType_Slot Sbk_QRandomGenerator64_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRandomGenerator64_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRandomGenerator64_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRandomGenerator64_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRandomGenerator64_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRandomGenerator64_spec = {
    "2:PySide6.QtCore.QRandomGenerator64",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRandomGenerator64_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRandomGenerator64_PythonToCpp_QRandomGenerator64_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRandomGenerator64_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRandomGenerator64_PythonToCpp_QRandomGenerator64_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRandomGenerator64_TypeF()))
        return QRandomGenerator64_PythonToCpp_QRandomGenerator64_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRandomGenerator64_PTR_CppToPython_QRandomGenerator64(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QRandomGenerator64_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRandomGenerator64_SignatureStrings[] = {
    "3:PySide6.QtCore.QRandomGenerator64(self,other:PySide6.QtCore.QRandomGenerator)",
    "2:PySide6.QtCore.QRandomGenerator64(self,begin:quint32*,end:quint32*)",
    "1:PySide6.QtCore.QRandomGenerator64(self,seedBuffer:quint32*,len:qsizetype)",
    "0:PySide6.QtCore.QRandomGenerator64(self,seedValue:quint32=1)",
    "PySide6.QtCore.QRandomGenerator64.discard(self,z:unsigned long long)",
    "PySide6.QtCore.QRandomGenerator64.generate(self)->quint64",
    "PySide6.QtCore.QRandomGenerator64.global_()->PySide6.QtCore.QRandomGenerator64",
    "PySide6.QtCore.QRandomGenerator64.max()->unsigned long long",
    "PySide6.QtCore.QRandomGenerator64.min()->unsigned long long",
    "PySide6.QtCore.QRandomGenerator64.securelySeeded()->PySide6.QtCore.QRandomGenerator64",
    "PySide6.QtCore.QRandomGenerator64.system()->PySide6.QtCore.QRandomGenerator64",
    nullptr}; // Sentinel
#else
static constexpr size_t QRandomGenerator64_SignatureByteSize = 211;
static constexpr uint8_t QRandomGenerator64_SignatureBytes[211] = {
    0x78, 0xda, 0xad, 0xd1, 0x3d, 0x0b, 0xc2, 0x30, 0x10, 0x06, 0xe0, 0xbd, 0xbf, 0xc2, 0xd1, 0x88,
    0x16, 0xbf, 0xe8, 0x50, 0xd0, 0x41, 0x07, 0x57, 0x3f, 0xc0, 0x55, 0xa2, 0x79, 0x5b, 0x03, 0xe9,
    0x45, 0xf3, 0x01, 0xd6, 0x5f, 0x6f, 0x6d, 0xd1, 0xc5, 0xa1, 0x51, 0x5c, 0x8e, 0x1c, 0xdc, 0xfb,
    0x70, 0x47, 0x26, 0xe9, 0xba, 0xdc, 0x49, 0x81, 0x24, 0xde, 0xb8, 0xa5, 0x36, 0x88, 0x37, 0x5b,
    0x4e, 0x42, 0x17, 0x2b, 0x10, 0x0c, 0x77, 0xda, 0x24, 0xd3, 0xae, 0x85, 0xca, 0xfa, 0xda, 0x9d,
    0x61, 0xda, 0x86, 0x59, 0x34, 0x0e, 0xf5, 0x8e, 0xc8, 0x25, 0xa5, 0x57, 0x2f, 0xc9, 0x4d, 0xc6,
    0xbd, 0x3e, 0x48, 0xbc, 0x1b, 0x16, 0x8d, 0x42, 0x15, 0x0b, 0x88, 0x85, 0xcf, 0xb2, 0x6a, 0xb5,
    0x37, 0xa5, 0x50, 0xb9, 0x56, 0xde, 0xe1, 0xca, 0x0b, 0x58, 0x34, 0xfc, 0xc6, 0xda, 0x73, 0xe5,
    0xf1, 0xa2, 0x66, 0x23, 0x16, 0xb5, 0x66, 0x63, 0x21, 0xed, 0x89, 0x1b, 0xd1, 0x18, 0xf7, 0xd4,
    0x93, 0x95, 0x39, 0x41, 0x74, 0x94, 0xa6, 0xbc, 0x2e, 0x21, 0x48, 0xde, 0xbc, 0x51, 0x2b, 0x6c,
    0x30, 0xaf, 0x37, 0x48, 0xa6, 0x21, 0x49, 0xa5, 0x8f, 0x5c, 0x1d, 0xba, 0x55, 0xa8, 0x75, 0x38,
    0x80, 0x2b, 0xf8, 0xed, 0x49, 0x7d, 0x5e, 0x11, 0x92, 0x95, 0xf4, 0x73, 0xd6, 0xe2, 0xe4, 0x0d,
    0x54, 0xb9, 0xab, 0x3e, 0x01, 0xe2, 0x5f, 0xd7, 0xd8, 0xd2, 0x3a, 0x14, 0x61, 0xda, 0x03, 0x00,
    0xa7, 0x12, 0x34
};
#endif

PyTypeObject *init_QRandomGenerator64(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX].type;

    Shiboken::AutoDecRef Sbk_QRandomGenerator64_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator_IDX]))));

    _Sbk_QRandomGenerator64_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRandomGenerator64",
        "QRandomGenerator64*",
        &Sbk_QRandomGenerator64_spec,
        &Shiboken::callCppDestructor< ::QRandomGenerator64 >,
        Sbk_QRandomGenerator64_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRandomGenerator64_TypeF(); // references _Sbk_QRandomGenerator64_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRandomGenerator64_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRandomGenerator64_SignatureBytes, QRandomGenerator64_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRandomGenerator64_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRandomGenerator64_PythonToCpp_QRandomGenerator64_PTR,
        is_QRandomGenerator64_PythonToCpp_QRandomGenerator64_PTR_Convertible,
        QRandomGenerator64_PTR_CppToPython_QRandomGenerator64);

    Shiboken::Conversions::registerConverterName(converter, "QRandomGenerator64");
    Shiboken::Conversions::registerConverterName(converter, "QRandomGenerator64*");
    Shiboken::Conversions::registerConverterName(converter, "QRandomGenerator64&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRandomGenerator64).name());

    qRegisterMetaType< ::QRandomGenerator64 *>();

    return pyType;
}
