// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qreadlocker_wrapper.h"

// Argument includes
#include <qreadwritelock.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QReadLocker_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QReadLocker >()))
        return -1;

    ::QReadLocker *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QReadLocker", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QReadLocker::QReadLocker(QReadWriteLock*)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QReadLocker(QReadWriteLock*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadLocker_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QReadLocker_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QReadWriteLock *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QReadLocker(QReadWriteLock*)
            cptr = new ::QReadLocker(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "QReadLocker(QReadWriteLock*)1", pyArgs[0]);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QReadLocker >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadLocker_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QReadLockerFunc___enter__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QReadLocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadLocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __enter__()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtcore.cpp (default-enter)]
        Py_INCREF(self);
        pyResult = self;
        // END of custom code block [file: ../glue/qtcore.cpp (default-enter)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QReadLockerFunc___exit__(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QReadLocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadLocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "__exit__", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QReadLocker::__exit__(PyObject*,PyObject*,PyObject*)
    if (numArgs == 3
        && true
        && true
        && true) {
        overloadId = 0; // __exit__(PyObject*,PyObject*,PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "__exit__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadLocker_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __exit__(PyObject*,PyObject*,PyObject*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (unlock)]
            cppSelf->unlock();
            // END of custom code block [file: ../glue/qtcore.cpp (unlock)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QReadLockerFunc_readWriteLock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QReadLocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadLocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readWriteLock()const
        QReadWriteLock * cppResult = const_cast<const ::QReadLocker *>(cppSelf)->readWriteLock();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QReadLockerFunc_relock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QReadLocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadLocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // relock()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        cppSelf->relock();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QReadLockerFunc_unlock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QReadLocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadLocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unlock()
        cppSelf->unlock();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QReadLocker_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QReadLocker_methods[] = {
    {"__enter__", reinterpret_cast<PyCFunction>(Sbk_QReadLockerFunc___enter__), METH_NOARGS, nullptr},
    {"__exit__", reinterpret_cast<PyCFunction>(Sbk_QReadLockerFunc___exit__), METH_VARARGS, nullptr},
    {"readWriteLock", reinterpret_cast<PyCFunction>(Sbk_QReadLockerFunc_readWriteLock), METH_NOARGS, nullptr},
    {"relock", reinterpret_cast<PyCFunction>(Sbk_QReadLockerFunc_relock), METH_NOARGS, nullptr},
    {"unlock", reinterpret_cast<PyCFunction>(Sbk_QReadLockerFunc_unlock), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QReadLocker_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QReadLocker_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QReadLocker_Type = nullptr;
static PyTypeObject *Sbk_QReadLocker_TypeF(void)
{
    return _Sbk_QReadLocker_Type;
}

static PyType_Slot Sbk_QReadLocker_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QReadLocker_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QReadLocker_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QReadLocker_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QReadLocker_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QReadLocker_spec = {
    "2:PySide6.QtCore.QReadLocker",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QReadLocker_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QReadLocker_PythonToCpp_QReadLocker_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QReadLocker_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QReadLocker_PythonToCpp_QReadLocker_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QReadLocker_TypeF()))
        return QReadLocker_PythonToCpp_QReadLocker_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QReadLocker_PTR_CppToPython_QReadLocker(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QReadLocker_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QReadLocker_SignatureStrings[] = {
    "PySide6.QtCore.QReadLocker(self,readWriteLock:PySide6.QtCore.QReadWriteLock)",
    "PySide6.QtCore.QReadLocker.__enter__(self)->PySide6.QtCore.QReadLocker",
    "PySide6.QtCore.QReadLocker.__exit__(self,arg__1:PyObject,arg__2:PyObject,arg__3:PyObject)",
    "PySide6.QtCore.QReadLocker.readWriteLock(self)->PySide6.QtCore.QReadWriteLock",
    "PySide6.QtCore.QReadLocker.relock(self)",
    "PySide6.QtCore.QReadLocker.unlock(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QReadLocker_SignatureByteSize = 130;
static constexpr uint8_t QReadLocker_SignatureBytes[130] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce, 0x2f, 0x4a,
    0xd5, 0x0b, 0x0c, 0x4a, 0x4d, 0x4c, 0xf1, 0xc9, 0x4f, 0xce, 0x4e, 0x2d, 0xd2, 0x28, 0x4e, 0xcd,
    0x49, 0xd3, 0x29, 0x02, 0xf2, 0xc3, 0x8b, 0x32, 0x4b, 0x52, 0x41, 0x82, 0x56, 0x01, 0x58, 0x54,
    0xc3, 0x65, 0x35, 0xb9, 0x02, 0x70, 0x1a, 0xa6, 0x17, 0x1f, 0x9f, 0x9a, 0x57, 0x92, 0x5a, 0x14,
    0x1f, 0x0f, 0x36, 0x56, 0x53, 0xd7, 0x0e, 0xb7, 0x5a, 0x02, 0xc6, 0x54, 0x64, 0x96, 0x40, 0x4d,
    0xd1, 0x49, 0x2c, 0x4a, 0x8f, 0x8f, 0x37, 0x04, 0xba, 0xca, 0x3f, 0x29, 0x2b, 0x35, 0xb9, 0x04,
    0xc2, 0x37, 0x42, 0xe3, 0x1b, 0xc3, 0xf9, 0x78, 0x1d, 0x88, 0xe2, 0x51, 0x7c, 0x8e, 0x84, 0x2b,
    0xc2, 0x6f, 0x5a, 0x0e, 0xdc, 0x18, 0x7c, 0xea, 0x4a, 0xf3, 0x90, 0xd4, 0x01, 0x00, 0x0d, 0x06,
    0x8c, 0x28
};
#endif

PyTypeObject *init_QReadLocker(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QReadLocker_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QReadLocker_IDX].type;

    Shiboken::AutoDecRef Sbk_QReadLocker_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QReadLocker_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QReadLocker",
        "QReadLocker*",
        &Sbk_QReadLocker_spec,
        &Shiboken::callCppDestructor< ::QReadLocker >,
        Sbk_QReadLocker_Type_bases.object(),
        0);
    auto *pyType = Sbk_QReadLocker_TypeF(); // references _Sbk_QReadLocker_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QReadLocker_SignatureStrings);
#else
    InitSignatureBytes(pyType, QReadLocker_SignatureBytes, QReadLocker_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QReadLocker_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QReadLocker_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QReadLocker_PythonToCpp_QReadLocker_PTR,
        is_QReadLocker_PythonToCpp_QReadLocker_PTR_Convertible,
        QReadLocker_PTR_CppToPython_QReadLocker);

    Shiboken::Conversions::registerConverterName(converter, "QReadLocker");
    Shiboken::Conversions::registerConverterName(converter, "QReadLocker*");
    Shiboken::Conversions::registerConverterName(converter, "QReadLocker&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QReadLocker).name());

    qRegisterMetaType< ::QReadLocker *>();

    return pyType;
}
