// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qreadwritelock_wrapper.h"

// Argument includes
#include <qdeadlinetimer.h>
#include <qreadwritelock.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QReadWriteLock_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QReadWriteLock >()))
        return -1;

    ::QReadWriteLock *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);

    if (PyArg_ParseTuple(args, "|O:QReadWriteLock", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QReadWriteLock::QReadWriteLock(QReadWriteLock::RecursionMode=)
    if (numArgs == 0) {
        overloadId = 0; // QReadWriteLock(QReadWriteLock::RecursionMode)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_RecursionMode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QReadWriteLock(QReadWriteLock::RecursionMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_recursionMode = Shiboken::String::createStaticString("recursionMode");
            if (PyDict_Contains(kwds, key_recursionMode) != 0) {
                value = PyDict_GetItem(kwds, key_recursionMode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_recursionMode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_RecursionMode_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_recursionMode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);
            }
        }
        ::QReadWriteLock::RecursionMode cppArg0(QReadWriteLock::RecursionMode::NonRecursive);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QReadWriteLock(QReadWriteLock::RecursionMode)
            cptr = new ::QReadWriteLock(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QReadWriteLock >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QReadWriteLockFunc_lockForRead(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QReadWriteLock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lockForRead()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        cppSelf->lockForRead();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QReadWriteLockFunc_lockForWrite(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QReadWriteLock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lockForWrite()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        cppSelf->lockForWrite();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QReadWriteLockFunc_tryLockForRead(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QReadWriteLock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "tryLockForRead", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);

    if (PyArg_ParseTuple(args, "|O:tryLockForRead", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QReadWriteLock::tryLockForRead(QDeadlineTimer=)->bool
    // 1: QReadWriteLock::tryLockForRead(int)->bool
    if (numArgs == 0) {
        overloadId = 0; // tryLockForRead(QDeadlineTimer)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 1; // tryLockForRead(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0])))) {
        overloadId = 0; // tryLockForRead(QDeadlineTimer)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "tryLockForRead", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // tryLockForRead(QDeadlineTimer timeout)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_timeout = Shiboken::String::createStaticString("timeout");
                if (PyDict_Contains(kwds, key_timeout) != 0) {
                    value = PyDict_GetItem(kwds, key_timeout);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_timeout);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "tryLockForRead", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "tryLockForRead", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_timeout);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "tryLockForRead", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDeadlineTimer cppArg0{};
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // tryLockForRead(QDeadlineTimer)
                bool cppResult = cppSelf->tryLockForRead(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // tryLockForRead(int timeout)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "tryLockForRead", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // tryLockForRead(int)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->tryLockForRead(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QReadWriteLockFunc_tryLockForWrite(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QReadWriteLock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "tryLockForWrite", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);

    if (PyArg_ParseTuple(args, "|O:tryLockForWrite", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QReadWriteLock::tryLockForWrite(QDeadlineTimer=)->bool
    // 1: QReadWriteLock::tryLockForWrite(int)->bool
    if (numArgs == 0) {
        overloadId = 0; // tryLockForWrite(QDeadlineTimer)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 1; // tryLockForWrite(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0])))) {
        overloadId = 0; // tryLockForWrite(QDeadlineTimer)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "tryLockForWrite", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // tryLockForWrite(QDeadlineTimer timeout)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_timeout = Shiboken::String::createStaticString("timeout");
                if (PyDict_Contains(kwds, key_timeout) != 0) {
                    value = PyDict_GetItem(kwds, key_timeout);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_timeout);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "tryLockForWrite", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "tryLockForWrite", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_timeout);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "tryLockForWrite", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDeadlineTimer cppArg0{};
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // tryLockForWrite(QDeadlineTimer)
                bool cppResult = cppSelf->tryLockForWrite(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // tryLockForWrite(int timeout)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "tryLockForWrite", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // tryLockForWrite(int)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->tryLockForWrite(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QReadWriteLockFunc_unlock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QReadWriteLock *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unlock()
        cppSelf->unlock();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QReadWriteLock_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QReadWriteLock_EnumFlagInfo[] = {
    "RecursionMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QReadWriteLock_methods[] = {
    {"lockForRead", reinterpret_cast<PyCFunction>(Sbk_QReadWriteLockFunc_lockForRead), METH_NOARGS, nullptr},
    {"lockForWrite", reinterpret_cast<PyCFunction>(Sbk_QReadWriteLockFunc_lockForWrite), METH_NOARGS, nullptr},
    {"tryLockForRead", reinterpret_cast<PyCFunction>(Sbk_QReadWriteLockFunc_tryLockForRead), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"tryLockForWrite", reinterpret_cast<PyCFunction>(Sbk_QReadWriteLockFunc_tryLockForWrite), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"unlock", reinterpret_cast<PyCFunction>(Sbk_QReadWriteLockFunc_unlock), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QReadWriteLock_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QReadWriteLock_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QReadWriteLock_Type = nullptr;
static PyTypeObject *Sbk_QReadWriteLock_TypeF(void)
{
    return _Sbk_QReadWriteLock_Type;
}

static PyType_Slot Sbk_QReadWriteLock_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QReadWriteLock_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QReadWriteLock_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QReadWriteLock_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QReadWriteLock_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QReadWriteLock_spec = {
    "2:PySide6.QtCore.QReadWriteLock",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QReadWriteLock_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QReadWriteLock_RecursionMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QReadWriteLock::RecursionMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QReadWriteLock::RecursionMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QReadWriteLock_RecursionMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_RecursionMode_IDX])))
        return Enum_PythonToCpp_QReadWriteLock_RecursionMode;
    return {};
}

static PyObject *QReadWriteLock_RecursionMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QReadWriteLock::RecursionMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QReadWriteLock::RecursionMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_RecursionMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QReadWriteLock_PythonToCpp_QReadWriteLock_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QReadWriteLock_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QReadWriteLock_PythonToCpp_QReadWriteLock_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QReadWriteLock_TypeF()))
        return QReadWriteLock_PythonToCpp_QReadWriteLock_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QReadWriteLock_PTR_CppToPython_QReadWriteLock(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QReadWriteLock_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QReadWriteLock_SignatureStrings[] = {
    "PySide6.QtCore.QReadWriteLock(self,recursionMode:PySide6.QtCore.QReadWriteLock.RecursionMode=QReadWriteLock.RecursionMode.NonRecursive)",
    "PySide6.QtCore.QReadWriteLock.lockForRead(self)",
    "PySide6.QtCore.QReadWriteLock.lockForWrite(self)",
    "1:PySide6.QtCore.QReadWriteLock.tryLockForRead(self,timeout:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64]={})->bool",
    "0:PySide6.QtCore.QReadWriteLock.tryLockForRead(self,timeout:int)->bool",
    "1:PySide6.QtCore.QReadWriteLock.tryLockForWrite(self,timeout:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64]={})->bool",
    "0:PySide6.QtCore.QReadWriteLock.tryLockForWrite(self,timeout:int)->bool",
    "PySide6.QtCore.QReadWriteLock.unlock(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QReadWriteLock_SignatureByteSize = 208;
static constexpr uint8_t QReadWriteLock_SignatureBytes[208] = {
    0x78, 0xda, 0xcd, 0x92, 0x31, 0x0b, 0xc2, 0x30, 0x10, 0x85, 0xf7, 0xfe, 0x8a, 0x8e, 0x16, 0x62,
    0x50, 0x10, 0x87, 0x42, 0x5d, 0x14, 0x27, 0x95, 0x5a, 0x15, 0x07, 0x71, 0x50, 0x7b, 0x4a, 0x30,
    0xde, 0x69, 0x7a, 0x2d, 0x14, 0xf1, 0xbf, 0x1b, 0x45, 0x51, 0x44, 0xa2, 0xe0, 0xe2, 0x92, 0xe1,
    0xdd, 0xbb, 0x2f, 0xef, 0x85, 0xc4, 0xe5, 0x48, 0xa5, 0xd0, 0x94, 0x43, 0x6e, 0x93, 0x01, 0x39,
    0x4c, 0x60, 0x91, 0x4e, 0x8d, 0x62, 0xe8, 0xd1, 0x6a, 0x5b, 0xc9, 0x40, 0xaf, 0x85, 0x81, 0x55,
    0x6e, 0x32, 0x45, 0xd8, 0xa7, 0x14, 0xc2, 0xd8, 0xb5, 0x20, 0x93, 0x67, 0x6f, 0xe4, 0x1a, 0xca,
    0x01, 0xe1, 0x4d, 0x28, 0x20, 0xf0, 0xdc, 0x58, 0x6d, 0x8f, 0x2e, 0x99, 0x8b, 0x78, 0xcd, 0xf4,
    0xa5, 0xff, 0x2a, 0xdc, 0x16, 0xea, 0x1f, 0x92, 0xb3, 0x29, 0x7b, 0x2f, 0xb7, 0x08, 0x56, 0x3b,
    0xa0, 0x9c, 0x43, 0x2e, 0xf7, 0x0a, 0x37, 0x72, 0x82, 0x36, 0xfb, 0xec, 0x15, 0xd3, 0xb1, 0x76,
    0xad, 0x10, 0xc6, 0xd6, 0x6c, 0x84, 0xef, 0x1c, 0x4b, 0x8b, 0x87, 0x02, 0x4c, 0x9b, 0x30, 0xe3,
    0x05, 0xb2, 0xf0, 0x0f, 0x0a, 0xb9, 0xd9, 0x98, 0x47, 0xc7, 0x53, 0x50, 0x6d, 0x2d, 0x89, 0xb4,
    0x57, 0xfb, 0x21, 0xa8, 0x85, 0xdd, 0x31, 0xdf, 0xf7, 0x7d, 0xbc, 0xd2, 0xbf, 0x17, 0x7e, 0x93,
    0xf4, 0xa9, 0xb1, 0x9b, 0x92, 0xa3, 0xbe, 0xff, 0xe8, 0xc0, 0x3b, 0x03, 0x52, 0x17, 0x13, 0x10
};
#endif

PyTypeObject *init_QReadWriteLock(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX].type;

    Shiboken::AutoDecRef Sbk_QReadWriteLock_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QReadWriteLock_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QReadWriteLock",
        "QReadWriteLock*",
        &Sbk_QReadWriteLock_spec,
        &Shiboken::callCppDestructor< ::QReadWriteLock >,
        Sbk_QReadWriteLock_Type_bases.object(),
        0);
    auto *pyType = Sbk_QReadWriteLock_TypeF(); // references _Sbk_QReadWriteLock_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QReadWriteLock_SignatureStrings);
#else
    InitSignatureBytes(pyType, QReadWriteLock_SignatureBytes, QReadWriteLock_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QReadWriteLock_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QReadWriteLock_PythonToCpp_QReadWriteLock_PTR,
        is_QReadWriteLock_PythonToCpp_QReadWriteLock_PTR_Convertible,
        QReadWriteLock_PTR_CppToPython_QReadWriteLock);

    Shiboken::Conversions::registerConverterName(converter, "QReadWriteLock");
    Shiboken::Conversions::registerConverterName(converter, "QReadWriteLock*");
    Shiboken::Conversions::registerConverterName(converter, "QReadWriteLock&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QReadWriteLock).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QReadWriteLock_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'RecursionMode'.
    const char *RecursionMode_Initializer[] = {
        "NonRecursive",
        "Recursive",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RecursionMode_InitializerValues[] = {
        uint8_t(QReadWriteLock::RecursionMode::NonRecursive), //  0x00  0
        uint8_t(QReadWriteLock::RecursionMode::Recursive)     //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QReadWriteLock_TypeF(),
        "2:PySide6.QtCore.QReadWriteLock.RecursionMode",
        RecursionMode_Initializer, RecursionMode_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_RecursionMode_IDX].type = EType;
    // Register converter for enum 'QReadWriteLock::RecursionMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QReadWriteLock_RecursionMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QReadWriteLock_RecursionMode,
            is_Enum_PythonToCpp_QReadWriteLock_RecursionMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QReadWriteLock::RecursionMode");
        Shiboken::Conversions::registerConverterAlias(converter, "RecursionMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'RecursionMode' enum.

    qRegisterMetaType< ::QReadWriteLock *>();
    qRegisterMetaType< ::QReadWriteLock::RecursionMode >("QReadWriteLock::RecursionMode");

    return pyType;
}
