// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qrecursivemutex_wrapper.h"

// Argument includes
#include <qdeadlinetimer.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRecursiveMutex_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRecursiveMutex >()))
        return -1;

    ::QRecursiveMutex *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QRecursiveMutex()
        cptr = new ::QRecursiveMutex();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRecursiveMutex >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRecursiveMutexFunc_lock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRecursiveMutex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lock()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        cppSelf->lock();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRecursiveMutexFunc_tryLock(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRecursiveMutex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "tryLock", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]);

    if (PyArg_ParseTuple(args, "|O:tryLock", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRecursiveMutex::tryLock(QDeadlineTimer=)->bool
    // 1: QRecursiveMutex::tryLock(int)->bool
    if (numArgs == 0) {
        overloadId = 0; // tryLock(QDeadlineTimer)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 1; // tryLock(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0])))) {
        overloadId = 0; // tryLock(QDeadlineTimer)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "tryLock", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // tryLock(QDeadlineTimer timer)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_timer = Shiboken::String::createStaticString("timer");
                if (PyDict_Contains(kwds, key_timer) != 0) {
                    value = PyDict_GetItem(kwds, key_timer);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_timer);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "tryLock", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "tryLock", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_timer);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "tryLock", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDeadlineTimer cppArg0{};
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // tryLock(QDeadlineTimer)
                bool cppResult = cppSelf->tryLock(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // tryLock(int timeout)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "tryLock", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // tryLock(int)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->tryLock(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRecursiveMutexFunc_try_lock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRecursiveMutex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // try_lock()
        bool cppResult = cppSelf->try_lock();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRecursiveMutexFunc_unlock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRecursiveMutex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unlock()
        cppSelf->unlock();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QRecursiveMutex_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRecursiveMutex_methods[] = {
    {"lock", reinterpret_cast<PyCFunction>(Sbk_QRecursiveMutexFunc_lock), METH_NOARGS, nullptr},
    {"tryLock", reinterpret_cast<PyCFunction>(Sbk_QRecursiveMutexFunc_tryLock), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"try_lock", reinterpret_cast<PyCFunction>(Sbk_QRecursiveMutexFunc_try_lock), METH_NOARGS, nullptr},
    {"unlock", reinterpret_cast<PyCFunction>(Sbk_QRecursiveMutexFunc_unlock), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRecursiveMutex_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRecursiveMutex_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRecursiveMutex_Type = nullptr;
static PyTypeObject *Sbk_QRecursiveMutex_TypeF(void)
{
    return _Sbk_QRecursiveMutex_Type;
}

static PyType_Slot Sbk_QRecursiveMutex_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRecursiveMutex_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRecursiveMutex_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRecursiveMutex_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRecursiveMutex_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRecursiveMutex_spec = {
    "2:PySide6.QtCore.QRecursiveMutex",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRecursiveMutex_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRecursiveMutex_PythonToCpp_QRecursiveMutex_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRecursiveMutex_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRecursiveMutex_PythonToCpp_QRecursiveMutex_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRecursiveMutex_TypeF()))
        return QRecursiveMutex_PythonToCpp_QRecursiveMutex_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRecursiveMutex_PTR_CppToPython_QRecursiveMutex(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QRecursiveMutex_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRecursiveMutex_SignatureStrings[] = {
    "PySide6.QtCore.QRecursiveMutex(self)",
    "PySide6.QtCore.QRecursiveMutex.lock(self)",
    "1:PySide6.QtCore.QRecursiveMutex.tryLock(self,timer:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64]={})->bool",
    "0:PySide6.QtCore.QRecursiveMutex.tryLock(self,timeout:int)->bool",
    "PySide6.QtCore.QRecursiveMutex.try_lock(self)->bool",
    "PySide6.QtCore.QRecursiveMutex.unlock(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QRecursiveMutex_SignatureByteSize = 162;
static constexpr uint8_t QRecursiveMutex_SignatureBytes[162] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce, 0x2f, 0x4a,
    0xd5, 0x0b, 0x0c, 0x4a, 0x4d, 0x2e, 0x2d, 0x2a, 0xce, 0x2c, 0x4b, 0xf5, 0x2d, 0x2d, 0x49, 0xad,
    0xd0, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x0a, 0xc0, 0xab, 0x48, 0x2f, 0x27, 0x3f, 0x39, 0x1b,
    0xaa, 0xd2, 0xd0, 0x8a, 0x80, 0xda, 0x92, 0xa2, 0x4a, 0x1f, 0x98, 0x72, 0x9d, 0x92, 0xcc, 0xdc,
    0xd4, 0x22, 0xab, 0x92, 0xca, 0x82, 0xcc, 0xbc, 0x74, 0xbd, 0xd0, 0xbc, 0xcc, 0xfc, 0xbc, 0x68,
    0x74, 0xed, 0x2e, 0xa9, 0x89, 0x29, 0x39, 0x99, 0x79, 0xa9, 0x21, 0x20, 0xa5, 0x3a, 0x0a, 0x78,
    0xa5, 0xf5, 0xdc, 0x80, 0x62, 0x65, 0xa9, 0x45, 0xce, 0xf9, 0x79, 0xc5, 0x25, 0x89, 0x79, 0x25,
    0x3a, 0x0a, 0x85, 0x99, 0x79, 0x25, 0x66, 0x26, 0xb1, 0xb6, 0xd5, 0xb5, 0x9a, 0xba, 0x76, 0x49,
    0xf9, 0xf9, 0x39, 0x5c, 0x06, 0x24, 0x3b, 0x30, 0xbf, 0xb4, 0xc4, 0x0a, 0x68, 0x0c, 0xcc, 0x00,
    0xc2, 0xda, 0xe3, 0x11, 0xe1, 0x41, 0x9c, 0x9e, 0xd2, 0x3c, 0xa4, 0x10, 0x04, 0x00, 0x3b, 0x61,
    0x91, 0x80
};
#endif

PyTypeObject *init_QRecursiveMutex(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX].type;

    Shiboken::AutoDecRef Sbk_QRecursiveMutex_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRecursiveMutex_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRecursiveMutex",
        "QRecursiveMutex*",
        &Sbk_QRecursiveMutex_spec,
        &Shiboken::callCppDestructor< ::QRecursiveMutex >,
        Sbk_QRecursiveMutex_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRecursiveMutex_TypeF(); // references _Sbk_QRecursiveMutex_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRecursiveMutex_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRecursiveMutex_SignatureBytes, QRecursiveMutex_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRecursiveMutex_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRecursiveMutex_PythonToCpp_QRecursiveMutex_PTR,
        is_QRecursiveMutex_PythonToCpp_QRecursiveMutex_PTR_Convertible,
        QRecursiveMutex_PTR_CppToPython_QRecursiveMutex);

    Shiboken::Conversions::registerConverterName(converter, "QRecursiveMutex");
    Shiboken::Conversions::registerConverterName(converter, "QRecursiveMutex*");
    Shiboken::Conversions::registerConverterName(converter, "QRecursiveMutex&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRecursiveMutex).name());

    qRegisterMetaType< ::QRecursiveMutex *>();

    return pyType;
}
