// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qresource_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <qbytearray.h>
#include <qdatetime.h>
#include <qlocale.h>
#include <qresource.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QResource_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QResource >()))
        return -1;

    ::QResource *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QResource", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QResource::QResource(const QString&=,const QLocale&=)
    if (numArgs == 0) {
        overloadId = 0; // QResource(QString,QLocale)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QResource(QString,QLocale)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QResource(QString,QLocale)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_file = Shiboken::String::createStaticString("file");
            if (PyDict_Contains(kwds, key_file) != 0) {
                value = PyDict_GetItem(kwds, key_file);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_file);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_file);
            }
            static PyObject *const key_locale = Shiboken::String::createStaticString("locale");
            if (PyDict_Contains(kwds, key_locale) != 0) {
                value = PyDict_GetItem(kwds, key_locale);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_locale);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_locale);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
            }
        }
        ::QString cppArg0 = QString();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QLocale cppArg1_local = QLocale();
        ::QLocale *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // QResource(QString,QLocale)
            cptr = new ::QResource(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QResource >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QResourceFunc_absoluteFilePath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // absoluteFilePath()const
        QString cppResult = const_cast<const ::QResource *>(cppSelf)->absoluteFilePath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_children(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // children()const
        QStringList cppResult = const_cast<const ::QResource *>(cppSelf)->children();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_compressionAlgorithm(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // compressionAlgorithm()const
        QResource::Compression cppResult = const_cast<const ::QResource *>(cppSelf)->compressionAlgorithm();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_Compression_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()const
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtcore.cpp (qresource-data)]
        const void *d = cppSelf->data();
        if (d) {
            pyResult = Shiboken::Buffer::newObject(d, cppSelf->size());
        } else {
            Py_INCREF(Py_None);
            pyResult = Py_None;
        }
        // END of custom code block [file: ../glue/qtcore.cpp (qresource-data)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_fileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileName()const
        QString cppResult = const_cast<const ::QResource *>(cppSelf)->fileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_isDir(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDir()const
        bool cppResult = const_cast<const ::QResource *>(cppSelf)->isDir();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_isFile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFile()const
        bool cppResult = const_cast<const ::QResource *>(cppSelf)->isFile();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QResource *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_lastModified(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastModified()const
        QDateTime cppResult = const_cast<const ::QResource *>(cppSelf)->lastModified();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_locale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // locale()const
        QLocale cppResult = const_cast<const ::QResource *>(cppSelf)->locale();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_registerResource(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "registerResource", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);

    if (PyArg_ParseTuple(args, "|OO:registerResource", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QResource::registerResource(QString,const QString&=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // registerResource(QString,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // registerResource(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "registerResource", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_resourceRoot = Shiboken::String::createStaticString("resourceRoot");
            if (PyDict_Contains(kwds, key_resourceRoot) != 0) {
                value = PyDict_GetItem(kwds, key_resourceRoot);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_resourceRoot);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "registerResource", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "registerResource", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_resourceRoot);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "registerResource", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // registerResource(QString,QString)
            bool cppResult = ::QResource::registerResource(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_registerResourceData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "registerResourceData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);

    if (PyArg_ParseTuple(args, "|OO:registerResourceData", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QResource::registerResource(PyBuffer,const QString&=)->bool
    if (numArgs >= 1
        && Shiboken::Buffer::checkType(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // registerResource(const uchar*,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // registerResource(const uchar*,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "registerResourceData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_resourceRoot = Shiboken::String::createStaticString("resourceRoot");
            if (PyDict_Contains(kwds, key_resourceRoot) != 0) {
                value = PyDict_GetItem(kwds, key_resourceRoot);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_resourceRoot);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "registerResourceData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "registerResourceData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_resourceRoot);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "registerResourceData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
            }
        }
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // registerResource(const uchar*,QString)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qresource-registerResource)]
            auto ptr = reinterpret_cast<uchar *>(Shiboken::Buffer::getPointer(pyArgs[1-1]));
            bool cppResult = QResource::registerResource(const_cast<const uchar *>(ptr), cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            // END of custom code block [file: ../glue/qtcore.cpp (qresource-registerResource)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_setFileName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QResource::setFileName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFileName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFileName(QString)
            cppSelf->setFileName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QResourceFunc_setLocale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QResource::setLocale(QLocale)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
        overloadId = 0; // setLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLocale", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocale(QLocale)
            cppSelf->setLocale(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QResourceFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        qint64 cppResult = const_cast<const ::QResource *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_uncompressedData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // uncompressedData()const
        QByteArray cppResult = const_cast<const ::QResource *>(cppSelf)->uncompressedData();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_uncompressedSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResource *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // uncompressedSize()const
        qint64 cppResult = const_cast<const ::QResource *>(cppSelf)->uncompressedSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_unregisterResource(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "unregisterResource", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);

    if (PyArg_ParseTuple(args, "|OO:unregisterResource", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QResource::unregisterResource(QString,const QString&=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // unregisterResource(QString,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // unregisterResource(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "unregisterResource", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_resourceRoot = Shiboken::String::createStaticString("resourceRoot");
            if (PyDict_Contains(kwds, key_resourceRoot) != 0) {
                value = PyDict_GetItem(kwds, key_resourceRoot);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_resourceRoot);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "unregisterResource", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "unregisterResource", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_resourceRoot);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "unregisterResource", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // unregisterResource(QString,QString)
            bool cppResult = ::QResource::unregisterResource(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResourceFunc_unregisterResourceData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "unregisterResourceData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);

    if (PyArg_ParseTuple(args, "|OO:unregisterResourceData", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QResource::unregisterResource(PyBuffer,const QString&=)->bool
    if (numArgs >= 1
        && Shiboken::Buffer::checkType(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // unregisterResource(const uchar*,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // unregisterResource(const uchar*,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "unregisterResourceData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_resourceRoot = Shiboken::String::createStaticString("resourceRoot");
            if (PyDict_Contains(kwds, key_resourceRoot) != 0) {
                value = PyDict_GetItem(kwds, key_resourceRoot);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_resourceRoot);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "unregisterResourceData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "unregisterResourceData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_resourceRoot);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "unregisterResourceData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX]);
            }
        }
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // unregisterResource(const uchar*,QString)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qresource-registerResource)]
            auto ptr = reinterpret_cast<uchar *>(Shiboken::Buffer::getPointer(pyArgs[1-1]));
            bool cppResult = QResource::unregisterResource(const_cast<const uchar *>(ptr), cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            // END of custom code block [file: ../glue/qtcore.cpp (qresource-registerResource)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QResource_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QResource_EnumFlagInfo[] = {
    "Compression:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QResource_methods[] = {
    {"absoluteFilePath", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_absoluteFilePath), METH_NOARGS, nullptr},
    {"children", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_children), METH_NOARGS, nullptr},
    {"compressionAlgorithm", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_compressionAlgorithm), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_data), METH_NOARGS, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_fileName), METH_NOARGS, nullptr},
    {"isDir", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_isDir), METH_NOARGS, nullptr},
    {"isFile", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_isFile), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_isValid), METH_NOARGS, nullptr},
    {"lastModified", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_lastModified), METH_NOARGS, nullptr},
    {"locale", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_locale), METH_NOARGS, nullptr},
    {"registerResource", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_registerResource), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"registerResourceData", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_registerResourceData), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"setFileName", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_setFileName), METH_O, nullptr},
    {"setLocale", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_setLocale), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_size), METH_NOARGS, nullptr},
    {"uncompressedData", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_uncompressedData), METH_NOARGS, nullptr},
    {"uncompressedSize", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_uncompressedSize), METH_NOARGS, nullptr},
    {"unregisterResource", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_unregisterResource), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"unregisterResourceData", reinterpret_cast<PyCFunction>(Sbk_QResourceFunc_unregisterResourceData), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QResource_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QResource_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QResource_Type = nullptr;
static PyTypeObject *Sbk_QResource_TypeF(void)
{
    return _Sbk_QResource_Type;
}

static PyType_Slot Sbk_QResource_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QResource_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QResource_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QResource_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QResource_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QResource_spec = {
    "2:PySide6.QtCore.QResource",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QResource_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QResource_Compression(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QResource::Compression>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QResource::Compression *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QResource_Compression_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_Compression_IDX])))
        return Enum_PythonToCpp_QResource_Compression;
    return {};
}

static PyObject *QResource_Compression_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QResource::Compression>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QResource::Compression *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QResource_Compression_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QResource_PythonToCpp_QResource_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QResource_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QResource_PythonToCpp_QResource_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QResource_TypeF()))
        return QResource_PythonToCpp_QResource_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QResource_PTR_CppToPython_QResource(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QResource_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QResource_SignatureStrings[] = {
    "PySide6.QtCore.QResource(self,file:QString=QString(),locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language]=QLocale())",
    "PySide6.QtCore.QResource.absoluteFilePath(self)->QString",
    "PySide6.QtCore.QResource.children(self)->QStringList",
    "PySide6.QtCore.QResource.compressionAlgorithm(self)->PySide6.QtCore.QResource.Compression",
    "PySide6.QtCore.QResource.data(self)->PyObject",
    "PySide6.QtCore.QResource.fileName(self)->QString",
    "PySide6.QtCore.QResource.isDir(self)->bool",
    "PySide6.QtCore.QResource.isFile(self)->bool",
    "PySide6.QtCore.QResource.isValid(self)->bool",
    "PySide6.QtCore.QResource.lastModified(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtCore.QResource.locale(self)->PySide6.QtCore.QLocale",
    "PySide6.QtCore.QResource.registerResource(rccFilename:QString,resourceRoot:QString=QString())->bool",
    "PySide6.QtCore.QResource.registerResourceData(rccData:PyBuffer,resourceRoot:QString=QString())->bool",
    "PySide6.QtCore.QResource.setFileName(self,file:QString)",
    "PySide6.QtCore.QResource.setLocale(self,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])",
    "PySide6.QtCore.QResource.size(self)->qint64",
    "PySide6.QtCore.QResource.uncompressedData(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QResource.uncompressedSize(self)->qint64",
    "PySide6.QtCore.QResource.unregisterResource(rccFilename:QString,resourceRoot:QString=QString())->bool",
    "PySide6.QtCore.QResource.unregisterResourceData(rccData:PyBuffer,resourceRoot:QString=QString())->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QResource_SignatureByteSize = 348;
static constexpr uint8_t QResource_SignatureBytes[348] = {
    0x78, 0xda, 0xbd, 0x53, 0x3d, 0x4f, 0xc3, 0x30, 0x10, 0xdd, 0xf9, 0x15, 0x8c, 0x8d, 0x14, 0x32,
    0xa1, 0x0e, 0x95, 0x8a, 0xd4, 0x36, 0xea, 0x14, 0x20, 0x6d, 0x81, 0x05, 0x31, 0xb8, 0xf1, 0x25,
    0x3d, 0xe4, 0xd8, 0xe5, 0xec, 0x0c, 0xe1, 0xd7, 0xe3, 0xb4, 0x49, 0x4b, 0x3f, 0x1c, 0x82, 0x8a,
    0x98, 0x2c, 0xdb, 0xef, 0xdd, 0xbd, 0xbb, 0x7b, 0x17, 0x97, 0x0b, 0xe4, 0xd0, 0x0f, 0x66, 0x66,
    0xa2, 0x08, 0x82, 0xd9, 0x1c, 0xb4, 0x2a, 0x28, 0x81, 0x9e, 0x06, 0x91, 0xfa, 0x29, 0x0a, 0x18,
    0xcc, 0x16, 0x86, 0x50, 0x66, 0xc3, 0xfa, 0xec, 0x79, 0xbe, 0x50, 0x09, 0xb3, 0x1f, 0xa6, 0x5c,
    0xdb, 0x7b, 0xf0, 0x2c, 0x51, 0xc9, 0xd7, 0xf8, 0x28, 0x50, 0xb4, 0xc1, 0xf8, 0xd7, 0xe7, 0xdf,
    0x83, 0x88, 0xc9, 0xac, 0x60, 0x19, 0xbc, 0x0d, 0xeb, 0x97, 0x9e, 0xe7, 0x5d, 0xc5, 0x0e, 0x31,
    0x01, 0x5b, 0x6a, 0x25, 0x0a, 0x03, 0x53, 0xab, 0x27, 0x66, 0x66, 0xb5, 0x51, 0xe7, 0xdd, 0xdc,
    0xd5, 0x92, 0xdc, 0xc4, 0x64, 0x85, 0x82, 0x13, 0xc8, 0x23, 0x42, 0x84, 0xda, 0xb4, 0x90, 0x54,
    0xbe, 0x26, 0xd0, 0xda, 0x96, 0x35, 0x12, 0x99, 0x22, 0x34, 0xab, 0xbc, 0x09, 0xe0, 0x24, 0x4d,
    0xf6, 0x24, 0x77, 0x64, 0xce, 0x0c, 0xdb, 0x47, 0x7a, 0x5c, 0xbe, 0x43, 0xd2, 0xa2, 0xa3, 0xea,
    0xfe, 0x03, 0xcb, 0xa1, 0x73, 0xb5, 0xa8, 0x43, 0xa4, 0x06, 0xbd, 0x54, 0x4a, 0xb4, 0x41, 0xab,
    0x5e, 0x76, 0xc5, 0xbe, 0x30, 0x81, 0xbc, 0x1b, 0x58, 0x30, 0x6d, 0xee, 0x15, 0xc7, 0x14, 0x81,
    0xbb, 0x9a, 0x16, 0x32, 0x03, 0x4f, 0x98, 0x43, 0x4b, 0x94, 0xad, 0x27, 0x1c, 0xfc, 0xad, 0x63,
    0xdc, 0x6c, 0x82, 0xcc, 0x0e, 0x18, 0x68, 0x67, 0x66, 0x4a, 0x92, 0xaa, 0x5c, 0x69, 0x9b, 0xd9,
    0xd8, 0xd9, 0xa7, 0xfa, 0x73, 0xae, 0x94, 0x39, 0xf5, 0xf8, 0x8f, 0x75, 0x1e, 0xe7, 0x08, 0xab,
    0xd1, 0xda, 0x3c, 0xd5, 0x39, 0x88, 0xcb, 0x71, 0x91, 0xa6, 0x40, 0x97, 0x26, 0xd1, 0x60, 0xa6,
    0xdf, 0x4d, 0x70, 0xb0, 0x90, 0x5e, 0x2b, 0x2f, 0xda, 0x77, 0xf0, 0x4f, 0xf7, 0xb5, 0x2d, 0x2b,
    0x7e, 0xee, 0x46, 0xf6, 0x81, 0xd2, 0xf4, 0x6f, 0xdd, 0xd8, 0x42, 0x36, 0x5b, 0x06, 0x3c, 0x3c,
    0xd8, 0x8a, 0x43, 0xc2, 0xb8, 0x34, 0x30, 0x22, 0x62, 0x65, 0xb7, 0x50, 0x8b, 0x5f, 0x49, 0xf8,
    0x0f, 0x9f, 0x9c, 0x66, 0xb9, 0xc4, 0x29, 0x5f, 0x29, 0x7d, 0x0b, 0xe9
};
#endif

PyTypeObject *init_QResource(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX].type;

    Shiboken::AutoDecRef Sbk_QResource_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QResource_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QResource",
        "QResource*",
        &Sbk_QResource_spec,
        &Shiboken::callCppDestructor< ::QResource >,
        Sbk_QResource_Type_bases.object(),
        0);
    auto *pyType = Sbk_QResource_TypeF(); // references _Sbk_QResource_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QResource_SignatureStrings);
#else
    InitSignatureBytes(pyType, QResource_SignatureBytes, QResource_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QResource_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QResource_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QResource_PythonToCpp_QResource_PTR,
        is_QResource_PythonToCpp_QResource_PTR_Convertible,
        QResource_PTR_CppToPython_QResource);

    Shiboken::Conversions::registerConverterName(converter, "QResource");
    Shiboken::Conversions::registerConverterName(converter, "QResource*");
    Shiboken::Conversions::registerConverterName(converter, "QResource&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QResource).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QResource_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Compression'.
    const char *Compression_Initializer[] = {
        "NoCompression",
        "ZlibCompression",
        "ZstdCompression",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Compression_InitializerValues[] = {
        uint8_t(QResource::Compression::NoCompression),   //  0x00  0
        uint8_t(QResource::Compression::ZlibCompression), //  0x01  1
        uint8_t(QResource::Compression::ZstdCompression)  //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QResource_TypeF(),
        "2:PySide6.QtCore.QResource.Compression",
        Compression_Initializer, Compression_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QResource_Compression_IDX].type = EType;
    // Register converter for enum 'QResource::Compression'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QResource_Compression_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QResource_Compression,
            is_Enum_PythonToCpp_QResource_Compression_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QResource::Compression");
        Shiboken::Conversions::registerConverterAlias(converter, "Compression");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Compression' enum.

    qRegisterMetaType< ::QResource *>();
    qRegisterMetaType< ::QResource::Compression >("QResource::Compression");

    return pyType;
}
