// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qsemaphore_wrapper.h"

// Argument includes
#include <qdeadlinetimer.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSemaphore_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSemaphore >()))
        return -1;

    ::QSemaphore *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);

    if (PyArg_ParseTuple(args, "|O:QSemaphore", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSemaphore::QSemaphore(int=)
    if (numArgs == 0) {
        overloadId = 0; // QSemaphore(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // QSemaphore(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_n = Shiboken::String::createStaticString("n");
            if (PyDict_Contains(kwds, key_n) != 0) {
                value = PyDict_GetItem(kwds, key_n);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_n);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_n);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);
            }
        }
        int cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSemaphore(int)
            cptr = new ::QSemaphore(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSemaphore >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSemaphoreFunc_acquire(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSemaphore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "acquire", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);

    if (PyArg_ParseTuple(args, "|O:acquire", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSemaphore::acquire(int=)
    if (numArgs == 0) {
        overloadId = 0; // acquire(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // acquire(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "acquire", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_n = Shiboken::String::createStaticString("n");
            if (PyDict_Contains(kwds, key_n) != 0) {
                value = PyDict_GetItem(kwds, key_n);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_n);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "acquire", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "acquire", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_n);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "acquire", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);
            }
        }
        int cppArg0 = 1;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // acquire(int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->acquire(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSemaphoreFunc_available(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSemaphore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // available()const
        int cppResult = const_cast<const ::QSemaphore *>(cppSelf)->available();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSemaphoreFunc_release(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSemaphore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "release", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);

    if (PyArg_ParseTuple(args, "|O:release", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSemaphore::release(int=)
    if (numArgs == 0) {
        overloadId = 0; // release(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // release(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "release", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_n = Shiboken::String::createStaticString("n");
            if (PyDict_Contains(kwds, key_n) != 0) {
                value = PyDict_GetItem(kwds, key_n);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_n);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "release", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "release", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_n);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "release", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);
            }
        }
        int cppArg0 = 1;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // release(int)
            cppSelf->release(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSemaphoreFunc_tryAcquire(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSemaphore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "tryAcquire", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);

    if (PyArg_ParseTuple(args, "|OO:tryAcquire", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSemaphore::tryAcquire(int=)->bool
    // 1: QSemaphore::tryAcquire(int,QDeadlineTimer)->bool
    // 2: QSemaphore::tryAcquire(int,int)->bool
    if (numArgs == 0) {
        overloadId = 0; // tryAcquire(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // tryAcquire(int)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 2; // tryAcquire(int,int)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[1])))) {
            overloadId = 1; // tryAcquire(int,QDeadlineTimer)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "tryAcquire", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // tryAcquire(int n)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_n = Shiboken::String::createStaticString("n");
                if (PyDict_Contains(kwds, key_n) != 0) {
                    value = PyDict_GetItem(kwds, key_n);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_n);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "tryAcquire", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "tryAcquire", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_n);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "tryAcquire", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);
                }
            }
            int cppArg0 = 1;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // tryAcquire(int)
                bool cppResult = cppSelf->tryAcquire(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // tryAcquire(int n, QDeadlineTimer timeout)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "tryAcquire", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QDeadlineTimer cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // tryAcquire(int,QDeadlineTimer)
                bool cppResult = cppSelf->tryAcquire(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // tryAcquire(int n, int timeout)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "tryAcquire", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // tryAcquire(int,int)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->tryAcquire(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSemaphore_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSemaphore_methods[] = {
    {"acquire", reinterpret_cast<PyCFunction>(Sbk_QSemaphoreFunc_acquire), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"available", reinterpret_cast<PyCFunction>(Sbk_QSemaphoreFunc_available), METH_NOARGS, nullptr},
    {"release", reinterpret_cast<PyCFunction>(Sbk_QSemaphoreFunc_release), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"tryAcquire", reinterpret_cast<PyCFunction>(Sbk_QSemaphoreFunc_tryAcquire), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSemaphore_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSemaphore_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSemaphore_Type = nullptr;
static PyTypeObject *Sbk_QSemaphore_TypeF(void)
{
    return _Sbk_QSemaphore_Type;
}

static PyType_Slot Sbk_QSemaphore_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSemaphore_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSemaphore_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSemaphore_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSemaphore_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSemaphore_spec = {
    "2:PySide6.QtCore.QSemaphore",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSemaphore_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSemaphore_PythonToCpp_QSemaphore_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSemaphore_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSemaphore_PythonToCpp_QSemaphore_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSemaphore_TypeF()))
        return QSemaphore_PythonToCpp_QSemaphore_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSemaphore_PTR_CppToPython_QSemaphore(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSemaphore_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSemaphore_SignatureStrings[] = {
    "PySide6.QtCore.QSemaphore(self,n:int=0)",
    "PySide6.QtCore.QSemaphore.acquire(self,n:int=1)",
    "PySide6.QtCore.QSemaphore.available(self)->int",
    "PySide6.QtCore.QSemaphore.release(self,n:int=1)",
    "2:PySide6.QtCore.QSemaphore.tryAcquire(self,n:int=1)->bool",
    "1:PySide6.QtCore.QSemaphore.tryAcquire(self,n:int,timeout:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64])->bool",
    "0:PySide6.QtCore.QSemaphore.tryAcquire(self,n:int,timeout:int)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QSemaphore_SignatureByteSize = 175;
static constexpr uint8_t QSemaphore_SignatureBytes[175] = {
    0x78, 0xda, 0x9d, 0x8e, 0x4d, 0x0b, 0x82, 0x40, 0x10, 0x86, 0xef, 0xfe, 0x0a, 0x8f, 0x09, 0xba,
    0x68, 0x84, 0x07, 0x21, 0x21, 0x8c, 0xce, 0x8a, 0x75, 0x8a, 0x0e, 0x63, 0x8e, 0x35, 0xb0, 0xee,
    0xea, 0xba, 0x0a, 0xfe, 0xfb, 0x16, 0xc2, 0x43, 0x92, 0x42, 0xdd, 0x5e, 0x66, 0x9e, 0xf7, 0x23,
    0x1d, 0x73, 0x2a, 0x31, 0x64, 0x99, 0x4e, 0xa4, 0x42, 0x96, 0xe5, 0x58, 0x43, 0xf3, 0x34, 0x72,
    0xd3, 0x21, 0xaf, 0x5c, 0x11, 0x91, 0xd0, 0x7b, 0xdf, 0xb1, 0xd2, 0x25, 0x8e, 0xc1, 0xbd, 0xed,
    0xe9, 0x93, 0x0f, 0x56, 0xf9, 0x01, 0x88, 0x43, 0xc1, 0xdf, 0x0e, 0xc7, 0x8b, 0x8d, 0x63, 0x05,
    0x57, 0xc8, 0x11, 0xba, 0x79, 0xfc, 0x36, 0x5a, 0x76, 0x68, 0x35, 0x1e, 0xbe, 0x6d, 0xf2, 0xe2,
    0x42, 0x4a, 0x6e, 0x05, 0xbf, 0x5a, 0x5d, 0x4d, 0x35, 0xca, 0x5e, 0x47, 0x7a, 0x6c, 0x48, 0x3c,
    0xd8, 0x45, 0x90, 0x14, 0xd7, 0x79, 0xc8, 0x11, 0xa1, 0xe4, 0x24, 0xf0, 0x6c, 0x60, 0xe5, 0xda,
    0xab, 0x6f, 0x76, 0x32, 0xb7, 0x01, 0x55, 0x22, 0x45, 0xa7, 0xc1, 0x34, 0xd8, 0xad, 0xe9, 0x09,
    0x77, 0xb7, 0x69, 0xa3, 0xff, 0xf7, 0x46, 0xa3, 0xa7, 0x90, 0x17, 0xd9, 0x76, 0xa8, 0xab
};
#endif

PyTypeObject *init_QSemaphore(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX].type;

    Shiboken::AutoDecRef Sbk_QSemaphore_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSemaphore_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSemaphore",
        "QSemaphore*",
        &Sbk_QSemaphore_spec,
        &Shiboken::callCppDestructor< ::QSemaphore >,
        Sbk_QSemaphore_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSemaphore_TypeF(); // references _Sbk_QSemaphore_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSemaphore_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSemaphore_SignatureBytes, QSemaphore_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSemaphore_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QSemaphore_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSemaphore_PythonToCpp_QSemaphore_PTR,
        is_QSemaphore_PythonToCpp_QSemaphore_PTR_Convertible,
        QSemaphore_PTR_CppToPython_QSemaphore);

    Shiboken::Conversions::registerConverterName(converter, "QSemaphore");
    Shiboken::Conversions::registerConverterName(converter, "QSemaphore*");
    Shiboken::Conversions::registerConverterName(converter, "QSemaphore&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSemaphore).name());

    qRegisterMetaType< ::QSemaphore *>();

    return pyType;
}
