// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qsignalblocker_wrapper.h"

// Argument includes
#include <qobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSignalBlocker_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSignalBlocker >()))
        return -1;

    ::QSignalBlocker *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSignalBlocker", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSignalBlocker::QSignalBlocker(QObject&)
    // 1: QSignalBlocker::QSignalBlocker(QObject*)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSignalBlocker(QObject&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSignalBlocker_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QSignalBlocker_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSignalBlocker(QObject &o)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSignalBlocker(QObject&)
                cptr = new ::QSignalBlocker(*cppArg0);
            }
            break;
        }
        case 1: // QSignalBlocker(QObject *o)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSignalBlocker(QObject*)
                cptr = new ::QSignalBlocker(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSignalBlocker >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSignalBlocker_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSignalBlockerFunc___enter__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalBlocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSignalBlocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __enter__()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtcore.cpp (default-enter)]
        Py_INCREF(self);
        pyResult = self;
        // END of custom code block [file: ../glue/qtcore.cpp (default-enter)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSignalBlockerFunc___exit__(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalBlocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSignalBlocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "__exit__", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSignalBlocker::__exit__(PyObject*,PyObject*,PyObject*)
    if (numArgs == 3
        && true
        && true
        && true) {
        overloadId = 0; // __exit__(PyObject*,PyObject*,PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "__exit__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSignalBlocker_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __exit__(PyObject*,PyObject*,PyObject*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qsignalblocker-unblock)]
            cppSelf->unblock();
            // END of custom code block [file: ../glue/qtcore.cpp (qsignalblocker-unblock)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSignalBlockerFunc_dismiss(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalBlocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSignalBlocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dismiss()
        cppSelf->dismiss();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSignalBlockerFunc_reblock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalBlocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSignalBlocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reblock()
        cppSelf->reblock();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSignalBlockerFunc_unblock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSignalBlocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSignalBlocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unblock()
        cppSelf->unblock();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QSignalBlocker_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSignalBlocker_methods[] = {
    {"__enter__", reinterpret_cast<PyCFunction>(Sbk_QSignalBlockerFunc___enter__), METH_NOARGS, nullptr},
    {"__exit__", reinterpret_cast<PyCFunction>(Sbk_QSignalBlockerFunc___exit__), METH_VARARGS, nullptr},
    {"dismiss", reinterpret_cast<PyCFunction>(Sbk_QSignalBlockerFunc_dismiss), METH_NOARGS, nullptr},
    {"reblock", reinterpret_cast<PyCFunction>(Sbk_QSignalBlockerFunc_reblock), METH_NOARGS, nullptr},
    {"unblock", reinterpret_cast<PyCFunction>(Sbk_QSignalBlockerFunc_unblock), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSignalBlocker_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSignalBlocker_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSignalBlocker_Type = nullptr;
static PyTypeObject *Sbk_QSignalBlocker_TypeF(void)
{
    return _Sbk_QSignalBlocker_Type;
}

static PyType_Slot Sbk_QSignalBlocker_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSignalBlocker_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSignalBlocker_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSignalBlocker_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSignalBlocker_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSignalBlocker_spec = {
    "2:PySide6.QtCore.QSignalBlocker",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSignalBlocker_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSignalBlocker_PythonToCpp_QSignalBlocker_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSignalBlocker_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSignalBlocker_PythonToCpp_QSignalBlocker_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSignalBlocker_TypeF()))
        return QSignalBlocker_PythonToCpp_QSignalBlocker_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSignalBlocker_PTR_CppToPython_QSignalBlocker(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSignalBlocker_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSignalBlocker_SignatureStrings[] = {
    "1:PySide6.QtCore.QSignalBlocker(self,o:PySide6.QtCore.QObject)",
    "0:PySide6.QtCore.QSignalBlocker(self,o:PySide6.QtCore.QObject)",
    "PySide6.QtCore.QSignalBlocker.__enter__(self)->PySide6.QtCore.QSignalBlocker",
    "PySide6.QtCore.QSignalBlocker.__exit__(self,arg__1:PyObject,arg__2:PyObject,arg__3:PyObject)",
    "PySide6.QtCore.QSignalBlocker.dismiss(self)",
    "PySide6.QtCore.QSignalBlocker.reblock(self)",
    "PySide6.QtCore.QSignalBlocker.unblock(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QSignalBlocker_SignatureByteSize = 130;
static constexpr uint8_t QSignalBlocker_SignatureBytes[130] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0x0c, 0xce, 0x4c, 0xcf, 0x4b, 0xcc, 0x71, 0xca, 0xc9, 0x4f, 0xce, 0x4e,
    0x2d, 0xd2, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xc9, 0xc7, 0x50, 0xe4, 0x9f, 0x94, 0x95, 0x9a, 0x5c,
    0xa2, 0xc9, 0x65, 0x40, 0x99, 0x76, 0xbc, 0x9a, 0xf5, 0xe2, 0xe3, 0x53, 0xf3, 0x4a, 0x52, 0x8b,
    0xe2, 0xe3, 0xc1, 0xc6, 0x68, 0xea, 0xda, 0xe1, 0x55, 0x4e, 0xd8, 0xb0, 0x8a, 0xcc, 0x12, 0xa8,
    0x59, 0x3a, 0x89, 0x45, 0xe9, 0xf1, 0xf1, 0x86, 0x40, 0x77, 0x41, 0x5c, 0x02, 0xe1, 0x1b, 0xa1,
    0xf1, 0x8d, 0xe1, 0x7c, 0x42, 0x2e, 0x4d, 0xc9, 0x2c, 0xce, 0xcd, 0x2c, 0x2e, 0x86, 0xb8, 0x93,
    0x80, 0xda, 0xa2, 0xd4, 0x24, 0x10, 0x8b, 0x28, 0xb5, 0xa5, 0x79, 0xc8, 0x6a, 0x01, 0x01, 0x39,
    0x97, 0x44
};
#endif

PyTypeObject *init_QSignalBlocker(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QSignalBlocker_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QSignalBlocker_IDX].type;

    Shiboken::AutoDecRef Sbk_QSignalBlocker_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSignalBlocker_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSignalBlocker",
        "QSignalBlocker*",
        &Sbk_QSignalBlocker_spec,
        &Shiboken::callCppDestructor< ::QSignalBlocker >,
        Sbk_QSignalBlocker_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSignalBlocker_TypeF(); // references _Sbk_QSignalBlocker_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSignalBlocker_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSignalBlocker_SignatureBytes, QSignalBlocker_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSignalBlocker_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QSignalBlocker_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSignalBlocker_PythonToCpp_QSignalBlocker_PTR,
        is_QSignalBlocker_PythonToCpp_QSignalBlocker_PTR_Convertible,
        QSignalBlocker_PTR_CppToPython_QSignalBlocker);

    Shiboken::Conversions::registerConverterName(converter, "QSignalBlocker");
    Shiboken::Conversions::registerConverterName(converter, "QSignalBlocker*");
    Shiboken::Conversions::registerConverterName(converter, "QSignalBlocker&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSignalBlocker).name());

    qRegisterMetaType< ::QSignalBlocker *>();

    return pyType;
}
