// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qsizef_wrapper.h"

// Argument includes
#include <qmargins.h>
#include <qnamespace.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSizeF_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSizeF >()))
        return -1;

    ::QSizeF *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSizeF", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSizeF::QSizeF()
    // 1: QSizeF::QSizeF(QSize)
    // 2: QSizeF::QSizeF(QSizeF)
    // 3: QSizeF::QSizeF(qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // QSizeF()
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 3; // QSizeF(qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QSizeF(QSize)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QSizeF(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSizeF()
        {

            // QSizeF()
            cptr = new ::QSizeF();
            break;
        }
        case 1: // QSizeF(const QSize &sz)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSize cppArg0_local;
            ::QSize *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSizeF(QSize)
                cptr = new ::QSizeF(*cppArg0);
            }
            break;
        }
        case 2: // QSizeF(const QSizeF &QSizeF)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSizeF cppArg0_local;
            ::QSizeF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSizeF(QSizeF)
                cptr = new ::QSizeF(*cppArg0);
            }
            break;
        }
        case 3: // QSizeF(qreal w, qreal h)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSizeF(qreal,qreal)
                cptr = new ::QSizeF(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSizeF >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSizeFFunc___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __reduce__()
        // Begin code injection
        // TEMPLATE - reduce_code - START
        pyResult = Py_BuildValue("(N(dd))", PyObject_Type(self), cppSelf->width(), cppSelf->height());
        // TEMPLATE - reduce_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - repr_code - START
        QString format = QString::asprintf("%s(%f, %f)",
            Py_TYPE(self)->tp_name, cppSelf->width(), cppSelf->height());
        pyResult = Shiboken::String::fromCString(qPrintable(format));
        // TEMPLATE - repr_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc_boundedTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSizeF::boundedTo(QSizeF)const->QSizeF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
        overloadId = 0; // boundedTo(QSizeF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "boundedTo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSizeF cppArg0_local;
        ::QSizeF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // boundedTo(QSizeF)const
            QSizeF cppResult = const_cast<const ::QSizeF *>(cppSelf)->boundedTo(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc_expandedTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSizeF::expandedTo(QSizeF)const->QSizeF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
        overloadId = 0; // expandedTo(QSizeF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "expandedTo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSizeF cppArg0_local;
        ::QSizeF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // expandedTo(QSizeF)const
            QSizeF cppResult = const_cast<const ::QSizeF *>(cppSelf)->expandedTo(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc_grownBy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSizeF::grownBy(QMarginsF)const->QSizeF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMarginsF_IDX]), (pyArg)))) {
        overloadId = 0; // grownBy(QMarginsF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "grownBy", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMarginsF cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // grownBy(QMarginsF)const
            QSizeF cppResult = const_cast<const ::QSizeF *>(cppSelf)->grownBy(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc_height(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // height()const
        qreal cppResult = const_cast<const ::QSizeF *>(cppSelf)->height();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QSizeF *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QSizeF *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QSizeF *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc_scale(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "scale", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSizeF::scale(QSizeF,Qt::AspectRatioMode)
    // 1: QSizeF::scale(qreal,qreal,Qt::AspectRatioMode)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_AspectRatioMode_IDX])))->converter, (pyArgs[2])))) {
        overloadId = 1; // scale(qreal,qreal,Qt::AspectRatioMode)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_AspectRatioMode_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // scale(QSizeF,Qt::AspectRatioMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "scale", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // scale(const QSizeF &s, Qt::AspectRatioMode mode)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSizeF cppArg0_local;
            ::QSizeF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::Qt::AspectRatioMode cppArg1{Qt::IgnoreAspectRatio};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // scale(QSizeF,Qt::AspectRatioMode)
                cppSelf->scale(*cppArg0, cppArg1);
            }
            break;
        }
        case 1: // scale(qreal w, qreal h, Qt::AspectRatioMode mode)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::AspectRatioMode cppArg2{Qt::IgnoreAspectRatio};
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // scale(qreal,qreal,Qt::AspectRatioMode)
                cppSelf->scale(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSizeFFunc_scaled(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "scaled", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSizeF::scaled(QSizeF,Qt::AspectRatioMode)const->QSizeF
    // 1: QSizeF::scaled(qreal,qreal,Qt::AspectRatioMode)const->QSizeF
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_AspectRatioMode_IDX])))->converter, (pyArgs[2])))) {
        overloadId = 1; // scaled(qreal,qreal,Qt::AspectRatioMode)const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_AspectRatioMode_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // scaled(QSizeF,Qt::AspectRatioMode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "scaled", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // scaled(const QSizeF &s, Qt::AspectRatioMode mode) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSizeF cppArg0_local;
            ::QSizeF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::Qt::AspectRatioMode cppArg1{Qt::IgnoreAspectRatio};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // scaled(QSizeF,Qt::AspectRatioMode)const
                QSizeF cppResult = const_cast<const ::QSizeF *>(cppSelf)->scaled(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
            }
            break;
        }
        case 1: // scaled(qreal w, qreal h, Qt::AspectRatioMode mode) const
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::AspectRatioMode cppArg2{Qt::IgnoreAspectRatio};
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // scaled(qreal,qreal,Qt::AspectRatioMode)const
                QSizeF cppResult = const_cast<const ::QSizeF *>(cppSelf)->scaled(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc_setHeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSizeF::setHeight(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setHeight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeight", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeight(qreal)
            cppSelf->setHeight(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSizeFFunc_setWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSizeF::setWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWidth", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWidth(qreal)
            cppSelf->setWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSizeFFunc_shrunkBy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSizeF::shrunkBy(QMarginsF)const->QSizeF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMarginsF_IDX]), (pyArg)))) {
        overloadId = 0; // shrunkBy(QMarginsF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "shrunkBy", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMarginsF cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // shrunkBy(QMarginsF)const
            QSizeF cppResult = const_cast<const ::QSizeF *>(cppSelf)->shrunkBy(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc_toSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toSize()const
        QSize cppResult = const_cast<const ::QSizeF *>(cppSelf)->toSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc_toTuple(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toTuple()
        // Begin code injection
        // TEMPLATE - to_tuple - START
        pyResult = Py_BuildValue("dd", cppSelf->width(), cppSelf->height());
        // TEMPLATE - to_tuple - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc_transpose(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // transpose()
        cppSelf->transpose();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSizeFFunc_transposed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // transposed()const
        QSizeF cppResult = const_cast<const ::QSizeF *>(cppSelf)->transposed();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc_width(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // width()const
        qreal cppResult = const_cast<const ::QSizeF *>(cppSelf)->width();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeF__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSizeF_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSizeF_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc___reduce__), METH_NOARGS, nullptr},
    {"boundedTo", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_boundedTo), METH_O, nullptr},
    {"expandedTo", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_expandedTo), METH_O, nullptr},
    {"grownBy", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_grownBy), METH_O, nullptr},
    {"height", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_height), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_isEmpty), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_isNull), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_isValid), METH_NOARGS, nullptr},
    {"scale", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_scale), METH_VARARGS, nullptr},
    {"scaled", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_scaled), METH_VARARGS, nullptr},
    {"setHeight", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_setHeight), METH_O, nullptr},
    {"setWidth", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_setWidth), METH_O, nullptr},
    {"shrunkBy", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_shrunkBy), METH_O, nullptr},
    {"toSize", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_toSize), METH_NOARGS, nullptr},
    {"toTuple", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_toTuple), METH_NOARGS, nullptr},
    {"transpose", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_transpose), METH_NOARGS, nullptr},
    {"transposed", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_transposed), METH_NOARGS, nullptr},
    {"width", reinterpret_cast<PyCFunction>(Sbk_QSizeFFunc_width), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSizeF__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSizeF___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

static PyObject *Sbk_QSizeFFunc___mul__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSizeF::operator*(qreal)->QSizeF
    // 1: QSizeF::operator*(qreal)->QSizeF
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 1; // operator*(QSizeF,qreal)
    } else if (isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // operator*(qreal,QSizeF)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator*", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // operator*(qreal c)
        {
            qreal cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(qreal,QSizeF) [reverse operator]
                QSizeF cppResult = cppArg0 * (*cppSelf);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
            }
            break;
        }
        case 1: // operator*(qreal c)
        {
            qreal cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QSizeF,qreal)
                QSizeF cppResult = (*cppSelf) * cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc___imul__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSizeF::operator*=(qreal)->QSizeF&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // operator*=(qreal)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator*=", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator*=(qreal)
            (*cppSelf) *= cppArg0;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QSizeFFunc___add__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSizeF::operator+(QSizeF)->QSizeF
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
        overloadId = 0; // operator+(QSizeF,QSizeF)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSizeF cppArg0_local;
        ::QSizeF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+(QSizeF,QSizeF)
            QSizeF cppResult = (*cppSelf) + (*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSizeF::operator+=(QSizeF)->QSizeF&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
        overloadId = 0; // operator+=(QSizeF)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+=", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSizeF cppArg0_local;
        ::QSizeF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+=(QSizeF)
            (*cppSelf) += (*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QSizeFFunc___sub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSizeF::operator-(QSizeF)->QSizeF
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
        overloadId = 0; // operator-(QSizeF,QSizeF)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSizeF cppArg0_local;
        ::QSizeF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator-(QSizeF,QSizeF)
            QSizeF cppResult = (*cppSelf) - (*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSizeFFunc___isub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSizeF::operator-=(QSizeF)->QSizeF&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
        overloadId = 0; // operator-=(QSizeF)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-=", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSizeF cppArg0_local;
        ::QSizeF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator-=(QSizeF)
            (*cppSelf) -= (*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QSizeFFunc___div__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSizeF::operator/(qreal)->QSizeF
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // operator/(QSizeF,qreal)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator/", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator/(QSizeF,qreal)
            QSizeF cppResult = (*cppSelf) / cppArg0;
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QSizeF_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
                // operator!=(const QSize &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSize cppArg0_local;
                ::QSize *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
                // operator!=(const QSizeF &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSizeF cppArg0_local;
                ::QSizeF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
                // operator==(const QSize &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSize cppArg0_local;
                ::QSize *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
                // operator==(const QSizeF &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSizeF cppArg0_local;
                ::QSizeF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QSizeF_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSizeF_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSizeF_Type = nullptr;
static PyTypeObject *Sbk_QSizeF_TypeF(void)
{
    return _Sbk_QSizeF_Type;
}

static PyType_Slot Sbk_QSizeF_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QSizeFFunc___repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSizeF_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSizeF_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QSizeF_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSizeF_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSizeF_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QSizeFFunc___iadd__)},
    {Py_nb_subtract,    reinterpret_cast<void *>(Sbk_QSizeFFunc___sub__)},
    {Py_nb_inplace_multiply,reinterpret_cast<void *>(Sbk_QSizeFFunc___imul__)},
    {Py_nb_multiply,    reinterpret_cast<void *>(Sbk_QSizeFFunc___mul__)},
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QSizeF___nb_bool)},
    {Py_nb_inplace_subtract,reinterpret_cast<void *>(Sbk_QSizeFFunc___isub__)},
    {Py_nb_true_divide, reinterpret_cast<void *>(Sbk_QSizeFFunc___div__)},
    {Py_nb_add,         reinterpret_cast<void *>(Sbk_QSizeFFunc___add__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSizeF_spec = {
    "2:PySide6.QtCore.QSizeF",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSizeF_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSizeF_PythonToCpp_QSizeF_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSizeF_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSizeF_PythonToCpp_QSizeF_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSizeF_TypeF()))
        return QSizeF_PythonToCpp_QSizeF_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSizeF_PTR_CppToPython_QSizeF(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSizeF_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QSizeF_COPY_CppToPython_QSizeF(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSizeF *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSizeF_TypeF(), new ::QSizeF(*source), true, true);
}

// Python to C++ copy conversion.
static void QSizeF_PythonToCpp_QSizeF_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSizeF *>(cppOut) = *reinterpret_cast< ::QSizeF *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QSizeF_PythonToCpp_QSizeF_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSizeF_TypeF()))
        return QSizeF_PythonToCpp_QSizeF_COPY;
    return {};
}

// Implicit conversions.
static void constQSizeREF_PythonToCpp_QSizeF(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSizeF *>(cppOut) = ::QSizeF( *reinterpret_cast< ::QSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQSizeREF_PythonToCpp_QSizeF_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyIn))
        return constQSizeREF_PythonToCpp_QSizeF;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSizeF_SignatureStrings[] = {
    "3:PySide6.QtCore.QSizeF(self)",
    "2:PySide6.QtCore.QSizeF(self,sz:PySide6.QtCore.QSize)",
    "1:PySide6.QtCore.QSizeF(self,QSizeF:PySide6.QtCore.QSizeF)",
    "0:PySide6.QtCore.QSizeF(self,w:qreal,h:qreal)",
    "PySide6.QtCore.QSizeF.__reduce__(self)->str",
    "PySide6.QtCore.QSizeF.__repr__(self)->str",
    "PySide6.QtCore.QSizeF.boundedTo(self,arg__1:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])->PySide6.QtCore.QSizeF",
    "PySide6.QtCore.QSizeF.expandedTo(self,arg__1:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])->PySide6.QtCore.QSizeF",
    "PySide6.QtCore.QSizeF.grownBy(self,m:typing.Union[PySide6.QtCore.QMarginsF, PySide6.QtCore.QMargins])->PySide6.QtCore.QSizeF",
    "PySide6.QtCore.QSizeF.height(self)->qreal",
    "PySide6.QtCore.QSizeF.isEmpty(self)->bool",
    "PySide6.QtCore.QSizeF.isNull(self)->bool",
    "PySide6.QtCore.QSizeF.isValid(self)->bool",
    "1:PySide6.QtCore.QSizeF.scale(self,s:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize],mode:PySide6.QtCore.Qt.AspectRatioMode)",
    "0:PySide6.QtCore.QSizeF.scale(self,w:qreal,h:qreal,mode:PySide6.QtCore.Qt.AspectRatioMode)",
    "1:PySide6.QtCore.QSizeF.scaled(self,s:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize],mode:PySide6.QtCore.Qt.AspectRatioMode)->PySide6.QtCore.QSizeF",
    "0:PySide6.QtCore.QSizeF.scaled(self,w:qreal,h:qreal,mode:PySide6.QtCore.Qt.AspectRatioMode)->PySide6.QtCore.QSizeF",
    "PySide6.QtCore.QSizeF.setHeight(self,h:qreal)",
    "PySide6.QtCore.QSizeF.setWidth(self,w:qreal)",
    "PySide6.QtCore.QSizeF.shrunkBy(self,m:typing.Union[PySide6.QtCore.QMarginsF, PySide6.QtCore.QMargins])->PySide6.QtCore.QSizeF",
    "PySide6.QtCore.QSizeF.toSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtCore.QSizeF.toTuple(self)->PyObject",
    "PySide6.QtCore.QSizeF.transpose(self)",
    "PySide6.QtCore.QSizeF.transposed(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtCore.QSizeF.width(self)->qreal",
    "PySide6.QtCore.QSizeF.__copy__(self)->typing.Self",
    "1:PySide6.QtCore.QSizeF.__mul__(self,c:qreal)->PySide6.QtCore.QSizeF",
    "0:PySide6.QtCore.QSizeF.__mul__(self,c:qreal)->PySide6.QtCore.QSizeF",
    "PySide6.QtCore.QSizeF.__imul__(self,c:qreal)->PySide6.QtCore.QSizeF",
    "PySide6.QtCore.QSizeF.__add__(self,s2:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])->PySide6.QtCore.QSizeF",
    "PySide6.QtCore.QSizeF.__iadd__(self,arg__1:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])->PySide6.QtCore.QSizeF",
    "PySide6.QtCore.QSizeF.__sub__(self,s2:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])->PySide6.QtCore.QSizeF",
    "PySide6.QtCore.QSizeF.__isub__(self,arg__1:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])->PySide6.QtCore.QSizeF",
    "PySide6.QtCore.QSizeF.__div__(self,c:qreal)->PySide6.QtCore.QSizeF",
    "1:PySide6.QtCore.QSizeF.__ne__(self,rhs:PySide6.QtCore.QSize)->bool",
    "0:PySide6.QtCore.QSizeF.__ne__(self,rhs:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])->bool",
    "1:PySide6.QtCore.QSizeF.__eq__(self,rhs:PySide6.QtCore.QSize)->bool",
    "0:PySide6.QtCore.QSizeF.__eq__(self,rhs:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QSizeF_SignatureByteSize = 439;
static constexpr uint8_t QSizeF_SignatureBytes[439] = {
    0x78, 0xda, 0xc5, 0x56, 0x3d, 0x4f, 0xc3, 0x30, 0x10, 0xdd, 0xfb, 0x2b, 0x18, 0x89, 0x14, 0xa2,
    0xb6, 0x48, 0x0c, 0x1d, 0x90, 0x00, 0x81, 0x58, 0x0a, 0x94, 0x16, 0x18, 0x10, 0xb2, 0x9c, 0xd8,
    0x24, 0x06, 0xc7, 0x4e, 0x6d, 0x87, 0x12, 0x7e, 0x3d, 0x81, 0x24, 0x34, 0x05, 0xdb, 0x4d, 0x5a,
    0x94, 0x4e, 0xf9, 0xf0, 0xbb, 0x7b, 0xef, 0xce, 0x77, 0x3e, 0x1f, 0x8e, 0x6e, 0xb2, 0x29, 0x41,
    0xf8, 0xc8, 0x9b, 0xa8, 0x33, 0x2e, 0xb0, 0x37, 0x99, 0x92, 0x0f, 0x7c, 0xb1, 0x2f, 0x31, 0x7d,
    0x76, 0x7a, 0x43, 0xcb, 0xaa, 0x2b, 0x3f, 0xb4, 0xab, 0x4e, 0x6f, 0x60, 0xb3, 0x2a, 0xde, 0xf5,
    0x08, 0xa7, 0xd7, 0xb7, 0x99, 0x2e, 0x46, 0x73, 0x81, 0x21, 0x75, 0xa3, 0xe2, 0xe9, 0xf4, 0xb4,
    0x58, 0x0f, 0x00, 0x81, 0x51, 0x1a, 0x60, 0x00, 0x8a, 0x28, 0x0e, 0x8e, 0xa5, 0x12, 0x16, 0x6c,
    0x22, 0x9a, 0x20, 0x7d, 0x9e, 0x32, 0x84, 0xd1, 0x8c, 0x17, 0x5a, 0xa0, 0x08, 0x01, 0x18, 0x8c,
    0x54, 0x96, 0x10, 0x16, 0x7a, 0x77, 0x8c, 0x70, 0xf6, 0xa8, 0x35, 0x74, 0xf7, 0x74, 0xbf, 0x9f,
    0x72, 0x2e, 0x2d, 0xdc, 0xc0, 0x8e, 0xdf, 0x13, 0xb8, 0x43, 0xfa, 0x50, 0xf0, 0x05, 0x3b, 0xcd,
    0x0a, 0xee, 0xd8, 0x4e, 0x3b, 0xce, 0xb5, 0x11, 0x26, 0x35, 0xcc, 0xe5, 0x4a, 0x5b, 0xf2, 0x08,
    0x93, 0x30, 0x52, 0xd5, 0x0e, 0x7d, 0x6f, 0xbd, 0x01, 0x49, 0xe4, 0x79, 0x9c, 0xa8, 0xac, 0x82,
    0xfa, 0x9c, 0x9b, 0x91, 0x57, 0x29, 0xa5, 0x8d, 0x80, 0xf7, 0x90, 0x12, 0xb4, 0x82, 0x34, 0xd4,
    0xb7, 0x27, 0x03, 0x48, 0x71, 0xd9, 0x1b, 0x9b, 0x6f, 0x8d, 0x1b, 0x73, 0x84, 0xff, 0x30, 0x28,
    0xef, 0x44, 0x26, 0x38, 0x50, 0xb7, 0x50, 0x11, 0x3e, 0xce, 0x11, 0xc6, 0x5e, 0xa9, 0xcb, 0xf8,
    0xd5, 0x31, 0x8d, 0x5d, 0x5b, 0x23, 0x44, 0x9d, 0x85, 0x68, 0xaa, 0x93, 0x7e, 0x03, 0x79, 0x1b,
    0x86, 0xde, 0xae, 0x34, 0x25, 0x56, 0x97, 0xcb, 0xea, 0x5c, 0x77, 0x30, 0xe5, 0xe8, 0x07, 0x82,
    0x54, 0xb4, 0x22, 0xd0, 0x08, 0x8e, 0x44, 0xca, 0x5e, 0x77, 0xd5, 0x73, 0x8a, 0x7f, 0x3d, 0xab,
    0xaa, 0xd7, 0x61, 0x8c, 0x86, 0xb3, 0x34, 0xa1, 0x35, 0xcb, 0x6b, 0xff, 0x25, 0x4f, 0xb0, 0x09,
    0x2d, 0x20, 0x93, 0x09, 0x97, 0x25, 0x7e, 0x1d, 0x0a, 0xd9, 0x04, 0x99, 0x42, 0x59, 0xfc, 0xa4,
    0x7c, 0xcd, 0xe9, 0x01, 0x40, 0xc0, 0x93, 0x6c, 0x39, 0x0b, 0xca, 0x8c, 0x4f, 0xf3, 0x2f, 0x63,
    0x43, 0x00, 0x10, 0xa7, 0xb4, 0x34, 0x71, 0x83, 0x72, 0x47, 0xdb, 0x96, 0x6d, 0x2b, 0x27, 0x26,
    0x17, 0xe4, 0x1f, 0x7c, 0x40, 0x84, 0x2a, 0x17, 0x72, 0xd8, 0xd9, 0x70, 0xc9, 0xb5, 0xd7, 0x88,
    0x3b, 0x9e, 0x6c, 0x00, 0xc8, 0xd4, 0xdf, 0x4d, 0xd0, 0x35, 0xe2, 0xce, 0x83, 0x46, 0xe4, 0xad,
    0x69, 0xb1, 0x98, 0x4b, 0x9f, 0x55, 0x57, 0x2c, 0x57, 0x44, 0x52, 0x7f, 0x17, 0x2c, 0x27, 0x66,
    0xbf, 0xa1, 0x8f, 0x6d, 0x12, 0x60, 0x1d, 0xcd, 0x00, 0xe0, 0xf9, 0xf6, 0x62, 0x57, 0x7d, 0x6c,
    0x2d, 0xf6, 0x13, 0x09, 0x2c, 0xfa, 0x99
};
#endif

PyTypeObject *init_QSizeF(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX].type;

    Shiboken::AutoDecRef Sbk_QSizeF_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSizeF_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSizeF",
        "QSizeF",
        &Sbk_QSizeF_spec,
        &Shiboken::callCppDestructor< ::QSizeF >,
        Sbk_QSizeF_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSizeF_TypeF(); // references _Sbk_QSizeF_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSizeF_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSizeF_SignatureBytes, QSizeF_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSizeF_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSizeF_PythonToCpp_QSizeF_PTR,
        is_QSizeF_PythonToCpp_QSizeF_PTR_Convertible,
        QSizeF_PTR_CppToPython_QSizeF,
        QSizeF_COPY_CppToPython_QSizeF);

    Shiboken::Conversions::registerConverterName(converter, "QSizeF");
    Shiboken::Conversions::registerConverterName(converter, "QSizeF*");
    Shiboken::Conversions::registerConverterName(converter, "QSizeF&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSizeF).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QSizeF_PythonToCpp_QSizeF_COPY,
        is_QSizeF_PythonToCpp_QSizeF_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQSizeREF_PythonToCpp_QSizeF,
        is_constQSizeREF_PythonToCpp_QSizeF_Convertible);

    qRegisterMetaType< ::QSizeF >("QSizeF");

    return pyType;
}
