// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qsocketdescriptor_wrapper.h"

// Argument includes
#include <qsocketnotifier.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (qsocketdescriptor)]
#ifdef WIN32
using DescriptorType = Qt::HANDLE;
#else
using DescriptorType = int;
#endif
// END of custom code block [file: ../glue/qtcore.cpp (qsocketdescriptor)]
// ========================================================================
// End of code injection



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSocketDescriptor_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSocketDescriptor >()))
        return -1;

    ::QSocketDescriptor *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]);

    if (PyArg_ParseTuple(args, "|O:QSocketDescriptor", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSocketDescriptor::QSocketDescriptor(QSocketDescriptor)
    // 1: QSocketDescriptor::QSocketDescriptor(int=)
    if (numArgs == 0) {
        overloadId = 1; // QSocketDescriptor(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 1; // QSocketDescriptor(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSocketDescriptor(QSocketDescriptor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSocketDescriptor(const QSocketDescriptor &QSocketDescriptor)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSocketDescriptor cppArg0_local;
            ::QSocketDescriptor *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSocketDescriptor(QSocketDescriptor)
                cptr = new ::QSocketDescriptor(*cppArg0);
            }
            break;
        }
        case 1: // QSocketDescriptor(int descriptor)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_descriptor = Shiboken::String::createStaticString("descriptor");
                if (PyDict_Contains(kwds, key_descriptor) != 0) {
                    value = PyDict_GetItem(kwds, key_descriptor);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_descriptor);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_descriptor);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]);
                }
            }
            int cppArg0 = DescriptorType(-1);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSocketDescriptor(int)
                cptr = new ::QSocketDescriptor(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSocketDescriptor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSocketDescriptorFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSocketDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QSocketDescriptor *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSocketDescriptor__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSocketDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSocketDescriptor_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSocketDescriptor_methods[] = {
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QSocketDescriptorFunc_isValid), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSocketDescriptor__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QSocketDescriptor_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSocketDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]), (pyArg)))) {
                // operator!=(const QSocketDescriptor &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSocketDescriptor cppArg0_local;
                ::QSocketDescriptor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]), (pyArg)))) {
                // operator==(const QSocketDescriptor &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSocketDescriptor cppArg0_local;
                ::QSocketDescriptor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QSocketDescriptor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSocketDescriptor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSocketDescriptor_Type = nullptr;
static PyTypeObject *Sbk_QSocketDescriptor_TypeF(void)
{
    return _Sbk_QSocketDescriptor_Type;
}

static PyType_Slot Sbk_QSocketDescriptor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSocketDescriptor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSocketDescriptor_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QSocketDescriptor_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSocketDescriptor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSocketDescriptor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSocketDescriptor_spec = {
    "2:PySide6.QtCore.QSocketDescriptor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSocketDescriptor_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSocketDescriptor_PythonToCpp_QSocketDescriptor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSocketDescriptor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSocketDescriptor_PythonToCpp_QSocketDescriptor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSocketDescriptor_TypeF()))
        return QSocketDescriptor_PythonToCpp_QSocketDescriptor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSocketDescriptor_PTR_CppToPython_QSocketDescriptor(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSocketDescriptor_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QSocketDescriptor_COPY_CppToPython_QSocketDescriptor(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSocketDescriptor *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSocketDescriptor_TypeF(), new ::QSocketDescriptor(*source), true, true);
}

// Python to C++ copy conversion.
static void QSocketDescriptor_PythonToCpp_QSocketDescriptor_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSocketDescriptor *>(cppOut) = *reinterpret_cast< ::QSocketDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QSocketDescriptor_PythonToCpp_QSocketDescriptor_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSocketDescriptor_TypeF()))
        return QSocketDescriptor_PythonToCpp_QSocketDescriptor_COPY;
    return {};
}

// Implicit conversions.
static void int_PythonToCpp_QSocketDescriptor(PyObject *pyIn, void *cppOut)
{
    int cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn, &cppIn);
    *reinterpret_cast<::QSocketDescriptor *>(cppOut) = ::QSocketDescriptor(cppIn);
}
static PythonToCppFunc is_int_PythonToCpp_QSocketDescriptor_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return int_PythonToCpp_QSocketDescriptor;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSocketDescriptor_SignatureStrings[] = {
    "1:PySide6.QtCore.QSocketDescriptor(self,QSocketDescriptor:PySide6.QtCore.QSocketDescriptor)",
    "0:PySide6.QtCore.QSocketDescriptor(self,descriptor:int=DescriptorType(-1))",
    "PySide6.QtCore.QSocketDescriptor.isValid(self)->bool",
    "PySide6.QtCore.QSocketDescriptor.__copy__(self)->typing.Self",
    "PySide6.QtCore.QSocketDescriptor.__ne__(self,rhs:typing.Union[PySide6.QtCore.QSocketDescriptor, int])->bool",
    "PySide6.QtCore.QSocketDescriptor.__eq__(self,rhs:typing.Union[PySide6.QtCore.QSocketDescriptor, int])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QSocketDescriptor_SignatureByteSize = 152;
static constexpr uint8_t QSocketDescriptor_SignatureBytes[152] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0x0c, 0xce, 0x4f, 0xce, 0x4e, 0x2d, 0x71, 0x49, 0x2d, 0x4e, 0x2e, 0xca,
    0x2c, 0x28, 0xc9, 0x2f, 0xd2, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xc1, 0x10, 0x26, 0xa8, 0x4f, 0x93,
    0xcb, 0x80, 0x48, 0xb3, 0x53, 0x10, 0x86, 0x66, 0xe6, 0x95, 0xd8, 0x22, 0xa4, 0x43, 0x2a, 0x0b,
    0x52, 0x35, 0x74, 0x0d, 0x35, 0x35, 0xb9, 0x08, 0x19, 0xa4, 0x97, 0x59, 0x1c, 0x96, 0x98, 0x93,
    0x99, 0x02, 0x36, 0x50, 0x53, 0xd7, 0x2e, 0x29, 0x3f, 0x3f, 0x87, 0xb0, 0xa6, 0xf8, 0xf8, 0xe4,
    0xfc, 0x82, 0xca, 0xf8, 0x78, 0x98, 0xae, 0x92, 0xca, 0x82, 0xcc, 0xbc, 0x74, 0xbd, 0x60, 0x20,
    0x8f, 0x18, 0xcd, 0x79, 0xa9, 0x50, 0xad, 0x3a, 0x45, 0x19, 0xc5, 0x56, 0x50, 0xcd, 0xa1, 0x79,
    0x99, 0xf9, 0x79, 0xd1, 0x84, 0x74, 0xeb, 0x28, 0x00, 0x7d, 0x1a, 0x4b, 0x82, 0x43, 0x53, 0x0b,
    0xa9, 0x64, 0x17, 0x00, 0x47, 0x39, 0xb5, 0x16
};
#endif

PyTypeObject *init_QSocketDescriptor(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX].type;

    Shiboken::AutoDecRef Sbk_QSocketDescriptor_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSocketDescriptor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSocketDescriptor",
        "QSocketDescriptor",
        &Sbk_QSocketDescriptor_spec,
        &Shiboken::callCppDestructor< ::QSocketDescriptor >,
        Sbk_QSocketDescriptor_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSocketDescriptor_TypeF(); // references _Sbk_QSocketDescriptor_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSocketDescriptor_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSocketDescriptor_SignatureBytes, QSocketDescriptor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSocketDescriptor_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QSocketDescriptor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSocketDescriptor_PythonToCpp_QSocketDescriptor_PTR,
        is_QSocketDescriptor_PythonToCpp_QSocketDescriptor_PTR_Convertible,
        QSocketDescriptor_PTR_CppToPython_QSocketDescriptor,
        QSocketDescriptor_COPY_CppToPython_QSocketDescriptor);

    Shiboken::Conversions::registerConverterName(converter, "QSocketDescriptor");
    Shiboken::Conversions::registerConverterName(converter, "QSocketDescriptor*");
    Shiboken::Conversions::registerConverterName(converter, "QSocketDescriptor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSocketDescriptor).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QSocketDescriptor_PythonToCpp_QSocketDescriptor_COPY,
        is_QSocketDescriptor_PythonToCpp_QSocketDescriptor_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        int_PythonToCpp_QSocketDescriptor,
        is_int_PythonToCpp_QSocketDescriptor_Convertible);



    qRegisterMetaType< ::QSocketDescriptor >("QSocketDescriptor");

    return pyType;
}

