// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qstandardpaths_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qstandardpaths.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QStandardPathsFunc_displayName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QStandardPaths::displayName(QStandardPaths::StandardLocation)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_StandardLocation_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // displayName(QStandardPaths::StandardLocation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "displayName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);

    // Call function/method
    {
        ::QStandardPaths::StandardLocation cppArg0{QStandardPaths::DesktopLocation};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // displayName(QStandardPaths::StandardLocation)
            QString cppResult = ::QStandardPaths::displayName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStandardPathsFunc_findExecutable(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "findExecutable", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);

    if (PyArg_ParseTuple(args, "|OO:findExecutable", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QStandardPaths::findExecutable(QString,const QStringList&=)->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // findExecutable(QString,QStringList)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1])))) {
            overloadId = 0; // findExecutable(QString,QStringList)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "findExecutable", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_paths = Shiboken::String::createStaticString("paths");
            if (PyDict_Contains(kwds, key_paths) != 0) {
                value = PyDict_GetItem(kwds, key_paths);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_paths);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "findExecutable", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "findExecutable", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_paths);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "findExecutable", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QStringList cppArg1 = QStringList();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // findExecutable(QString,QStringList)
            QString cppResult = ::QStandardPaths::findExecutable(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStandardPathsFunc_isTestModeEnabled(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isTestModeEnabled()
        bool cppResult = ::QStandardPaths::isTestModeEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStandardPathsFunc_locate(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "locate", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:locate", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QStandardPaths::locate(QStandardPaths::StandardLocation,QString,QFlags<QStandardPaths::LocateOption>=)->QString
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_StandardLocation_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // locate(QStandardPaths::StandardLocation,QString,QFlags<QStandardPaths::LocateOption>)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStandardPaths_LocateOption_IDX])))->flagsConverter, (pyArgs[2])))) {
            overloadId = 0; // locate(QStandardPaths::StandardLocation,QString,QFlags<QStandardPaths::LocateOption>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "locate", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "locate", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStandardPaths_LocateOption_IDX])))->flagsConverter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "locate", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "locate", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);
            }
        }
        ::QStandardPaths::StandardLocation cppArg0{QStandardPaths::DesktopLocation};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QFlags<QStandardPaths::LocateOption> cppArg2(QStandardPaths::LocateOption::LocateFile);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // locate(QStandardPaths::StandardLocation,QString,QFlags<QStandardPaths::LocateOption>)
            QString cppResult = ::QStandardPaths::locate(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStandardPathsFunc_locateAll(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "locateAll", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:locateAll", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QStandardPaths::locateAll(QStandardPaths::StandardLocation,QString,QFlags<QStandardPaths::LocateOption>=)->QStringList
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_StandardLocation_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // locateAll(QStandardPaths::StandardLocation,QString,QFlags<QStandardPaths::LocateOption>)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStandardPaths_LocateOption_IDX])))->flagsConverter, (pyArgs[2])))) {
            overloadId = 0; // locateAll(QStandardPaths::StandardLocation,QString,QFlags<QStandardPaths::LocateOption>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "locateAll", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "locateAll", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStandardPaths_LocateOption_IDX])))->flagsConverter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "locateAll", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "locateAll", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);
            }
        }
        ::QStandardPaths::StandardLocation cppArg0{QStandardPaths::DesktopLocation};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QFlags<QStandardPaths::LocateOption> cppArg2(QStandardPaths::LocateOption::LocateFile);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // locateAll(QStandardPaths::StandardLocation,QString,QFlags<QStandardPaths::LocateOption>)
            QStringList cppResult = ::QStandardPaths::locateAll(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStandardPathsFunc_setTestModeEnabled(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QStandardPaths::setTestModeEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setTestModeEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTestModeEnabled", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTestModeEnabled(bool)
            ::QStandardPaths::setTestModeEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStandardPathsFunc_standardLocations(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QStandardPaths::standardLocations(QStandardPaths::StandardLocation)->QStringList
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_StandardLocation_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // standardLocations(QStandardPaths::StandardLocation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "standardLocations", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);

    // Call function/method
    {
        ::QStandardPaths::StandardLocation cppArg0{QStandardPaths::DesktopLocation};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // standardLocations(QStandardPaths::StandardLocation)
            QStringList cppResult = ::QStandardPaths::standardLocations(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStandardPathsFunc_writableLocation(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QStandardPaths::writableLocation(QStandardPaths::StandardLocation)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_StandardLocation_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // writableLocation(QStandardPaths::StandardLocation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "writableLocation", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX]);

    // Call function/method
    {
        ::QStandardPaths::StandardLocation cppArg0{QStandardPaths::DesktopLocation};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writableLocation(QStandardPaths::StandardLocation)
            QString cppResult = ::QStandardPaths::writableLocation(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QStandardPaths_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QStandardPaths_EnumFlagInfo[] = {
    "LocateOption:Flag:LocateOptions",
    "StandardLocation:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStandardPaths_methods[] = {
    {"displayName", reinterpret_cast<PyCFunction>(Sbk_QStandardPathsFunc_displayName), METH_O|METH_STATIC, nullptr},
    {"findExecutable", reinterpret_cast<PyCFunction>(Sbk_QStandardPathsFunc_findExecutable), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"isTestModeEnabled", reinterpret_cast<PyCFunction>(Sbk_QStandardPathsFunc_isTestModeEnabled), METH_NOARGS|METH_STATIC, nullptr},
    {"locate", reinterpret_cast<PyCFunction>(Sbk_QStandardPathsFunc_locate), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"locateAll", reinterpret_cast<PyCFunction>(Sbk_QStandardPathsFunc_locateAll), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"setTestModeEnabled", reinterpret_cast<PyCFunction>(Sbk_QStandardPathsFunc_setTestModeEnabled), METH_O|METH_STATIC, nullptr},
    {"standardLocations", reinterpret_cast<PyCFunction>(Sbk_QStandardPathsFunc_standardLocations), METH_O|METH_STATIC, nullptr},
    {"writableLocation", reinterpret_cast<PyCFunction>(Sbk_QStandardPathsFunc_writableLocation), METH_O|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStandardPaths_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStandardPaths_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStandardPaths_Type = nullptr;
static PyTypeObject *Sbk_QStandardPaths_TypeF(void)
{
    return _Sbk_QStandardPaths_Type;
}

static PyType_Slot Sbk_QStandardPaths_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(SbkDeallocWrapperWithPrivateDtor)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStandardPaths_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStandardPaths_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStandardPaths_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStandardPaths_spec = {
    "2:PySide6.QtCore.QStandardPaths",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStandardPaths_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QStandardPaths_StandardLocation(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStandardPaths::StandardLocation>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStandardPaths::StandardLocation *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStandardPaths_StandardLocation_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_StandardLocation_IDX])))
        return Enum_PythonToCpp_QStandardPaths_StandardLocation;
    return {};
}

static PyObject *QStandardPaths_StandardLocation_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStandardPaths::StandardLocation>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStandardPaths::StandardLocation *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_StandardLocation_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QStandardPaths_LocateOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStandardPaths::LocateOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStandardPaths::LocateOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStandardPaths_LocateOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_LocateOption_IDX])))
        return Enum_PythonToCpp_QStandardPaths_LocateOption;
    return {};
}

static PyObject *QStandardPaths_LocateOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStandardPaths::LocateOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStandardPaths::LocateOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_LocateOption_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QStandardPaths_LocateOption(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QStandardPaths::LocateOption>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QStandardPaths::LocateOption> *>(cppOut) = value;

}

static PyObject *QStandardPaths_LocateOption_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QStandardPaths::LocateOption> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_LocateOption_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStandardPaths_PythonToCpp_QStandardPaths_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStandardPaths_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStandardPaths_PythonToCpp_QStandardPaths_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStandardPaths_TypeF()))
        return QStandardPaths_PythonToCpp_QStandardPaths_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStandardPaths_PTR_CppToPython_QStandardPaths(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStandardPaths_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStandardPaths_SignatureStrings[] = {
    "PySide6.QtCore.QStandardPaths.displayName(type:PySide6.QtCore.QStandardPaths.StandardLocation)->QString",
    "PySide6.QtCore.QStandardPaths.findExecutable(executableName:QString,paths:QStringList=QStringList())->QString",
    "PySide6.QtCore.QStandardPaths.isTestModeEnabled()->bool",
    "PySide6.QtCore.QStandardPaths.locate(type:PySide6.QtCore.QStandardPaths.StandardLocation,fileName:QString,options:PySide6.QtCore.QStandardPaths.LocateOption=QStandardPaths.LocateOption.LocateFile)->QString",
    "PySide6.QtCore.QStandardPaths.locateAll(type:PySide6.QtCore.QStandardPaths.StandardLocation,fileName:QString,options:PySide6.QtCore.QStandardPaths.LocateOption=QStandardPaths.LocateOption.LocateFile)->QStringList",
    "PySide6.QtCore.QStandardPaths.setTestModeEnabled(testMode:bool)",
    "PySide6.QtCore.QStandardPaths.standardLocations(type:PySide6.QtCore.QStandardPaths.StandardLocation)->QStringList",
    "PySide6.QtCore.QStandardPaths.writableLocation(type:PySide6.QtCore.QStandardPaths.StandardLocation)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QStandardPaths_SignatureByteSize = 218;
static constexpr uint8_t QStandardPaths_SignatureBytes[218] = {
    0x78, 0xda, 0xd5, 0x53, 0x4d, 0x0f, 0x82, 0x30, 0x0c, 0xbd, 0xfb, 0x4b, 0x46, 0x82, 0x1c, 0x3d,
    0x90, 0x60, 0x62, 0x0c, 0x9e, 0xfc, 0x80, 0xe0, 0x1f, 0x18, 0xac, 0x68, 0x93, 0xb9, 0x11, 0x56,
    0xa3, 0xfc, 0x7b, 0x19, 0x82, 0x31, 0x1c, 0x80, 0xc8, 0xc9, 0x5b, 0xdf, 0xd6, 0xd7, 0xb7, 0xd7,
    0x76, 0x51, 0x95, 0xa0, 0x80, 0x95, 0x17, 0xd3, 0x56, 0x97, 0xe0, 0xc5, 0x09, 0x71, 0x25, 0x78,
    0x29, 0x22, 0x4e, 0x57, 0xe3, 0x09, 0x34, 0x85, 0xe4, 0xd5, 0x91, 0xdf, 0x80, 0x51, 0x55, 0x80,
    0x1f, 0x0d, 0xa6, 0x77, 0x68, 0xaf, 0x33, 0x4e, 0xa8, 0x95, 0xb3, 0x5c, 0xd7, 0x19, 0x25, 0xaa,
    0xcb, 0x62, 0x98, 0x98, 0xa3, 0x12, 0xe1, 0x13, 0xb2, 0x3b, 0xf1, 0x54, 0x02, 0x83, 0x4f, 0x68,
    0x95, 0xfd, 0xb6, 0x86, 0x5b, 0xd8, 0xdc, 0x0e, 0xed, 0xd1, 0x50, 0xf0, 0x15, 0x33, 0x67, 0xb2,
    0x1a, 0x9a, 0x33, 0x18, 0x3a, 0x68, 0x01, 0xa1, 0xb2, 0x22, 0x82, 0xd5, 0xd4, 0x54, 0x6b, 0x39,
    0xc2, 0x93, 0xd6, 0xd6, 0x4f, 0x8d, 0x70, 0x73, 0xec, 0x79, 0xd1, 0x85, 0x3d, 0x37, 0x23, 0x75,
    0x1a, 0x3e, 0x9c, 0x9a, 0xdc, 0x60, 0xe0, 0xae, 0x05, 0xbb, 0x5a, 0x65, 0x72, 0x17, 0xde, 0x6e,
    0x36, 0x52, 0xfe, 0x8d, 0x21, 0x3b, 0xe6, 0x11, 0x53, 0x06, 0xa8, 0x3f, 0x5b, 0x6a, 0xb1, 0x6f,
    0x27, 0xec, 0x8c, 0xf1, 0x7b, 0x3e, 0xcd, 0xbc, 0xb5, 0x9f, 0xf0, 0xe2, 0x47, 0x89, 0xcd, 0xa6,
    0x77, 0xe4, 0x99, 0xff, 0xec, 0x05, 0x64, 0x9b, 0x68, 0x3c
};
#endif

PyTypeObject *init_QStandardPaths(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX].type;

    Shiboken::AutoDecRef Sbk_QStandardPaths_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QStandardPaths_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStandardPaths",
        "QStandardPaths*",
        &Sbk_QStandardPaths_spec,
        nullptr,
        Sbk_QStandardPaths_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStandardPaths_TypeF(); // references _Sbk_QStandardPaths_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStandardPaths_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStandardPaths_SignatureBytes, QStandardPaths_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStandardPaths_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStandardPaths_PythonToCpp_QStandardPaths_PTR,
        is_QStandardPaths_PythonToCpp_QStandardPaths_PTR_Convertible,
        QStandardPaths_PTR_CppToPython_QStandardPaths);

    Shiboken::Conversions::registerConverterName(converter, "QStandardPaths");
    Shiboken::Conversions::registerConverterName(converter, "QStandardPaths*");
    Shiboken::Conversions::registerConverterName(converter, "QStandardPaths&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStandardPaths).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStandardPaths_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StandardLocation'.
    const char *StandardLocation_Initializer[] = {
        "DesktopLocation",
        "DocumentsLocation",
        "FontsLocation",
        "ApplicationsLocation",
        "MusicLocation",
        "MoviesLocation",
        "PicturesLocation",
        "TempLocation",
        "HomeLocation",
        "AppLocalDataLocation",
        "CacheLocation",
        "GenericDataLocation",
        "RuntimeLocation",
        "ConfigLocation",
        "DownloadLocation",
        "GenericCacheLocation",
        "GenericConfigLocation",
        "AppDataLocation",
        "AppConfigLocation",
        "PublicShareLocation",
        "TemplatesLocation",
        "StateLocation",
        "GenericStateLocation",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StandardLocation_InitializerValues[] = {
        uint8_t(QStandardPaths::StandardLocation::DesktopLocation),       //  0x00  0
        uint8_t(QStandardPaths::StandardLocation::DocumentsLocation),     //  0x01  1
        uint8_t(QStandardPaths::StandardLocation::FontsLocation),         //  0x02  2
        uint8_t(QStandardPaths::StandardLocation::ApplicationsLocation),  //  0x03  3
        uint8_t(QStandardPaths::StandardLocation::MusicLocation),         //  0x04  4
        uint8_t(QStandardPaths::StandardLocation::MoviesLocation),        //  0x05  5
        uint8_t(QStandardPaths::StandardLocation::PicturesLocation),      //  0x06  6
        uint8_t(QStandardPaths::StandardLocation::TempLocation),          //  0x07  7
        uint8_t(QStandardPaths::StandardLocation::HomeLocation),          //  0x08  8
        uint8_t(QStandardPaths::StandardLocation::AppLocalDataLocation),  //  0x09  9
        uint8_t(QStandardPaths::StandardLocation::CacheLocation),         //  0x0a  10
        uint8_t(QStandardPaths::StandardLocation::GenericDataLocation),   //  0x0b  11
        uint8_t(QStandardPaths::StandardLocation::RuntimeLocation),       //  0x0c  12
        uint8_t(QStandardPaths::StandardLocation::ConfigLocation),        //  0x0d  13
        uint8_t(QStandardPaths::StandardLocation::DownloadLocation),      //  0x0e  14
        uint8_t(QStandardPaths::StandardLocation::GenericCacheLocation),  //  0x0f  15
        uint8_t(QStandardPaths::StandardLocation::GenericConfigLocation), //  0x10  16
        uint8_t(QStandardPaths::StandardLocation::AppDataLocation),       //  0x11  17
        uint8_t(QStandardPaths::StandardLocation::AppConfigLocation),     //  0x12  18
        uint8_t(QStandardPaths::StandardLocation::PublicShareLocation),   //  0x13  19
        uint8_t(QStandardPaths::StandardLocation::TemplatesLocation),     //  0x14  20
        uint8_t(QStandardPaths::StandardLocation::StateLocation),         //  0x15  21
        uint8_t(QStandardPaths::StandardLocation::GenericStateLocation)   //  0x16  22
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStandardPaths_TypeF(),
        "2:PySide6.QtCore.QStandardPaths.StandardLocation",
        StandardLocation_Initializer, StandardLocation_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_StandardLocation_IDX].type = EType;
    // Register converter for enum 'QStandardPaths::StandardLocation'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStandardPaths_StandardLocation_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStandardPaths_StandardLocation,
            is_Enum_PythonToCpp_QStandardPaths_StandardLocation_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStandardPaths::StandardLocation");
        Shiboken::Conversions::registerConverterAlias(converter, "StandardLocation");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StandardLocation' enum.

    // Initialization of enum 'LocateOption'.
    const char *LocateOption_Initializer[] = {
        "LocateFile",
        "LocateDirectory",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t LocateOption_InitializerValues[] = {
        uint8_t(QStandardPaths::LocateOption::LocateFile),     //  0x00  0
        uint8_t(QStandardPaths::LocateOption::LocateDirectory) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStandardPaths_TypeF(),
        "2:PySide6.QtCore.QStandardPaths.LocateOption",
        LocateOption_Initializer, LocateOption_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QStandardPaths_LocateOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStandardPaths_LocateOption_IDX].type =
        EType;
    // Register converter for enum 'QStandardPaths::LocateOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStandardPaths_LocateOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStandardPaths_LocateOption,
            is_Enum_PythonToCpp_QStandardPaths_LocateOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStandardPaths::LocateOption");
        Shiboken::Conversions::registerConverterAlias(converter, "LocateOption");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QStandardPaths_LocateOption_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QStandardPaths_LocateOption,
            is_Enum_PythonToCpp_QStandardPaths_LocateOption_Convertible);
        // Register converter for flag 'QFlags<QStandardPaths::LocateOption>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QStandardPaths::LocateOption>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QStandardPaths::LocateOptions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'LocateOption' enum/flags.

    qRegisterMetaType< ::QStandardPaths *>();
    qRegisterMetaType< ::QStandardPaths::StandardLocation >("QStandardPaths::StandardLocation");
    qRegisterMetaType< ::QStandardPaths::LocateOption >("QStandardPaths::LocateOption");

    return pyType;
}
