// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qstorageinfo_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <qbytearray.h>
#include <qdir.h>
#include <qstorageinfo.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStorageInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStorageInfo >()))
        return -1;

    ::QStorageInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QStorageInfo", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStorageInfo::QStorageInfo()
    // 1: QStorageInfo::QStorageInfo(QDir)
    // 2: QStorageInfo::QStorageInfo(QStorageInfo)
    // 3: QStorageInfo::QStorageInfo(QString)
    if (numArgs == 0) {
        overloadId = 0; // QStorageInfo()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 3; // QStorageInfo(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QStorageInfo(QStorageInfo)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QStorageInfo(QDir)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStorageInfo()
        {

            // QStorageInfo()
            cptr = new ::QStorageInfo();
            break;
        }
        case 1: // QStorageInfo(const QDir &dir)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDir cppArg0_local;
            ::QDir *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QStorageInfo(QDir)
                cptr = new ::QStorageInfo(*cppArg0);
            }
            break;
        }
        case 2: // QStorageInfo(const QStorageInfo &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QStorageInfo cppArg0_local;
            ::QStorageInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QStorageInfo(QStorageInfo)
                cptr = new ::QStorageInfo(*cppArg0);
            }
            break;
        }
        case 3: // QStorageInfo(const QString &path)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStorageInfo(QString)
                cptr = new ::QStorageInfo(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStorageInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QStorageInfoFunc_blockSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // blockSize()const
        int cppResult = const_cast<const ::QStorageInfo *>(cppSelf)->blockSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_bytesAvailable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bytesAvailable()const
        qint64 cppResult = const_cast<const ::QStorageInfo *>(cppSelf)->bytesAvailable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_bytesFree(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bytesFree()const
        qint64 cppResult = const_cast<const ::QStorageInfo *>(cppSelf)->bytesFree();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_bytesTotal(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bytesTotal()const
        qint64 cppResult = const_cast<const ::QStorageInfo *>(cppSelf)->bytesTotal();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_device(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // device()const
        QByteArray cppResult = const_cast<const ::QStorageInfo *>(cppSelf)->device();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_displayName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // displayName()const
        QString cppResult = const_cast<const ::QStorageInfo *>(cppSelf)->displayName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_fileSystemType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileSystemType()const
        QByteArray cppResult = const_cast<const ::QStorageInfo *>(cppSelf)->fileSystemType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_isReadOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isReadOnly()const
        bool cppResult = const_cast<const ::QStorageInfo *>(cppSelf)->isReadOnly();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_isReady(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isReady()const
        bool cppResult = const_cast<const ::QStorageInfo *>(cppSelf)->isReady();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_isRoot(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRoot()const
        bool cppResult = const_cast<const ::QStorageInfo *>(cppSelf)->isRoot();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QStorageInfo *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_mountedVolumes(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mountedVolumes()
        QList<QStorageInfo> cppResult = ::QStorageInfo::mountedVolumes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QStorageInfo_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QStorageInfo *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_refresh(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // refresh()
        cppSelf->refresh();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStorageInfoFunc_root(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // root()
        QStorageInfo cppResult = ::QStorageInfo::root();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_rootPath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rootPath()const
        QString cppResult = const_cast<const ::QStorageInfo *>(cppSelf)->rootPath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_setPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStorageInfo::setPath(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPath(QString)
            cppSelf->setPath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStorageInfoFunc_subvolume(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // subvolume()const
        QByteArray cppResult = const_cast<const ::QStorageInfo *>(cppSelf)->subvolume();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStorageInfoFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStorageInfo::swap(QStorageInfo&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QStorageInfo&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QStorageInfo cppArg0_local;
        ::QStorageInfo *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QStorageInfo&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStorageInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QStorageInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStorageInfo_methods[] = {
    {"blockSize", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_blockSize), METH_NOARGS, nullptr},
    {"bytesAvailable", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_bytesAvailable), METH_NOARGS, nullptr},
    {"bytesFree", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_bytesFree), METH_NOARGS, nullptr},
    {"bytesTotal", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_bytesTotal), METH_NOARGS, nullptr},
    {"device", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_device), METH_NOARGS, nullptr},
    {"displayName", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_displayName), METH_NOARGS, nullptr},
    {"fileSystemType", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_fileSystemType), METH_NOARGS, nullptr},
    {"isReadOnly", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_isReadOnly), METH_NOARGS, nullptr},
    {"isReady", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_isReady), METH_NOARGS, nullptr},
    {"isRoot", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_isRoot), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_isValid), METH_NOARGS, nullptr},
    {"mountedVolumes", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_mountedVolumes), METH_NOARGS|METH_STATIC, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_name), METH_NOARGS, nullptr},
    {"refresh", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_refresh), METH_NOARGS, nullptr},
    {"root", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_root), METH_NOARGS|METH_STATIC, nullptr},
    {"rootPath", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_rootPath), METH_NOARGS, nullptr},
    {"setPath", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_setPath), METH_O, nullptr},
    {"subvolume", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_subvolume), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QStorageInfoFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QStorageInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QStorageInfo_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), (pyArg)))) {
                // operator!=(const QStorageInfo &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QStorageInfo cppArg0_local;
                ::QStorageInfo *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), (pyArg)))) {
                // operator==(const QStorageInfo &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QStorageInfo cppArg0_local;
                ::QStorageInfo *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QStorageInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStorageInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QStorageInfo__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStorageInfo_Type = nullptr;
static PyTypeObject *Sbk_QStorageInfo_TypeF(void)
{
    return _Sbk_QStorageInfo_Type;
}

static PyType_Slot Sbk_QStorageInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QStorageInfo__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStorageInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStorageInfo_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QStorageInfo_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStorageInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStorageInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStorageInfo_spec = {
    "2:PySide6.QtCore.QStorageInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStorageInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStorageInfo_PythonToCpp_QStorageInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStorageInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStorageInfo_PythonToCpp_QStorageInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStorageInfo_TypeF()))
        return QStorageInfo_PythonToCpp_QStorageInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStorageInfo_PTR_CppToPython_QStorageInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStorageInfo_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QStorageInfo_COPY_CppToPython_QStorageInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QStorageInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QStorageInfo_TypeF(), new ::QStorageInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QStorageInfo_PythonToCpp_QStorageInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QStorageInfo *>(cppOut) = *reinterpret_cast< ::QStorageInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QStorageInfo_PythonToCpp_QStorageInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QStorageInfo_TypeF()))
        return QStorageInfo_PythonToCpp_QStorageInfo_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStorageInfo_SignatureStrings[] = {
    "3:PySide6.QtCore.QStorageInfo(self)",
    "2:PySide6.QtCore.QStorageInfo(self,dir:PySide6.QtCore.QDir)",
    "1:PySide6.QtCore.QStorageInfo(self,other:PySide6.QtCore.QStorageInfo)",
    "0:PySide6.QtCore.QStorageInfo(self,path:QString)",
    "PySide6.QtCore.QStorageInfo.blockSize(self)->int",
    "PySide6.QtCore.QStorageInfo.bytesAvailable(self)->qint64",
    "PySide6.QtCore.QStorageInfo.bytesFree(self)->qint64",
    "PySide6.QtCore.QStorageInfo.bytesTotal(self)->qint64",
    "PySide6.QtCore.QStorageInfo.device(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QStorageInfo.displayName(self)->QString",
    "PySide6.QtCore.QStorageInfo.fileSystemType(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QStorageInfo.isReadOnly(self)->bool",
    "PySide6.QtCore.QStorageInfo.isReady(self)->bool",
    "PySide6.QtCore.QStorageInfo.isRoot(self)->bool",
    "PySide6.QtCore.QStorageInfo.isValid(self)->bool",
    "PySide6.QtCore.QStorageInfo.mountedVolumes()->QList[PySide6.QtCore.QStorageInfo]",
    "PySide6.QtCore.QStorageInfo.name(self)->QString",
    "PySide6.QtCore.QStorageInfo.refresh(self)",
    "PySide6.QtCore.QStorageInfo.root()->PySide6.QtCore.QStorageInfo",
    "PySide6.QtCore.QStorageInfo.rootPath(self)->QString",
    "PySide6.QtCore.QStorageInfo.setPath(self,path:QString)",
    "PySide6.QtCore.QStorageInfo.subvolume(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QStorageInfo.swap(self,other:PySide6.QtCore.QStorageInfo)",
    "PySide6.QtCore.QStorageInfo.__copy__(self)->typing.Self",
    "PySide6.QtCore.QStorageInfo.__ne__(self,rhs:PySide6.QtCore.QStorageInfo)->bool",
    "PySide6.QtCore.QStorageInfo.__eq__(self,rhs:PySide6.QtCore.QStorageInfo)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QStorageInfo_SignatureByteSize = 320;
static constexpr uint8_t QStorageInfo_SignatureBytes[320] = {
    0x78, 0xda, 0xa5, 0x94, 0x5d, 0x4b, 0xc3, 0x30, 0x14, 0x86, 0xef, 0xfb, 0x4b, 0x56, 0x98, 0xc5,
    0x2f, 0x76, 0xb1, 0x0b, 0x61, 0x2a, 0x82, 0x20, 0xba, 0xd9, 0xb1, 0x1b, 0x91, 0x92, 0x36, 0xa7,
    0xeb, 0xc1, 0x34, 0xa7, 0x4b, 0xd2, 0x49, 0xfc, 0xf5, 0x76, 0xda, 0x75, 0xa2, 0x92, 0x36, 0xec,
    0xb2, 0xe1, 0x79, 0xde, 0x9e, 0x9c, 0xe4, 0xe4, 0x62, 0x3a, 0xb7, 0x31, 0x72, 0x98, 0x44, 0x0b,
    0x73, 0x43, 0x0a, 0xa2, 0x45, 0x6c, 0x48, 0xb1, 0x35, 0xdc, 0xcb, 0x9c, 0x46, 0x1a, 0x44, 0x1e,
    0x06, 0xe7, 0xbd, 0xcc, 0x98, 0xa3, 0xfa, 0x03, 0xdd, 0xa2, 0x0a, 0x83, 0xb3, 0x7e, 0x97, 0x4c,
    0x01, 0xca, 0x85, 0x85, 0xc1, 0x69, 0x7f, 0x4a, 0xc5, 0x4c, 0x31, 0x6d, 0x96, 0x15, 0xca, 0x75,
    0x18, 0x38, 0xf0, 0x28, 0x15, 0x94, 0xbd, 0xc5, 0xf8, 0x01, 0xdf, 0xdb, 0x3b, 0xb9, 0x42, 0x69,
    0xdc, 0x82, 0x35, 0xa0, 0x67, 0x5b, 0x86, 0x82, 0xa5, 0xa2, 0xb3, 0x36, 0x8d, 0x36, 0xb9, 0xec,
    0x17, 0xef, 0x14, 0x78, 0x3b, 0x4b, 0x32, 0x4c, 0x78, 0x48, 0x1c, 0xb6, 0x98, 0x75, 0x7f, 0xf9,
    0x4d, 0x5e, 0x37, 0x91, 0x33, 0xa5, 0x98, 0x75, 0x67, 0xa0, 0xae, 0x04, 0xb3, 0x8f, 0xac, 0xec,
    0x82, 0xda, 0x76, 0x3a, 0xb5, 0x1c, 0x05, 0xc4, 0x56, 0x1b, 0x28, 0x97, 0xb6, 0x3a, 0xb2, 0x04,
    0xd4, 0xcf, 0xc0, 0xf8, 0x93, 0x14, 0x76, 0x9f, 0x93, 0x12, 0x89, 0x01, 0x8a, 0x17, 0x4f, 0x64,
    0x3c, 0xf0, 0x15, 0x13, 0xc8, 0x07, 0xf3, 0x25, 0xd5, 0xd2, 0x00, 0x5f, 0x91, 0xa8, 0x4b, 0xd0,
    0xa3, 0x5d, 0x0f, 0x1f, 0x50, 0x9b, 0x17, 0x87, 0xf3, 0xea, 0x0c, 0x94, 0x9e, 0xc7, 0xa1, 0x20,
    0x57, 0xa0, 0x8b, 0x76, 0x72, 0x9d, 0xe4, 0xae, 0x0f, 0xff, 0x1c, 0xd5, 0x0f, 0xa6, 0xd7, 0x9f,
    0x37, 0x43, 0xe7, 0x53, 0x9d, 0x86, 0x83, 0xe2, 0x31, 0xb1, 0xba, 0x4e, 0xb7, 0x5f, 0x1d, 0x3d,
    0xee, 0x7a, 0xe9, 0x77, 0x56, 0x0d, 0x7e, 0x72, 0x5c, 0x41, 0x49, 0x92, 0x51, 0x65, 0x93, 0x64,
    0x5f, 0x8e, 0xb1, 0x55, 0xb3, 0x87, 0x28, 0x6e, 0xbe, 0x7a, 0x3c, 0x09, 0xad, 0x35, 0x56, 0x85,
    0x76, 0x16, 0x30, 0xe0, 0xb2, 0x25, 0x09, 0x6c, 0x3c, 0xe3, 0x3e, 0x01, 0x3f, 0x08, 0x1b, 0x5b
};
#endif

PyTypeObject *init_QStorageInfo(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QStorageInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QStorageInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStorageInfo",
        "QStorageInfo",
        &Sbk_QStorageInfo_spec,
        &Shiboken::callCppDestructor< ::QStorageInfo >,
        Sbk_QStorageInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QStorageInfo_TypeF(); // references _Sbk_QStorageInfo_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStorageInfo_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStorageInfo_SignatureBytes, QStorageInfo_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStorageInfo_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStorageInfo_PythonToCpp_QStorageInfo_PTR,
        is_QStorageInfo_PythonToCpp_QStorageInfo_PTR_Convertible,
        QStorageInfo_PTR_CppToPython_QStorageInfo,
        QStorageInfo_COPY_CppToPython_QStorageInfo);

    Shiboken::Conversions::registerConverterName(converter, "QStorageInfo");
    Shiboken::Conversions::registerConverterName(converter, "QStorageInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QStorageInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStorageInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QStorageInfo_PythonToCpp_QStorageInfo_COPY,
        is_QStorageInfo_PythonToCpp_QStorageInfo_COPY_Convertible);

    qRegisterMetaType< ::QStorageInfo >("QStorageInfo");

    return pyType;
}
