// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qstringconverter_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QStringList>
#include <qstringconverter_base.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStringConverter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStringConverter >()))
        return -1;

    ::QStringConverter *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX]);

    if (PyArg_UnpackTuple(args, "QStringConverter", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStringConverter::QStringConverter()
    // 1: QStringConverter::QStringConverter(QAnyStringView,QFlags<QStringConverterBase::Flag>)
    // 2: QStringConverter::QStringConverter(QStringConverter::Encoding,QFlags<QStringConverterBase::Flag>)
    if (numArgs == 0) {
        overloadId = 0; // QStringConverter()
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_Encoding_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->flagsConverter, (pyArgs[1])))) {
        overloadId = 2; // QStringConverter(QStringConverter::Encoding,QFlags<QStringConverterBase::Flag>)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->flagsConverter, (pyArgs[1])))) {
        overloadId = 1; // QStringConverter(QAnyStringView,QFlags<QStringConverterBase::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStringConverter()
        {

            // QStringConverter()
            cptr = new ::QStringConverter();
            break;
        }
        case 1: // QStringConverter(QAnyStringView name, QFlags<QStringConverterBase::Flag> f)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QStringConverterBase::Flag> cppArg1 = QFlags<QStringConverterBase::Flag>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStringConverter(QAnyStringView,QFlags<QStringConverterBase::Flag>)
                cptr = new ::QStringConverter(QAnyStringView(cppArg0), cppArg1);
            }
            break;
        }
        case 2: // QStringConverter(QStringConverter::Encoding encoding, QFlags<QStringConverterBase::Flag> f)
        {
            ::QStringConverter::Encoding cppArg0{QStringConverter::Utf8};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QStringConverterBase::Flag> cppArg1 = QFlags<QStringConverterBase::Flag>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStringConverter(QStringConverter::Encoding,QFlags<QStringConverterBase::Flag>)
                cptr = new ::QStringConverter(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStringConverter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QStringConverterFunc_availableCodecs(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // availableCodecs()
        QStringList cppResult = ::QStringConverter::availableCodecs();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStringConverterFunc_hasError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringConverter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasError()const
        bool cppResult = const_cast<const ::QStringConverter *>(cppSelf)->hasError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStringConverterFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringConverter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QStringConverter *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStringConverterFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringConverter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        const char * cppResult = const_cast<const ::QStringConverter *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStringConverterFunc_nameForEncoding(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QStringConverter::nameForEncoding(QStringConverter::Encoding)->const char*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_Encoding_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // nameForEncoding(QStringConverter::Encoding)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "nameForEncoding", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX]);

    // Call function/method
    {
        ::QStringConverter::Encoding cppArg0{QStringConverter::Utf8};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // nameForEncoding(QStringConverter::Encoding)
            const char * cppResult = ::QStringConverter::nameForEncoding(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStringConverterFunc_resetState(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringConverter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resetState()
        cppSelf->resetState();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QStringConverter_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QStringConverter_EnumFlagInfo[] = {
    "Encoding:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStringConverter_methods[] = {
    {"availableCodecs", reinterpret_cast<PyCFunction>(Sbk_QStringConverterFunc_availableCodecs), METH_NOARGS|METH_STATIC, nullptr},
    {"hasError", reinterpret_cast<PyCFunction>(Sbk_QStringConverterFunc_hasError), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QStringConverterFunc_isValid), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QStringConverterFunc_name), METH_NOARGS, nullptr},
    {"nameForEncoding", reinterpret_cast<PyCFunction>(Sbk_QStringConverterFunc_nameForEncoding), METH_O|METH_STATIC, nullptr},
    {"resetState", reinterpret_cast<PyCFunction>(Sbk_QStringConverterFunc_resetState), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QStringConverter_get_state(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringConverter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->state)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->state))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->state)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]), &(cppSelf->state), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStringConverter_set_state(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStringConverter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("state");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("state", "State");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->state;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

// Getters and Setters for QStringConverter
static PyGetSetDef Sbk_QStringConverter_getsetlist[] = {
    {const_cast<char *>("state"), Sbk_QStringConverter_get_state, Sbk_QStringConverter_set_state, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStringConverter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStringConverter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStringConverter_Type = nullptr;
static PyTypeObject *Sbk_QStringConverter_TypeF(void)
{
    return _Sbk_QStringConverter_Type;
}

static PyType_Slot Sbk_QStringConverter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStringConverter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStringConverter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStringConverter_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QStringConverter_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStringConverter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStringConverter_spec = {
    "2:PySide6.QtCore.QStringConverter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStringConverter_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QStringConverter_Encoding(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStringConverter::Encoding>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStringConverter::Encoding *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStringConverter_Encoding_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_Encoding_IDX])))
        return Enum_PythonToCpp_QStringConverter_Encoding;
    return {};
}

static PyObject *QStringConverter_Encoding_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStringConverter::Encoding>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStringConverter::Encoding *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_Encoding_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStringConverter_PythonToCpp_QStringConverter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStringConverter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStringConverter_PythonToCpp_QStringConverter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStringConverter_TypeF()))
        return QStringConverter_PythonToCpp_QStringConverter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStringConverter_PTR_CppToPython_QStringConverter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStringConverter_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStringConverter_SignatureStrings[] = {
    "2:PySide6.QtCore.QStringConverter(self)",
    "1:PySide6.QtCore.QStringConverter(self,name:QString,f:PySide6.QtCore.QStringConverterBase.Flag)",
    "0:PySide6.QtCore.QStringConverter(self,encoding:PySide6.QtCore.QStringConverter.Encoding,f:PySide6.QtCore.QStringConverterBase.Flag)",
    "PySide6.QtCore.QStringConverter.availableCodecs()->QStringList",
    "PySide6.QtCore.QStringConverter.hasError(self)->bool",
    "PySide6.QtCore.QStringConverter.isValid(self)->bool",
    "PySide6.QtCore.QStringConverter.name(self)->char*",
    "PySide6.QtCore.QStringConverter.nameForEncoding(e:PySide6.QtCore.QStringConverter.Encoding)->char*",
    "PySide6.QtCore.QStringConverter.resetState(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QStringConverter_SignatureByteSize = 174;
static constexpr uint8_t QStringConverter_SignatureBytes[174] = {
    0x78, 0xda, 0x95, 0x91, 0x31, 0x0b, 0x83, 0x30, 0x10, 0x85, 0x77, 0x7f, 0x89, 0x16, 0x0d, 0x6d,
    0x87, 0x0e, 0x0e, 0x0e, 0x15, 0x9d, 0x3a, 0x54, 0x02, 0xdd, 0x4f, 0x73, 0x6a, 0x20, 0xcd, 0xc1,
    0x25, 0x08, 0xfd, 0xf7, 0x6d, 0x21, 0xce, 0x89, 0xeb, 0xdd, 0xfb, 0xde, 0x3d, 0xde, 0x5d, 0xeb,
    0xe7, 0x47, 0x6a, 0x85, 0x37, 0x31, 0xf8, 0x96, 0x18, 0xc5, 0x20, 0x3d, 0x6b, 0xbb, 0xb4, 0x64,
    0x37, 0x64, 0x8f, 0x9c, 0x3b, 0x34, 0x73, 0x91, 0x5d, 0x92, 0x74, 0xa5, 0x85, 0x37, 0xd6, 0x61,
    0x55, 0xce, 0x31, 0xe6, 0x0e, 0x0e, 0x45, 0x6f, 0x60, 0x29, 0xb2, 0x73, 0x9a, 0x3f, 0xda, 0x89,
    0xd4, 0x6f, 0x1c, 0x53, 0x8b, 0x2e, 0x08, 0x0f, 0x85, 0x88, 0x99, 0xc2, 0x06, 0xda, 0xc0, 0x68,
    0xb0, 0x25, 0x85, 0x93, 0xcb, 0x8b, 0xaa, 0x09, 0x9a, 0x87, 0x76, 0x3e, 0x8a, 0xaf, 0xe0, 0x3a,
    0x66, 0x0a, 0x95, 0x56, 0xcd, 0x48, 0x64, 0xa2, 0x90, 0x76, 0x2f, 0x30, 0x5a, 0x1d, 0x62, 0xfe,
    0x5f, 0xd8, 0x81, 0x69, 0x05, 0x3e, 0x25, 0x11, 0x3d, 0xf1, 0xde, 0x5a, 0x8e, 0xc9, 0x05, 0x27,
    0x9f, 0x60, 0x74, 0xe8, 0xa5, 0x07, 0x1f, 0xa2, 0x65, 0x5f, 0x11, 0x90, 0xe5, 0xc3
};
#endif

PyTypeObject *init_QStringConverter(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX].type;

    Shiboken::AutoDecRef Sbk_QStringConverter_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_IDX]))));

    _Sbk_QStringConverter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStringConverter",
        "QStringConverter*",
        &Sbk_QStringConverter_spec,
        &Shiboken::callCppDestructor< ::QStringConverter >,
        Sbk_QStringConverter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStringConverter_TypeF(); // references _Sbk_QStringConverter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStringConverter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStringConverter_SignatureBytes, QStringConverter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStringConverter_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStringConverter_PythonToCpp_QStringConverter_PTR,
        is_QStringConverter_PythonToCpp_QStringConverter_PTR_Convertible,
        QStringConverter_PTR_CppToPython_QStringConverter);

    Shiboken::Conversions::registerConverterName(converter, "QStringConverter");
    Shiboken::Conversions::registerConverterName(converter, "QStringConverter*");
    Shiboken::Conversions::registerConverterName(converter, "QStringConverter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStringConverter).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStringConverter_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Encoding'.
    const char *Encoding_Initializer[] = {
        "Utf8",
        "Utf16",
        "Utf16LE",
        "Utf16BE",
        "Utf32",
        "Utf32LE",
        "Utf32BE",
        "Latin1",
        "System",
        "LastEncoding",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Encoding_InitializerValues[] = {
        uint8_t(QStringConverter::Encoding::Utf8),        //  0x00  0
        uint8_t(QStringConverter::Encoding::Utf16),       //  0x01  1
        uint8_t(QStringConverter::Encoding::Utf16LE),     //  0x02  2
        uint8_t(QStringConverter::Encoding::Utf16BE),     //  0x03  3
        uint8_t(QStringConverter::Encoding::Utf32),       //  0x04  4
        uint8_t(QStringConverter::Encoding::Utf32LE),     //  0x05  5
        uint8_t(QStringConverter::Encoding::Utf32BE),     //  0x06  6
        uint8_t(QStringConverter::Encoding::Latin1),      //  0x07  7
        uint8_t(QStringConverter::Encoding::System),      //  0x08  8
        uint8_t(QStringConverter::Encoding::LastEncoding) //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStringConverter_TypeF(),
        "2:PySide6.QtCore.QStringConverter.Encoding",
        Encoding_Initializer, Encoding_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_Encoding_IDX].type = EType;
    // Register converter for enum 'QStringConverter::Encoding'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStringConverter_Encoding_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStringConverter_Encoding,
            is_Enum_PythonToCpp_QStringConverter_Encoding_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStringConverter::Encoding");
        Shiboken::Conversions::registerConverterAlias(converter, "Encoding");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Encoding' enum.

    qRegisterMetaType< ::QStringConverter *>();
    qRegisterMetaType< ::QStringConverter::Encoding >("QStringConverter::Encoding");

    return pyType;
}
