// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qstringconverterbase_state_wrapper.h"

// Argument includes
#include <qstringconverter_base.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStringConverterBase_State_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStringConverterBase::State >()))
        return -1;

    ::QStringConverterBase::State *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]);

    if (PyArg_ParseTuple(args, "|O:State", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: State::State(QFlags<QStringConverterBase::Flag>=)
    if (numArgs == 0) {
        overloadId = 0; // State(QFlags<QStringConverterBase::Flag>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // State(QFlags<QStringConverterBase::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_f = Shiboken::String::createStaticString("f");
            if (PyDict_Contains(kwds, key_f) != 0) {
                value = PyDict_GetItem(kwds, key_f);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_f);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_f);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]);
            }
        }
        ::QFlags<QStringConverterBase::Flag> cppArg0(QStringConverterBase::Flag::Default);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // State(QFlags<QStringConverterBase::Flag>)
            cptr = new ::QStringConverterBase::State(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStringConverterBase::State >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QStringConverterBase_StateFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringConverterBase::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStringConverterBase_StateFunc_reset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringConverterBase::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reset()
        cppSelf->reset();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QStringConverterBase_State_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStringConverterBase_State_methods[] = {
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QStringConverterBase_StateFunc_clear), METH_NOARGS, nullptr},
    {"reset", reinterpret_cast<PyCFunction>(Sbk_QStringConverterBase_StateFunc_reset), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QStringConverterBase_State_get_flags(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringConverterBase::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->flagsConverter, &cppSelf->flags);
    return pyOut;
}
static int Sbk_QStringConverterBase_State_set_flags(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStringConverterBase::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("flags");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("flags", "Flags");
        return -1;
    }

    auto cppOut_local = cppSelf->flags;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->flags = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStringConverterBase_State_get_internalState(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringConverterBase::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->internalState;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStringConverterBase_State_set_internalState(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStringConverterBase::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("internalState");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("internalState", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->internalState;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->internalState = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStringConverterBase_State_get_remainingChars(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringConverterBase::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    qsizetype cppOut_local = cppSelf->remainingChars;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStringConverterBase_State_set_remainingChars(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStringConverterBase::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("remainingChars");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("remainingChars", "qsizetype");
        return -1;
    }

    auto cppOut_local = cppSelf->remainingChars;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->remainingChars = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStringConverterBase_State_get_invalidChars(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringConverterBase::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    qsizetype cppOut_local = cppSelf->invalidChars;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStringConverterBase_State_set_invalidChars(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStringConverterBase::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("invalidChars");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("invalidChars", "qsizetype");
        return -1;
    }

    auto cppOut_local = cppSelf->invalidChars;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->invalidChars = cppOut_local;

    return 0;
}

// Getters and Setters for State
static PyGetSetDef Sbk_QStringConverterBase_State_getsetlist[] = {
    {const_cast<char *>("flags"), Sbk_QStringConverterBase_State_get_flags, Sbk_QStringConverterBase_State_set_flags, nullptr, nullptr},
    {const_cast<char *>("internalState"), Sbk_QStringConverterBase_State_get_internalState, Sbk_QStringConverterBase_State_set_internalState, nullptr, nullptr},
    {const_cast<char *>("remainingChars"), Sbk_QStringConverterBase_State_get_remainingChars, Sbk_QStringConverterBase_State_set_remainingChars, nullptr, nullptr},
    {const_cast<char *>("invalidChars"), Sbk_QStringConverterBase_State_get_invalidChars, Sbk_QStringConverterBase_State_set_invalidChars, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStringConverterBase_State_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStringConverterBase_State_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStringConverterBase_State_Type = nullptr;
static PyTypeObject *Sbk_QStringConverterBase_State_TypeF(void)
{
    return _Sbk_QStringConverterBase_State_Type;
}

static PyType_Slot Sbk_QStringConverterBase_State_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStringConverterBase_State_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStringConverterBase_State_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStringConverterBase_State_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QStringConverterBase_State_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStringConverterBase_State_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStringConverterBase_State_spec = {
    "2:PySide6.QtCore.QStringConverterBase.State",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStringConverterBase_State_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void State_PythonToCpp_State_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStringConverterBase_State_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_State_PythonToCpp_State_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStringConverterBase_State_TypeF()))
        return State_PythonToCpp_State_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *State_PTR_CppToPython_State(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStringConverterBase_State_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStringConverterBase_State_SignatureStrings[] = {
    "PySide6.QtCore.QStringConverterBase.State(self,f:PySide6.QtCore.QStringConverterBase.Flag=QStringConverterBase.Flag.Default)",
    "PySide6.QtCore.QStringConverterBase.State.clear(self)",
    "PySide6.QtCore.QStringConverterBase.State.reset(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QStringConverterBase_State_SignatureByteSize = 98;
static constexpr uint8_t QStringConverterBase_State_SignatureBytes[98] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce, 0x2f, 0x4a,
    0xd5, 0x0b, 0x0c, 0x2e, 0x29, 0xca, 0xcc, 0x4b, 0x77, 0xce, 0xcf, 0x2b, 0x4b, 0x2d, 0x2a, 0x49,
    0x2d, 0x72, 0x4a, 0x2c, 0x4e, 0xd5, 0x0b, 0x2e, 0x49, 0x2c, 0x49, 0xd5, 0x28, 0x4e, 0xcd, 0x49,
    0xd3, 0x49, 0xb3, 0x0a, 0x20, 0x42, 0x83, 0x5b, 0x4e, 0x62, 0xba, 0x2d, 0x4e, 0x19, 0x3d, 0x97,
    0xd4, 0xb4, 0xc4, 0xd2, 0x9c, 0x12, 0x4d, 0xae, 0x00, 0x62, 0x2d, 0xd7, 0x4b, 0xce, 0x49, 0x4d,
    0x2c, 0x02, 0x3b, 0x81, 0x14, 0x5d, 0x45, 0xa9, 0xc5, 0xa9, 0x25, 0x50, 0x5d, 0x00, 0x0d, 0x65,
    0x55, 0x0e
};
#endif

PyTypeObject *init_QStringConverterBase_State(PyObject *enclosingClass)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX].type;

    Shiboken::AutoDecRef Sbk_QStringConverterBase_State_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QStringConverterBase_State_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "State",
        "QStringConverterBase::State*",
        &Sbk_QStringConverterBase_State_spec,
        &Shiboken::callCppDestructor< ::QStringConverterBase::State >,
        Sbk_QStringConverterBase_State_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_QStringConverterBase_State_TypeF(); // references _Sbk_QStringConverterBase_State_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStringConverterBase_State_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStringConverterBase_State_SignatureBytes, QStringConverterBase_State_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStringConverterBase_State_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_State_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        State_PythonToCpp_State_PTR,
        is_State_PythonToCpp_State_PTR_Convertible,
        State_PTR_CppToPython_State);

    Shiboken::Conversions::registerConverterName(converter, "QStringConverterBase::State");
    Shiboken::Conversions::registerConverterName(converter, "QStringConverterBase::State*");
    Shiboken::Conversions::registerConverterName(converter, "QStringConverterBase::State&");
    Shiboken::Conversions::registerConverterAlias(converter, "State");
    Shiboken::Conversions::registerConverterAlias(converter, "State*");
    Shiboken::Conversions::registerConverterAlias(converter, "State&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStringConverterBase::State).name());

    qRegisterMetaType< ::QStringConverterBase::State *>();

    return pyType;
}
