// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qstringconverterbase_wrapper.h"

// inner classes
#include "qstringconverterbase_state_wrapper.h"

// Argument includes
#include <qstringconverter_base.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStringConverterBase_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStringConverterBase >()))
        return -1;

    ::QStringConverterBase *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QStringConverterBase()
        cptr = new ::QStringConverterBase();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStringConverterBase >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}


static const char *Sbk_QStringConverterBase_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QStringConverterBase_EnumFlagInfo[] = {
    "Flag:Flag:Flags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStringConverterBase_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStringConverterBase_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStringConverterBase_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStringConverterBase_Type = nullptr;
static PyTypeObject *Sbk_QStringConverterBase_TypeF(void)
{
    return _Sbk_QStringConverterBase_Type;
}

static PyType_Slot Sbk_QStringConverterBase_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStringConverterBase_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStringConverterBase_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStringConverterBase_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStringConverterBase_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStringConverterBase_spec = {
    "2:PySide6.QtCore.QStringConverterBase",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStringConverterBase_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QStringConverterBase_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStringConverterBase::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStringConverterBase::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QStringConverterBase_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_Flag_IDX])))
        return Enum_PythonToCpp_QStringConverterBase_Flag;
    return {};
}

static PyObject *QStringConverterBase_Flag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QStringConverterBase::Flag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QStringConverterBase::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_Flag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QStringConverterBase_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QStringConverterBase::Flag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QStringConverterBase::Flag> *>(cppOut) = value;

}

static PyObject *QStringConverterBase_Flag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QStringConverterBase::Flag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_Flag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStringConverterBase_PythonToCpp_QStringConverterBase_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStringConverterBase_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStringConverterBase_PythonToCpp_QStringConverterBase_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStringConverterBase_TypeF()))
        return QStringConverterBase_PythonToCpp_QStringConverterBase_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStringConverterBase_PTR_CppToPython_QStringConverterBase(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStringConverterBase_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStringConverterBase_SignatureStrings[] = {
    "PySide6.QtCore.QStringConverterBase(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QStringConverterBase_SignatureByteSize = 50;
static constexpr uint8_t QStringConverterBase_SignatureBytes[50] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce, 0x2f, 0x4a,
    0xd5, 0x0b, 0x0c, 0x2e, 0x29, 0xca, 0xcc, 0x4b, 0x77, 0xce, 0xcf, 0x2b, 0x4b, 0x2d, 0x2a, 0x49,
    0x2d, 0x72, 0x4a, 0x2c, 0x4e, 0xd5, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x02, 0x00, 0x4a, 0x61,
    0x0f, 0x2f
};
#endif

PyTypeObject *init_QStringConverterBase(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_IDX].type;

    Shiboken::AutoDecRef Sbk_QStringConverterBase_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QStringConverterBase_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStringConverterBase",
        "QStringConverterBase*",
        &Sbk_QStringConverterBase_spec,
        &Shiboken::callCppDestructor< ::QStringConverterBase >,
        Sbk_QStringConverterBase_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStringConverterBase_TypeF(); // references _Sbk_QStringConverterBase_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStringConverterBase_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStringConverterBase_SignatureBytes, QStringConverterBase_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStringConverterBase_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStringConverterBase_PythonToCpp_QStringConverterBase_PTR,
        is_QStringConverterBase_PythonToCpp_QStringConverterBase_PTR_Convertible,
        QStringConverterBase_PTR_CppToPython_QStringConverterBase);

    Shiboken::Conversions::registerConverterName(converter, "QStringConverterBase");
    Shiboken::Conversions::registerConverterName(converter, "QStringConverterBase*");
    Shiboken::Conversions::registerConverterName(converter, "QStringConverterBase&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStringConverterBase).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStringConverterBase_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "Default",
        "Stateless",
        "ConvertInvalidToNull",
        "WriteBom",
        "ConvertInitialBom",
        "UsesIcu",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Flag_InitializerValues[] = {
        int8_t(QStringConverterBase::Flag::Default),              //  0x00  0
        int8_t(QStringConverterBase::Flag::Stateless),            //  0x01  1
        int8_t(QStringConverterBase::Flag::ConvertInvalidToNull), //  0x02  2
        int8_t(QStringConverterBase::Flag::WriteBom),             //  0x04  4
        int8_t(QStringConverterBase::Flag::ConvertInitialBom),    //  0x08  8
        int8_t(QStringConverterBase::Flag::UsesIcu)               //  0x10  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStringConverterBase_TypeF(),
        "2:PySide6.QtCore.QStringConverterBase.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QStringConverterBase_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX].type =
        EType;
    // Register converter for enum 'QStringConverterBase::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStringConverterBase_Flag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QStringConverterBase_Flag,
            is_Enum_PythonToCpp_QStringConverterBase_Flag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QStringConverterBase::Flag");
        Shiboken::Conversions::registerConverterAlias(converter, "Flag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QStringConverterBase_Flag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QStringConverterBase_Flag,
            is_Enum_PythonToCpp_QStringConverterBase_Flag_Convertible);
        // Register converter for flag 'QFlags<QStringConverterBase::Flag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QStringConverterBase::Flag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QStringConverterBase::Flags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Flag' enum/flags.

    qRegisterMetaType< ::QStringConverterBase *>();
    qRegisterMetaType< ::QStringConverterBase::Flag >("QStringConverterBase::Flag");

    return pyType;
}
