// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qstringdecoder_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QString>
#include <QStringList>
#include <qbytearrayview.h>
#include <qchar.h>
#include <qstringconverter.h>
#include <qstringconverter_base.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStringDecoder_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStringDecoder >()))
        return -1;

    ::QStringDecoder *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QStringDecoder", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStringDecoder::QStringDecoder()
    // 1: QStringDecoder::QStringDecoder(QAnyStringView,QFlags<QStringConverterBase::Flag>=)
    // 2: QStringDecoder::QStringDecoder(QStringConverter::Encoding,QFlags<QStringConverterBase::Flag>=)
    if (numArgs == 0) {
        overloadId = 0; // QStringDecoder()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_Encoding_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QStringDecoder(QStringConverter::Encoding,QFlags<QStringConverterBase::Flag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 2; // QStringDecoder(QStringConverter::Encoding,QFlags<QStringConverterBase::Flag>)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QStringDecoder(QAnyStringView,QFlags<QStringConverterBase::Flag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 1; // QStringDecoder(QAnyStringView,QFlags<QStringConverterBase::Flag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStringDecoder()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]);
            }

            // QStringDecoder()
            cptr = new ::QStringDecoder();
            break;
        }
        case 1: // QStringDecoder(QAnyStringView name, QFlags<QStringConverterBase::Flag> f)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_f = Shiboken::String::createStaticString("f");
                if (PyDict_Contains(kwds, key_f) != 0) {
                    value = PyDict_GetItem(kwds, key_f);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_f);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_f);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QStringConverterBase::Flag> cppArg1(QStringConverterBase::Flag::Default);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStringDecoder(QAnyStringView,QFlags<QStringConverterBase::Flag>)
                cptr = new ::QStringDecoder(QAnyStringView(cppArg0), cppArg1);
            }
            break;
        }
        case 2: // QStringDecoder(QStringConverter::Encoding encoding, QFlags<QStringConverterBase::Flag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]);
                }
            }
            ::QStringConverter::Encoding cppArg0{QStringConverter::Utf8};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QStringConverterBase::Flag> cppArg1(QStringConverterBase::Flag::Default);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStringDecoder(QStringConverter::Encoding,QFlags<QStringConverterBase::Flag>)
                cptr = new ::QStringDecoder(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStringDecoder >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QStringDecoderFunc_appendToBuffer(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringDecoder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "appendToBuffer", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStringDecoder::appendToBuffer(QChar*,QByteArrayView)->QChar*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // appendToBuffer(QChar*,QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "appendToBuffer", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]);

    // Call function/method
    {
        ::QChar *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // appendToBuffer(QChar*,QByteArrayView)
            QChar * cppResult = cppSelf->appendToBuffer(cppArg0, QByteArrayView(cppArg1));
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStringDecoderFunc_decoderForHtml(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QStringDecoder::decoderForHtml(QByteArrayView)->QStringDecoder
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // decoderForHtml(QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "decoderForHtml", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // decoderForHtml(QByteArrayView)
            QStringDecoder* cppResult = new QStringDecoder(::QStringDecoder::decoderForHtml(QByteArrayView(cppArg0)));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStringDecoderFunc_requiredSpace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringDecoder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStringDecoder::requiredSpace(qsizetype)const->qsizetype
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // requiredSpace(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "requiredSpace", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // requiredSpace(qsizetype)const
            qsizetype cppResult = const_cast<const ::QStringDecoder *>(cppSelf)->requiredSpace(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QStringDecoder_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStringDecoder_methods[] = {
    {"appendToBuffer", reinterpret_cast<PyCFunction>(Sbk_QStringDecoderFunc_appendToBuffer), METH_VARARGS, nullptr},
    {"decoderForHtml", reinterpret_cast<PyCFunction>(Sbk_QStringDecoderFunc_decoderForHtml), METH_O|METH_STATIC, nullptr},
    {"requiredSpace", reinterpret_cast<PyCFunction>(Sbk_QStringDecoderFunc_requiredSpace), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStringDecoder_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStringDecoder_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStringDecoder_Type = nullptr;
static PyTypeObject *Sbk_QStringDecoder_TypeF(void)
{
    return _Sbk_QStringDecoder_Type;
}

static PyType_Slot Sbk_QStringDecoder_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStringDecoder_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStringDecoder_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStringDecoder_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStringDecoder_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStringDecoder_spec = {
    "2:PySide6.QtCore.QStringDecoder",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStringDecoder_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStringDecoder_PythonToCpp_QStringDecoder_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStringDecoder_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStringDecoder_PythonToCpp_QStringDecoder_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStringDecoder_TypeF()))
        return QStringDecoder_PythonToCpp_QStringDecoder_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStringDecoder_PTR_CppToPython_QStringDecoder(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStringDecoder_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStringDecoder_SignatureStrings[] = {
    "2:PySide6.QtCore.QStringDecoder(self)",
    "1:PySide6.QtCore.QStringDecoder(self,name:QString,f:PySide6.QtCore.QStringConverterBase.Flag=QStringConverterBase.Flag.Default)",
    "0:PySide6.QtCore.QStringDecoder(self,encoding:PySide6.QtCore.QStringConverter.Encoding,flags:PySide6.QtCore.QStringConverterBase.Flag=QStringConverterBase.Flag.Default)",
    "PySide6.QtCore.QStringDecoder.appendToBuffer(self,out:QChar*,ba:typing.Union[PySide6.QtCore.QByteArray, char*])->QChar*",
    "PySide6.QtCore.QStringDecoder.decoderForHtml(data:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QStringDecoder",
    "PySide6.QtCore.QStringDecoder.requiredSpace(self,inputLength:qsizetype)->qsizetype",
    nullptr}; // Sentinel
#else
static constexpr size_t QStringDecoder_SignatureByteSize = 232;
static constexpr uint8_t QStringDecoder_SignatureBytes[232] = {
    0x78, 0xda, 0xad, 0x8f, 0x3d, 0x4f, 0xc3, 0x30, 0x10, 0x86, 0xf7, 0xfc, 0x8a, 0x8e, 0x4d, 0x65,
    0x2c, 0xe8, 0xc0, 0x60, 0x09, 0x24, 0x92, 0x52, 0x31, 0x30, 0x34, 0x0a, 0x4c, 0x88, 0xe1, 0x88,
    0xcf, 0xa9, 0xa5, 0xd4, 0x76, 0x2f, 0x67, 0xa4, 0xf0, 0xeb, 0x31, 0x4a, 0x61, 0x40, 0x6a, 0x53,
    0x21, 0x26, 0x7f, 0xdc, 0xfb, 0xfa, 0x79, 0xbc, 0x54, 0x9b, 0xa1, 0xb6, 0x1a, 0xaf, 0x65, 0xc5,
    0xa5, 0x27, 0x94, 0x55, 0xcd, 0x64, 0x5d, 0xbb, 0xc2, 0xc6, 0x6b, 0xa4, 0x79, 0x8f, 0x9d, 0xc9,
    0xb3, 0xab, 0x33, 0x52, 0xc2, 0xc1, 0x0e, 0xd5, 0x61, 0x20, 0xcc, 0x91, 0x46, 0xe9, 0xdd, 0x3b,
    0x12, 0x23, 0x15, 0xd0, 0xa3, 0x5c, 0x77, 0xd0, 0xde, 0x1c, 0x9d, 0xc8, 0x15, 0x1a, 0x88, 0x1d,
    0xe7, 0xd9, 0xe5, 0x39, 0x7c, 0x74, 0xe9, 0x90, 0x2e, 0xa7, 0xc8, 0xf2, 0xfe, 0x10, 0x14, 0x26,
    0x41, 0xfa, 0x7f, 0x15, 0x3d, 0xa9, 0x29, 0x21, 0x04, 0x74, 0xfa, 0xc9, 0x17, 0xd1, 0x98, 0x6f,
    0x6b, 0x1f, 0x59, 0x55, 0xe5, 0x16, 0x68, 0x21, 0xde, 0x40, 0xf1, 0x10, 0x52, 0x5e, 0x3e, 0x3b,
    0xeb, 0xdd, 0xcb, 0xef, 0xc7, 0x8a, 0x81, 0xf1, 0x8e, 0x08, 0x06, 0x31, 0x6b, 0xbe, 0x0a, 0xaf,
    0xf9, 0xc5, 0xed, 0x58, 0x9d, 0xe0, 0xea, 0x71, 0x5d, 0x7b, 0x7a, 0xe0, 0x5d, 0x37, 0xd7, 0xc0,
    0x7f, 0x20, 0x9d, 0x44, 0x4c, 0x08, 0x10, 0xee, 0xa3, 0x25, 0xd4, 0x75, 0x80, 0x06, 0xc7, 0x7f,
    0x5b, 0x17, 0x22, 0x3f, 0xa2, 0x6b, 0x79, 0xab, 0xf6, 0xbd, 0xfd, 0xc0, 0x24, 0x84, 0x09, 0xf3,
    0xb3, 0xcf, 0x3e, 0x01, 0xe2, 0x74, 0xf1, 0x90
};
#endif

PyTypeObject *init_QStringDecoder(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX].type;

    Shiboken::AutoDecRef Sbk_QStringDecoder_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX]))));

    _Sbk_QStringDecoder_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStringDecoder",
        "QStringDecoder*",
        &Sbk_QStringDecoder_spec,
        &Shiboken::callCppDestructor< ::QStringDecoder >,
        Sbk_QStringDecoder_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStringDecoder_TypeF(); // references _Sbk_QStringDecoder_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStringDecoder_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStringDecoder_SignatureBytes, QStringDecoder_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStringDecoder_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStringDecoder_PythonToCpp_QStringDecoder_PTR,
        is_QStringDecoder_PythonToCpp_QStringDecoder_PTR_Convertible,
        QStringDecoder_PTR_CppToPython_QStringDecoder);

    Shiboken::Conversions::registerConverterName(converter, "QStringDecoder");
    Shiboken::Conversions::registerConverterName(converter, "QStringDecoder*");
    Shiboken::Conversions::registerConverterName(converter, "QStringDecoder&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStringDecoder).name());

    qRegisterMetaType< ::QStringDecoder *>();

    return pyType;
}
