// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qstringencoder_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QStringList>
#include <QStringView>
#include <qbytearray.h>
#include <qstringconverter_base.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStringEncoder_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStringEncoder >()))
        return -1;

    ::QStringEncoder *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QStringEncoder", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStringEncoder::QStringEncoder()
    // 1: QStringEncoder::QStringEncoder(QAnyStringView,QFlags<QStringConverterBase::Flag>=)
    // 2: QStringEncoder::QStringEncoder(QStringConverter::Encoding,QFlags<QStringConverterBase::Flag>=)
    if (numArgs == 0) {
        overloadId = 0; // QStringEncoder()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_Encoding_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QStringEncoder(QStringConverter::Encoding,QFlags<QStringConverterBase::Flag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 2; // QStringEncoder(QStringConverter::Encoding,QFlags<QStringConverterBase::Flag>)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QStringEncoder(QAnyStringView,QFlags<QStringConverterBase::Flag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 1; // QStringEncoder(QAnyStringView,QFlags<QStringConverterBase::Flag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStringEncoder()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX]);
            }

            // QStringEncoder()
            cptr = new ::QStringEncoder();
            break;
        }
        case 1: // QStringEncoder(QAnyStringView name, QFlags<QStringConverterBase::Flag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QStringConverterBase::Flag> cppArg1(QStringConverterBase::Flag::Default);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStringEncoder(QAnyStringView,QFlags<QStringConverterBase::Flag>)
                cptr = new ::QStringEncoder(QAnyStringView(cppArg0), cppArg1);
            }
            break;
        }
        case 2: // QStringEncoder(QStringConverter::Encoding encoding, QFlags<QStringConverterBase::Flag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX]);
                }
            }
            ::QStringConverter::Encoding cppArg0{QStringConverter::Utf8};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QStringConverterBase::Flag> cppArg1(QStringConverterBase::Flag::Default);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStringEncoder(QStringConverter::Encoding,QFlags<QStringConverterBase::Flag>)
                cptr = new ::QStringEncoder(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStringEncoder >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QStringEncoderFunc_requiredSpace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringEncoder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStringEncoder::requiredSpace(qsizetype)const->qsizetype
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // requiredSpace(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "requiredSpace", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // requiredSpace(qsizetype)const
            qsizetype cppResult = const_cast<const ::QStringEncoder *>(cppSelf)->requiredSpace(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QStringEncoder_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStringEncoder_methods[] = {
    {"requiredSpace", reinterpret_cast<PyCFunction>(Sbk_QStringEncoderFunc_requiredSpace), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStringEncoder_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStringEncoder_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStringEncoder_Type = nullptr;
static PyTypeObject *Sbk_QStringEncoder_TypeF(void)
{
    return _Sbk_QStringEncoder_Type;
}

static PyType_Slot Sbk_QStringEncoder_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStringEncoder_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStringEncoder_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStringEncoder_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStringEncoder_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStringEncoder_spec = {
    "2:PySide6.QtCore.QStringEncoder",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStringEncoder_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStringEncoder_PythonToCpp_QStringEncoder_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStringEncoder_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStringEncoder_PythonToCpp_QStringEncoder_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStringEncoder_TypeF()))
        return QStringEncoder_PythonToCpp_QStringEncoder_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStringEncoder_PTR_CppToPython_QStringEncoder(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QStringEncoder_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QStringEncoder_SignatureStrings[] = {
    "2:PySide6.QtCore.QStringEncoder(self)",
    "1:PySide6.QtCore.QStringEncoder(self,name:QString,flags:PySide6.QtCore.QStringConverterBase.Flag=QStringConverterBase.Flag.Default)",
    "0:PySide6.QtCore.QStringEncoder(self,encoding:PySide6.QtCore.QStringConverter.Encoding,flags:PySide6.QtCore.QStringConverterBase.Flag=QStringConverterBase.Flag.Default)",
    "PySide6.QtCore.QStringEncoder.requiredSpace(self,inputLength:qsizetype)->qsizetype",
    nullptr}; // Sentinel
#else
static constexpr size_t QStringEncoder_SignatureByteSize = 156;
static constexpr uint8_t QStringEncoder_SignatureBytes[156] = {
    0x78, 0xda, 0xb5, 0x8e, 0xb1, 0x0e, 0x82, 0x30, 0x10, 0x86, 0x77, 0x9e, 0x44, 0x12, 0x6c, 0xd4,
    0xc1, 0xa1, 0x89, 0x0e, 0x22, 0x4e, 0x0e, 0x92, 0x3e, 0x41, 0x43, 0xff, 0x62, 0x13, 0x2c, 0x70,
    0x3d, 0x4c, 0xf0, 0xe9, 0xc5, 0x48, 0xdc, 0x50, 0x16, 0xb7, 0xfb, 0xef, 0xff, 0x2e, 0xf7, 0x6d,
    0xe4, 0xa5, 0x57, 0xce, 0x60, 0x2b, 0x72, 0x4e, 0x6b, 0x82, 0xc8, 0x15, 0x93, 0xf3, 0x65, 0xe6,
    0x8b, 0xda, 0x80, 0x16, 0x01, 0x95, 0x8d, 0xa3, 0xf5, 0x0c, 0x2a, 0xf1, 0xfa, 0x06, 0x39, 0x16,
    0x89, 0xad, 0x74, 0x19, 0x26, 0xae, 0xd2, 0xda, 0xdf, 0x41, 0x0c, 0x3a, 0xe8, 0x00, 0x71, 0x1a,
    0xc8, 0xdd, 0x64, 0x23, 0x8e, 0xb0, 0xba, 0xab, 0x38, 0x8e, 0x56, 0x73, 0x1c, 0xf0, 0x0a, 0xc3,
    0xf2, 0xd7, 0x67, 0x91, 0x8d, 0xe0, 0x1f, 0x44, 0xbf, 0x6a, 0x0a, 0x42, 0xdb, 0x39, 0x82, 0x51,
    0x8d, 0x2e, 0xf0, 0x96, 0x76, 0xbe, 0xe9, 0xf8, 0x0c, 0x5f, 0xf2, 0x55, 0xb6, 0xc1, 0x3d, 0xc0,
    0x7d, 0x83, 0x78, 0xb9, 0xff, 0xcc, 0xd1, 0x13, 0x2a, 0x5d, 0x9a, 0x95
};
#endif

PyTypeObject *init_QStringEncoder(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX].type;

    Shiboken::AutoDecRef Sbk_QStringEncoder_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX]))));

    _Sbk_QStringEncoder_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStringEncoder",
        "QStringEncoder*",
        &Sbk_QStringEncoder_spec,
        &Shiboken::callCppDestructor< ::QStringEncoder >,
        Sbk_QStringEncoder_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStringEncoder_TypeF(); // references _Sbk_QStringEncoder_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QStringEncoder_SignatureStrings);
#else
    InitSignatureBytes(pyType, QStringEncoder_SignatureBytes, QStringEncoder_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStringEncoder_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QStringEncoder_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStringEncoder_PythonToCpp_QStringEncoder_PTR,
        is_QStringEncoder_PythonToCpp_QStringEncoder_PTR_Convertible,
        QStringEncoder_PTR_CppToPython_QStringEncoder);

    Shiboken::Conversions::registerConverterName(converter, "QStringEncoder");
    Shiboken::Conversions::registerConverterName(converter, "QStringEncoder*");
    Shiboken::Conversions::registerConverterName(converter, "QStringEncoder&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStringEncoder).name());

    qRegisterMetaType< ::QStringEncoder *>();

    return pyType;
}
