// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qsysinfo_wrapper.h"

// Argument includes
#include <QString>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSysInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSysInfo >()))
        return -1;

    ::QSysInfo *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QSysInfo()
        cptr = new ::QSysInfo();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSysInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSysInfoFunc_bootUniqueId(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bootUniqueId()
        QByteArray cppResult = ::QSysInfo::bootUniqueId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_buildAbi(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // buildAbi()
        QString cppResult = ::QSysInfo::buildAbi();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_buildCpuArchitecture(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // buildCpuArchitecture()
        QString cppResult = ::QSysInfo::buildCpuArchitecture();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_currentCpuArchitecture(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentCpuArchitecture()
        QString cppResult = ::QSysInfo::currentCpuArchitecture();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_kernelType(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // kernelType()
        QString cppResult = ::QSysInfo::kernelType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_kernelVersion(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // kernelVersion()
        QString cppResult = ::QSysInfo::kernelVersion();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_machineHostName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // machineHostName()
        QString cppResult = ::QSysInfo::machineHostName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_machineUniqueId(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // machineUniqueId()
        QByteArray cppResult = ::QSysInfo::machineUniqueId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_prettyProductName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // prettyProductName()
        QString cppResult = ::QSysInfo::prettyProductName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_productType(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // productType()
        QString cppResult = ::QSysInfo::productType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_productVersion(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // productVersion()
        QString cppResult = ::QSysInfo::productVersion();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSysInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSysInfo_EnumFlagInfo[] = {
    "Endian:Enum",
    "Sizes:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSysInfo_methods[] = {
    {"bootUniqueId", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_bootUniqueId), METH_NOARGS|METH_STATIC, nullptr},
    {"buildAbi", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_buildAbi), METH_NOARGS|METH_STATIC, nullptr},
    {"buildCpuArchitecture", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_buildCpuArchitecture), METH_NOARGS|METH_STATIC, nullptr},
    {"currentCpuArchitecture", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_currentCpuArchitecture), METH_NOARGS|METH_STATIC, nullptr},
    {"kernelType", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_kernelType), METH_NOARGS|METH_STATIC, nullptr},
    {"kernelVersion", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_kernelVersion), METH_NOARGS|METH_STATIC, nullptr},
    {"machineHostName", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_machineHostName), METH_NOARGS|METH_STATIC, nullptr},
    {"machineUniqueId", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_machineUniqueId), METH_NOARGS|METH_STATIC, nullptr},
    {"prettyProductName", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_prettyProductName), METH_NOARGS|METH_STATIC, nullptr},
    {"productType", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_productType), METH_NOARGS|METH_STATIC, nullptr},
    {"productVersion", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_productVersion), METH_NOARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSysInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSysInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSysInfo_Type = nullptr;
static PyTypeObject *Sbk_QSysInfo_TypeF(void)
{
    return _Sbk_QSysInfo_Type;
}

static PyType_Slot Sbk_QSysInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSysInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSysInfo_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSysInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSysInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSysInfo_spec = {
    "2:PySide6.QtCore.QSysInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSysInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSysInfo_Sizes(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSysInfo::Sizes>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSysInfo::Sizes *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSysInfo_Sizes_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_Sizes_IDX])))
        return Enum_PythonToCpp_QSysInfo_Sizes;
    return {};
}

static PyObject *QSysInfo_Sizes_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSysInfo::Sizes>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSysInfo::Sizes *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_Sizes_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSysInfo_Endian(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSysInfo::Endian>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSysInfo::Endian *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSysInfo_Endian_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_Endian_IDX])))
        return Enum_PythonToCpp_QSysInfo_Endian;
    return {};
}

static PyObject *QSysInfo_Endian_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSysInfo::Endian>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSysInfo::Endian *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_Endian_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSysInfo_PythonToCpp_QSysInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSysInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSysInfo_PythonToCpp_QSysInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSysInfo_TypeF()))
        return QSysInfo_PythonToCpp_QSysInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSysInfo_PTR_CppToPython_QSysInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSysInfo_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSysInfo_SignatureStrings[] = {
    "PySide6.QtCore.QSysInfo(self)",
    "PySide6.QtCore.QSysInfo.bootUniqueId()->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QSysInfo.buildAbi()->QString",
    "PySide6.QtCore.QSysInfo.buildCpuArchitecture()->QString",
    "PySide6.QtCore.QSysInfo.currentCpuArchitecture()->QString",
    "PySide6.QtCore.QSysInfo.kernelType()->QString",
    "PySide6.QtCore.QSysInfo.kernelVersion()->QString",
    "PySide6.QtCore.QSysInfo.machineHostName()->QString",
    "PySide6.QtCore.QSysInfo.machineUniqueId()->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QSysInfo.prettyProductName()->QString",
    "PySide6.QtCore.QSysInfo.productType()->QString",
    "PySide6.QtCore.QSysInfo.productVersion()->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QSysInfo_SignatureByteSize = 167;
static constexpr uint8_t QSysInfo_SignatureBytes[167] = {
    0x78, 0xda, 0xa5, 0x90, 0xb1, 0x0e, 0x82, 0x40, 0x0c, 0x40, 0x77, 0xbf, 0x04, 0x06, 0x19, 0x1d,
    0x4d, 0x90, 0x45, 0x16, 0x03, 0x41, 0xdd, 0xe1, 0xae, 0xe8, 0x45, 0x68, 0xcf, 0x5e, 0x6f, 0xb8,
    0xbf, 0x57, 0xa3, 0x93, 0x41, 0x73, 0xe8, 0xdc, 0xf7, 0xda, 0xe6, 0x55, 0xa1, 0x31, 0x1a, 0x56,
    0x59, 0x2d, 0x05, 0x31, 0x64, 0x75, 0x13, 0x5c, 0x89, 0x3d, 0x25, 0x0e, 0x86, 0x3e, 0x5d, 0x54,
    0xd3, 0xd3, 0xac, 0x23, 0x92, 0x03, 0x9a, 0xab, 0x87, 0x52, 0x27, 0xe9, 0x72, 0xfd, 0xce, 0x6d,
    0x82, 0x40, 0xce, 0xdc, 0x86, 0xcf, 0x1b, 0xbc, 0x19, 0x74, 0xde, 0x99, 0x87, 0x5d, 0x37, 0xc2,
    0x06, 0x4f, 0xdf, 0xd9, 0xc2, 0xfa, 0x9c, 0xd5, 0xd9, 0x08, 0x28, 0xf1, 0x0c, 0x31, 0x9e, 0xf2,
    0xcc, 0x80, 0xf2, 0x83, 0x79, 0x01, 0x46, 0x18, 0xf6, 0xc1, 0xce, 0xa0, 0x8f, 0xc0, 0xce, 0x10,
    0xc6, 0x08, 0x63, 0x7b, 0x7f, 0x07, 0x61, 0x4b, 0x4e, 0x76, 0xed, 0x08, 0x33, 0x94, 0xff, 0xa2,
    0x5b, 0x06, 0x91, 0x50, 0x31, 0x69, 0xaf, 0xa2, 0x2f, 0xdb, 0x27, 0x1e, 0x1b, 0xe3, 0x85, 0x4f,
    0xd4, 0xb8, 0x01, 0xf5, 0x87, 0xdb, 0x4e
};
#endif

PyTypeObject *init_QSysInfo(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QSysInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSysInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSysInfo",
        "QSysInfo*",
        &Sbk_QSysInfo_spec,
        &Shiboken::callCppDestructor< ::QSysInfo >,
        Sbk_QSysInfo_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSysInfo_TypeF(); // references _Sbk_QSysInfo_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSysInfo_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSysInfo_SignatureBytes, QSysInfo_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSysInfo_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSysInfo_PythonToCpp_QSysInfo_PTR,
        is_QSysInfo_PythonToCpp_QSysInfo_PTR_Convertible,
        QSysInfo_PTR_CppToPython_QSysInfo);

    Shiboken::Conversions::registerConverterName(converter, "QSysInfo");
    Shiboken::Conversions::registerConverterName(converter, "QSysInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QSysInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSysInfo).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSysInfo_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Sizes'.
    const char *Sizes_Initializer[] = {
        "WordSize",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Sizes_InitializerValues[] = {
        uint8_t(QSysInfo::Sizes::WordSize) //  0x40  64
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSysInfo_TypeF(),
        "2:PySide6.QtCore.QSysInfo.Sizes",
        Sizes_Initializer, Sizes_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_Sizes_IDX].type = EType;
    // Register converter for enum 'QSysInfo::Sizes'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSysInfo_Sizes_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSysInfo_Sizes,
            is_Enum_PythonToCpp_QSysInfo_Sizes_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSysInfo::Sizes");
        Shiboken::Conversions::registerConverterAlias(converter, "Sizes");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Sizes' enum.

    // Initialization of enum 'Endian'.
    const char *Endian_Initializer[] = {
        "BigEndian",
        "LittleEndian",
        "ByteOrder",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Endian_InitializerValues[] = {
        uint8_t(QSysInfo::Endian::BigEndian),    //  0x00  0
        uint8_t(QSysInfo::Endian::LittleEndian), //  0x01  1
        uint8_t(QSysInfo::Endian::ByteOrder)     //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSysInfo_TypeF(),
        "2:PySide6.QtCore.QSysInfo.Endian",
        Endian_Initializer, Endian_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_Endian_IDX].type = EType;
    // Register converter for enum 'QSysInfo::Endian'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSysInfo_Endian_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSysInfo_Endian,
            is_Enum_PythonToCpp_QSysInfo_Endian_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSysInfo::Endian");
        Shiboken::Conversions::registerConverterAlias(converter, "Endian");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Endian' enum.

    qRegisterMetaType< ::QSysInfo *>();
    qRegisterMetaType< ::QSysInfo::Sizes >("QSysInfo::Sizes");
    qRegisterMetaType< ::QSysInfo::Endian >("QSysInfo::Endian");

    return pyType;
}
