// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qtcorehelper_qmutexlocker_wrapper.h"

// Argument includes
#include <qmutex.h>
#include <qtcorehelper.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace QtCoreHelper;


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QtCoreHelper_QMutexLocker_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QtCoreHelper::QMutexLocker >()))
        return -1;

    ::QtCoreHelper::QMutexLocker *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QMutexLocker", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMutexLocker::QMutexLocker(QMutex*)
    // 1: QMutexLocker::QMutexLocker(QRecursiveMutex*)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QMutexLocker(QRecursiveMutex*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMutex_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QMutexLocker(QMutex*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QMutexLocker_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QMutexLocker_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QMutexLocker(QMutex *m)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QMutex *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMutexLocker(QMutex*)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QtCoreHelper::QMutexLocker(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "mutex()const0", pyArgs[0]);
            }
            break;
        }
        case 1: // QMutexLocker(QRecursiveMutex *m)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRecursiveMutex *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMutexLocker(QRecursiveMutex*)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QtCoreHelper::QMutexLocker(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "recursiveMutex()const0", pyArgs[0]);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QtCoreHelper::QMutexLocker >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QMutexLocker_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QtCoreHelper_QMutexLockerFunc___enter__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtCoreHelper::QMutexLocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QMutexLocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __enter__()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtcore.cpp (default-enter)]
        Py_INCREF(self);
        pyResult = self;
        // END of custom code block [file: ../glue/qtcore.cpp (default-enter)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtCoreHelper_QMutexLockerFunc___exit__(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtCoreHelper::QMutexLocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QMutexLocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "__exit__", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMutexLocker::__exit__(PyObject*,PyObject*,PyObject*)
    if (numArgs == 3
        && true
        && true
        && true) {
        overloadId = 0; // __exit__(PyObject*,PyObject*,PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "__exit__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QMutexLocker_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __exit__(PyObject*,PyObject*,PyObject*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (unlock)]
            cppSelf->unlock();
            // END of custom code block [file: ../glue/qtcore.cpp (unlock)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QtCoreHelper_QMutexLockerFunc_mutex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtCoreHelper::QMutexLocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QMutexLocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mutex()const
        QMutex * cppResult = const_cast<const ::QtCoreHelper::QMutexLocker *>(cppSelf)->mutex();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMutex_IDX]), cppResult);
        Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "mutex()const0", pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtCoreHelper_QMutexLockerFunc_recursiveMutex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtCoreHelper::QMutexLocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QMutexLocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // recursiveMutex()const
        QRecursiveMutex * cppResult = const_cast<const ::QtCoreHelper::QMutexLocker *>(cppSelf)->recursiveMutex();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]), cppResult);
        Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "recursiveMutex()const0", pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtCoreHelper_QMutexLockerFunc_relock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtCoreHelper::QMutexLocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QMutexLocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // relock()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        cppSelf->relock();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QtCoreHelper_QMutexLockerFunc_unlock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtCoreHelper::QMutexLocker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QMutexLocker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unlock()
        cppSelf->unlock();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QtCoreHelper_QMutexLocker_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QtCoreHelper_QMutexLocker_methods[] = {
    {"__enter__", reinterpret_cast<PyCFunction>(Sbk_QtCoreHelper_QMutexLockerFunc___enter__), METH_NOARGS, nullptr},
    {"__exit__", reinterpret_cast<PyCFunction>(Sbk_QtCoreHelper_QMutexLockerFunc___exit__), METH_VARARGS, nullptr},
    {"mutex", reinterpret_cast<PyCFunction>(Sbk_QtCoreHelper_QMutexLockerFunc_mutex), METH_NOARGS, nullptr},
    {"recursiveMutex", reinterpret_cast<PyCFunction>(Sbk_QtCoreHelper_QMutexLockerFunc_recursiveMutex), METH_NOARGS, nullptr},
    {"relock", reinterpret_cast<PyCFunction>(Sbk_QtCoreHelper_QMutexLockerFunc_relock), METH_NOARGS, nullptr},
    {"unlock", reinterpret_cast<PyCFunction>(Sbk_QtCoreHelper_QMutexLockerFunc_unlock), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QtCoreHelper_QMutexLocker_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QtCoreHelper_QMutexLocker_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QtCoreHelper_QMutexLocker_Type = nullptr;
static PyTypeObject *Sbk_QtCoreHelper_QMutexLocker_TypeF(void)
{
    return _Sbk_QtCoreHelper_QMutexLocker_Type;
}

static PyType_Slot Sbk_QtCoreHelper_QMutexLocker_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QtCoreHelper_QMutexLocker_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QtCoreHelper_QMutexLocker_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QtCoreHelper_QMutexLocker_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QtCoreHelper_QMutexLocker_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QtCoreHelper_QMutexLocker_spec = {
    "2:PySide6.QtCore.QMutexLocker",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QtCoreHelper_QMutexLocker_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMutexLocker_PythonToCpp_QMutexLocker_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QtCoreHelper_QMutexLocker_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMutexLocker_PythonToCpp_QMutexLocker_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QtCoreHelper_QMutexLocker_TypeF()))
        return QMutexLocker_PythonToCpp_QMutexLocker_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMutexLocker_PTR_CppToPython_QMutexLocker(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QtCoreHelper_QMutexLocker_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QtCoreHelper_QMutexLocker_SignatureStrings[] = {
    "1:PySide6.QtCore.QMutexLocker(self,m:PySide6.QtCore.QMutex)",
    "0:PySide6.QtCore.QMutexLocker(self,m:PySide6.QtCore.QRecursiveMutex)",
    "PySide6.QtCore.QMutexLocker.__enter__(self)->PySide6.QtCore.QMutexLocker",
    "PySide6.QtCore.QMutexLocker.__exit__(self,arg__1:PyObject,arg__2:PyObject,arg__3:PyObject)",
    "PySide6.QtCore.QMutexLocker.mutex(self)->PySide6.QtCore.QMutex",
    "PySide6.QtCore.QMutexLocker.recursiveMutex(self)->PySide6.QtCore.QRecursiveMutex",
    "PySide6.QtCore.QMutexLocker.relock(self)",
    "PySide6.QtCore.QMutexLocker.unlock(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QtCoreHelper_QMutexLocker_SignatureByteSize = 144;
static constexpr uint8_t QtCoreHelper_QMutexLocker_SignatureBytes[144] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce,
    0x2f, 0x4a, 0xd5, 0x0b, 0xf4, 0x2d, 0x2d, 0x49, 0xad, 0xf0, 0xc9, 0x4f, 0xce, 0x4e, 0x2d, 0xd2,
    0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xc9, 0xc5, 0xae, 0x44, 0x93, 0xcb, 0x80, 0x1c, 0xbd, 0x41, 0xa9,
    0xc9, 0xa5, 0x45, 0xc5, 0x99, 0x65, 0xa9, 0x50, 0x43, 0xf0, 0x18, 0xa1, 0x17, 0x1f, 0x9f, 0x9a,
    0x57, 0x92, 0x5a, 0x14, 0x1f, 0x0f, 0x36, 0x4c, 0x53, 0xd7, 0x0e, 0x8f, 0x62, 0x42, 0x06, 0x55,
    0x64, 0x96, 0x40, 0xcd, 0xd1, 0x49, 0x2c, 0x4a, 0x8f, 0x8f, 0x37, 0x04, 0xba, 0xcc, 0x3f, 0x29,
    0x2b, 0x35, 0xb9, 0x04, 0xc2, 0x37, 0x42, 0xe3, 0x1b, 0xc3, 0xf9, 0xf8, 0xdd, 0x98, 0x0b, 0x62,
    0xe3, 0x75, 0x1f, 0x5e, 0xed, 0x45, 0x28, 0xc1, 0x81, 0xcb, 0x1c, 0xd4, 0x40, 0x23, 0x60, 0x60,
    0x0e, 0x90, 0x01, 0x31, 0x08, 0xaf, 0xc2, 0xd2, 0x3c, 0x24, 0x85, 0x00, 0x38, 0x16, 0xb9, 0x3d
};
#endif

PyTypeObject *init_QtCoreHelper_QMutexLocker(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QMutexLocker_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QMutexLocker_IDX].type;

    Shiboken::AutoDecRef Sbk_QtCoreHelper_QMutexLocker_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QtCoreHelper_QMutexLocker_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMutexLocker",
        "QtCoreHelper::QMutexLocker*",
        &Sbk_QtCoreHelper_QMutexLocker_spec,
        &Shiboken::callCppDestructor< ::QtCoreHelper::QMutexLocker >,
        Sbk_QtCoreHelper_QMutexLocker_Type_bases.object(),
        0);
    auto *pyType = Sbk_QtCoreHelper_QMutexLocker_TypeF(); // references _Sbk_QtCoreHelper_QMutexLocker_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QtCoreHelper_QMutexLocker_SignatureStrings);
#else
    InitSignatureBytes(pyType, QtCoreHelper_QMutexLocker_SignatureBytes, QtCoreHelper_QMutexLocker_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QtCoreHelper_QMutexLocker_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QMutexLocker_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMutexLocker_PythonToCpp_QMutexLocker_PTR,
        is_QMutexLocker_PythonToCpp_QMutexLocker_PTR_Convertible,
        QMutexLocker_PTR_CppToPython_QMutexLocker);

    Shiboken::Conversions::registerConverterName(converter, "QtCoreHelper::QMutexLocker");
    Shiboken::Conversions::registerConverterName(converter, "QtCoreHelper::QMutexLocker*");
    Shiboken::Conversions::registerConverterName(converter, "QtCoreHelper::QMutexLocker&");
    Shiboken::Conversions::registerConverterAlias(converter, "QMutexLocker");
    Shiboken::Conversions::registerConverterAlias(converter, "QMutexLocker*");
    Shiboken::Conversions::registerConverterAlias(converter, "QMutexLocker&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QtCoreHelper::QMutexLocker).name());

    qRegisterMetaType< ::QtCoreHelper::QMutexLocker *>();

    return pyType;
}
