// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qtextboundaryfinder_wrapper.h"

// Argument includes
#include <QString>
#include <QStringView>
#include <qchar.h>
#include <qtextboundaryfinder.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextBoundaryFinder_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextBoundaryFinder >()))
        return -1;

    ::QTextBoundaryFinder *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:QTextBoundaryFinder", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextBoundaryFinder::QTextBoundaryFinder()
    // 1: QTextBoundaryFinder::QTextBoundaryFinder(QTextBoundaryFinder::BoundaryType,QStringView,uchar*=,qsizetype=)
    // 2: QTextBoundaryFinder::QTextBoundaryFinder(QTextBoundaryFinder::BoundaryType,QString)
    // 3: QTextBoundaryFinder::QTextBoundaryFinder(QTextBoundaryFinder)
    if (numArgs == 0) {
        overloadId = 0; // QTextBoundaryFinder()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QTextBoundaryFinder(QTextBoundaryFinder)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_BoundaryType_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 2; // QTextBoundaryFinder(QTextBoundaryFinder::BoundaryType,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // QTextBoundaryFinder(QTextBoundaryFinder::BoundaryType,QStringView,uchar*,qsizetype)
            } else if (numArgs >= 3
                && SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // QTextBoundaryFinder(QTextBoundaryFinder::BoundaryType,QStringView,uchar*,qsizetype)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[3])))) {
                    overloadId = 1; // QTextBoundaryFinder(QTextBoundaryFinder::BoundaryType,QStringView,uchar*,qsizetype)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextBoundaryFinder()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]);
            }

            // QTextBoundaryFinder()
            cptr = new ::QTextBoundaryFinder();
            break;
        }
        case 1: // QTextBoundaryFinder(QTextBoundaryFinder::BoundaryType type, QStringView str, unsigned char *buffer, qsizetype bufferSize)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_buffer = Shiboken::String::createStaticString("buffer");
                if (PyDict_Contains(kwds, key_buffer) != 0) {
                    value = PyDict_GetItem(kwds, key_buffer);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_buffer);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_buffer);
                }
                static PyObject *const key_bufferSize = Shiboken::String::createStaticString("bufferSize");
                if (PyDict_Contains(kwds, key_bufferSize) != 0) {
                    value = PyDict_GetItem(kwds, key_bufferSize);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_bufferSize);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_bufferSize);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]);
                }
            }
            ::QTextBoundaryFinder::BoundaryType cppArg0{QTextBoundaryFinder::Grapheme};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            unsigned char *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            qsizetype cppArg3 = 0;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextBoundaryFinder(QTextBoundaryFinder::BoundaryType,QStringView,uchar*,qsizetype)
                cptr = new ::QTextBoundaryFinder(cppArg0, QStringView(cppArg1), cppArg2, cppArg3);
            }
            break;
        }
        case 2: // QTextBoundaryFinder(QTextBoundaryFinder::BoundaryType type, const QString &string)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]);
            }
            ::QTextBoundaryFinder::BoundaryType cppArg0{QTextBoundaryFinder::Grapheme};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextBoundaryFinder(QTextBoundaryFinder::BoundaryType,QString)
                cptr = new ::QTextBoundaryFinder(cppArg0, cppArg1);
            }
            break;
        }
        case 3: // QTextBoundaryFinder(const QTextBoundaryFinder &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextBoundaryFinder cppArg0_local;
            ::QTextBoundaryFinder *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextBoundaryFinder(QTextBoundaryFinder)
                cptr = new ::QTextBoundaryFinder(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextBoundaryFinder >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextBoundaryFinderFunc_boundaryReasons(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBoundaryFinder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // boundaryReasons()const
        QFlags<QTextBoundaryFinder::BoundaryReason> cppResult = const_cast<const ::QTextBoundaryFinder *>(cppSelf)->boundaryReasons();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QTextBoundaryFinder_BoundaryReason_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBoundaryFinderFunc_isAtBoundary(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBoundaryFinder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAtBoundary()const
        bool cppResult = const_cast<const ::QTextBoundaryFinder *>(cppSelf)->isAtBoundary();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBoundaryFinderFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBoundaryFinder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QTextBoundaryFinder *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBoundaryFinderFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBoundaryFinder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // position()const
        qsizetype cppResult = const_cast<const ::QTextBoundaryFinder *>(cppSelf)->position();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBoundaryFinderFunc_setPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBoundaryFinder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextBoundaryFinder::setPosition(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // setPosition(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPosition", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPosition(qsizetype)
            cppSelf->setPosition(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBoundaryFinderFunc_string(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBoundaryFinder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // string()const
        QString cppResult = const_cast<const ::QTextBoundaryFinder *>(cppSelf)->string();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBoundaryFinderFunc_toEnd(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBoundaryFinder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toEnd()
        cppSelf->toEnd();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBoundaryFinderFunc_toNextBoundary(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBoundaryFinder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toNextBoundary()
        qsizetype cppResult = cppSelf->toNextBoundary();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBoundaryFinderFunc_toPreviousBoundary(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBoundaryFinder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toPreviousBoundary()
        qsizetype cppResult = cppSelf->toPreviousBoundary();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBoundaryFinderFunc_toStart(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBoundaryFinder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toStart()
        cppSelf->toStart();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextBoundaryFinderFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextBoundaryFinder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QTextBoundaryFinder::BoundaryType cppResult = const_cast<const ::QTextBoundaryFinder *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_BoundaryType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextBoundaryFinder__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextBoundaryFinder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextBoundaryFinder_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTextBoundaryFinder_EnumFlagInfo[] = {
    "BoundaryReason:Flag:BoundaryReasons",
    "BoundaryType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextBoundaryFinder_methods[] = {
    {"boundaryReasons", reinterpret_cast<PyCFunction>(Sbk_QTextBoundaryFinderFunc_boundaryReasons), METH_NOARGS, nullptr},
    {"isAtBoundary", reinterpret_cast<PyCFunction>(Sbk_QTextBoundaryFinderFunc_isAtBoundary), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QTextBoundaryFinderFunc_isValid), METH_NOARGS, nullptr},
    {"position", reinterpret_cast<PyCFunction>(Sbk_QTextBoundaryFinderFunc_position), METH_NOARGS, nullptr},
    {"setPosition", reinterpret_cast<PyCFunction>(Sbk_QTextBoundaryFinderFunc_setPosition), METH_O, nullptr},
    {"string", reinterpret_cast<PyCFunction>(Sbk_QTextBoundaryFinderFunc_string), METH_NOARGS, nullptr},
    {"toEnd", reinterpret_cast<PyCFunction>(Sbk_QTextBoundaryFinderFunc_toEnd), METH_NOARGS, nullptr},
    {"toNextBoundary", reinterpret_cast<PyCFunction>(Sbk_QTextBoundaryFinderFunc_toNextBoundary), METH_NOARGS, nullptr},
    {"toPreviousBoundary", reinterpret_cast<PyCFunction>(Sbk_QTextBoundaryFinderFunc_toPreviousBoundary), METH_NOARGS, nullptr},
    {"toStart", reinterpret_cast<PyCFunction>(Sbk_QTextBoundaryFinderFunc_toStart), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QTextBoundaryFinderFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextBoundaryFinder__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTextBoundaryFinder_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextBoundaryFinder_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextBoundaryFinder_Type = nullptr;
static PyTypeObject *Sbk_QTextBoundaryFinder_TypeF(void)
{
    return _Sbk_QTextBoundaryFinder_Type;
}

static PyType_Slot Sbk_QTextBoundaryFinder_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextBoundaryFinder_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextBoundaryFinder_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextBoundaryFinder_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextBoundaryFinder_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextBoundaryFinder_spec = {
    "2:PySide6.QtCore.QTextBoundaryFinder",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextBoundaryFinder_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QTextBoundaryFinder_BoundaryType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextBoundaryFinder::BoundaryType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextBoundaryFinder::BoundaryType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextBoundaryFinder_BoundaryType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_BoundaryType_IDX])))
        return Enum_PythonToCpp_QTextBoundaryFinder_BoundaryType;
    return {};
}

static PyObject *QTextBoundaryFinder_BoundaryType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextBoundaryFinder::BoundaryType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextBoundaryFinder::BoundaryType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_BoundaryType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTextBoundaryFinder_BoundaryReason(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextBoundaryFinder::BoundaryReason>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextBoundaryFinder::BoundaryReason *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextBoundaryFinder_BoundaryReason_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_BoundaryReason_IDX])))
        return Enum_PythonToCpp_QTextBoundaryFinder_BoundaryReason;
    return {};
}

static PyObject *QTextBoundaryFinder_BoundaryReason_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextBoundaryFinder::BoundaryReason>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextBoundaryFinder::BoundaryReason *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_BoundaryReason_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QTextBoundaryFinder_BoundaryReason(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QTextBoundaryFinder::BoundaryReason>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QTextBoundaryFinder::BoundaryReason> *>(cppOut) = value;

}

static PyObject *QTextBoundaryFinder_BoundaryReason_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QTextBoundaryFinder::BoundaryReason> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_BoundaryReason_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextBoundaryFinder_PythonToCpp_QTextBoundaryFinder_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextBoundaryFinder_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextBoundaryFinder_PythonToCpp_QTextBoundaryFinder_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextBoundaryFinder_TypeF()))
        return QTextBoundaryFinder_PythonToCpp_QTextBoundaryFinder_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextBoundaryFinder_PTR_CppToPython_QTextBoundaryFinder(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTextBoundaryFinder_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTextBoundaryFinder_COPY_CppToPython_QTextBoundaryFinder(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextBoundaryFinder *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextBoundaryFinder_TypeF(), new ::QTextBoundaryFinder(*source), true, true);
}

// Python to C++ copy conversion.
static void QTextBoundaryFinder_PythonToCpp_QTextBoundaryFinder_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextBoundaryFinder *>(cppOut) = *reinterpret_cast< ::QTextBoundaryFinder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextBoundaryFinder_PythonToCpp_QTextBoundaryFinder_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextBoundaryFinder_TypeF()))
        return QTextBoundaryFinder_PythonToCpp_QTextBoundaryFinder_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextBoundaryFinder_SignatureStrings[] = {
    "3:PySide6.QtCore.QTextBoundaryFinder(self)",
    "2:PySide6.QtCore.QTextBoundaryFinder(self,type:PySide6.QtCore.QTextBoundaryFinder.BoundaryType,str:QString,buffer:unsigned char*=nullptr,bufferSize:qsizetype=0)",
    "1:PySide6.QtCore.QTextBoundaryFinder(self,type:PySide6.QtCore.QTextBoundaryFinder.BoundaryType,string:QString)",
    "0:PySide6.QtCore.QTextBoundaryFinder(self,other:PySide6.QtCore.QTextBoundaryFinder)",
    "PySide6.QtCore.QTextBoundaryFinder.boundaryReasons(self)->PySide6.QtCore.QTextBoundaryFinder.BoundaryReason",
    "PySide6.QtCore.QTextBoundaryFinder.isAtBoundary(self)->bool",
    "PySide6.QtCore.QTextBoundaryFinder.isValid(self)->bool",
    "PySide6.QtCore.QTextBoundaryFinder.position(self)->qsizetype",
    "PySide6.QtCore.QTextBoundaryFinder.setPosition(self,position:qsizetype)",
    "PySide6.QtCore.QTextBoundaryFinder.string(self)->QString",
    "PySide6.QtCore.QTextBoundaryFinder.toEnd(self)",
    "PySide6.QtCore.QTextBoundaryFinder.toNextBoundary(self)->qsizetype",
    "PySide6.QtCore.QTextBoundaryFinder.toPreviousBoundary(self)->qsizetype",
    "PySide6.QtCore.QTextBoundaryFinder.toStart(self)",
    "PySide6.QtCore.QTextBoundaryFinder.type(self)->PySide6.QtCore.QTextBoundaryFinder.BoundaryType",
    "PySide6.QtCore.QTextBoundaryFinder.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextBoundaryFinder_SignatureByteSize = 273;
static constexpr uint8_t QTextBoundaryFinder_SignatureBytes[273] = {
    0x78, 0xda, 0xb5, 0x52, 0xc1, 0x4a, 0xc4, 0x30, 0x10, 0xbd, 0xe7, 0x2b, 0x3c, 0x5a, 0xa9, 0x65,
    0x55, 0xf0, 0x50, 0x58, 0x41, 0x45, 0x8f, 0xd2, 0xda, 0xe2, 0xb5, 0xa4, 0x9b, 0xe9, 0x6e, 0xa0,
    0x64, 0x6a, 0x32, 0x11, 0xeb, 0xd7, 0x1b, 0x69, 0xb3, 0xee, 0xcd, 0xe9, 0x2e, 0x5e, 0x02, 0x93,
    0xbc, 0x37, 0xef, 0x4d, 0xde, 0xdc, 0xe4, 0xc5, 0x58, 0x69, 0x05, 0xb7, 0x59, 0x49, 0x8f, 0x68,
    0x21, 0x2b, 0x6b, 0xf8, 0xa4, 0x07, 0xf4, 0x46, 0x49, 0x3b, 0x3e, 0x6b, 0xa3, 0xc0, 0x9e, 0x3b,
    0xe8, 0xbb, 0x44, 0x5c, 0x73, 0xa1, 0x29, 0x8d, 0x03, 0x30, 0xc0, 0x59, 0x2c, 0xeb, 0x80, 0x4f,
    0x1d, 0xd9, 0xbc, 0xac, 0xc8, 0x6a, 0xb3, 0x4d, 0x5b, 0xdf, 0x75, 0x60, 0x73, 0x6f, 0x9c, 0xde,
    0x1a, 0x50, 0x67, 0x9b, 0x9d, 0xb4, 0x17, 0x6b, 0xe3, 0xfb, 0x7e, 0x20, 0x3b, 0xbf, 0x56, 0xfa,
    0x0b, 0xf2, 0x77, 0x17, 0xce, 0x1f, 0xb9, 0xf5, 0x2a, 0x11, 0x57, 0xff, 0x6e, 0x30, 0x78, 0x8b,
    0x1e, 0x13, 0xb1, 0x62, 0xcb, 0x21, 0xed, 0xc2, 0x34, 0x7f, 0xa3, 0x13, 0xc1, 0xf0, 0xd4, 0xce,
    0xe5, 0x2b, 0x48, 0x87, 0xc6, 0x4d, 0xe1, 0x5c, 0xde, 0x2d, 0x98, 0x66, 0x62, 0x72, 0xb4, 0xb4,
    0xbb, 0xdf, 0x5f, 0x45, 0xa1, 0x16, 0xb1, 0xe7, 0x71, 0xdf, 0x64, 0xaf, 0xd5, 0x52, 0xda, 0x80,
    0x4e, 0x93, 0x46, 0x13, 0x79, 0xfb, 0x84, 0x39, 0x64, 0x07, 0x54, 0x1c, 0xf2, 0xd3, 0xd8, 0xed,
    0x77, 0x51, 0x58, 0x7f, 0x3c, 0x45, 0x1d, 0x2d, 0xcc, 0x89, 0x73, 0x88, 0x84, 0x4f, 0x66, 0x1e,
    0x99, 0x07, 0x7f, 0x39, 0xb8, 0x3c, 0x6a, 0x64, 0xc2, 0xc2, 0xc2, 0x87, 0x46, 0xef, 0x4e, 0x6c,
    0x53, 0x91, 0xb4, 0xb4, 0xc0, 0x7a, 0x68, 0x7c, 0xc4, 0xee, 0xd5, 0x4c, 0x3f, 0x4d, 0xb3, 0xc1,
    0x61, 0x6c, 0x9a, 0x28, 0x11, 0xe4, 0x42, 0x04, 0x59, 0x15, 0x2a, 0xf1, 0x0d, 0x18, 0xe7, 0xbb,
    0xfd
};
#endif

PyTypeObject *init_QTextBoundaryFinder(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextBoundaryFinder_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextBoundaryFinder_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextBoundaryFinder",
        "QTextBoundaryFinder",
        &Sbk_QTextBoundaryFinder_spec,
        &Shiboken::callCppDestructor< ::QTextBoundaryFinder >,
        Sbk_QTextBoundaryFinder_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextBoundaryFinder_TypeF(); // references _Sbk_QTextBoundaryFinder_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextBoundaryFinder_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextBoundaryFinder_SignatureBytes, QTextBoundaryFinder_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextBoundaryFinder_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextBoundaryFinder_PythonToCpp_QTextBoundaryFinder_PTR,
        is_QTextBoundaryFinder_PythonToCpp_QTextBoundaryFinder_PTR_Convertible,
        QTextBoundaryFinder_PTR_CppToPython_QTextBoundaryFinder,
        QTextBoundaryFinder_COPY_CppToPython_QTextBoundaryFinder);

    Shiboken::Conversions::registerConverterName(converter, "QTextBoundaryFinder");
    Shiboken::Conversions::registerConverterName(converter, "QTextBoundaryFinder*");
    Shiboken::Conversions::registerConverterName(converter, "QTextBoundaryFinder&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextBoundaryFinder).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextBoundaryFinder_PythonToCpp_QTextBoundaryFinder_COPY,
        is_QTextBoundaryFinder_PythonToCpp_QTextBoundaryFinder_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTextBoundaryFinder_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'BoundaryType'.
    const char *BoundaryType_Initializer[] = {
        "Grapheme",
        "Word",
        "Sentence",
        "Line",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t BoundaryType_InitializerValues[] = {
        uint8_t(QTextBoundaryFinder::BoundaryType::Grapheme), //  0x00  0
        uint8_t(QTextBoundaryFinder::BoundaryType::Word),     //  0x01  1
        uint8_t(QTextBoundaryFinder::BoundaryType::Sentence), //  0x02  2
        uint8_t(QTextBoundaryFinder::BoundaryType::Line)      //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextBoundaryFinder_TypeF(),
        "2:PySide6.QtCore.QTextBoundaryFinder.BoundaryType",
        BoundaryType_Initializer, BoundaryType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_BoundaryType_IDX].type = EType;
    // Register converter for enum 'QTextBoundaryFinder::BoundaryType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextBoundaryFinder_BoundaryType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextBoundaryFinder_BoundaryType,
            is_Enum_PythonToCpp_QTextBoundaryFinder_BoundaryType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextBoundaryFinder::BoundaryType");
        Shiboken::Conversions::registerConverterAlias(converter, "BoundaryType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'BoundaryType' enum.

    // Initialization of enum 'BoundaryReason'.
    const char *BoundaryReason_Initializer[] = {
        "NotAtBoundary",
        "BreakOpportunity",
        "StartOfItem",
        "EndOfItem",
        "MandatoryBreak",
        "SoftHyphen",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t BoundaryReason_InitializerValues[] = {
        uint16_t(QTextBoundaryFinder::BoundaryReason::NotAtBoundary),    //  0x0000  0
        uint16_t(QTextBoundaryFinder::BoundaryReason::BreakOpportunity), //  0x001f  31
        uint16_t(QTextBoundaryFinder::BoundaryReason::StartOfItem),      //  0x0020  32
        uint16_t(QTextBoundaryFinder::BoundaryReason::EndOfItem),        //  0x0040  64
        uint16_t(QTextBoundaryFinder::BoundaryReason::MandatoryBreak),   //  0x0080  128
        uint16_t(QTextBoundaryFinder::BoundaryReason::SoftHyphen)        //  0x0100  256
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextBoundaryFinder_TypeF(),
        "2:PySide6.QtCore.QTextBoundaryFinder.BoundaryReason",
        BoundaryReason_Initializer, BoundaryReason_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QTextBoundaryFinder_BoundaryReason_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QTextBoundaryFinder_BoundaryReason_IDX].type =
        EType;
    // Register converter for enum 'QTextBoundaryFinder::BoundaryReason'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextBoundaryFinder_BoundaryReason_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextBoundaryFinder_BoundaryReason,
            is_Enum_PythonToCpp_QTextBoundaryFinder_BoundaryReason_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextBoundaryFinder::BoundaryReason");
        Shiboken::Conversions::registerConverterAlias(converter, "BoundaryReason");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QTextBoundaryFinder_BoundaryReason_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QTextBoundaryFinder_BoundaryReason,
            is_Enum_PythonToCpp_QTextBoundaryFinder_BoundaryReason_Convertible);
        // Register converter for flag 'QFlags<QTextBoundaryFinder::BoundaryReason>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QTextBoundaryFinder::BoundaryReason>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QTextBoundaryFinder::BoundaryReasons");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'BoundaryReason' enum/flags.

    qRegisterMetaType< ::QTextBoundaryFinder >("QTextBoundaryFinder");
    qRegisterMetaType< ::QTextBoundaryFinder::BoundaryType >("QTextBoundaryFinder::BoundaryType");
    qRegisterMetaType< ::QTextBoundaryFinder::BoundaryReason >("QTextBoundaryFinder::BoundaryReason");

    return pyType;
}
