// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qtextstream_wrapper.h"

// Argument includes
#include <QString>
#include <QStringView>
#include <QtCore/qlatin1stringview.h>
#include <qbytearray.h>
#include <qchar.h>
#include <qiodevice.h>
#include <qlocale.h>
#include <qstringconverter_base.h>
#include <qtextstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

QTextStreamWrapper::QTextStreamWrapper()
{
}

QTextStreamWrapper::QTextStreamWrapper(::QByteArray * array, ::QFlags<QIODeviceBase::OpenModeFlag> openMode) : QTextStream(array, openMode)
{
}

QTextStreamWrapper::QTextStreamWrapper(::QIODevice * device) : QTextStream(device)
{
}

QTextStreamWrapper::~QTextStreamWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextStream_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextStream >()))
        return -1;

    QTextStreamWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QTextStream", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextStream::QTextStream()
    // 1: QTextStream::QTextStream(QByteArray*,QFlags<QIODeviceBase::OpenModeFlag>=)
    // 2: QTextStream::QTextStream(QIODevice*)
    if (numArgs == 0) {
        overloadId = 0; // QTextStream()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QTextStream(QIODevice*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QTextStream(QByteArray*,QFlags<QIODeviceBase::OpenModeFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 1; // QTextStream(QByteArray*,QFlags<QIODeviceBase::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextStream()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);
            }

            // QTextStream()
            cptr = new QTextStreamWrapper();
            break;
        }
        case 1: // QTextStream(QByteArray *array, QFlags<QIODeviceBase::OpenModeFlag> openMode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_openMode = Shiboken::String::createStaticString("openMode");
                if (PyDict_Contains(kwds, key_openMode) != 0) {
                    value = PyDict_GetItem(kwds, key_openMode);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_openMode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_openMode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QIODeviceBase::OpenModeFlag> cppArg1(QIODeviceBase::OpenModeFlag::ReadWrite);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextStream(QByteArray*,QFlags<QIODeviceBase::OpenModeFlag>)
                cptr = new QTextStreamWrapper(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QTextStream(QIODevice *device)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextStream(QIODevice*)
                cptr = new QTextStreamWrapper(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QTextStream >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextStreamFunc_atEnd(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // atEnd()const
        bool cppResult = const_cast<const ::QTextStream *>(cppSelf)->atEnd();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_autoDetectUnicode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoDetectUnicode()const
        bool cppResult = const_cast<const ::QTextStream *>(cppSelf)->autoDetectUnicode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_device(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // device()const
        QIODevice * cppResult = const_cast<const ::QTextStream *>(cppSelf)->device();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_encoding(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // encoding()const
        QStringConverter::Encoding cppResult = const_cast<const ::QTextStream *>(cppSelf)->encoding();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_Encoding_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_fieldAlignment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fieldAlignment()const
        QTextStream::FieldAlignment cppResult = const_cast<const ::QTextStream *>(cppSelf)->fieldAlignment();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_FieldAlignment_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_fieldWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fieldWidth()const
        int cppResult = const_cast<const ::QTextStream *>(cppSelf)->fieldWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_flush(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flush()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        cppSelf->flush();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_generateByteOrderMark(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // generateByteOrderMark()const
        bool cppResult = const_cast<const ::QTextStream *>(cppSelf)->generateByteOrderMark();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_integerBase(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // integerBase()const
        int cppResult = const_cast<const ::QTextStream *>(cppSelf)->integerBase();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_locale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // locale()const
        QLocale cppResult = const_cast<const ::QTextStream *>(cppSelf)->locale();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_numberFlags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // numberFlags()const
        QFlags<QTextStream::NumberFlag> cppResult = const_cast<const ::QTextStream *>(cppSelf)->numberFlags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QTextStream_NumberFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_padChar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // padChar()const
        QChar cppResult = const_cast<const ::QTextStream *>(cppSelf)->padChar();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_pos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pos()const
        qint64 cppResult = const_cast<const ::QTextStream *>(cppSelf)->pos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_read(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextStream::read(qint64)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // read(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "read", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // read(qint64)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = cppSelf->read(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_readAll(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readAll()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        QString cppResult = cppSelf->readAll();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_readLine(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "readLine", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    if (PyArg_ParseTuple(args, "|O:readLine", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextStream::readLine(qint64=)->QString
    if (numArgs == 0) {
        overloadId = 0; // readLine(qint64)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        overloadId = 0; // readLine(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "readLine", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_maxlen = Shiboken::String::createStaticString("maxlen");
            if (PyDict_Contains(kwds, key_maxlen) != 0) {
                value = PyDict_GetItem(kwds, key_maxlen);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_maxlen);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "readLine", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "readLine", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_maxlen);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "readLine", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);
            }
        }
        qint64 cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // readLine(qint64)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = cppSelf->readLine(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_readLineInto(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "readLineInto", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    if (PyArg_ParseTuple(args, "|OO:readLineInto", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextStream::readLineInto(QString*,qint64=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // readLineInto(QString*,qint64)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))) {
            overloadId = 0; // readLineInto(QString*,qint64)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "readLineInto", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_maxlen = Shiboken::String::createStaticString("maxlen");
            if (PyDict_Contains(kwds, key_maxlen) != 0) {
                value = PyDict_GetItem(kwds, key_maxlen);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_maxlen);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "readLineInto", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "readLineInto", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_maxlen);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "readLineInto", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);
            }
        }
        ::QString *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qint64 cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // readLineInto(QString*,qint64)
            bool cppResult = cppSelf->readLineInto(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_realNumberNotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // realNumberNotation()const
        QTextStream::RealNumberNotation cppResult = const_cast<const ::QTextStream *>(cppSelf)->realNumberNotation();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_RealNumberNotation_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_realNumberPrecision(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // realNumberPrecision()const
        int cppResult = const_cast<const ::QTextStream *>(cppSelf)->realNumberPrecision();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_reset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reset()
        cppSelf->reset();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_resetStatus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resetStatus()
        cppSelf->resetStatus();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_seek(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextStream::seek(qint64)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // seek(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "seek", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // seek(qint64)
            bool cppResult = cppSelf->seek(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_setAutoDetectUnicode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextStream::setAutoDetectUnicode(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoDetectUnicode(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoDetectUnicode", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoDetectUnicode(bool)
            cppSelf->setAutoDetectUnicode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_setDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextStream::setDevice(QIODevice*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDevice", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDevice(QIODevice*)
            cppSelf->setDevice(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_setEncoding(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextStream::setEncoding(QStringConverter::Encoding)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_Encoding_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setEncoding(QStringConverter::Encoding)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEncoding", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        ::QStringConverter::Encoding cppArg0{QStringConverter::Utf8};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEncoding(QStringConverter::Encoding)
            cppSelf->setEncoding(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_setFieldAlignment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextStream::setFieldAlignment(QTextStream::FieldAlignment)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_FieldAlignment_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFieldAlignment(QTextStream::FieldAlignment)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFieldAlignment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        ::QTextStream::FieldAlignment cppArg0{QTextStream::AlignLeft};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFieldAlignment(QTextStream::FieldAlignment)
            cppSelf->setFieldAlignment(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_setFieldWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextStream::setFieldWidth(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setFieldWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFieldWidth", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFieldWidth(int)
            cppSelf->setFieldWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_setGenerateByteOrderMark(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextStream::setGenerateByteOrderMark(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setGenerateByteOrderMark(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGenerateByteOrderMark", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGenerateByteOrderMark(bool)
            cppSelf->setGenerateByteOrderMark(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_setIntegerBase(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextStream::setIntegerBase(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setIntegerBase(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIntegerBase", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIntegerBase(int)
            cppSelf->setIntegerBase(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_setLocale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextStream::setLocale(QLocale)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
        overloadId = 0; // setLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLocale", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocale(QLocale)
            cppSelf->setLocale(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_setNumberFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextStream::setNumberFlags(QFlags<QTextStream::NumberFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QTextStream_NumberFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setNumberFlags(QFlags<QTextStream::NumberFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNumberFlags", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        ::QFlags<QTextStream::NumberFlag> cppArg0 = QFlags<QTextStream::NumberFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNumberFlags(QFlags<QTextStream::NumberFlag>)
            cppSelf->setNumberFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_setPadChar(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextStream::setPadChar(QChar)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArg)))) {
        overloadId = 0; // setPadChar(QChar)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPadChar", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        ::QChar cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPadChar(QChar)
            cppSelf->setPadChar(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_setRealNumberNotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextStream::setRealNumberNotation(QTextStream::RealNumberNotation)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_RealNumberNotation_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setRealNumberNotation(QTextStream::RealNumberNotation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRealNumberNotation", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        ::QTextStream::RealNumberNotation cppArg0{QTextStream::SmartNotation};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRealNumberNotation(QTextStream::RealNumberNotation)
            cppSelf->setRealNumberNotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_setRealNumberPrecision(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextStream::setRealNumberPrecision(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setRealNumberPrecision(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRealNumberPrecision", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRealNumberPrecision(int)
            cppSelf->setRealNumberPrecision(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_setStatus(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextStream::setStatus(QTextStream::Status)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_Status_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setStatus(QTextStream::Status)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStatus", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

    // Call function/method
    {
        ::QTextStream::Status cppArg0{QTextStream::Ok};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStatus(QTextStream::Status)
            cppSelf->setStatus(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_skipWhiteSpace(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // skipWhiteSpace()
        cppSelf->skipWhiteSpace();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextStreamFunc_status(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // status()const
        QTextStream::Status cppResult = const_cast<const ::QTextStream *>(cppSelf)->status();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_Status_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc_string(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // string()const
        QString * cppResult = const_cast<const ::QTextStream *>(cppSelf)->string();
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtcore.cpp (return-qstring-ref)]
        QString &res = *cppResult;
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &res);
        // END of custom code block [file: ../glue/qtcore.cpp (return-qstring-ref)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextStream_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTextStream_EnumFlagInfo[] = {
    "FieldAlignment:Enum",
    "NumberFlag:Flag:NumberFlags",
    "RealNumberNotation:Enum",
    "Status:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextStream_methods[] = {
    {"atEnd", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_atEnd), METH_NOARGS, nullptr},
    {"autoDetectUnicode", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_autoDetectUnicode), METH_NOARGS, nullptr},
    {"device", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_device), METH_NOARGS, nullptr},
    {"encoding", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_encoding), METH_NOARGS, nullptr},
    {"fieldAlignment", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_fieldAlignment), METH_NOARGS, nullptr},
    {"fieldWidth", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_fieldWidth), METH_NOARGS, nullptr},
    {"flush", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_flush), METH_NOARGS, nullptr},
    {"generateByteOrderMark", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_generateByteOrderMark), METH_NOARGS, nullptr},
    {"integerBase", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_integerBase), METH_NOARGS, nullptr},
    {"locale", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_locale), METH_NOARGS, nullptr},
    {"numberFlags", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_numberFlags), METH_NOARGS, nullptr},
    {"padChar", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_padChar), METH_NOARGS, nullptr},
    {"pos", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_pos), METH_NOARGS, nullptr},
    {"read", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_read), METH_O, nullptr},
    {"readAll", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_readAll), METH_NOARGS, nullptr},
    {"readLine", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_readLine), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"readLineInto", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_readLineInto), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"realNumberNotation", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_realNumberNotation), METH_NOARGS, nullptr},
    {"realNumberPrecision", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_realNumberPrecision), METH_NOARGS, nullptr},
    {"reset", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_reset), METH_NOARGS, nullptr},
    {"resetStatus", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_resetStatus), METH_NOARGS, nullptr},
    {"seek", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_seek), METH_O, nullptr},
    {"setAutoDetectUnicode", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_setAutoDetectUnicode), METH_O, nullptr},
    {"setDevice", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_setDevice), METH_O, nullptr},
    {"setEncoding", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_setEncoding), METH_O, nullptr},
    {"setFieldAlignment", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_setFieldAlignment), METH_O, nullptr},
    {"setFieldWidth", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_setFieldWidth), METH_O, nullptr},
    {"setGenerateByteOrderMark", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_setGenerateByteOrderMark), METH_O, nullptr},
    {"setIntegerBase", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_setIntegerBase), METH_O, nullptr},
    {"setLocale", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_setLocale), METH_O, nullptr},
    {"setNumberFlags", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_setNumberFlags), METH_O, nullptr},
    {"setPadChar", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_setPadChar), METH_O, nullptr},
    {"setRealNumberNotation", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_setRealNumberNotation), METH_O, nullptr},
    {"setRealNumberPrecision", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_setRealNumberPrecision), METH_O, nullptr},
    {"setStatus", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_setStatus), METH_O, nullptr},
    {"skipWhiteSpace", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_skipWhiteSpace), METH_NOARGS, nullptr},
    {"status", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_status), METH_NOARGS, nullptr},
    {"string", reinterpret_cast<PyCFunction>(Sbk_QTextStreamFunc_string), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QTextStreamFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QTextStream::operator<<(QChar)->QTextStream&
        // 1: QTextStream::operator<<(QLatin1String)->QTextStream&
        // 2: QTextStream::operator<<(QStringView)->QTextStream&
        // 3: QTextStream::operator<<(QTextStreamManipulator)->QTextStream&
        // 4: QTextStream::operator<<(char)->QTextStream&
        // 5: QTextStream::operator<<(QByteArray)->QTextStream&
        // 6: QTextStream::operator<<(QString)->QTextStream&
        // 7: QTextStream::operator<<(double)->QTextStream&
        // 8: QTextStream::operator<<(long)->QTextStream&
        // 9: QTextStream::operator<<(ulong)->QTextStream&
        if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArg)))) {
            overloadId = 9; // operator<<(ulong)
        } else if (!isReverse
            && PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
            overloadId = 7; // operator<<(double)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<long>(), (pyArg)))) {
            overloadId = 8; // operator<<(long)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
            overloadId = 6; // operator<<(QString)
        } else if (!isReverse
            && SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArg)))) {
            overloadId = 4; // operator<<(char)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
            overloadId = 5; // operator<<(QByteArray)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStreamManipulator_IDX]), (pyArg)))) {
            overloadId = 3; // operator<<(QTextStream&,QTextStreamManipulator)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
            overloadId = 2; // operator<<(QStringView)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], (pyArg)))) {
            overloadId = 1; // operator<<(QLatin1String)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArg)))) {
            overloadId = 0; // operator<<(QChar)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

        // Call function/method
        switch (overloadId) {
            case 0: // operator<<(QChar ch)
            {
                ::QChar cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QChar)
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), &cppResult);
                }
                break;
            }
            case 1: // operator<<(QLatin1String s)
            {
                ::QLatin1String cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QLatin1String)
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), &cppResult);
                }
                break;
            }
            case 2: // operator<<(QStringView s)
            {
                ::QString cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QStringView)
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), &cppResult);
                }
                break;
            }
            case 3: // operator<<(QTextStreamManipulator m)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextStreamManipulator cppArg0 = QTextStreamManipulator(0, 0);
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QTextStream&,QTextStreamManipulator)
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), &cppResult);
                }
                break;
            }
            case 4: // operator<<(char ch)
            {
                char cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(char)
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), &cppResult);
                }
                break;
            }
            case 5: // operator<<(const QByteArray &array)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QByteArray cppArg0_local;
                ::QByteArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QByteArray)
                    QTextStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), &cppResult);
                }
                break;
            }
            case 6: // operator<<(const QString &s)
            {
                ::QString cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QString)
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), &cppResult);
                }
                break;
            }
            case 7: // operator<<(double f)
            {
                double cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(double)
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), &cppResult);
                }
                break;
            }
            case 8: // operator<<(long i)
            {
                long cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(long)
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), &cppResult);
                }
                break;
            }
            case 9: // operator<<(unsigned long i)
            {
                unsigned long cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(ulong)
                    QTextStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), &cppResult);
                }
                break;
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextStreamFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QTextStream::operator>>(QByteArray&)->QTextStream&
        if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QByteArray&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QByteArray&)
                QTextStream & cppResult = (*cppSelf) >> (*cppArg0);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

} // extern "C"

static int Sbk_QTextStream_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextStream_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextStream_Type = nullptr;
static PyTypeObject *Sbk_QTextStream_TypeF(void)
{
    return _Sbk_QTextStream_Type;
}

static PyType_Slot Sbk_QTextStream_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextStream_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextStream_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextStream_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextStream_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QTextStreamFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QTextStreamFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextStream_spec = {
    "2:PySide6.QtCore.QTextStream",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextStream_slots
};

} //extern "C"

static void *Sbk_QTextStream_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QTextStream_RealNumberNotation(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextStream::RealNumberNotation>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextStream::RealNumberNotation *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextStream_RealNumberNotation_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_RealNumberNotation_IDX])))
        return Enum_PythonToCpp_QTextStream_RealNumberNotation;
    return {};
}

static PyObject *QTextStream_RealNumberNotation_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextStream::RealNumberNotation>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextStream::RealNumberNotation *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_RealNumberNotation_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTextStream_FieldAlignment(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextStream::FieldAlignment>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextStream::FieldAlignment *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextStream_FieldAlignment_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_FieldAlignment_IDX])))
        return Enum_PythonToCpp_QTextStream_FieldAlignment;
    return {};
}

static PyObject *QTextStream_FieldAlignment_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextStream::FieldAlignment>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextStream::FieldAlignment *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_FieldAlignment_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTextStream_Status(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextStream::Status>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextStream::Status *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextStream_Status_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_Status_IDX])))
        return Enum_PythonToCpp_QTextStream_Status;
    return {};
}

static PyObject *QTextStream_Status_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextStream::Status>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextStream::Status *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_Status_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTextStream_NumberFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextStream::NumberFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextStream::NumberFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextStream_NumberFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_NumberFlag_IDX])))
        return Enum_PythonToCpp_QTextStream_NumberFlag;
    return {};
}

static PyObject *QTextStream_NumberFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextStream::NumberFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextStream::NumberFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_NumberFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QTextStream_NumberFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QTextStream::NumberFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QTextStream::NumberFlag> *>(cppOut) = value;

}

static PyObject *QTextStream_NumberFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QTextStream::NumberFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_NumberFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextStream_PythonToCpp_QTextStream_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextStream_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextStream_PythonToCpp_QTextStream_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextStream_TypeF()))
        return QTextStream_PythonToCpp_QTextStream_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextStream_PTR_CppToPython_QTextStream(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QTextStream *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QTextStream_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextStream_SignatureStrings[] = {
    "2:PySide6.QtCore.QTextStream(self)",
    "1:PySide6.QtCore.QTextStream(self,array:typing.Union[PySide6.QtCore.QByteArray, char*],openMode:PySide6.QtCore.QIODeviceBase.OpenModeFlag=QIODeviceBase.OpenModeFlag.ReadWrite)",
    "0:PySide6.QtCore.QTextStream(self,device:PySide6.QtCore.QIODevice)",
    "PySide6.QtCore.QTextStream.atEnd(self)->bool",
    "PySide6.QtCore.QTextStream.autoDetectUnicode(self)->bool",
    "PySide6.QtCore.QTextStream.device(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtCore.QTextStream.encoding(self)->PySide6.QtCore.QStringConverter.Encoding",
    "PySide6.QtCore.QTextStream.fieldAlignment(self)->PySide6.QtCore.QTextStream.FieldAlignment",
    "PySide6.QtCore.QTextStream.fieldWidth(self)->int",
    "PySide6.QtCore.QTextStream.flush(self)",
    "PySide6.QtCore.QTextStream.generateByteOrderMark(self)->bool",
    "PySide6.QtCore.QTextStream.integerBase(self)->int",
    "PySide6.QtCore.QTextStream.locale(self)->PySide6.QtCore.QLocale",
    "PySide6.QtCore.QTextStream.numberFlags(self)->PySide6.QtCore.QTextStream.NumberFlag",
    "PySide6.QtCore.QTextStream.padChar(self)->QChar",
    "PySide6.QtCore.QTextStream.pos(self)->qint64",
    "PySide6.QtCore.QTextStream.read(self,maxlen:qint64)->QString",
    "PySide6.QtCore.QTextStream.readAll(self)->QString",
    "PySide6.QtCore.QTextStream.readLine(self,maxlen:qint64=0)->QString",
    "PySide6.QtCore.QTextStream.readLineInto(self,line:QString*,maxlen:qint64=0)->bool",
    "PySide6.QtCore.QTextStream.realNumberNotation(self)->PySide6.QtCore.QTextStream.RealNumberNotation",
    "PySide6.QtCore.QTextStream.realNumberPrecision(self)->int",
    "PySide6.QtCore.QTextStream.reset(self)",
    "PySide6.QtCore.QTextStream.resetStatus(self)",
    "PySide6.QtCore.QTextStream.seek(self,pos:qint64)->bool",
    "PySide6.QtCore.QTextStream.setAutoDetectUnicode(self,enabled:bool)",
    "PySide6.QtCore.QTextStream.setDevice(self,device:PySide6.QtCore.QIODevice)",
    "PySide6.QtCore.QTextStream.setEncoding(self,encoding:PySide6.QtCore.QStringConverter.Encoding)",
    "PySide6.QtCore.QTextStream.setFieldAlignment(self,alignment:PySide6.QtCore.QTextStream.FieldAlignment)",
    "PySide6.QtCore.QTextStream.setFieldWidth(self,width:int)",
    "PySide6.QtCore.QTextStream.setGenerateByteOrderMark(self,generate:bool)",
    "PySide6.QtCore.QTextStream.setIntegerBase(self,base:int)",
    "PySide6.QtCore.QTextStream.setLocale(self,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])",
    "PySide6.QtCore.QTextStream.setNumberFlags(self,flags:PySide6.QtCore.QTextStream.NumberFlag)",
    "PySide6.QtCore.QTextStream.setPadChar(self,ch:QChar)",
    "PySide6.QtCore.QTextStream.setRealNumberNotation(self,notation:PySide6.QtCore.QTextStream.RealNumberNotation)",
    "PySide6.QtCore.QTextStream.setRealNumberPrecision(self,precision:int)",
    "PySide6.QtCore.QTextStream.setStatus(self,status:PySide6.QtCore.QTextStream.Status)",
    "PySide6.QtCore.QTextStream.skipWhiteSpace(self)",
    "PySide6.QtCore.QTextStream.status(self)->PySide6.QtCore.QTextStream.Status",
    "PySide6.QtCore.QTextStream.string(self)->QString*",
    "9:PySide6.QtCore.QTextStream.__lshift__(self,ch:QChar)->PySide6.QtCore.QTextStream",
    "8:PySide6.QtCore.QTextStream.__lshift__(self,s:QLatin1String)->PySide6.QtCore.QTextStream",
    "7:PySide6.QtCore.QTextStream.__lshift__(self,s:QString)->PySide6.QtCore.QTextStream",
    "6:PySide6.QtCore.QTextStream.__lshift__(self,m:PySide6.QtCore.QTextStreamManipulator)->PySide6.QtCore.QTextStream",
    "5:PySide6.QtCore.QTextStream.__lshift__(self,ch:char)->PySide6.QtCore.QTextStream",
    "4:PySide6.QtCore.QTextStream.__lshift__(self,array:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QTextStream",
    "3:PySide6.QtCore.QTextStream.__lshift__(self,s:QString)->PySide6.QtCore.QTextStream",
    "2:PySide6.QtCore.QTextStream.__lshift__(self,f:double)->PySide6.QtCore.QTextStream",
    "1:PySide6.QtCore.QTextStream.__lshift__(self,i:long)->PySide6.QtCore.QTextStream",
    "0:PySide6.QtCore.QTextStream.__lshift__(self,i:unsigned long)->PySide6.QtCore.QTextStream",
    "PySide6.QtCore.QTextStream.__rshift__(self,array:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QTextStream",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextStream_SignatureByteSize = 708;
static constexpr uint8_t QTextStream_SignatureBytes[708] = {
    0x78, 0xda, 0xb5, 0x97, 0x5d, 0x6f, 0xda, 0x30, 0x14, 0x86, 0xef, 0xf9, 0x15, 0x5c, 0x8e, 0xca,
    0x8b, 0xa0, 0xeb, 0xba, 0xcd, 0x52, 0x27, 0x51, 0xda, 0x4e, 0x95, 0x68, 0xcb, 0xc7, 0x26, 0x2e,
    0xa6, 0x0a, 0x99, 0xe4, 0x10, 0xac, 0x1a, 0x3b, 0x73, 0x9c, 0xb6, 0xfc, 0xfb, 0x39, 0x98, 0x40,
    0x0a, 0xc4, 0x76, 0x36, 0xf5, 0x26, 0xb2, 0xc9, 0x7b, 0x9e, 0x73, 0xe2, 0xe3, 0xbc, 0x31, 0xa7,
    0x78, 0xb0, 0x1a, 0xd3, 0x08, 0xce, 0x83, 0xa1, 0xea, 0x09, 0x09, 0xc1, 0xf0, 0x27, 0xbc, 0xaa,
    0xb1, 0x92, 0x40, 0x96, 0x1f, 0x52, 0x60, 0xf3, 0x56, 0xa3, 0xe3, 0x92, 0x20, 0x22, 0x25, 0x59,
    0x61, 0xb5, 0x4a, 0x28, 0x8f, 0x83, 0x5f, 0x9c, 0x0a, 0xfe, 0x7b, 0x3f, 0xe4, 0x72, 0xa5, 0xa0,
    0x9b, 0xcb, 0x50, 0x33, 0x5c, 0x10, 0x79, 0xf2, 0x88, 0x44, 0x02, 0xfc, 0x4e, 0x44, 0x70, 0x40,
    0xbf, 0x7d, 0xb8, 0x82, 0x67, 0x1a, 0xc2, 0x25, 0x49, 0x21, 0x78, 0xd8, 0xa8, 0x6e, 0x18, 0x89,
    0x2f, 0xaa, 0x6f, 0x05, 0x23, 0x20, 0xd1, 0x44, 0x52, 0x05, 0xad, 0x46, 0xdb, 0x59, 0x6f, 0xb4,
    0x86, 0x54, 0x26, 0x6e, 0x35, 0xaa, 0x01, 0x01, 0x51, 0xd7, 0x3c, 0x32, 0x2b, 0xf3, 0xf1, 0xfb,
    0x4c, 0x08, 0x66, 0x15, 0x67, 0x4a, 0x5c, 0x81, 0x82, 0x50, 0xe9, 0x55, 0x09, 0x75, 0xad, 0xbe,
    0x81, 0xa6, 0xc2, 0x42, 0x5d, 0x55, 0xa8, 0x8d, 0x00, 0x5c, 0xe7, 0xd3, 0xfd, 0xa8, 0x62, 0x68,
    0x99, 0xbe, 0xdb, 0x13, 0xfc, 0x19, 0xa4, 0x02, 0x19, 0x5c, 0x6f, 0xf4, 0x36, 0xe6, 0x9c, 0x02,
    0x8b, 0xba, 0x8c, 0xc6, 0x7c, 0x09, 0x5c, 0x55, 0x91, 0x4b, 0x01, 0x37, 0x6f, 0x02, 0x9c, 0xe8,
    0x09, 0x8d, 0xd4, 0xa2, 0xc0, 0x52, 0x47, 0x00, 0xcb, 0xd2, 0x8d, 0xd6, 0x26, 0x8b, 0x81, 0x83,
    0x24, 0x0a, 0xf2, 0xfd, 0xf7, 0x20, 0x23, 0x90, 0x77, 0x44, 0x3e, 0xf9, 0x76, 0x41, 0x97, 0x00,
    0x31, 0xc8, 0x7c, 0xb7, 0x79, 0x56, 0xc5, 0x44, 0x48, 0x58, 0x65, 0xdf, 0xfa, 0xeb, 0xbb, 0xb6,
    0x78, 0x9e, 0x2d, 0x67, 0x20, 0xf3, 0x1d, 0x9d, 0x7a, 0x2c, 0xef, 0xfd, 0x56, 0x6d, 0x63, 0x26,
    0x24, 0xea, 0xe9, 0x57, 0xae, 0xe0, 0x0d, 0xf3, 0x89, 0x55, 0x2f, 0xb6, 0xb9, 0xff, 0xe8, 0xc7,
    0x3d, 0x3f, 0xb3, 0x89, 0xf5, 0xc5, 0xbc, 0x0d, 0x68, 0x49, 0x5e, 0x19, 0x70, 0x6c, 0x42, 0xf2,
    0x3c, 0x66, 0x87, 0xb9, 0x82, 0xbb, 0x8c, 0x6d, 0x2b, 0xf3, 0x8b, 0xe8, 0x53, 0x0e, 0x47, 0x52,
    0x5e, 0xb4, 0xeb, 0x21, 0x6e, 0xb9, 0x12, 0x06, 0xc3, 0xf4, 0x0c, 0x6f, 0x22, 0x4f, 0x8e, 0x40,
    0x5d, 0xdb, 0x44, 0x5f, 0x98, 0x69, 0xc5, 0xbd, 0x50, 0x44, 0x69, 0xfb, 0xf3, 0xe8, 0xdd, 0xe8,
    0x20, 0xc8, 0x2f, 0xc5, 0x40, 0x42, 0x48, 0xd3, 0x52, 0x0e, 0xc7, 0x8e, 0x94, 0x90, 0x82, 0x72,
    0xbf, 0x27, 0x6b, 0xd9, 0x58, 0x17, 0x92, 0xa5, 0x6e, 0x71, 0x0a, 0x60, 0xde, 0x21, 0xa4, 0xf7,
    0xca, 0xae, 0xe3, 0xae, 0x75, 0xd2, 0x19, 0xba, 0x47, 0x0d, 0x11, 0x01, 0x27, 0x33, 0x06, 0x11,
    0xce, 0x09, 0x8e, 0xcc, 0xea, 0x6a, 0x67, 0x8d, 0xff, 0x65, 0xe4, 0x1a, 0x75, 0x5d, 0xf6, 0x48,
    0x54, 0x38, 0x26, 0xf6, 0xb5, 0x4a, 0x17, 0xfe, 0xe6, 0xd0, 0x2e, 0x11, 0x29, 0xa6, 0xd8, 0xdb,
    0x36, 0xbd, 0xd2, 0xec, 0xac, 0x13, 0xbd, 0xe4, 0x43, 0x4c, 0xdd, 0x81, 0x3f, 0x2a, 0xbd, 0x11,
    0x15, 0xb6, 0xe9, 0xd5, 0x91, 0xdb, 0x3d, 0x9b, 0x44, 0x33, 0x3d, 0xf2, 0x29, 0xa0, 0xbf, 0x73,
    0x4b, 0x64, 0x9c, 0xd3, 0x7e, 0x88, 0x30, 0x7a, 0xd4, 0x3c, 0xfe, 0x7b, 0xd0, 0x27, 0x3c, 0xce,
    0x48, 0x0c, 0x8f, 0xae, 0xbc, 0xf7, 0x7b, 0x2e, 0x8b, 0xe6, 0xf9, 0x10, 0x7b, 0x39, 0xad, 0x8b,
    0x3d, 0x28, 0xb9, 0x2d, 0x0a, 0x17, 0x78, 0x6d, 0xb7, 0xae, 0xa0, 0xd1, 0x71, 0x07, 0x41, 0x7c,
    0x33, 0xc3, 0xb5, 0x8c, 0xc4, 0x3f, 0xdb, 0x5b, 0x33, 0x41, 0x49, 0x31, 0xf5, 0x69, 0x5e, 0xc9,
    0x2c, 0x50, 0xba, 0x1e, 0xdb, 0xaa, 0x34, 0x6a, 0x3b, 0xf3, 0x89, 0x26, 0x93, 0x85, 0x3e, 0xc2,
    0x8d, 0x13, 0x52, 0x9c, 0x7d, 0xac, 0xfa, 0x92, 0x5b, 0x59, 0xad, 0xd6, 0xe4, 0xb6, 0xa3, 0x64,
    0xe9, 0xa8, 0x54, 0x7c, 0x0a, 0x1a, 0xdf, 0x6c, 0x4f, 0x34, 0x9d, 0xb2, 0x74, 0x41, 0xe7, 0x6a,
    0x3a, 0xdd, 0xeb, 0xb5, 0xad, 0x96, 0xc6, 0xd7, 0x3a, 0xc8, 0x14, 0x0f, 0xfb, 0xba, 0xa3, 0xbc,
    0x63, 0x0a, 0xb2, 0x93, 0xbf, 0xd4, 0x24, 0xfb, 0x30, 0xcf, 0xeb, 0x30, 0x97, 0x16, 0xf1, 0x1d,
    0xe1, 0x34, 0xc9, 0x18, 0x51, 0xc2, 0xb1, 0x3e, 0x9f, 0x6b, 0x2e, 0x79, 0xe8, 0x5c, 0xf1, 0xb3,
    0x3a, 0xc4, 0x7f, 0xf9, 0x27, 0x63, 0x4f, 0xff, 0xe9, 0x1d, 0xda, 0x72, 0x5a, 0x87, 0x39, 0xc7,
    0x91, 0xc8, 0xf4, 0xd7, 0xd5, 0x8e, 0xec, 0xd4, 0x41, 0x52, 0xcc, 0x84, 0xab, 0xc6, 0x76, 0x3d,
    0x60, 0xc6, 0x53, 0xfd, 0xb9, 0x83, 0xa8, 0xe9, 0x26, 0x5b, 0xb9, 0xf2, 0x9d, 0xdb, 0xf9, 0x17,
    0x1c, 0x32, 0x74, 0xa0
};
#endif

PyTypeObject *init_QTextStream(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextStream_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_IDX]))));

    _Sbk_QTextStream_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextStream",
        "QTextStream*",
        &Sbk_QTextStream_spec,
        &Shiboken::callCppDestructor< QTextStream >,
        Sbk_QTextStream_Type_bases.object(),
        0);
    auto *pyType = Sbk_QTextStream_TypeF(); // references _Sbk_QTextStream_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextStream_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextStream_SignatureBytes, QTextStream_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextStream_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextStream_PythonToCpp_QTextStream_PTR,
        is_QTextStream_PythonToCpp_QTextStream_PTR_Convertible,
        QTextStream_PTR_CppToPython_QTextStream);

    Shiboken::Conversions::registerConverterName(converter, "QTextStream");
    Shiboken::Conversions::registerConverterName(converter, "QTextStream*");
    Shiboken::Conversions::registerConverterName(converter, "QTextStream&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextStream).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QTextStreamWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QTextStream_TypeF(), &Sbk_QTextStream_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTextStream_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'RealNumberNotation'.
    const char *RealNumberNotation_Initializer[] = {
        "SmartNotation",
        "FixedNotation",
        "ScientificNotation",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RealNumberNotation_InitializerValues[] = {
        uint8_t(QTextStream::RealNumberNotation::SmartNotation),     //  0x00  0
        uint8_t(QTextStream::RealNumberNotation::FixedNotation),     //  0x01  1
        uint8_t(QTextStream::RealNumberNotation::ScientificNotation) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextStream_TypeF(),
        "2:PySide6.QtCore.QTextStream.RealNumberNotation",
        RealNumberNotation_Initializer, RealNumberNotation_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_RealNumberNotation_IDX].type = EType;
    // Register converter for enum 'QTextStream::RealNumberNotation'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextStream_RealNumberNotation_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextStream_RealNumberNotation,
            is_Enum_PythonToCpp_QTextStream_RealNumberNotation_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextStream::RealNumberNotation");
        Shiboken::Conversions::registerConverterAlias(converter, "RealNumberNotation");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'RealNumberNotation' enum.

    // Initialization of enum 'FieldAlignment'.
    const char *FieldAlignment_Initializer[] = {
        "AlignLeft",
        "AlignRight",
        "AlignCenter",
        "AlignAccountingStyle",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FieldAlignment_InitializerValues[] = {
        uint8_t(QTextStream::FieldAlignment::AlignLeft),           //  0x00  0
        uint8_t(QTextStream::FieldAlignment::AlignRight),          //  0x01  1
        uint8_t(QTextStream::FieldAlignment::AlignCenter),         //  0x02  2
        uint8_t(QTextStream::FieldAlignment::AlignAccountingStyle) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextStream_TypeF(),
        "2:PySide6.QtCore.QTextStream.FieldAlignment",
        FieldAlignment_Initializer, FieldAlignment_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_FieldAlignment_IDX].type = EType;
    // Register converter for enum 'QTextStream::FieldAlignment'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextStream_FieldAlignment_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextStream_FieldAlignment,
            is_Enum_PythonToCpp_QTextStream_FieldAlignment_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextStream::FieldAlignment");
        Shiboken::Conversions::registerConverterAlias(converter, "FieldAlignment");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FieldAlignment' enum.

    // Initialization of enum 'Status'.
    const char *Status_Initializer[] = {
        "Ok",
        "ReadPastEnd",
        "ReadCorruptData",
        "WriteFailed",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Status_InitializerValues[] = {
        uint8_t(QTextStream::Status::Ok),              //  0x00  0
        uint8_t(QTextStream::Status::ReadPastEnd),     //  0x01  1
        uint8_t(QTextStream::Status::ReadCorruptData), //  0x02  2
        uint8_t(QTextStream::Status::WriteFailed)      //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextStream_TypeF(),
        "2:PySide6.QtCore.QTextStream.Status",
        Status_Initializer, Status_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_Status_IDX].type = EType;
    // Register converter for enum 'QTextStream::Status'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextStream_Status_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextStream_Status,
            is_Enum_PythonToCpp_QTextStream_Status_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextStream::Status");
        Shiboken::Conversions::registerConverterAlias(converter, "Status");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Status' enum.

    // Initialization of enum 'NumberFlag'.
    const char *NumberFlag_Initializer[] = {
        "ShowBase",
        "ForcePoint",
        "ForceSign",
        "UppercaseBase",
        "UppercaseDigits",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t NumberFlag_InitializerValues[] = {
        uint8_t(QTextStream::NumberFlag::ShowBase),       //  0x01  1
        uint8_t(QTextStream::NumberFlag::ForcePoint),     //  0x02  2
        uint8_t(QTextStream::NumberFlag::ForceSign),      //  0x04  4
        uint8_t(QTextStream::NumberFlag::UppercaseBase),  //  0x08  8
        uint8_t(QTextStream::NumberFlag::UppercaseDigits) //  0x10  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextStream_TypeF(),
        "2:PySide6.QtCore.QTextStream.NumberFlag",
        NumberFlag_Initializer, NumberFlag_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_NumberFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QTextStream_NumberFlag_IDX].type =
        EType;
    // Register converter for enum 'QTextStream::NumberFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextStream_NumberFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextStream_NumberFlag,
            is_Enum_PythonToCpp_QTextStream_NumberFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextStream::NumberFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "NumberFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QTextStream_NumberFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QTextStream_NumberFlag,
            is_Enum_PythonToCpp_QTextStream_NumberFlag_Convertible);
        // Register converter for flag 'QFlags<QTextStream::NumberFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QTextStream::NumberFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QTextStream::NumberFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'NumberFlag' enum/flags.

    qRegisterMetaType< ::QTextStream *>();
    qRegisterMetaType< ::QTextStream::RealNumberNotation >("QTextStream::RealNumberNotation");
    qRegisterMetaType< ::QTextStream::FieldAlignment >("QTextStream::FieldAlignment");
    qRegisterMetaType< ::QTextStream::Status >("QTextStream::Status");
    qRegisterMetaType< ::QTextStream::NumberFlag >("QTextStream::NumberFlag");

    return pyType;
}
