// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qthread_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <qabstracteventdispatcher.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdeadlinetimer.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (qthread_pthread_cleanup)]
#ifdef Q_OS_UNIX
#  include <pthread.h>
static void qthread_pthread_cleanup(void *arg)
{
    // PYSIDE 1282: When terminating a thread using QThread::terminate()
    // (pthread_cancel()), QThread::run() is aborted and the lock is released,
    // but ~GilState() is still executed for some reason. Prevent it from
    // releasing.
    auto gil = reinterpret_cast<Shiboken::GilState *>(arg);
    gil->abandon();
}
#endif // Q_OS_UNIX
// END of custom code block [file: ../glue/qtcore.cpp (qthread_pthread_cleanup)]
// ========================================================================
// End of code injection


// Native ---------------------------------------------------------

void QThreadWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QThreadWrapper::QThreadWrapper(::QObject * parent) : QThread(parent)
{
}

void QThreadWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QThread", funcName);
        return;
    }
}

void QThreadWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QThread", funcName);
        return;
    }
}

void QThreadWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QThread", funcName);
        return;
    }
}

void QThreadWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QThread", funcName);
        return;
    }
}

bool QThreadWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QThread::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QThread::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QThread", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QThread", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QThreadWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QThread", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QThread", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QThreadWrapper::run()
{
    if (m_PyMethodCache[6]) {
        return this->::QThread::run();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "run";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QThread::run();
    }

    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (qthread_pthread_cleanup_install)]
#ifdef Q_OS_UNIX
    pthread_cleanup_push(qthread_pthread_cleanup, &gil);
#endif
    // END of custom code block [file: ../glue/qtcore.cpp (qthread_pthread_cleanup_install)]
    // ========================================================================
    // End of code injection

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QThread", funcName);
        return;
    }

    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (qthread_pthread_cleanup_uninstall)]
#ifdef Q_OS_UNIX
    pthread_cleanup_pop(0);
#endif
    // END of custom code block [file: ../glue/qtcore.cpp (qthread_pthread_cleanup_uninstall)]
    // ========================================================================
    // End of code injection

}

void QThreadWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[7]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QThread", funcName);
        return;
    }
}

const QMetaObject *QThreadWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QThread::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QThreadWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QThread::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QThreadWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QThreadWrapper *>(this));
    return QThread::qt_metacast(_clname);
}

QThreadWrapper::~QThreadWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QThread_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QThread >()))
        return -1;

    QThreadWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QThread", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QThread::QThread(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QThread(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QThread(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QThread(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QThreadWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QThreadWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QThread >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QThreadFunc_currentThread(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentThread()
        QThread * cppResult = ::QThread::currentThread();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QThread::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_eventDispatcher(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // eventDispatcher()const
        QAbstractEventDispatcher * cppResult = const_cast<const ::QThread *>(cppSelf)->eventDispatcher();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractEventDispatcher_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_exec(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();

    // Call function/method
    {

        // exec()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        int cppResult = cppSelf->exec();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_exec_(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();

    // Call function/method
    {

        // exec_()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtcore.cpp (qthread_exec_)]
        if (PyErr_WarnEx(PyExc_DeprecationWarning,
                         "'exec_' will be removed in the future. "
                         "Use 'exec' instead.",
                         1)) {
            return nullptr;
        }
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
#ifndef AVOID_PROTECTED_HACK
        int cppResult = cppSelf->exec();
#else
        int cppResult = static_cast<::QThreadWrapper *>(cppSelf)->QThreadWrapper::exec_protected();
#endif
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        // END of custom code block [file: ../glue/qtcore.cpp (qthread_exec_)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_exit(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "exit", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    if (PyArg_ParseTuple(args, "|O:exit", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QThread::exit(int=)
    if (numArgs == 0) {
        overloadId = 0; // exit(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // exit(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "exit", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_retcode = Shiboken::String::createStaticString("retcode");
            if (PyDict_Contains(kwds, key_retcode) != 0) {
                value = PyDict_GetItem(kwds, key_retcode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_retcode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "exit", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "exit", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_retcode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "exit", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
            }
        }
        int cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // exit(int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->exit(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_idealThreadCount(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // idealThreadCount()
        int cppResult = ::QThread::idealThreadCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_isCurrentThread(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isCurrentThread()const
        bool cppResult = const_cast<const ::QThread *>(cppSelf)->isCurrentThread();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_isFinished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFinished()const
        bool cppResult = const_cast<const ::QThread *>(cppSelf)->isFinished();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_isInterruptionRequested(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isInterruptionRequested()const
        bool cppResult = const_cast<const ::QThread *>(cppSelf)->isInterruptionRequested();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_isMainThread(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isMainThread()
        bool cppResult = ::QThread::isMainThread();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_isRunning(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRunning()const
        bool cppResult = const_cast<const ::QThread *>(cppSelf)->isRunning();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_loopLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // loopLevel()const
        int cppResult = const_cast<const ::QThread *>(cppSelf)->loopLevel();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_msleep(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QThread::msleep(ulong)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArg)))) {
        overloadId = 0; // msleep(ulong)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "msleep", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    // Call function/method
    {
        unsigned long cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // msleep(ulong)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            ::QThread::msleep(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_priority(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // priority()const
        QThread::Priority cppResult = const_cast<const ::QThread *>(cppSelf)->priority();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_Priority_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_quit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // quit()
        cppSelf->quit();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_requestInterruption(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // requestInterruption()
        cppSelf->requestInterruption();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_run(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();

    // Call function/method
    {

        // run()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QThread::run()
            : cppSelf->run();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_setEventDispatcher(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QThread::setEventDispatcher(QAbstractEventDispatcher*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractEventDispatcher_IDX]), (pyArg)))) {
        overloadId = 0; // setEventDispatcher(QAbstractEventDispatcher*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEventDispatcher", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractEventDispatcher *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEventDispatcher(QAbstractEventDispatcher*)
            cppSelf->setEventDispatcher(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_setPriority(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QThread::setPriority(QThread::Priority)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_Priority_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPriority(QThread::Priority)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPriority", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    // Call function/method
    {
        ::QThread::Priority cppArg0{QThread::IdlePriority};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPriority(QThread::Priority)
            cppSelf->setPriority(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_setStackSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QThread::setStackSize(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // setStackSize(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStackSize", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStackSize(uint)
            cppSelf->setStackSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_setTerminationEnabled(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setTerminationEnabled", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    if (PyArg_ParseTuple(args, "|O:setTerminationEnabled", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QThread::setTerminationEnabled(bool=)
    if (numArgs == 0) {
        overloadId = 0; // setTerminationEnabled(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // setTerminationEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setTerminationEnabled", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_enabled = Shiboken::String::createStaticString("enabled");
            if (PyDict_Contains(kwds, key_enabled) != 0) {
                value = PyDict_GetItem(kwds, key_enabled);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_enabled);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setTerminationEnabled", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "setTerminationEnabled", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_enabled);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setTerminationEnabled", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTerminationEnabled(bool)
            ::QThread::setTerminationEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_sleep(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QThread::sleep(ulong)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArg)))) {
        overloadId = 0; // sleep(ulong)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "sleep", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    // Call function/method
    {
        unsigned long cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sleep(ulong)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            ::QThread::sleep(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_stackSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stackSize()const
        uint cppResult = const_cast<const ::QThread *>(cppSelf)->stackSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_start(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    if (PyArg_ParseTuple(args, "|O:start", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QThread::start(QThread::Priority=)
    if (numArgs == 0) {
        overloadId = 0; // start(QThread::Priority)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_Priority_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // start(QThread::Priority)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_priority = Shiboken::String::createStaticString("priority");
            if (PyDict_Contains(kwds, key_priority) != 0) {
                value = PyDict_GetItem(kwds, key_priority);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_priority);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_Priority_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_priority);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
            }
        }
        ::QThread::Priority cppArg0(QThread::Priority::InheritPriority);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // start(QThread::Priority)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qthread_init_pypy)]
#ifdef PYPY_VERSION
            // PYSIDE-535: PyPy 7.3.8 needs this call, which is actually a no-op in Python 3.9
            //             This function should be replaced by a `Py_Initialize` call, but
            //             that is still undefined. So we don't rely yet on any PyPy version.
            PyEval_InitThreads();
#endif
            // END of custom code block [file: ../glue/qtcore.cpp (qthread_init_pypy)]
            // ========================================================================
            // End of code injection

            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->start(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_terminate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // terminate()
        cppSelf->terminate();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_usleep(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QThread::usleep(ulong)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArg)))) {
        overloadId = 0; // usleep(ulong)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "usleep", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    // Call function/method
    {
        unsigned long cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // usleep(ulong)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            ::QThread::usleep(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_wait(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    if (PyArg_ParseTuple(args, "|O:wait", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QThread::wait(QDeadlineTimer=)->bool
    // 1: QThread::wait(ulong)->bool
    if (numArgs == 0) {
        overloadId = 0; // wait(QDeadlineTimer)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArgs[0])))) {
        overloadId = 1; // wait(ulong)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0])))) {
        overloadId = 0; // wait(QDeadlineTimer)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // wait(QDeadlineTimer deadline)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_deadline = Shiboken::String::createStaticString("deadline");
                if (PyDict_Contains(kwds, key_deadline) != 0) {
                    value = PyDict_GetItem(kwds, key_deadline);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_deadline);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_deadline);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDeadlineTimer cppArg0 = QDeadlineTimer(QDeadlineTimer::Forever);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // wait(QDeadlineTimer)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->wait(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // wait(unsigned long time)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]);
            }
            unsigned long cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // wait(ulong)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->wait(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_yieldCurrentThread(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // yieldCurrentThread()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        ::QThread::yieldCurrentThread();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QThread_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QThread_EnumFlagInfo[] = {
    "Priority:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QThread_methods[] = {
    {"currentThread", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_currentThread), METH_NOARGS|METH_STATIC, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_event), METH_O, nullptr},
    {"eventDispatcher", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_eventDispatcher), METH_NOARGS, nullptr},
    {"exec", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_exec), METH_NOARGS, nullptr},
    {"exec_", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_exec_), METH_NOARGS, nullptr},
    {"exit", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_exit), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"idealThreadCount", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_idealThreadCount), METH_NOARGS|METH_STATIC, nullptr},
    {"isCurrentThread", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_isCurrentThread), METH_NOARGS, nullptr},
    {"isFinished", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_isFinished), METH_NOARGS, nullptr},
    {"isInterruptionRequested", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_isInterruptionRequested), METH_NOARGS, nullptr},
    {"isMainThread", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_isMainThread), METH_NOARGS|METH_STATIC, nullptr},
    {"isRunning", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_isRunning), METH_NOARGS, nullptr},
    {"loopLevel", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_loopLevel), METH_NOARGS, nullptr},
    {"msleep", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_msleep), METH_O|METH_STATIC, nullptr},
    {"priority", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_priority), METH_NOARGS, nullptr},
    {"quit", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_quit), METH_NOARGS, nullptr},
    {"requestInterruption", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_requestInterruption), METH_NOARGS, nullptr},
    {"run", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_run), METH_NOARGS, nullptr},
    {"setEventDispatcher", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_setEventDispatcher), METH_O, nullptr},
    {"setPriority", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_setPriority), METH_O, nullptr},
    {"setStackSize", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_setStackSize), METH_O, nullptr},
    {"setTerminationEnabled", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_setTerminationEnabled), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"sleep", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_sleep), METH_O|METH_STATIC, nullptr},
    {"stackSize", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_stackSize), METH_NOARGS, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_start), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"terminate", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_terminate), METH_NOARGS, nullptr},
    {"usleep", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_usleep), METH_O|METH_STATIC, nullptr},
    {"wait", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_wait), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"yieldCurrentThread", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_yieldCurrentThread), METH_NOARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QThread_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QThreadWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QThread_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QThread_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QThread_Type = nullptr;
static PyTypeObject *Sbk_QThread_TypeF(void)
{
    return _Sbk_QThread_Type;
}

static PyType_Slot Sbk_QThread_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QThread_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QThread_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QThread_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QThread_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QThread_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QThread_spec = {
    "2:PySide6.QtCore.QThread",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QThread_slots
};

} //extern "C"

static void *Sbk_QThread_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QThread *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QThread_Priority(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QThread::Priority>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QThread::Priority *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QThread_Priority_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_Priority_IDX])))
        return Enum_PythonToCpp_QThread_Priority;
    return {};
}

static PyObject *QThread_Priority_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QThread::Priority>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QThread::Priority *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_Priority_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QThread_PythonToCpp_QThread_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QThread_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QThread_PythonToCpp_QThread_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QThread_TypeF()))
        return QThread_PythonToCpp_QThread_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QThread_PTR_CppToPython_QThread(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QThread *>(const_cast<void *>(cppIn)), Sbk_QThread_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QThread_SignatureStrings[] = {
    "PySide6.QtCore.QThread(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtCore.QThread.currentThread()->PySide6.QtCore.QThread",
    "PySide6.QtCore.QThread.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtCore.QThread.eventDispatcher(self)->PySide6.QtCore.QAbstractEventDispatcher",
    "PySide6.QtCore.QThread.exec(self)->int",
    "PySide6.QtCore.QThread.exec_(self)->int",
    "PySide6.QtCore.QThread.exit(self,retcode:int=0)",
    "PySide6.QtCore.QThread.idealThreadCount()->int",
    "PySide6.QtCore.QThread.isCurrentThread(self)->bool",
    "PySide6.QtCore.QThread.isFinished(self)->bool",
    "PySide6.QtCore.QThread.isInterruptionRequested(self)->bool",
    "PySide6.QtCore.QThread.isMainThread()->bool",
    "PySide6.QtCore.QThread.isRunning(self)->bool",
    "PySide6.QtCore.QThread.loopLevel(self)->int",
    "PySide6.QtCore.QThread.msleep(arg__1:unsigned long)",
    "PySide6.QtCore.QThread.priority(self)->PySide6.QtCore.QThread.Priority",
    "PySide6.QtCore.QThread.quit(self)",
    "PySide6.QtCore.QThread.requestInterruption(self)",
    "PySide6.QtCore.QThread.run(self)",
    "PySide6.QtCore.QThread.setEventDispatcher(self,eventDispatcher:PySide6.QtCore.QAbstractEventDispatcher)",
    "PySide6.QtCore.QThread.setPriority(self,priority:PySide6.QtCore.QThread.Priority)",
    "PySide6.QtCore.QThread.setStackSize(self,stackSize:uint)",
    "PySide6.QtCore.QThread.setTerminationEnabled(enabled:bool=true)",
    "PySide6.QtCore.QThread.sleep(arg__1:unsigned long)",
    "PySide6.QtCore.QThread.stackSize(self)->uint",
    "PySide6.QtCore.QThread.start(self,priority:PySide6.QtCore.QThread.Priority=QThread.Priority.InheritPriority)",
    "PySide6.QtCore.QThread.terminate(self)",
    "PySide6.QtCore.QThread.usleep(arg__1:unsigned long)",
    "1:PySide6.QtCore.QThread.wait(self,deadline:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64]=QDeadlineTimer(QDeadlineTimer.Forever))->bool",
    "0:PySide6.QtCore.QThread.wait(self,time:unsigned long)->bool",
    "PySide6.QtCore.QThread.yieldCurrentThread()",
    nullptr}; // Sentinel
#else
static constexpr size_t QThread_SignatureByteSize = 469;
static constexpr uint8_t QThread_SignatureBytes[469] = {
    0x78, 0xda, 0x95, 0x54, 0xc1, 0x6a, 0xdb, 0x40, 0x10, 0xbd, 0xe7, 0x2b, 0x7c, 0xb4, 0xc1, 0x15,
    0x09, 0x84, 0x1c, 0x04, 0x2a, 0x14, 0xc7, 0x81, 0x40, 0x42, 0x94, 0xd8, 0x3d, 0x95, 0x62, 0xd6,
    0xd2, 0xd4, 0x9e, 0x76, 0x3d, 0x2b, 0xcf, 0xce, 0xa6, 0x75, 0xbf, 0xbe, 0xeb, 0x48, 0x22, 0x96,
    0x6a, 0xad, 0x94, 0x93, 0xe5, 0xd1, 0x7b, 0x4f, 0xb3, 0x6f, 0xde, 0x4e, 0x7a, 0x58, 0x60, 0x0e,
    0x37, 0xd1, 0xb3, 0xcc, 0x0c, 0x43, 0xf4, 0xbc, 0xdc, 0x32, 0xa8, 0x7c, 0x6c, 0x41, 0xff, 0x98,
    0x16, 0x8a, 0x81, 0x24, 0x4e, 0x5b, 0x90, 0xa7, 0xf5, 0x4f, 0xc8, 0x24, 0x21, 0xa7, 0x75, 0x21,
    0x3c, 0xb9, 0x48, 0xcf, 0x4a, 0x44, 0x99, 0xe3, 0x23, 0xbd, 0x12, 0x9c, 0x7c, 0xfa, 0x7c, 0x1e,
    0xd7, 0x45, 0x87, 0x57, 0x4f, 0x2e, 0xfb, 0x78, 0x7b, 0xfc, 0xaf, 0x8d, 0xf9, 0xb1, 0xea, 0x65,
    0xd7, 0xc6, 0xe8, 0xa0, 0xc8, 0x2d, 0xda, 0x42, 0x49, 0xb6, 0x05, 0x7e, 0x93, 0x3b, 0xd3, 0xc9,
    0x97, 0xb5, 0x15, 0x56, 0x99, 0xcc, 0x9b, 0xf0, 0x4e, 0xd5, 0x3f, 0x90, 0xd5, 0x52, 0x48, 0x12,
    0x82, 0xad, 0x06, 0xe1, 0xb0, 0x3a, 0x28, 0x83, 0x64, 0x26, 0x87, 0xd8, 0x83, 0x93, 0xcb, 0x4e,
    0x63, 0x7d, 0x4d, 0xe9, 0xf2, 0x79, 0x66, 0x9c, 0x37, 0x29, 0x2c, 0x8f, 0x76, 0xd6, 0x98, 0x44,
    0xd5, 0x50, 0xc8, 0x36, 0xb4, 0x77, 0x48, 0x68, 0xb7, 0x30, 0x10, 0x7d, 0x4f, 0x02, 0xcc, 0xae,
    0x10, 0x34, 0xf4, 0x02, 0x7b, 0x07, 0x56, 0x86, 0x52, 0x1f, 0x15, 0xd2, 0x7b, 0x44, 0xc2, 0xd8,
    0x17, 0x47, 0x84, 0xb4, 0x19, 0x22, 0xac, 0x8d, 0x29, 0x1e, 0xfc, 0xf4, 0xf5, 0x00, 0xff, 0x77,
    0x56, 0x03, 0x14, 0x63, 0xc5, 0x9b, 0xd5, 0xea, 0x2a, 0x76, 0x64, 0x71, 0x43, 0x90, 0x8f, 0xb4,
    0xa1, 0x4d, 0xe7, 0x0c, 0x0a, 0x46, 0xc3, 0x28, 0x87, 0xae, 0x44, 0x55, 0xb0, 0xb4, 0x82, 0x75,
    0xc9, 0xec, 0x5d, 0x35, 0xfa, 0xce, 0x0f, 0x71, 0x69, 0xe7, 0xa9, 0xc3, 0x3d, 0x04, 0xd7, 0x03,
    0xb0, 0xd0, 0xce, 0xf9, 0xc9, 0x2d, 0x7b, 0x2f, 0xc6, 0x03, 0x2f, 0x49, 0xe8, 0x3b, 0xe9, 0xa9,
    0x4b, 0xd3, 0xda, 0xb3, 0xb8, 0xc7, 0xac, 0x90, 0xe2, 0x42, 0x54, 0xf6, 0x6b, 0x81, 0x7f, 0xa1,
    0x94, 0xb4, 0xf5, 0xdf, 0xd8, 0xf9, 0x01, 0x87, 0x88, 0x4b, 0xe0, 0x1d, 0x92, 0x3a, 0xfa, 0x37,
    0x27, 0xb5, 0xd6, 0x3e, 0x9f, 0x50, 0xfe, 0xc6, 0xc7, 0x1c, 0x25, 0xc2, 0x0e, 0xba, 0xf9, 0x1f,
    0x0f, 0x88, 0x6d, 0x34, 0xea, 0x13, 0xe2, 0x02, 0x09, 0xf4, 0x60, 0x96, 0x8f, 0x99, 0x94, 0xb4,
    0x0b, 0xd1, 0x3d, 0xf9, 0x69, 0xa0, 0xf4, 0xba, 0x28, 0x95, 0x13, 0x10, 0x8e, 0x89, 0x0b, 0x1d,
    0xfa, 0xaa, 0xab, 0xbd, 0xdf, 0xaa, 0xde, 0x65, 0x7e, 0x49, 0xe5, 0x1a, 0x09, 0x62, 0x39, 0x14,
    0xfe, 0xd2, 0x46, 0x5f, 0xc9, 0x5b, 0xff, 0xad, 0x4d, 0xbb, 0xad, 0x50, 0x4b, 0xdc, 0x01, 0x4f,
    0x47, 0xc1, 0xd7, 0xd1, 0x9d, 0xaf, 0xbd, 0x02, 0xcf, 0x0c, 0x79, 0xc3, 0x48, 0xa6, 0xa3, 0xbd,
    0xf7, 0xf4, 0xe6, 0xfa, 0x7b, 0xd2, 0xc4, 0x8d, 0xcf, 0xd3, 0x26, 0xf5, 0xca, 0xb8, 0xec, 0x6f,
    0x5e, 0x3c, 0xb1, 0x75, 0xe6, 0xf0, 0xbe, 0x39, 0x20, 0xe8, 0xbc, 0xb9, 0x67, 0x27, 0x17, 0xff,
    0x00, 0x55, 0x9a, 0xa2, 0xb9
};
#endif

PyTypeObject *init_QThread(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX].type;

    Shiboken::AutoDecRef Sbk_QThread_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QThread_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QThread",
        "QThread*",
        &Sbk_QThread_spec,
        &Shiboken::callCppDestructor< QThread >,
        Sbk_QThread_Type_bases.object(),
        0);
    auto *pyType = Sbk_QThread_TypeF(); // references _Sbk_QThread_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QThread_SignatureStrings);
#else
    InitSignatureBytes(pyType, QThread_SignatureBytes, QThread_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QThread_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QThread_PythonToCpp_QThread_PTR,
        is_QThread_PythonToCpp_QThread_PTR_Convertible,
        QThread_PTR_CppToPython_QThread);

    Shiboken::Conversions::registerConverterName(converter, "QThread");
    Shiboken::Conversions::registerConverterName(converter, "QThread*");
    Shiboken::Conversions::registerConverterName(converter, "QThread&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QThread).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QThreadWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QThread_TypeF(), &Sbk_QThread_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QThread_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Priority'.
    const char *Priority_Initializer[] = {
        "IdlePriority",
        "LowestPriority",
        "LowPriority",
        "NormalPriority",
        "HighPriority",
        "HighestPriority",
        "TimeCriticalPriority",
        "InheritPriority",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Priority_InitializerValues[] = {
        uint8_t(QThread::Priority::IdlePriority),         //  0x00  0
        uint8_t(QThread::Priority::LowestPriority),       //  0x01  1
        uint8_t(QThread::Priority::LowPriority),          //  0x02  2
        uint8_t(QThread::Priority::NormalPriority),       //  0x03  3
        uint8_t(QThread::Priority::HighPriority),         //  0x04  4
        uint8_t(QThread::Priority::HighestPriority),      //  0x05  5
        uint8_t(QThread::Priority::TimeCriticalPriority), //  0x06  6
        uint8_t(QThread::Priority::InheritPriority)       //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QThread_TypeF(),
        "2:PySide6.QtCore.QThread.Priority",
        Priority_Initializer, Priority_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QThread_Priority_IDX].type = EType;
    // Register converter for enum 'QThread::Priority'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QThread_Priority_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QThread_Priority,
            is_Enum_PythonToCpp_QThread_Priority_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QThread::Priority");
        Shiboken::Conversions::registerConverterAlias(converter, "Priority");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Priority' enum.

    PySide::Signal::registerSignals(pyType, &::QThread::staticMetaObject);

    qRegisterMetaType< ::QThread::Priority >("QThread::Priority");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QThread::staticMetaObject, sizeof(QThreadWrapper));

    return pyType;
}

