// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qthreadpool_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdeadlinetimer.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qrunnable.h>
#include <qthread.h>
#include <qthreadpool.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QThreadPoolWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QThreadPoolWrapper::QThreadPoolWrapper(::QObject * parent) : QThreadPool(parent)
{
}

void QThreadPoolWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QThreadPool", funcName);
        return;
    }
}

void QThreadPoolWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QThreadPool", funcName);
        return;
    }
}

void QThreadPoolWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QThreadPool", funcName);
        return;
    }
}

void QThreadPoolWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QThreadPool", funcName);
        return;
    }
}

bool QThreadPoolWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QThreadPool", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QThreadPool", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QThreadPoolWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QThreadPool", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QThreadPool", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QThreadPoolWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QThreadPool", funcName);
        return;
    }
}

const QMetaObject *QThreadPoolWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QThreadPool::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QThreadPoolWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QThreadPool::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QThreadPoolWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QThreadPoolWrapper *>(this));
    return QThreadPool::qt_metacast(_clname);
}

QThreadPoolWrapper::~QThreadPoolWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QThreadPool_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QThreadPool >()))
        return -1;

    QThreadPoolWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QThreadPool", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QThreadPool::QThreadPool(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QThreadPool(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QThreadPool(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QThreadPool(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QThreadPoolWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QThreadPoolWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QThreadPool >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QThreadPoolFunc_activeThreadCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activeThreadCount()const
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        int cppResult = const_cast<const ::QThreadPool *>(cppSelf)->activeThreadCount();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadPoolFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        cppSelf->clear();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadPoolFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QThreadPool::contains(const QThread*)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), (pyArg)))) {
        overloadId = 0; // contains(const QThread*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contains", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QThread *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contains(const QThread*)const
            bool cppResult = const_cast<const ::QThreadPool *>(cppSelf)->contains(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadPoolFunc_expiryTimeout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // expiryTimeout()const
        int cppResult = const_cast<const ::QThreadPool *>(cppSelf)->expiryTimeout();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadPoolFunc_globalInstance(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // globalInstance()
        QThreadPool * cppResult = ::QThreadPool::globalInstance();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), cppResult);
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtcore.cpp (releaseownership)]
        Shiboken::Object::releaseOwnership(pyResult);
        // END of custom code block [file: ../glue/qtcore.cpp (releaseownership)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadPoolFunc_maxThreadCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxThreadCount()const
        int cppResult = const_cast<const ::QThreadPool *>(cppSelf)->maxThreadCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadPoolFunc_releaseThread(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // releaseThread()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        cppSelf->releaseThread();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadPoolFunc_reserveThread(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reserveThread()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        cppSelf->reserveThread();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadPoolFunc_setExpiryTimeout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QThreadPool::setExpiryTimeout(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setExpiryTimeout(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExpiryTimeout", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExpiryTimeout(int)
            cppSelf->setExpiryTimeout(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadPoolFunc_setMaxThreadCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QThreadPool::setMaxThreadCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMaxThreadCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxThreadCount", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxThreadCount(int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setMaxThreadCount(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadPoolFunc_setStackSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QThreadPool::setStackSize(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // setStackSize(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStackSize", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStackSize(uint)
            cppSelf->setStackSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadPoolFunc_setThreadPriority(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QThreadPool::setThreadPriority(QThread::Priority)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_Priority_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setThreadPriority(QThread::Priority)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setThreadPriority", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);

    // Call function/method
    {
        ::QThread::Priority cppArg0{QThread::IdlePriority};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setThreadPriority(QThread::Priority)
            cppSelf->setThreadPriority(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadPoolFunc_stackSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stackSize()const
        uint cppResult = const_cast<const ::QThreadPool *>(cppSelf)->stackSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadPoolFunc_start(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);

    if (PyArg_ParseTuple(args, "|OO:start", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QThreadPool::start(PyCallable,int=)
    // 1: QThreadPool::start(QRunnable*,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRunnable_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // start(QRunnable*,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // start(QRunnable*,int)
        }
    } else if (numArgs >= 1
        && PyCallable_Check(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // start(PyCallable,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // start(PyCallable,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // start(PyCallable arg__1, int priority)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_priority = Shiboken::String::createStaticString("priority");
                if (PyDict_Contains(kwds, key_priority) != 0) {
                    value = PyDict_GetItem(kwds, key_priority);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_priority);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_priority);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);
                }
            }
            int cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // start(PyCallable,int)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (std-function-void-lambda)]
                auto *callable = pyArgs[1-1];
                auto cppCallback = [callable]()
                {
                    Shiboken::GilState state;
                    Shiboken::AutoDecRef arglist(PyTuple_New(0));
                    Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
                    Py_DECREF(callable);
                };
                // END of custom code block [file: ../glue/qtcore.cpp (std-function-void-lambda)]
                // ========================================================================
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qthreadpool-start)]
                Py_INCREF(callable);
                cppSelf->start(cppCallback, cppArg1);
                // END of custom code block [file: ../glue/qtcore.cpp (qthreadpool-start)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // start(QRunnable *runnable, int priority)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_priority = Shiboken::String::createStaticString("priority");
                if (PyDict_Contains(kwds, key_priority) != 0) {
                    value = PyDict_GetItem(kwds, key_priority);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_priority);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_priority);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "start", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRunnable *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // start(QRunnable*,int)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->start(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyArgs[0]);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadPoolFunc_startOnReservedThread(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QThreadPool::startOnReservedThread(QRunnable*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRunnable_IDX]), (pyArg)))) {
        overloadId = 0; // startOnReservedThread(QRunnable*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "startOnReservedThread", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRunnable *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // startOnReservedThread(QRunnable*)
            cppSelf->startOnReservedThread(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadPoolFunc_threadPriority(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // threadPriority()const
        QThread::Priority cppResult = const_cast<const ::QThreadPool *>(cppSelf)->threadPriority();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_Priority_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadPoolFunc_tryStart(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QThreadPool::tryStart(PyCallable)->bool
    // 1: QThreadPool::tryStart(QRunnable*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRunnable_IDX]), (pyArg)))) {
        overloadId = 1; // tryStart(QRunnable*)
    } else if (PyCallable_Check(pyArg)) {
        overloadId = 0; // tryStart(PyCallable)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "tryStart", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // tryStart(PyCallable callable)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // tryStart(PyCallable)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (std-function-void-lambda)]
                auto *callable = pyArg;
                auto cppCallback = [callable]()
                {
                    Shiboken::GilState state;
                    Shiboken::AutoDecRef arglist(PyTuple_New(0));
                    Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
                    Py_DECREF(callable);
                };
                // END of custom code block [file: ../glue/qtcore.cpp (std-function-void-lambda)]
                // ========================================================================
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qthreadpool-trystart)]
                Py_INCREF(callable);
                bool cppResult = cppSelf->tryStart(cppCallback);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
                // END of custom code block [file: ../glue/qtcore.cpp (qthreadpool-trystart)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // tryStart(QRunnable *runnable)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QRunnable *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // tryStart(QRunnable*)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->tryStart(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyArg);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadPoolFunc_tryTake(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QThreadPool::tryTake(QRunnable*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRunnable_IDX]), (pyArg)))) {
        overloadId = 0; // tryTake(QRunnable*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "tryTake", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRunnable *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // tryTake(QRunnable*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->tryTake(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadPoolFunc_waitForDone(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "waitForDone", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);

    if (PyArg_ParseTuple(args, "|O:waitForDone", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QThreadPool::waitForDone(QDeadlineTimer=)->bool
    // 1: QThreadPool::waitForDone(int)->bool
    if (numArgs == 0) {
        overloadId = 0; // waitForDone(QDeadlineTimer)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 1; // waitForDone(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0])))) {
        overloadId = 0; // waitForDone(QDeadlineTimer)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "waitForDone", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // waitForDone(QDeadlineTimer deadline)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_deadline = Shiboken::String::createStaticString("deadline");
                if (PyDict_Contains(kwds, key_deadline) != 0) {
                    value = PyDict_GetItem(kwds, key_deadline);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_deadline);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "waitForDone", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "waitForDone", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_deadline);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "waitForDone", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDeadlineTimer cppArg0(QDeadlineTimer::Forever);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // waitForDone(QDeadlineTimer)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->waitForDone(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // waitForDone(int msecs)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "waitForDone", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // waitForDone(int)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->waitForDone(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QThreadPool_PropertyStrings[] = {
    "activeThreadCount:",
    "expiryTimeout::",
    "maxThreadCount::",
    "stackSize::",
    "threadPriority::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QThreadPool_methods[] = {
    {"activeThreadCount", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_activeThreadCount), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_clear), METH_NOARGS, nullptr},
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_contains), METH_O, nullptr},
    {"expiryTimeout", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_expiryTimeout), METH_NOARGS, nullptr},
    {"globalInstance", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_globalInstance), METH_NOARGS|METH_STATIC, nullptr},
    {"maxThreadCount", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_maxThreadCount), METH_NOARGS, nullptr},
    {"releaseThread", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_releaseThread), METH_NOARGS, nullptr},
    {"reserveThread", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_reserveThread), METH_NOARGS, nullptr},
    {"setExpiryTimeout", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_setExpiryTimeout), METH_O, nullptr},
    {"setMaxThreadCount", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_setMaxThreadCount), METH_O, nullptr},
    {"setStackSize", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_setStackSize), METH_O, nullptr},
    {"setThreadPriority", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_setThreadPriority), METH_O, nullptr},
    {"stackSize", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_stackSize), METH_NOARGS, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_start), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"startOnReservedThread", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_startOnReservedThread), METH_O, nullptr},
    {"threadPriority", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_threadPriority), METH_NOARGS, nullptr},
    {"tryStart", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_tryStart), METH_O, nullptr},
    {"tryTake", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_tryTake), METH_O, nullptr},
    {"waitForDone", reinterpret_cast<PyCFunction>(Sbk_QThreadPoolFunc_waitForDone), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QThreadPool_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QThreadPool *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QThreadPoolWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QThreadPool_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QThreadPool_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QThreadPool_Type = nullptr;
static PyTypeObject *Sbk_QThreadPool_TypeF(void)
{
    return _Sbk_QThreadPool_Type;
}

static PyType_Slot Sbk_QThreadPool_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QThreadPool_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QThreadPool_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QThreadPool_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QThreadPool_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QThreadPool_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QThreadPool_spec = {
    "2:PySide6.QtCore.QThreadPool",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QThreadPool_slots
};

} //extern "C"

static void *Sbk_QThreadPool_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QThreadPool *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QThreadPool_PythonToCpp_QThreadPool_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QThreadPool_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QThreadPool_PythonToCpp_QThreadPool_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QThreadPool_TypeF()))
        return QThreadPool_PythonToCpp_QThreadPool_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QThreadPool_PTR_CppToPython_QThreadPool(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QThreadPool *>(const_cast<void *>(cppIn)), Sbk_QThreadPool_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QThreadPool_SignatureStrings[] = {
    "PySide6.QtCore.QThreadPool(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,expiryTimeout:int=None,maxThreadCount:int=None,activeThreadCount:int=None,stackSize:uint=None,threadPriority:QThread.Priority=None)",
    "PySide6.QtCore.QThreadPool.activeThreadCount(self)->int",
    "PySide6.QtCore.QThreadPool.clear(self)",
    "PySide6.QtCore.QThreadPool.contains(self,thread:PySide6.QtCore.QThread)->bool",
    "PySide6.QtCore.QThreadPool.expiryTimeout(self)->int",
    "PySide6.QtCore.QThreadPool.globalInstance()->PySide6.QtCore.QThreadPool",
    "PySide6.QtCore.QThreadPool.maxThreadCount(self)->int",
    "PySide6.QtCore.QThreadPool.releaseThread(self)",
    "PySide6.QtCore.QThreadPool.reserveThread(self)",
    "PySide6.QtCore.QThreadPool.setExpiryTimeout(self,expiryTimeout:int)",
    "PySide6.QtCore.QThreadPool.setMaxThreadCount(self,maxThreadCount:int)",
    "PySide6.QtCore.QThreadPool.setStackSize(self,stackSize:uint)",
    "PySide6.QtCore.QThreadPool.setThreadPriority(self,priority:PySide6.QtCore.QThread.Priority)",
    "PySide6.QtCore.QThreadPool.stackSize(self)->uint",
    "1:PySide6.QtCore.QThreadPool.start(self,arg__1:PyCallable,priority:int=0)",
    "0:PySide6.QtCore.QThreadPool.start(self,runnable:PySide6.QtCore.QRunnable,priority:int=0)",
    "PySide6.QtCore.QThreadPool.startOnReservedThread(self,runnable:PySide6.QtCore.QRunnable)",
    "PySide6.QtCore.QThreadPool.threadPriority(self)->PySide6.QtCore.QThread.Priority",
    "1:PySide6.QtCore.QThreadPool.tryStart(self,callable:PyCallable)->bool",
    "0:PySide6.QtCore.QThreadPool.tryStart(self,runnable:PySide6.QtCore.QRunnable)->bool",
    "PySide6.QtCore.QThreadPool.tryTake(self,runnable:PySide6.QtCore.QRunnable)->bool",
    "1:PySide6.QtCore.QThreadPool.waitForDone(self,deadline:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64]=QDeadlineTimer.Forever)->bool",
    "0:PySide6.QtCore.QThreadPool.waitForDone(self,msecs:int)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QThreadPool_SignatureByteSize = 446;
static constexpr uint8_t QThreadPool_SignatureBytes[446] = {
    0x78, 0xda, 0x95, 0x54, 0x4d, 0x4f, 0xc2, 0x40, 0x10, 0xbd, 0xf3, 0x2b, 0x3c, 0x8a, 0xa9, 0x0d,
    0x26, 0xc6, 0x43, 0x13, 0xbc, 0xa0, 0x26, 0xc6, 0x28, 0x28, 0x78, 0x32, 0x86, 0x2c, 0xed, 0x88,
    0xab, 0xcb, 0x2c, 0x4e, 0xa7, 0x40, 0xfd, 0xf5, 0x6e, 0xd9, 0xf2, 0x51, 0x5a, 0xb6, 0xf5, 0x3a,
    0xf3, 0xe6, 0xcd, 0xcc, 0xdb, 0x37, 0x3b, 0x48, 0x87, 0x32, 0x82, 0x2b, 0xff, 0x99, 0x7b, 0x9a,
    0xc0, 0x7f, 0x1e, 0x7d, 0x12, 0x88, 0x68, 0xa0, 0xb5, 0x3a, 0x8d, 0x41, 0x7d, 0x78, 0x73, 0x41,
    0x80, 0x1c, 0x0c, 0x0e, 0x60, 0xfd, 0xc9, 0x17, 0x84, 0xdc, 0xc5, 0x44, 0xa9, 0x39, 0x93, 0x77,
    0x16, 0x3c, 0x40, 0xba, 0xd4, 0x14, 0xf5, 0x51, 0xa5, 0xdd, 0x27, 0x8d, 0xe0, 0xc1, 0x6a, 0x2e,
    0x29, 0x1d, 0xc9, 0x19, 0xe8, 0x84, 0x03, 0x89, 0x6c, 0xc3, 0x33, 0xb1, 0xb2, 0x2d, 0x7a, 0x3a,
    0xc1, 0xbd, 0xb8, 0x08, 0x59, 0x2e, 0xa0, 0x32, 0x15, 0xb3, 0x08, 0xbf, 0x87, 0xf2, 0x17, 0x82,
    0x64, 0x1b, 0x63, 0x3b, 0x26, 0x49, 0x4d, 0x92, 0xd3, 0x20, 0x1f, 0xdb, 0xdf, 0x04, 0xd6, 0xa0,
    0x76, 0x6b, 0x70, 0x74, 0x39, 0xbf, 0xd4, 0x6f, 0xbd, 0x6e, 0xfb, 0xfc, 0xda, 0xb4, 0x70, 0xd5,
    0x85, 0x0a, 0x04, 0x59, 0xac, 0x13, 0xa6, 0x91, 0x85, 0xc4, 0xd8, 0x8a, 0x68, 0xa7, 0x0d, 0xaa,
    0xf1, 0xa6, 0xe7, 0xc4, 0x94, 0xb8, 0xd8, 0x0a, 0x5a, 0x36, 0x1c, 0x74, 0xaa, 0xf4, 0x44, 0xa8,
    0x7b, 0x34, 0xea, 0x61, 0x08, 0xa7, 0xa6, 0xe0, 0x38, 0xd8, 0xc5, 0x53, 0x7c, 0xb0, 0x86, 0xcd,
    0x09, 0x8c, 0x4c, 0x71, 0x2e, 0x6f, 0xbd, 0x5a, 0x04, 0x31, 0xd0, 0xa2, 0x31, 0x3c, 0x06, 0xbe,
    0x2d, 0x29, 0x52, 0x36, 0x5c, 0x1d, 0xc7, 0x63, 0x79, 0xb3, 0x0a, 0x7b, 0xd6, 0xb1, 0x0c, 0x37,
    0xee, 0xb4, 0x04, 0x45, 0xb3, 0xd6, 0x15, 0x8f, 0x0a, 0x36, 0xce, 0x2f, 0x6e, 0x63, 0xea, 0xea,
    0xd2, 0xad, 0xc7, 0xdd, 0xdc, 0x85, 0xa9, 0xcc, 0x83, 0x65, 0xd3, 0xb4, 0x2e, 0x02, 0x77, 0x09,
    0xe5, 0x2a, 0x08, 0x9a, 0x8e, 0xc7, 0x19, 0xb8, 0x27, 0x94, 0x12, 0x13, 0x05, 0xbb, 0xa1, 0xb2,
    0x0b, 0xec, 0xb4, 0x5b, 0x9d, 0x86, 0x4c, 0x94, 0x20, 0x66, 0x04, 0x25, 0xf8, 0x4b, 0x9e, 0x28,
    0x31, 0xd7, 0xf1, 0xf6, 0xf1, 0xc5, 0xba, 0x25, 0xda, 0xb3, 0x4b, 0x7d, 0x1f, 0x27, 0x31, 0x97,
    0x9f, 0xe1, 0xe8, 0xbd, 0x6c, 0xf5, 0x77, 0xab, 0xc9, 0x94, 0x0e, 0x77, 0x32, 0x84, 0xb9, 0x8e,
    0x7b, 0x92, 0x6e, 0xce, 0xbe, 0xd3, 0x9c, 0xa5, 0x7e, 0xc9, 0xfa, 0xaf, 0xc4, 0x30, 0x8e, 0xc4,
    0x37, 0xfc, 0x93, 0xd0, 0xb9, 0xea, 0x52, 0x48, 0xbe, 0xd3, 0x74, 0x63, 0xbe, 0x5c, 0x4b, 0x1b,
    0x99, 0x8c, 0x92, 0x08, 0x01, 0xa7, 0x73, 0x89, 0x53, 0xff, 0x15, 0xa5, 0xc6, 0xb7, 0x43, 0x86,
    0x9b, 0x1c, 0x95, 0x5d, 0x2c, 0x79, 0x27, 0xce, 0xb4, 0x6f, 0xf8, 0x61, 0x01, 0xd4, 0xd3, 0xeb,
    0xff, 0x8c, 0xbd, 0x93, 0x1f, 0x63, 0x97, 0xab, 0xcb, 0xf7, 0x6e, 0x35, 0xae, 0x91, 0xb8, 0xa5,
    0xb9, 0x67, 0x31, 0x84, 0xf1, 0xfa, 0xe6, 0xf3, 0xf2, 0x3f, 0x81, 0xec, 0x94, 0x92
};
#endif

PyTypeObject *init_QThreadPool(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX].type;

    Shiboken::AutoDecRef Sbk_QThreadPool_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QThreadPool_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QThreadPool",
        "QThreadPool*",
        &Sbk_QThreadPool_spec,
        &Shiboken::callCppDestructor< QThreadPool >,
        Sbk_QThreadPool_Type_bases.object(),
        0);
    auto *pyType = Sbk_QThreadPool_TypeF(); // references _Sbk_QThreadPool_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QThreadPool_SignatureStrings);
#else
    InitSignatureBytes(pyType, QThreadPool_SignatureBytes, QThreadPool_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QThreadPool_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QThreadPool_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QThreadPool_PythonToCpp_QThreadPool_PTR,
        is_QThreadPool_PythonToCpp_QThreadPool_PTR_Convertible,
        QThreadPool_PTR_CppToPython_QThreadPool);

    Shiboken::Conversions::registerConverterName(converter, "QThreadPool");
    Shiboken::Conversions::registerConverterName(converter, "QThreadPool*");
    Shiboken::Conversions::registerConverterName(converter, "QThreadPool&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QThreadPool).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QThreadPoolWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QThreadPool_TypeF(), &Sbk_QThreadPool_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QThreadPool::staticMetaObject, sizeof(QThreadPoolWrapper));

    return pyType;
}
