// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qtime_wrapper.h"

// Extra includes
#include <datetime.h>

// Argument includes
#include <QString>
#include <QStringView>
#include <qdatetime.h>
#include <qnamespace.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (core-snippets-p-h)]
#include "glue/core_snippets_p.h"
// END of custom code block [file: ../glue/qtcore.cpp (core-snippets-p-h)]
// ========================================================================
// End of code injection



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTime_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTime >()))
        return -1;

    ::QTime *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:QTime", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTime::QTime()
    // 1: QTime::QTime(QTime)
    // 2: QTime::QTime(int,int,int=,int=)
    if (numArgs == 0) {
        overloadId = 0; // QTime()
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // QTime(int,int,int,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 2; // QTime(int,int,int,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                overloadId = 2; // QTime(int,int,int,int)
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QTime(QTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTime()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
            }

            // QTime()
            cptr = new ::QTime();
            break;
        }
        case 1: // QTime(const QTime &QTime)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTime cppArg0_local;
            ::QTime *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTime(QTime)
                cptr = new ::QTime(*cppArg0);
            }
            break;
        }
        case 2: // QTime(int h, int m, int s, int ms)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_s = Shiboken::String::createStaticString("s");
                if (PyDict_Contains(kwds, key_s) != 0) {
                    value = PyDict_GetItem(kwds, key_s);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_s);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_s);
                }
                static PyObject *const key_ms = Shiboken::String::createStaticString("ms");
                if (PyDict_Contains(kwds, key_ms) != 0) {
                    value = PyDict_GetItem(kwds, key_ms);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_ms);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_ms);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = 0;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = 0;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTime(int,int,int,int)
                cptr = new ::QTime(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTime >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTimeFunc___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __reduce__()
        // Begin code injection
        // TEMPLATE - reduce_code - START
        pyResult = Py_BuildValue("(N(iiii))", PyObject_Type(self), cppSelf->hour(), cppSelf->minute(), cppSelf->second(), cppSelf->msec());
        // TEMPLATE - reduce_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - repr_code - START
        QString format = QString::asprintf("%s(%i, %i, %i, %i)",
            Py_TYPE(self)->tp_name, cppSelf->hour(), cppSelf->minute(), cppSelf->second(), cppSelf->msec());
        pyResult = Shiboken::String::fromCString(qPrintable(format));
        // TEMPLATE - repr_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_addMSecs(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTime::addMSecs(int)const->QTime
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // addMSecs(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addMSecs", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addMSecs(int)const
            QTime cppResult = const_cast<const ::QTime *>(cppSelf)->addMSecs(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_addSecs(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTime::addSecs(int)const->QTime
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // addSecs(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addSecs", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addSecs(int)const
            QTime cppResult = const_cast<const ::QTime *>(cppSelf)->addSecs(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_currentTime(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentTime()
        QTime cppResult = ::QTime::currentTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_fromMSecsSinceStartOfDay(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QTime::fromMSecsSinceStartOfDay(int)->QTime
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // fromMSecsSinceStartOfDay(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromMSecsSinceStartOfDay", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromMSecsSinceStartOfDay(int)
            QTime cppResult = ::QTime::fromMSecsSinceStartOfDay(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_fromString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fromString", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTime::fromString(QStringView,QStringView)->QTime
    // 1: static QTime::fromString(QStringView,Qt::DateFormat=)->QTime
    // 2: static QTime::fromString(QString,QStringView)->QTime
    // 3: static QTime::fromString(QString,Qt::DateFormat=)->QTime
    // 4: static QTime::fromString(QString,QString)->QTime
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // fromString(QString,Qt::DateFormat)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 4; // fromString(QString,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DateFormat_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 3; // fromString(QString,Qt::DateFormat)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 2; // fromString(QString,QStringView)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // fromString(QStringView,Qt::DateFormat)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DateFormat_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // fromString(QStringView,Qt::DateFormat)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // fromString(QStringView,QStringView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // fromString(QStringView string, QStringView format)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QStringView,QStringView)
                QTime cppResult = ::QTime::fromString(QStringView(cppArg0), QStringView(cppArg1));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), &cppResult);
            }
            break;
        }
        case 1: // fromString(QStringView string, Qt::DateFormat format)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DateFormat_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::DateFormat cppArg1(Qt::TextDate);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QStringView,Qt::DateFormat)
                QTime cppResult = ::QTime::fromString(QStringView(cppArg0), cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), &cppResult);
            }
            break;
        }
        case 2: // fromString(const QString &string, QStringView format)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QString,QStringView)
                QTime cppResult = ::QTime::fromString(cppArg0, QStringView(cppArg1));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), &cppResult);
            }
            break;
        }
        case 3: // fromString(const QString &string, Qt::DateFormat format)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DateFormat_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::DateFormat cppArg1(Qt::TextDate);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QString,Qt::DateFormat)
                QTime cppResult = ::QTime::fromString(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), &cppResult);
            }
            break;
        }
        case 4: // fromString(const QString &string, const QString &format)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromString(QString,QString)
                QTime cppResult = ::QTime::fromString(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_hour(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hour()const
        int cppResult = const_cast<const ::QTime *>(cppSelf)->hour();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QTime *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_isValid(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QTime *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "isValid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
    if (numArgs == 1 || numArgs == 2)
        return Shiboken::returnWrongArguments(args, "isValid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:isValid", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTime::isValid()const->bool
    // 1: static QTime::isValid(int,int,int,int=)->bool
    if (numArgs == 0) {
        overloadId = 0; // isValid()const
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 1; // isValid(int,int,int,int)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 1; // isValid(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isValid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // isValid() const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "isValid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
            }

            // isValid()const
            bool cppResult = const_cast<const ::QTime *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            break;
        }
        case 1: // isValid(int h, int m, int s, int ms)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_ms = Shiboken::String::createStaticString("ms");
                if (PyDict_Contains(kwds, key_ms) != 0) {
                    value = PyDict_GetItem(kwds, key_ms);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_ms);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "isValid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "isValid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_ms);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "isValid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = 0;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isValid(int,int,int,int)
                bool cppResult = ::QTime::isValid(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_minute(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minute()const
        int cppResult = const_cast<const ::QTime *>(cppSelf)->minute();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_msec(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // msec()const
        int cppResult = const_cast<const ::QTime *>(cppSelf)->msec();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_msecsSinceStartOfDay(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // msecsSinceStartOfDay()const
        int cppResult = const_cast<const ::QTime *>(cppSelf)->msecsSinceStartOfDay();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_msecsTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTime::msecsTo(QTime)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArg)))) {
        overloadId = 0; // msecsTo(QTime)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "msecsTo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTime cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // msecsTo(QTime)const
            int cppResult = const_cast<const ::QTime *>(cppSelf)->msecsTo(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_second(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // second()const
        int cppResult = const_cast<const ::QTime *>(cppSelf)->second();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_secsTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTime::secsTo(QTime)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArg)))) {
        overloadId = 0; // secsTo(QTime)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "secsTo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTime cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // secsTo(QTime)const
            int cppResult = const_cast<const ::QTime *>(cppSelf)->secsTo(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_setHMS(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setHMS", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:setHMS", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTime::setHMS(int,int,int,int=)->bool
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // setHMS(int,int,int,int)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 0; // setHMS(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setHMS", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_ms = Shiboken::String::createStaticString("ms");
            if (PyDict_Contains(kwds, key_ms) != 0) {
                value = PyDict_GetItem(kwds, key_ms);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_ms);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setHMS", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "setHMS", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_ms);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setHMS", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3 = 0;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHMS(int,int,int,int)
            bool cppResult = cppSelf->setHMS(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_toPython(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toPython()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtcore.cpp (qtime-topython)]
        if (!PyDateTimeAPI)
            PyDateTime_IMPORT;
        pyResult = PyTime_FromTime(cppSelf->hour(), cppSelf->minute(), cppSelf->second(), cppSelf->msec()*1000);
        // END of custom code block [file: ../glue/qtcore.cpp (qtime-topython)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTimeFunc_toString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);

    if (PyArg_ParseTuple(args, "|O:toString", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTime::toString(QStringView)const->QString
    // 1: QTime::toString(Qt::DateFormat=)const->QString
    // 2: QTime::toString(QString)const->QString
    if (numArgs == 0) {
        overloadId = 1; // toString(Qt::DateFormat)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 2; // toString(QString)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DateFormat_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // toString(Qt::DateFormat)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // toString(QStringView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // toString(QStringView format) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QStringView)const
                QString cppResult = const_cast<const ::QTime *>(cppSelf)->toString(QStringView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // toString(Qt::DateFormat f) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_f = Shiboken::String::createStaticString("f");
                if (PyDict_Contains(kwds, key_f) != 0) {
                    value = PyDict_GetItem(kwds, key_f);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_f);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DateFormat_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_f);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
                }
            }
            ::Qt::DateFormat cppArg0(Qt::TextDate);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(Qt::DateFormat)const
                QString cppResult = const_cast<const ::QTime *>(cppSelf)->toString(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 2: // toString(const QString &format) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QString)const
                QString cppResult = const_cast<const ::QTime *>(cppSelf)->toString(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTime__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QTimeMethod_isValid = {"isValid", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_isValid), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr};


static const char *Sbk_QTime_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTime_EnumFlagInfo[] = {
    "TimeFlag:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTime_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc___reduce__), METH_NOARGS, nullptr},
    {"addMSecs", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_addMSecs), METH_O, nullptr},
    {"addSecs", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_addSecs), METH_O, nullptr},
    {"currentTime", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_currentTime), METH_NOARGS|METH_STATIC, nullptr},
    {"fromMSecsSinceStartOfDay", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_fromMSecsSinceStartOfDay), METH_O|METH_STATIC, nullptr},
    {"fromString", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_fromString), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"hour", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_hour), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_isNull), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_isValid), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"minute", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_minute), METH_NOARGS, nullptr},
    {"msec", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_msec), METH_NOARGS, nullptr},
    {"msecsSinceStartOfDay", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_msecsSinceStartOfDay), METH_NOARGS, nullptr},
    {"msecsTo", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_msecsTo), METH_O, nullptr},
    {"second", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_second), METH_NOARGS, nullptr},
    {"secsTo", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_secsTo), METH_O, nullptr},
    {"setHMS", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_setHMS), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toPython", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_toPython), METH_NOARGS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QTimeFunc_toString), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTime__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QTime_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QTimeMethod_isValid = {
        Sbk_QTimeMethod_isValid.ml_name,
        Sbk_QTimeMethod_isValid.ml_meth,
        Sbk_QTimeMethod_isValid.ml_flags & (~METH_STATIC),
        Sbk_QTimeMethod_isValid.ml_doc,
    };
    if (Shiboken::String::compare(name, "isValid") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QTimeMethod_isValid, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

static int Sbk_QTime___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QTime_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArg)))) {
                // operator!=(const QTime &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTime cppArg0_local;
                ::QTime *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArg)))) {
                // operator<(const QTime &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTime cppArg0_local;
                ::QTime *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArg)))) {
                // operator<=(const QTime &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTime cppArg0_local;
                ::QTime *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArg)))) {
                // operator==(const QTime &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTime cppArg0_local;
                ::QTime *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArg)))) {
                // operator>(const QTime &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTime cppArg0_local;
                ::QTime *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArg)))) {
                // operator>=(const QTime &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTime cppArg0_local;
                ::QTime *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QTime_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QTime_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTime_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTime_Type = nullptr;
static PyTypeObject *Sbk_QTime_TypeF(void)
{
    return _Sbk_QTime_Type;
}

static PyType_Slot Sbk_QTime_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QTimeFunc___repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QTime_HashFunc)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QTime_getattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTime_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTime_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QTime_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTime_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTime_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QTime___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTime_spec = {
    "2:PySide6.QtCore.QTime",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTime_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTime_PythonToCpp_QTime_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTime_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTime_PythonToCpp_QTime_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTime_TypeF()))
        return QTime_PythonToCpp_QTime_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTime_PTR_CppToPython_QTime(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QTime_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QTime_COPY_CppToPython_QTime(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTime *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTime_TypeF(), new ::QTime(*source), true, true);
}

// Python to C++ copy conversion.
static void QTime_PythonToCpp_QTime_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTime *>(cppOut) = *reinterpret_cast< ::QTime *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTime_PythonToCpp_QTime_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTime_TypeF()))
        return QTime_PythonToCpp_QTime_COPY;
    return {};
}

// Python to C++ conversions for type 'QTime'.
static void Py_None_PythonToCpp_QTime(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pynone)]
    SBK_UNUSED(pyIn)
    *reinterpret_cast<::QTime *>(cppOut) = QTime();
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pynone)]
    // ========================================================================

}
static PythonToCppFunc is_Py_None_PythonToCpp_QTime_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Py_None_PythonToCpp_QTime;
    return {};
}
static void PyTime_PythonToCpp_QTime(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-qtime-pytime)]
    int hour = PyDateTime_TIME_GET_HOUR(pyIn);
    int min = PyDateTime_TIME_GET_MINUTE(pyIn);
    int sec = PyDateTime_TIME_GET_SECOND(pyIn);
    int usec = PyDateTime_TIME_GET_MICROSECOND(pyIn);
    *reinterpret_cast<::QTime *>(cppOut) = QTime(hour, min, sec, usec/1000);
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-qtime-pytime)]
    // ========================================================================

}
static PythonToCppFunc is_PyTime_PythonToCpp_QTime_Convertible(PyObject *pyIn)
{
    if (PyTime_ImportAndCheck(pyIn))
        return PyTime_PythonToCpp_QTime;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTime_SignatureStrings[] = {
    "2:PySide6.QtCore.QTime(self)",
    "1:PySide6.QtCore.QTime(self,QTime:PySide6.QtCore.QTime)",
    "0:PySide6.QtCore.QTime(self,h:int,m:int,s:int=0,ms:int=0)",
    "PySide6.QtCore.QTime.__reduce__(self)->str",
    "PySide6.QtCore.QTime.__repr__(self)->str",
    "PySide6.QtCore.QTime.addMSecs(self,ms:int)->PySide6.QtCore.QTime",
    "PySide6.QtCore.QTime.addSecs(self,secs:int)->PySide6.QtCore.QTime",
    "PySide6.QtCore.QTime.currentTime()->PySide6.QtCore.QTime",
    "PySide6.QtCore.QTime.fromMSecsSinceStartOfDay(msecs:int)->PySide6.QtCore.QTime",
    "4:PySide6.QtCore.QTime.fromString(string:QString,format:QString)->PySide6.QtCore.QTime",
    "3:PySide6.QtCore.QTime.fromString(string:QString,format:PySide6.QtCore.Qt.DateFormat=Qt.TextDate)->PySide6.QtCore.QTime",
    "2:PySide6.QtCore.QTime.fromString(string:QString,format:QString)->PySide6.QtCore.QTime",
    "1:PySide6.QtCore.QTime.fromString(string:QString,format:PySide6.QtCore.Qt.DateFormat=Qt.TextDate)->PySide6.QtCore.QTime",
    "0:PySide6.QtCore.QTime.fromString(string:QString,format:QString)->PySide6.QtCore.QTime",
    "PySide6.QtCore.QTime.hour(self)->int",
    "PySide6.QtCore.QTime.isNull(self)->bool",
    "1:PySide6.QtCore.QTime.isValid(self)->bool",
    "0:PySide6.QtCore.QTime.isValid(h:int,m:int,s:int,ms:int=0)->bool",
    "PySide6.QtCore.QTime.minute(self)->int",
    "PySide6.QtCore.QTime.msec(self)->int",
    "PySide6.QtCore.QTime.msecsSinceStartOfDay(self)->int",
    "PySide6.QtCore.QTime.msecsTo(self,t:PySide6.QtCore.QTime)->int",
    "PySide6.QtCore.QTime.second(self)->int",
    "PySide6.QtCore.QTime.secsTo(self,t:PySide6.QtCore.QTime)->int",
    "PySide6.QtCore.QTime.setHMS(self,h:int,m:int,s:int,ms:int=0)->bool",
    "PySide6.QtCore.QTime.toPython(self)->PyObject",
    "2:PySide6.QtCore.QTime.toString(self,format:QString)->QString",
    "1:PySide6.QtCore.QTime.toString(self,f:PySide6.QtCore.Qt.DateFormat=Qt.TextDate)->QString",
    "0:PySide6.QtCore.QTime.toString(self,format:QString)->QString",
    "PySide6.QtCore.QTime.__copy__(self)->typing.Self",
    "PySide6.QtCore.QTime.__ne__(self,rhs:PySide6.QtCore.QTime)->bool",
    "PySide6.QtCore.QTime.__lt__(self,rhs:PySide6.QtCore.QTime)->bool",
    "PySide6.QtCore.QTime.__le__(self,rhs:PySide6.QtCore.QTime)->bool",
    "PySide6.QtCore.QTime.__eq__(self,rhs:PySide6.QtCore.QTime)->bool",
    "PySide6.QtCore.QTime.__gt__(self,rhs:PySide6.QtCore.QTime)->bool",
    "PySide6.QtCore.QTime.__ge__(self,rhs:PySide6.QtCore.QTime)->bool",
    "PySide6.QtCore.QTime.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QTime_SignatureByteSize = 398;
static constexpr uint8_t QTime_SignatureBytes[398] = {
    0x78, 0xda, 0xc5, 0x55, 0xd1, 0x6e, 0xc2, 0x20, 0x14, 0x7d, 0xf7, 0x4b, 0x34, 0xe9, 0x9a, 0xea,
    0x96, 0x3d, 0x34, 0x71, 0x2f, 0x33, 0xcb, 0x5e, 0x9c, 0x1a, 0xcc, 0x5e, 0x1b, 0xd6, 0x52, 0xcb,
    0x52, 0xc0, 0xc1, 0x6d, 0xb2, 0xfe, 0xfd, 0x68, 0x2b, 0x69, 0xa6, 0xa0, 0x75, 0xc4, 0xec, 0x85,
    0x42, 0x39, 0xe7, 0x70, 0x2e, 0x70, 0x2f, 0xb3, 0x78, 0x5d, 0x23, 0x9a, 0x91, 0xc7, 0x70, 0x03,
    0xcf, 0x42, 0x92, 0x70, 0xb3, 0xa5, 0x8c, 0x8c, 0x15, 0x29, 0xf3, 0xc9, 0x68, 0xea, 0x9e, 0x0c,
    0xda, 0xae, 0x75, 0x7e, 0x32, 0x8a, 0xce, 0xf0, 0x8a, 0x98, 0x72, 0x08, 0x58, 0xdb, 0xaa, 0xa6,
    0x9d, 0x47, 0x01, 0x3b, 0x74, 0x26, 0x23, 0x1b, 0x2f, 0x4c, 0x12, 0x49, 0xb2, 0x2a, 0x25, 0x49,
    0xd2, 0xf9, 0xba, 0x7b, 0x52, 0x20, 0xdd, 0xd0, 0xbd, 0x1c, 0x00, 0xc4, 0x59, 0xb6, 0x44, 0x24,
    0x55, 0x9d, 0xa9, 0xce, 0x80, 0xc6, 0xdb, 0xb0, 0x4e, 0x81, 0x9e, 0xaf, 0x74, 0xef, 0x6a, 0x85,
    0xb4, 0x92, 0x92, 0x70, 0x68, 0xb7, 0xe6, 0x2a, 0x62, 0x2e, 0x05, 0x6b, 0xcd, 0x23, 0xca, 0x53,
    0x82, 0x00, 0x4b, 0x58, 0xe5, 0x0b, 0x5c, 0x8f, 0xd9, 0x25, 0x1f, 0x0f, 0xb1, 0x53, 0x10, 0x81,
    0xa4, 0x7c, 0x37, 0x56, 0xed, 0x27, 0xde, 0x74, 0xc3, 0x20, 0x17, 0x92, 0x61, 0x30, 0x43, 0x97,
    0xec, 0xfd, 0x1f, 0x65, 0x8f, 0x59, 0x10, 0x2e, 0x30, 0x90, 0x97, 0x76, 0x72, 0xae, 0x47, 0x5b,
    0xf2, 0x0d, 0xcd, 0x1f, 0xd7, 0xba, 0xb3, 0xdb, 0x84, 0x33, 0xfd, 0xa7, 0x70, 0xa2, 0xdb, 0x84,
    0x63, 0x15, 0x2d, 0x44, 0x25, 0x4d, 0x92, 0xe8, 0x0b, 0x63, 0x07, 0x51, 0xf5, 0x56, 0x95, 0xa5,
    0x81, 0x7d, 0x08, 0x51, 0xba, 0xf6, 0x86, 0xaa, 0x77, 0x5c, 0xd2, 0xec, 0x17, 0x34, 0x3a, 0x0f,
    0x3d, 0x29, 0x04, 0x7d, 0x19, 0x38, 0x08, 0x58, 0xe9, 0x8c, 0xf2, 0x0a, 0xc8, 0x45, 0xeb, 0x4d,
    0x2a, 0x0c, 0x02, 0x9d, 0x24, 0xd1, 0x20, 0xd2, 0x56, 0x74, 0x89, 0x0f, 0xf6, 0x0a, 0x78, 0x86,
    0xae, 0xd9, 0x82, 0x67, 0x17, 0x57, 0xf1, 0x5d, 0x04, 0x5e, 0x97, 0xc8, 0x51, 0x70, 0x87, 0xed,
    0x33, 0x88, 0x75, 0x0d, 0x85, 0xe0, 0xc6, 0xe9, 0xba, 0x5e, 0x7d, 0x7c, 0x92, 0x14, 0x5c, 0x49,
    0x07, 0xc2, 0xdc, 0xd1, 0x66, 0xd1, 0x93, 0x9b, 0x79, 0xe8, 0xb9, 0xee, 0xcf, 0x11, 0xfb, 0x9a,
    0x54, 0x32, 0xca, 0x91, 0x97, 0x2f, 0xc7, 0x6b, 0x92, 0x8a, 0x7d, 0xdd, 0xbf, 0x26, 0x50, 0xef,
    0x35, 0x36, 0x44, 0x7a, 0xe4, 0x22, 0x70, 0xf3, 0x4a, 0x05, 0xb2, 0x50, 0xae, 0x73, 0x73, 0xef,
    0x7a, 0x92, 0x94, 0xe0, 0x2b, 0xe0, 0xeb, 0x80, 0x7c, 0x79, 0x0a, 0xec, 0x7c, 0x43, 0xd8, 0xf9,
    0x86, 0x50, 0x60, 0x55, 0xf4, 0xc7, 0xd6, 0xa4, 0xc9, 0x0f, 0xb1, 0x25, 0x18, 0x94
};
#endif

PyTypeObject *init_QTime(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX].type;

    Shiboken::AutoDecRef Sbk_QTime_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTime_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTime",
        "QTime",
        &Sbk_QTime_spec,
        &Shiboken::callCppDestructor< ::QTime >,
        Sbk_QTime_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTime_TypeF(); // references _Sbk_QTime_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTime_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTime_SignatureBytes, QTime_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTime_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTime_PythonToCpp_QTime_PTR,
        is_QTime_PythonToCpp_QTime_PTR_Convertible,
        QTime_PTR_CppToPython_QTime,
        QTime_COPY_CppToPython_QTime);

    Shiboken::Conversions::registerConverterName(converter, "QTime");
    Shiboken::Conversions::registerConverterName(converter, "QTime*");
    Shiboken::Conversions::registerConverterName(converter, "QTime&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTime).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTime_PythonToCpp_QTime_COPY,
        is_QTime_PythonToCpp_QTime_COPY_Convertible);
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Py_None_PythonToCpp_QTime,
        is_Py_None_PythonToCpp_QTime_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PyTime_PythonToCpp_QTime,
        is_PyTime_PythonToCpp_QTime_Convertible);


    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTime_EnumFlagInfo);



    return pyType;
}

