// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qurlquery_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <qchar.h>
#include <qurl.h>
#include <qurlquery.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QUrlQuery_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QUrlQuery >()))
        return -1;

    ::QUrlQuery *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QUrlQuery", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QUrlQuery::QUrlQuery()
    // 1: QUrlQuery::QUrlQuery(QString)
    // 2: QUrlQuery::QUrlQuery(QUrl)
    // 3: QUrlQuery::QUrlQuery(QUrlQuery)
    if (numArgs == 0) {
        overloadId = 0; // QUrlQuery()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QUrlQuery(QUrlQuery)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // QUrlQuery(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QUrlQuery(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QUrlQuery()
        {

            // QUrlQuery()
            cptr = new ::QUrlQuery();
            break;
        }
        case 1: // QUrlQuery(const QString &queryString)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QUrlQuery(QString)
                cptr = new ::QUrlQuery(cppArg0);
            }
            break;
        }
        case 2: // QUrlQuery(const QUrl &url)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QUrlQuery(QUrl)
                cptr = new ::QUrlQuery(*cppArg0);
            }
            break;
        }
        case 3: // QUrlQuery(const QUrlQuery &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrlQuery cppArg0_local;
            ::QUrlQuery *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QUrlQuery(QUrlQuery)
                cptr = new ::QUrlQuery(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QUrlQuery >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QUrlQueryFunc_addQueryItem(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addQueryItem", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrlQuery::addQueryItem(QString,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // addQueryItem(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addQueryItem", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addQueryItem(QString,QString)
            cppSelf->addQueryItem(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlQueryFunc_allQueryItemValues(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "allQueryItemValues", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    if (PyArg_ParseTuple(args, "|OO:allQueryItemValues", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrlQuery::allQueryItemValues(QString,QFlags<QUrl::ComponentFormattingOption>=)const->QStringList
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // allQueryItemValues(QString,QFlags<QUrl::ComponentFormattingOption>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // allQueryItemValues(QString,QFlags<QUrl::ComponentFormattingOption>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "allQueryItemValues", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_encoding = Shiboken::String::createStaticString("encoding");
            if (PyDict_Contains(kwds, key_encoding) != 0) {
                value = PyDict_GetItem(kwds, key_encoding);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_encoding);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "allQueryItemValues", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "allQueryItemValues", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_encoding);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "allQueryItemValues", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QUrl::ComponentFormattingOption> cppArg1(QUrl::PrettyDecoded);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // allQueryItemValues(QString,QFlags<QUrl::ComponentFormattingOption>)const
            QStringList cppResult = const_cast<const ::QUrlQuery *>(cppSelf)->allQueryItemValues(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlQueryFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlQueryFunc_hasQueryItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QUrlQuery::hasQueryItem(QString)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // hasQueryItem(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasQueryItem", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasQueryItem(QString)const
            bool cppResult = const_cast<const ::QUrlQuery *>(cppSelf)->hasQueryItem(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlQueryFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QUrlQuery *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlQueryFunc_query(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "query", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    if (PyArg_ParseTuple(args, "|O:query", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrlQuery::query(QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // query(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // query(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "query", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_encoding = Shiboken::String::createStaticString("encoding");
            if (PyDict_Contains(kwds, key_encoding) != 0) {
                value = PyDict_GetItem(kwds, key_encoding);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_encoding);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "query", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "query", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_encoding);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "query", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0(QUrl::PrettyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // query(QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QUrlQuery *>(cppSelf)->query(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlQueryFunc_queryItemValue(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "queryItemValue", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    if (PyArg_ParseTuple(args, "|OO:queryItemValue", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrlQuery::queryItemValue(QString,QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // queryItemValue(QString,QFlags<QUrl::ComponentFormattingOption>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // queryItemValue(QString,QFlags<QUrl::ComponentFormattingOption>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "queryItemValue", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_encoding = Shiboken::String::createStaticString("encoding");
            if (PyDict_Contains(kwds, key_encoding) != 0) {
                value = PyDict_GetItem(kwds, key_encoding);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_encoding);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "queryItemValue", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "queryItemValue", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_encoding);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "queryItemValue", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QUrl::ComponentFormattingOption> cppArg1(QUrl::PrettyDecoded);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // queryItemValue(QString,QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QUrlQuery *>(cppSelf)->queryItemValue(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlQueryFunc_queryItems(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "queryItems", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    if (PyArg_ParseTuple(args, "|O:queryItems", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrlQuery::queryItems(QFlags<QUrl::ComponentFormattingOption>=)const->QList<std::pair<QString,QString>>
    if (numArgs == 0) {
        overloadId = 0; // queryItems(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // queryItems(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "queryItems", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_encoding = Shiboken::String::createStaticString("encoding");
            if (PyDict_Contains(kwds, key_encoding) != 0) {
                value = PyDict_GetItem(kwds, key_encoding);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_encoding);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "queryItems", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "queryItems", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_encoding);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "queryItems", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0(QUrl::PrettyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // queryItems(QFlags<QUrl::ComponentFormattingOption>)const
            QList<std::pair<QString,QString>> cppResult = const_cast<const ::QUrlQuery *>(cppSelf)->queryItems(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_std_pair_QString_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlQueryFunc_queryPairDelimiter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // queryPairDelimiter()const
        QChar cppResult = const_cast<const ::QUrlQuery *>(cppSelf)->queryPairDelimiter();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlQueryFunc_queryValueDelimiter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // queryValueDelimiter()const
        QChar cppResult = const_cast<const ::QUrlQuery *>(cppSelf)->queryValueDelimiter();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlQueryFunc_removeAllQueryItems(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QUrlQuery::removeAllQueryItems(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // removeAllQueryItems(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAllQueryItems", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAllQueryItems(QString)
            cppSelf->removeAllQueryItems(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlQueryFunc_removeQueryItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QUrlQuery::removeQueryItem(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // removeQueryItem(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeQueryItem", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeQueryItem(QString)
            cppSelf->removeQueryItem(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlQueryFunc_setQuery(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QUrlQuery::setQuery(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setQuery(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setQuery", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setQuery(QString)
            cppSelf->setQuery(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlQueryFunc_setQueryDelimiters(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setQueryDelimiters", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrlQuery::setQueryDelimiters(QChar,QChar)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArgs[1])))) {
        overloadId = 0; // setQueryDelimiters(QChar,QChar)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setQueryDelimiters", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    // Call function/method
    {
        ::QChar cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QChar cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setQueryDelimiters(QChar,QChar)
            cppSelf->setQueryDelimiters(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlQueryFunc_setQueryItems(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QUrlQuery::setQueryItems(QList<std::pair<QString,QString>>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_std_pair_QString_QString_IDX], (pyArg)))) {
        overloadId = 0; // setQueryItems(QList<std::pair<QString,QString>>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setQueryItems", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    // Call function/method
    {
        ::QList<std::pair<QString,QString>> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setQueryItems(QList<std::pair<QString,QString>>)
            cppSelf->setQueryItems(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlQueryFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QUrlQuery::swap(QUrlQuery&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QUrlQuery&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrlQuery cppArg0_local;
        ::QUrlQuery *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QUrlQuery&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlQueryFunc_toString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    if (PyArg_ParseTuple(args, "|O:toString", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrlQuery::toString(QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // toString(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // toString(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_encoding = Shiboken::String::createStaticString("encoding");
            if (PyDict_Contains(kwds, key_encoding) != 0) {
                value = PyDict_GetItem(kwds, key_encoding);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_encoding);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_encoding);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0(QUrl::PrettyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toString(QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QUrlQuery *>(cppSelf)->toString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlQuery__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QUrlQuery_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QUrlQuery_methods[] = {
    {"addQueryItem", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_addQueryItem), METH_VARARGS, nullptr},
    {"allQueryItemValues", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_allQueryItemValues), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_clear), METH_NOARGS, nullptr},
    {"hasQueryItem", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_hasQueryItem), METH_O, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_isEmpty), METH_NOARGS, nullptr},
    {"query", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_query), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"queryItemValue", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_queryItemValue), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"queryItems", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_queryItems), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"queryPairDelimiter", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_queryPairDelimiter), METH_NOARGS, nullptr},
    {"queryValueDelimiter", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_queryValueDelimiter), METH_NOARGS, nullptr},
    {"removeAllQueryItems", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_removeAllQueryItems), METH_O, nullptr},
    {"removeQueryItem", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_removeQueryItem), METH_O, nullptr},
    {"setQuery", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_setQuery), METH_O, nullptr},
    {"setQueryDelimiters", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_setQueryDelimiters), METH_VARARGS, nullptr},
    {"setQueryItems", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_setQueryItems), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_swap), METH_O, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QUrlQueryFunc_toString), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QUrlQuery__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QUrlQuery_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), (pyArg)))) {
                // operator!=(const QUrlQuery &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUrlQuery cppArg0_local;
                ::QUrlQuery *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), (pyArg)))) {
                // operator==(const QUrlQuery &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUrlQuery cppArg0_local;
                ::QUrlQuery *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QUrlQuery_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QUrlQuery_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QUrlQuery_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QUrlQuery_Type = nullptr;
static PyTypeObject *Sbk_QUrlQuery_TypeF(void)
{
    return _Sbk_QUrlQuery_Type;
}

static PyType_Slot Sbk_QUrlQuery_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QUrlQuery_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QUrlQuery_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QUrlQuery_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QUrlQuery_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QUrlQuery_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QUrlQuery_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QUrlQuery_spec = {
    "2:PySide6.QtCore.QUrlQuery",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QUrlQuery_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QUrlQuery_PythonToCpp_QUrlQuery_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QUrlQuery_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QUrlQuery_PythonToCpp_QUrlQuery_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QUrlQuery_TypeF()))
        return QUrlQuery_PythonToCpp_QUrlQuery_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QUrlQuery_PTR_CppToPython_QUrlQuery(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QUrlQuery_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QUrlQuery_COPY_CppToPython_QUrlQuery(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QUrlQuery *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QUrlQuery_TypeF(), new ::QUrlQuery(*source), true, true);
}

// Python to C++ copy conversion.
static void QUrlQuery_PythonToCpp_QUrlQuery_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QUrlQuery *>(cppOut) = *reinterpret_cast< ::QUrlQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QUrlQuery_PythonToCpp_QUrlQuery_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QUrlQuery_TypeF()))
        return QUrlQuery_PythonToCpp_QUrlQuery_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QUrlQuery_SignatureStrings[] = {
    "3:PySide6.QtCore.QUrlQuery(self)",
    "2:PySide6.QtCore.QUrlQuery(self,queryString:QString)",
    "1:PySide6.QtCore.QUrlQuery(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "0:PySide6.QtCore.QUrlQuery(self,other:PySide6.QtCore.QUrlQuery)",
    "PySide6.QtCore.QUrlQuery.addQueryItem(self,key:QString,value:QString)",
    "PySide6.QtCore.QUrlQuery.allQueryItemValues(self,key:QString,encoding:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.PrettyDecoded)->QStringList",
    "PySide6.QtCore.QUrlQuery.clear(self)",
    "PySide6.QtCore.QUrlQuery.hasQueryItem(self,key:QString)->bool",
    "PySide6.QtCore.QUrlQuery.isEmpty(self)->bool",
    "PySide6.QtCore.QUrlQuery.query(self,encoding:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.PrettyDecoded)->QString",
    "PySide6.QtCore.QUrlQuery.queryItemValue(self,key:QString,encoding:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.PrettyDecoded)->QString",
    "PySide6.QtCore.QUrlQuery.queryItems(self,encoding:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.PrettyDecoded)->QList[std.pair[QString, QString]]",
    "PySide6.QtCore.QUrlQuery.queryPairDelimiter(self)->QChar",
    "PySide6.QtCore.QUrlQuery.queryValueDelimiter(self)->QChar",
    "PySide6.QtCore.QUrlQuery.removeAllQueryItems(self,key:QString)",
    "PySide6.QtCore.QUrlQuery.removeQueryItem(self,key:QString)",
    "PySide6.QtCore.QUrlQuery.setQuery(self,queryString:QString)",
    "PySide6.QtCore.QUrlQuery.setQueryDelimiters(self,valueDelimiter:QChar,pairDelimiter:QChar)",
    "PySide6.QtCore.QUrlQuery.setQueryItems(self,query:QList[std.pair[QString, QString]])",
    "PySide6.QtCore.QUrlQuery.swap(self,other:PySide6.QtCore.QUrlQuery)",
    "PySide6.QtCore.QUrlQuery.toString(self,encoding:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.PrettyDecoded)->QString",
    "PySide6.QtCore.QUrlQuery.__copy__(self)->typing.Self",
    "PySide6.QtCore.QUrlQuery.__ne__(self,rhs:PySide6.QtCore.QUrlQuery)->bool",
    "PySide6.QtCore.QUrlQuery.__eq__(self,rhs:PySide6.QtCore.QUrlQuery)->bool",
    "PySide6.QtCore.QUrlQuery.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QUrlQuery_SignatureByteSize = 389;
static constexpr uint8_t QUrlQuery_SignatureBytes[389] = {
    0x78, 0xda, 0xc5, 0x55, 0x5d, 0x4b, 0xc3, 0x30, 0x14, 0x7d, 0xef, 0xaf, 0xf0, 0xd1, 0x42, 0x2d,
    0x7e, 0x80, 0x0f, 0x05, 0x05, 0xd9, 0x14, 0x04, 0xc1, 0x95, 0x31, 0x5f, 0xc6, 0x28, 0x71, 0xbd,
    0xda, 0x60, 0x9a, 0x64, 0xc9, 0xdd, 0xa4, 0xff, 0xde, 0xf4, 0x73, 0x1b, 0x5b, 0x9a, 0x89, 0x4e,
    0x9f, 0x9a, 0x36, 0xf7, 0x9c, 0xdc, 0x73, 0xee, 0xcd, 0xed, 0x55, 0x34, 0x2a, 0xc6, 0x34, 0x85,
    0xeb, 0x30, 0xc6, 0x81, 0x50, 0x10, 0xc6, 0x13, 0xc5, 0xe2, 0x25, 0xa8, 0xe2, 0x54, 0x03, 0x7b,
    0xf3, 0xbd, 0xcb, 0xfe, 0x80, 0x60, 0x51, 0x2e, 0xc7, 0xa8, 0x28, 0x7f, 0x8f, 0xe2, 0xfa, 0xe9,
    0x7b, 0x17, 0x0e, 0xd0, 0x52, 0xb1, 0x08, 0x0b, 0x69, 0x62, 0xc3, 0x09, 0xa7, 0x82, 0x4f, 0xf7,
    0x84, 0x07, 0x27, 0x0d, 0xdd, 0xcc, 0xf7, 0xce, 0x1d, 0x7c, 0x02, 0x33, 0x50, 0xd6, 0x18, 0xdf,
    0xb3, 0xed, 0x84, 0x24, 0x4d, 0xab, 0xc5, 0x23, 0x42, 0x5e, 0x53, 0x7d, 0x40, 0xd1, 0xea, 0x08,
    0x56, 0x84, 0x2d, 0x61, 0xad, 0xca, 0xce, 0xc2, 0x58, 0xc7, 0xf2, 0x52, 0x62, 0xf4, 0x2e, 0x17,
    0xf0, 0xb9, 0x48, 0x4b, 0x93, 0xf6, 0xb0, 0x84, 0x03, 0x91, 0x4b, 0xc1, 0x81, 0xe3, 0x83, 0x50,
    0x39, 0x41, 0x34, 0x71, 0xcf, 0x12, 0x8d, 0x31, 0x37, 0xd5, 0xf6, 0x48, 0x01, 0x62, 0x31, 0x04,
    0xc3, 0x00, 0xa9, 0x7f, 0x76, 0xdb, 0x70, 0x3e, 0x51, 0x8d, 0xf6, 0xa4, 0xe6, 0x0c, 0x88, 0x6a,
    0x8a, 0x68, 0x0d, 0xca, 0x88, 0xb6, 0xeb, 0x37, 0x27, 0xbd, 0x0a, 0xc1, 0xec, 0x68, 0xaa, 0xef,
    0x73, 0x89, 0x4d, 0xa7, 0xb8, 0x82, 0x17, 0xeb, 0x72, 0x1d, 0xc1, 0x0b, 0xc7, 0xb9, 0x5d, 0x65,
    0xfe, 0xa4, 0x30, 0x07, 0x24, 0xa3, 0x8f, 0xe0, 0x44, 0xd9, 0x0f, 0x53, 0x8d, 0x69, 0x28, 0x09,
    0x55, 0xd3, 0x56, 0x5f, 0x77, 0x8d, 0x66, 0x8e, 0xb4, 0x46, 0x06, 0x35, 0x04, 0x46, 0x73, 0x8a,
    0xa0, 0xda, 0x9a, 0xc6, 0x83, 0x8c, 0x28, 0x07, 0xb0, 0x32, 0xf6, 0xbb, 0x48, 0x05, 0xb9, 0x58,
    0xc1, 0xdd, 0xc6, 0xcd, 0xd9, 0xbd, 0x34, 0xbe, 0x0b, 0xde, 0xd3, 0xbb, 0x76, 0xa8, 0x06, 0x74,
    0xcd, 0x2f, 0x27, 0xb6, 0x53, 0xdb, 0x24, 0xbd, 0xda, 0xb2, 0x20, 0xaa, 0xb4, 0x07, 0x72, 0xd3,
    0xd0, 0xfa, 0xdb, 0x01, 0xd4, 0x1b, 0x56, 0x54, 0xb9, 0x45, 0xce, 0xba, 0xf6, 0x91, 0x7e, 0x12,
    0xf9, 0xc3, 0x11, 0x89, 0xa2, 0x3e, 0xe7, 0x1f, 0xae, 0x6e, 0x92, 0xcc, 0x85, 0x2c, 0x92, 0xa4,
    0x6d, 0xa9, 0xe6, 0x97, 0x31, 0x36, 0x6f, 0x7d, 0x20, 0x0e, 0x0d, 0x24, 0x50, 0x99, 0xb6, 0x4b,
    0x76, 0x0d, 0xac, 0x24, 0x81, 0xc5, 0x2f, 0x11, 0x99, 0x31, 0x9b, 0xad, 0x65, 0x50, 0x8e, 0xde,
    0x17, 0x31, 0xb0, 0xb8, 0x2c
};
#endif

PyTypeObject *init_QUrlQuery(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX].type;

    Shiboken::AutoDecRef Sbk_QUrlQuery_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QUrlQuery_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QUrlQuery",
        "QUrlQuery",
        &Sbk_QUrlQuery_spec,
        &Shiboken::callCppDestructor< ::QUrlQuery >,
        Sbk_QUrlQuery_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QUrlQuery_TypeF(); // references _Sbk_QUrlQuery_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QUrlQuery_SignatureStrings);
#else
    InitSignatureBytes(pyType, QUrlQuery_SignatureBytes, QUrlQuery_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QUrlQuery_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QUrlQuery_PythonToCpp_QUrlQuery_PTR,
        is_QUrlQuery_PythonToCpp_QUrlQuery_PTR_Convertible,
        QUrlQuery_PTR_CppToPython_QUrlQuery,
        QUrlQuery_COPY_CppToPython_QUrlQuery);

    Shiboken::Conversions::registerConverterName(converter, "QUrlQuery");
    Shiboken::Conversions::registerConverterName(converter, "QUrlQuery*");
    Shiboken::Conversions::registerConverterName(converter, "QUrlQuery&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QUrlQuery).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QUrlQuery_PythonToCpp_QUrlQuery_COPY,
        is_QUrlQuery_PythonToCpp_QUrlQuery_COPY_Convertible);

    qRegisterMetaType< ::QUrlQuery >("QUrlQuery");

    return pyType;
}
