// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qversionnumber_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <qversionnumber.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QVersionNumber_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QVersionNumber >()))
        return -1;

    ::QVersionNumber *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QVersionNumber", 0, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QVersionNumber::QVersionNumber()
    // 1: QVersionNumber::QVersionNumber(int)
    // 2: QVersionNumber::QVersionNumber(int,int)
    // 3: QVersionNumber::QVersionNumber(int,int,int)
    if (numArgs == 0) {
        overloadId = 0; // QVersionNumber()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QVersionNumber(int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // QVersionNumber(int,int)
            } else if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 3; // QVersionNumber(int,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QVersionNumber()
        {

            // QVersionNumber()
            cptr = new ::QVersionNumber();
            break;
        }
        case 1: // QVersionNumber(int maj)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QVersionNumber(int)
                cptr = new ::QVersionNumber(cppArg0);
            }
            break;
        }
        case 2: // QVersionNumber(int maj, int min)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QVersionNumber(int,int)
                cptr = new ::QVersionNumber(cppArg0, cppArg1);
            }
            break;
        }
        case 3: // QVersionNumber(int maj, int min, int mic)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QVersionNumber(int,int,int)
                cptr = new ::QVersionNumber(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QVersionNumber >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QVersionNumberFunc_commonPrefix(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "commonPrefix", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QVersionNumber::commonPrefix(QVersionNumber,QVersionNumber)->QVersionNumber
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), (pyArgs[1])))) {
        overloadId = 0; // commonPrefix(QVersionNumber,QVersionNumber)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "commonPrefix", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVersionNumber cppArg0_local;
        ::QVersionNumber *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QVersionNumber cppArg1_local;
        ::QVersionNumber *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // commonPrefix(QVersionNumber,QVersionNumber)
            QVersionNumber cppResult = ::QVersionNumber::commonPrefix(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVersionNumberFunc_compare(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "compare", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QVersionNumber::compare(QVersionNumber,QVersionNumber)->int
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), (pyArgs[1])))) {
        overloadId = 0; // compare(QVersionNumber,QVersionNumber)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "compare", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVersionNumber cppArg0_local;
        ::QVersionNumber *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QVersionNumber cppArg1_local;
        ::QVersionNumber *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // compare(QVersionNumber,QVersionNumber)
            int cppResult = ::QVersionNumber::compare(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVersionNumberFunc_fromString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QVersionNumber::fromString(QAnyStringView,qsizetype*=)->QVersionNumber
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // fromString(QAnyStringView,qsizetype*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        qsizetype* removed_cppArg1 = nullptr;
        SBK_UNUSED(removed_cppArg1)

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromString(QAnyStringView,qsizetype*)
            QVersionNumber cppResult = ::QVersionNumber::fromString(QAnyStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVersionNumberFunc_isNormalized(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNormalized()const
        bool cppResult = const_cast<const ::QVersionNumber *>(cppSelf)->isNormalized();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVersionNumberFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QVersionNumber *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVersionNumberFunc_isPrefixOf(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVersionNumber::isPrefixOf(QVersionNumber)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), (pyArg)))) {
        overloadId = 0; // isPrefixOf(QVersionNumber)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isPrefixOf", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVersionNumber cppArg0_local;
        ::QVersionNumber *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isPrefixOf(QVersionNumber)const
            bool cppResult = const_cast<const ::QVersionNumber *>(cppSelf)->isPrefixOf(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVersionNumberFunc_majorVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // majorVersion()const
        int cppResult = const_cast<const ::QVersionNumber *>(cppSelf)->majorVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVersionNumberFunc_microVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // microVersion()const
        int cppResult = const_cast<const ::QVersionNumber *>(cppSelf)->microVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVersionNumberFunc_minorVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minorVersion()const
        int cppResult = const_cast<const ::QVersionNumber *>(cppSelf)->minorVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVersionNumberFunc_normalized(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // normalized()const
        QVersionNumber cppResult = const_cast<const ::QVersionNumber *>(cppSelf)->normalized();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVersionNumberFunc_segmentAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVersionNumber::segmentAt(qsizetype)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // segmentAt(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "segmentAt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // segmentAt(qsizetype)const
            int cppResult = const_cast<const ::QVersionNumber *>(cppSelf)->segmentAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVersionNumberFunc_segmentCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // segmentCount()const
        qsizetype cppResult = const_cast<const ::QVersionNumber *>(cppSelf)->segmentCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVersionNumberFunc_segments(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // segments()const
        QList<int> cppResult = const_cast<const ::QVersionNumber *>(cppSelf)->segments();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_int_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVersionNumberFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toString()const
        QString cppResult = const_cast<const ::QVersionNumber *>(cppSelf)->toString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVersionNumber__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QVersionNumber_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QVersionNumber_EnumFlagInfo[] = {
    "enum_264:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QVersionNumber_methods[] = {
    {"commonPrefix", reinterpret_cast<PyCFunction>(Sbk_QVersionNumberFunc_commonPrefix), METH_VARARGS|METH_STATIC, nullptr},
    {"compare", reinterpret_cast<PyCFunction>(Sbk_QVersionNumberFunc_compare), METH_VARARGS|METH_STATIC, nullptr},
    {"fromString", reinterpret_cast<PyCFunction>(Sbk_QVersionNumberFunc_fromString), METH_O|METH_STATIC, nullptr},
    {"isNormalized", reinterpret_cast<PyCFunction>(Sbk_QVersionNumberFunc_isNormalized), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QVersionNumberFunc_isNull), METH_NOARGS, nullptr},
    {"isPrefixOf", reinterpret_cast<PyCFunction>(Sbk_QVersionNumberFunc_isPrefixOf), METH_O, nullptr},
    {"majorVersion", reinterpret_cast<PyCFunction>(Sbk_QVersionNumberFunc_majorVersion), METH_NOARGS, nullptr},
    {"microVersion", reinterpret_cast<PyCFunction>(Sbk_QVersionNumberFunc_microVersion), METH_NOARGS, nullptr},
    {"minorVersion", reinterpret_cast<PyCFunction>(Sbk_QVersionNumberFunc_minorVersion), METH_NOARGS, nullptr},
    {"normalized", reinterpret_cast<PyCFunction>(Sbk_QVersionNumberFunc_normalized), METH_NOARGS, nullptr},
    {"segmentAt", reinterpret_cast<PyCFunction>(Sbk_QVersionNumberFunc_segmentAt), METH_O, nullptr},
    {"segmentCount", reinterpret_cast<PyCFunction>(Sbk_QVersionNumberFunc_segmentCount), METH_NOARGS, nullptr},
    {"segments", reinterpret_cast<PyCFunction>(Sbk_QVersionNumberFunc_segments), METH_NOARGS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QVersionNumberFunc_toString), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QVersionNumber__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QVersionNumber___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QVersionNumber_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), (pyArg)))) {
                // operator!=(const QVersionNumber &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QVersionNumber cppArg0_local;
                ::QVersionNumber *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), (pyArg)))) {
                // operator<(const QVersionNumber &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QVersionNumber cppArg0_local;
                ::QVersionNumber *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), (pyArg)))) {
                // operator<=(const QVersionNumber &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QVersionNumber cppArg0_local;
                ::QVersionNumber *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), (pyArg)))) {
                // operator==(const QVersionNumber &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QVersionNumber cppArg0_local;
                ::QVersionNumber *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), (pyArg)))) {
                // operator>(const QVersionNumber &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QVersionNumber cppArg0_local;
                ::QVersionNumber *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), (pyArg)))) {
                // operator>=(const QVersionNumber &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QVersionNumber cppArg0_local;
                ::QVersionNumber *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QVersionNumber_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QVersionNumber_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QVersionNumber_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QVersionNumber__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QVersionNumber_Type = nullptr;
static PyTypeObject *Sbk_QVersionNumber_TypeF(void)
{
    return _Sbk_QVersionNumber_Type;
}

static PyType_Slot Sbk_QVersionNumber_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QVersionNumber__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QVersionNumber_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QVersionNumber_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QVersionNumber_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QVersionNumber_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QVersionNumber_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QVersionNumber_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QVersionNumber___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QVersionNumber_spec = {
    "2:PySide6.QtCore.QVersionNumber",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QVersionNumber_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QVersionNumber_PythonToCpp_QVersionNumber_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QVersionNumber_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QVersionNumber_PythonToCpp_QVersionNumber_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QVersionNumber_TypeF()))
        return QVersionNumber_PythonToCpp_QVersionNumber_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QVersionNumber_PTR_CppToPython_QVersionNumber(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QVersionNumber_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QVersionNumber_COPY_CppToPython_QVersionNumber(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QVersionNumber *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QVersionNumber_TypeF(), new ::QVersionNumber(*source), true, true);
}

// Python to C++ copy conversion.
static void QVersionNumber_PythonToCpp_QVersionNumber_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QVersionNumber *>(cppOut) = *reinterpret_cast< ::QVersionNumber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QVersionNumber_PythonToCpp_QVersionNumber_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QVersionNumber_TypeF()))
        return QVersionNumber_PythonToCpp_QVersionNumber_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QVersionNumber_SignatureStrings[] = {
    "3:PySide6.QtCore.QVersionNumber(self)",
    "2:PySide6.QtCore.QVersionNumber(self,maj:int)",
    "1:PySide6.QtCore.QVersionNumber(self,maj:int,min:int)",
    "0:PySide6.QtCore.QVersionNumber(self,maj:int,min:int,mic:int)",
    "PySide6.QtCore.QVersionNumber.commonPrefix(v1:PySide6.QtCore.QVersionNumber,v2:PySide6.QtCore.QVersionNumber)->PySide6.QtCore.QVersionNumber",
    "PySide6.QtCore.QVersionNumber.compare(v1:PySide6.QtCore.QVersionNumber,v2:PySide6.QtCore.QVersionNumber)->int",
    "PySide6.QtCore.QVersionNumber.fromString(string:QString)->PySide6.QtCore.QVersionNumber",
    "PySide6.QtCore.QVersionNumber.isNormalized(self)->bool",
    "PySide6.QtCore.QVersionNumber.isNull(self)->bool",
    "PySide6.QtCore.QVersionNumber.isPrefixOf(self,other:PySide6.QtCore.QVersionNumber)->bool",
    "PySide6.QtCore.QVersionNumber.majorVersion(self)->int",
    "PySide6.QtCore.QVersionNumber.microVersion(self)->int",
    "PySide6.QtCore.QVersionNumber.minorVersion(self)->int",
    "PySide6.QtCore.QVersionNumber.normalized(self)->PySide6.QtCore.QVersionNumber",
    "PySide6.QtCore.QVersionNumber.segmentAt(self,index:qsizetype)->int",
    "PySide6.QtCore.QVersionNumber.segmentCount(self)->qsizetype",
    "PySide6.QtCore.QVersionNumber.segments(self)->QList[int]",
    "PySide6.QtCore.QVersionNumber.toString(self)->QString",
    "PySide6.QtCore.QVersionNumber.__copy__(self)->typing.Self",
    "PySide6.QtCore.QVersionNumber.__ne__(self,rhs:PySide6.QtCore.QVersionNumber)->bool",
    "PySide6.QtCore.QVersionNumber.__lt__(self,rhs:PySide6.QtCore.QVersionNumber)->bool",
    "PySide6.QtCore.QVersionNumber.__le__(self,rhs:PySide6.QtCore.QVersionNumber)->bool",
    "PySide6.QtCore.QVersionNumber.__eq__(self,rhs:PySide6.QtCore.QVersionNumber)->bool",
    "PySide6.QtCore.QVersionNumber.__gt__(self,rhs:PySide6.QtCore.QVersionNumber)->bool",
    "PySide6.QtCore.QVersionNumber.__ge__(self,rhs:PySide6.QtCore.QVersionNumber)->bool",
    "PySide6.QtCore.QVersionNumber.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QVersionNumber_SignatureByteSize = 313;
static constexpr uint8_t QVersionNumber_SignatureBytes[313] = {
    0x78, 0xda, 0xad, 0x93, 0xcd, 0x6e, 0x83, 0x30, 0x10, 0x84, 0xef, 0x79, 0x12, 0x90, 0x08, 0xea,
    0x8f, 0xd4, 0x03, 0x87, 0x48, 0x55, 0xae, 0x51, 0x1a, 0x84, 0xd4, 0x4b, 0x55, 0x21, 0x12, 0x16,
    0x70, 0x65, 0x7b, 0xc9, 0xda, 0x44, 0xa1, 0x4f, 0x5f, 0xb7, 0x86, 0xf6, 0x50, 0x29, 0x26, 0xc4,
    0x27, 0xcb, 0xd8, 0xdf, 0xec, 0xec, 0x7a, 0x78, 0x4c, 0x76, 0x7d, 0xc6, 0x4a, 0x78, 0x8a, 0x53,
    0xbd, 0x46, 0x82, 0x38, 0x7d, 0x05, 0x52, 0x0c, 0xe5, 0xb6, 0x13, 0x7b, 0xa0, 0x40, 0x01, 0xaf,
    0xc2, 0xc5, 0xc3, 0x84, 0x5b, 0x91, 0x28, 0x3e, 0x12, 0x26, 0x75, 0xb8, 0xb8, 0xbf, 0xe2, 0x76,
    0x24, 0x98, 0xb4, 0xd4, 0xdd, 0x0c, 0xca, 0xac, 0x07, 0x4b, 0x5f, 0x64, 0xe3, 0x03, 0x0a, 0x81,
    0x72, 0x47, 0x50, 0xb1, 0x73, 0x70, 0x72, 0xf8, 0x8b, 0x4e, 0x8e, 0x76, 0xc3, 0xe5, 0xea, 0xe2,
    0xb9, 0xdb, 0x4c, 0x5b, 0x10, 0x78, 0xf1, 0x61, 0x7a, 0x77, 0x54, 0xab, 0x08, 0x45, 0xa6, 0x89,
    0xc9, 0x3a, 0x50, 0x3f, 0x4b, 0x92, 0xda, 0xed, 0x8d, 0x5d, 0x30, 0xb5, 0x45, 0x12, 0x05, 0x67,
    0x9f, 0x50, 0xda, 0x94, 0x2c, 0x57, 0x7b, 0x44, 0xee, 0xc6, 0x3a, 0xce, 0xaf, 0x02, 0xec, 0xb3,
    0xbd, 0x54, 0x36, 0x01, 0xa8, 0x1b, 0x20, 0xe7, 0x5c, 0x26, 0x08, 0x9b, 0x28, 0x21, 0x0d, 0x9f,
    0x46, 0x3f, 0xee, 0x71, 0x9a, 0xc0, 0x11, 0xce, 0xa0, 0xe4, 0x8c, 0x5a, 0xf2, 0xdf, 0x80, 0x6f,
    0x79, 0x30, 0x05, 0xb5, 0x00, 0xa9, 0x9f, 0xb5, 0x9d, 0x23, 0x93, 0x25, 0x9c, 0x93, 0xa3, 0x32,
    0xf2, 0xba, 0x6f, 0x61, 0x92, 0xa1, 0x41, 0x62, 0x8d, 0x9d, 0xd4, 0xa3, 0xa5, 0x5f, 0x85, 0x69,
    0xac, 0x1a, 0xb9, 0x74, 0xc3, 0x94, 0x7e, 0x33, 0x35, 0xdf, 0x1d, 0xa0, 0xc6, 0x31, 0xbe, 0x03,
    0x68, 0xb7, 0x0e, 0x2a, 0xcf, 0x0f, 0xd8, 0xf6, 0x79, 0x3e, 0x52, 0xc6, 0xa1, 0x81, 0xe2, 0xcc,
    0xec, 0x9c, 0xa4, 0x84, 0x81, 0x8b, 0xa8, 0x51, 0x3e, 0xa2, 0x96, 0xe7, 0x5c, 0xfb, 0x97, 0xf4,
    0xef, 0x12, 0x8e, 0xde, 0x25, 0x6b, 0xff, 0x8d, 0xd7, 0xfe, 0x1b, 0x6f, 0x0a, 0xd5, 0xfc, 0x65,
    0xe5, 0xfb, 0x47, 0xf8, 0x02, 0xd0, 0x99, 0x90, 0xed
};
#endif

PyTypeObject *init_QVersionNumber(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX].type;

    Shiboken::AutoDecRef Sbk_QVersionNumber_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QVersionNumber_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QVersionNumber",
        "QVersionNumber",
        &Sbk_QVersionNumber_spec,
        &Shiboken::callCppDestructor< ::QVersionNumber >,
        Sbk_QVersionNumber_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QVersionNumber_TypeF(); // references _Sbk_QVersionNumber_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QVersionNumber_SignatureStrings);
#else
    InitSignatureBytes(pyType, QVersionNumber_SignatureBytes, QVersionNumber_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QVersionNumber_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QVersionNumber_PythonToCpp_QVersionNumber_PTR,
        is_QVersionNumber_PythonToCpp_QVersionNumber_PTR_Convertible,
        QVersionNumber_PTR_CppToPython_QVersionNumber,
        QVersionNumber_COPY_CppToPython_QVersionNumber);

    Shiboken::Conversions::registerConverterName(converter, "QVersionNumber");
    Shiboken::Conversions::registerConverterName(converter, "QVersionNumber*");
    Shiboken::Conversions::registerConverterName(converter, "QVersionNumber&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QVersionNumber).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QVersionNumber_PythonToCpp_QVersionNumber_COPY,
        is_QVersionNumber_PythonToCpp_QVersionNumber_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QVersionNumber_EnumFlagInfo);

    qRegisterMetaType< ::QVersionNumber >("QVersionNumber");

    return pyType;
}
