// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qwaitcondition_wrapper.h"

// Argument includes
#include <qdeadlinetimer.h>
#include <qmutex.h>
#include <qreadwritelock.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWaitCondition_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWaitCondition >()))
        return -1;

    ::QWaitCondition *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QWaitCondition()
        cptr = new ::QWaitCondition();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWaitCondition >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWaitConditionFunc_notify_all(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWaitCondition *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // notify_all()
        cppSelf->notify_all();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWaitConditionFunc_notify_one(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWaitCondition *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // notify_one()
        cppSelf->notify_one();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWaitConditionFunc_wait(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWaitCondition *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]);

    if (PyArg_ParseTuple(args, "|OO:wait", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWaitCondition::wait(QMutex*,QDeadlineTimer=)->bool
    // 1: QWaitCondition::wait(QMutex*,ulong)->bool
    // 2: QWaitCondition::wait(QReadWriteLock*,QDeadlineTimer=)->bool
    // 3: QWaitCondition::wait(QReadWriteLock*,ulong)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QReadWriteLock_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // wait(QReadWriteLock*,QDeadlineTimer)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArgs[1])))) {
            overloadId = 3; // wait(QReadWriteLock*,ulong)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[1])))) {
            overloadId = 2; // wait(QReadWriteLock*,QDeadlineTimer)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMutex_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // wait(QMutex*,QDeadlineTimer)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArgs[1])))) {
            overloadId = 1; // wait(QMutex*,ulong)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[1])))) {
            overloadId = 0; // wait(QMutex*,QDeadlineTimer)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // wait(QMutex *lockedMutex, QDeadlineTimer deadline)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_deadline = Shiboken::String::createStaticString("deadline");
                if (PyDict_Contains(kwds, key_deadline) != 0) {
                    value = PyDict_GetItem(kwds, key_deadline);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_deadline);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_deadline);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QMutex *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QDeadlineTimer cppArg1 = QDeadlineTimer(QDeadlineTimer::Forever);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // wait(QMutex*,QDeadlineTimer)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->wait(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // wait(QMutex *lockedMutex, unsigned long time)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QMutex *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            unsigned long cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // wait(QMutex*,ulong)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->wait(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // wait(QReadWriteLock *lockedReadWriteLock, QDeadlineTimer deadline)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_deadline = Shiboken::String::createStaticString("deadline");
                if (PyDict_Contains(kwds, key_deadline) != 0) {
                    value = PyDict_GetItem(kwds, key_deadline);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_deadline);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_deadline);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QReadWriteLock *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QDeadlineTimer cppArg1 = QDeadlineTimer(QDeadlineTimer::Forever);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // wait(QReadWriteLock*,QDeadlineTimer)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->wait(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 3: // wait(QReadWriteLock *lockedReadWriteLock, unsigned long time)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "wait", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QReadWriteLock *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            unsigned long cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // wait(QReadWriteLock*,ulong)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->wait(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWaitConditionFunc_wakeAll(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWaitCondition *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wakeAll()
        cppSelf->wakeAll();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWaitConditionFunc_wakeOne(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWaitCondition *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wakeOne()
        cppSelf->wakeOne();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QWaitCondition_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWaitCondition_methods[] = {
    {"notify_all", reinterpret_cast<PyCFunction>(Sbk_QWaitConditionFunc_notify_all), METH_NOARGS, nullptr},
    {"notify_one", reinterpret_cast<PyCFunction>(Sbk_QWaitConditionFunc_notify_one), METH_NOARGS, nullptr},
    {"wait", reinterpret_cast<PyCFunction>(Sbk_QWaitConditionFunc_wait), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"wakeAll", reinterpret_cast<PyCFunction>(Sbk_QWaitConditionFunc_wakeAll), METH_NOARGS, nullptr},
    {"wakeOne", reinterpret_cast<PyCFunction>(Sbk_QWaitConditionFunc_wakeOne), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QWaitCondition_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWaitCondition_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWaitCondition_Type = nullptr;
static PyTypeObject *Sbk_QWaitCondition_TypeF(void)
{
    return _Sbk_QWaitCondition_Type;
}

static PyType_Slot Sbk_QWaitCondition_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWaitCondition_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWaitCondition_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWaitCondition_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWaitCondition_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWaitCondition_spec = {
    "2:PySide6.QtCore.QWaitCondition",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWaitCondition_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWaitCondition_PythonToCpp_QWaitCondition_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWaitCondition_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWaitCondition_PythonToCpp_QWaitCondition_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWaitCondition_TypeF()))
        return QWaitCondition_PythonToCpp_QWaitCondition_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWaitCondition_PTR_CppToPython_QWaitCondition(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWaitCondition_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWaitCondition_SignatureStrings[] = {
    "PySide6.QtCore.QWaitCondition(self)",
    "PySide6.QtCore.QWaitCondition.notify_all(self)",
    "PySide6.QtCore.QWaitCondition.notify_one(self)",
    "3:PySide6.QtCore.QWaitCondition.wait(self,lockedMutex:PySide6.QtCore.QMutex,deadline:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64]=QDeadlineTimer(QDeadlineTimer.Forever))->bool",
    "2:PySide6.QtCore.QWaitCondition.wait(self,lockedMutex:PySide6.QtCore.QMutex,time:unsigned long)->bool",
    "1:PySide6.QtCore.QWaitCondition.wait(self,lockedReadWriteLock:PySide6.QtCore.QReadWriteLock,deadline:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64]=QDeadlineTimer(QDeadlineTimer.Forever))->bool",
    "0:PySide6.QtCore.QWaitCondition.wait(self,lockedReadWriteLock:PySide6.QtCore.QReadWriteLock,time:unsigned long)->bool",
    "PySide6.QtCore.QWaitCondition.wakeAll(self)",
    "PySide6.QtCore.QWaitCondition.wakeOne(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QWaitCondition_SignatureByteSize = 222;
static constexpr uint8_t QWaitCondition_SignatureBytes[222] = {
    0x78, 0xda, 0xcd, 0x93, 0xc9, 0x0a, 0xc2, 0x40, 0x0c, 0x86, 0xef, 0x3e, 0x45, 0x8f, 0x16, 0xea,
    0xe0, 0x86, 0x87, 0x82, 0x82, 0x28, 0x9e, 0x14, 0x77, 0x3c, 0x88, 0x48, 0x75, 0x62, 0x09, 0x8e,
    0x19, 0x6d, 0xe3, 0xd2, 0xb7, 0x77, 0x14, 0x15, 0xdc, 0xaa, 0x82, 0x82, 0xb7, 0x49, 0xf2, 0xfd,
    0xf3, 0x27, 0x81, 0xb4, 0xa2, 0x2e, 0x4a, 0x28, 0x88, 0x36, 0x57, 0x74, 0x00, 0xa2, 0x3d, 0xf0,
    0xd0, 0xbc, 0x48, 0x22, 0xa3, 0xa6, 0x64, 0x08, 0x6a, 0x66, 0x27, 0x5a, 0x71, 0x8c, 0x20, 0xcd,
    0x38, 0x8b, 0xc6, 0x9e, 0x52, 0x9f, 0xe0, 0x9a, 0xe0, 0x84, 0xe7, 0xdc, 0x78, 0xc1, 0xd6, 0x44,
    0x47, 0xd4, 0x51, 0x7a, 0x3a, 0x07, 0xd9, 0x58, 0x33, 0xec, 0xee, 0x34, 0xc7, 0xac, 0x23, 0xc1,
    0x93, 0x0a, 0x09, 0x5c, 0x8e, 0x96, 0x48, 0xbe, 0xe8, 0x93, 0xf9, 0x61, 0x78, 0xcb, 0x56, 0x4f,
    0x54, 0x0f, 0x17, 0x10, 0x38, 0x56, 0x6c, 0x59, 0xd4, 0x4c, 0x6e, 0x03, 0x81, 0xe9, 0x27, 0x64,
    0x8f, 0xd8, 0xb1, 0x56, 0x48, 0x5c, 0xc8, 0x8f, 0x8a, 0xd7, 0x5c, 0xf2, 0xb1, 0xcc, 0xb6, 0x53,
    0xa5, 0x89, 0xd6, 0x2a, 0x91, 0xfd, 0xe2, 0x94, 0x6c, 0x1c, 0xdc, 0x35, 0x85, 0xe8, 0x13, 0x48,
    0x4b, 0x69, 0xf2, 0xcf, 0x2e, 0x99, 0x0f, 0x5d, 0x3a, 0xa6, 0xe7, 0x41, 0x80, 0x0c, 0x75, 0x13,
    0xde, 0x69, 0xaf, 0xaa, 0x7f, 0xbc, 0xdb, 0xf4, 0x0f, 0xa7, 0x7e, 0xbe, 0xeb, 0x57, 0x9e, 0x73,
    0x28, 0xbf, 0x79, 0x12, 0x07, 0xb6, 0x79, 0xb9, 0x87, 0x3d, 0x76, 0x1f, 0x4b, 0x0c
};
#endif

PyTypeObject *init_QWaitCondition(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX].type;

    Shiboken::AutoDecRef Sbk_QWaitCondition_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWaitCondition_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWaitCondition",
        "QWaitCondition*",
        &Sbk_QWaitCondition_spec,
        &Shiboken::callCppDestructor< ::QWaitCondition >,
        Sbk_QWaitCondition_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWaitCondition_TypeF(); // references _Sbk_QWaitCondition_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWaitCondition_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWaitCondition_SignatureBytes, QWaitCondition_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWaitCondition_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QWaitCondition_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWaitCondition_PythonToCpp_QWaitCondition_PTR,
        is_QWaitCondition_PythonToCpp_QWaitCondition_PTR_Convertible,
        QWaitCondition_PTR_CppToPython_QWaitCondition);

    Shiboken::Conversions::registerConverterName(converter, "QWaitCondition");
    Shiboken::Conversions::registerConverterName(converter, "QWaitCondition*");
    Shiboken::Conversions::registerConverterName(converter, "QWaitCondition&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWaitCondition).name());

    qRegisterMetaType< ::QWaitCondition *>();

    return pyType;
}
