// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qxmlstreamattribute_wrapper.h"

// Argument includes
#include <QString>
#include <QStringView>
#include <qxmlstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlStreamAttribute_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QXmlStreamAttribute >()))
        return -1;

    ::QXmlStreamAttribute *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QXmlStreamAttribute", 0, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QXmlStreamAttribute::QXmlStreamAttribute()
    // 1: QXmlStreamAttribute::QXmlStreamAttribute(QString,QString,QString)
    // 2: QXmlStreamAttribute::QXmlStreamAttribute(QString,QString)
    // 3: QXmlStreamAttribute::QXmlStreamAttribute(QXmlStreamAttribute)
    if (numArgs == 0) {
        overloadId = 0; // QXmlStreamAttribute()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QXmlStreamAttribute(QXmlStreamAttribute)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // QXmlStreamAttribute(QString,QString)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 1; // QXmlStreamAttribute(QString,QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QXmlStreamAttribute()
        {

            // QXmlStreamAttribute()
            cptr = new ::QXmlStreamAttribute();
            break;
        }
        case 1: // QXmlStreamAttribute(const QString &namespaceUri, const QString &name, const QString &value)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QXmlStreamAttribute(QString,QString,QString)
                cptr = new ::QXmlStreamAttribute(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 2: // QXmlStreamAttribute(const QString &qualifiedName, const QString &value)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QXmlStreamAttribute(QString,QString)
                cptr = new ::QXmlStreamAttribute(cppArg0, cppArg1);
            }
            break;
        }
        case 3: // QXmlStreamAttribute(const QXmlStreamAttribute &QXmlStreamAttribute)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QXmlStreamAttribute cppArg0_local;
            ::QXmlStreamAttribute *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QXmlStreamAttribute(QXmlStreamAttribute)
                cptr = new ::QXmlStreamAttribute(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QXmlStreamAttribute >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QXmlStreamAttributeFunc_isDefault(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDefault()const
        bool cppResult = const_cast<const ::QXmlStreamAttribute *>(cppSelf)->isDefault();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributeFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QStringView cppResult = const_cast<const ::QXmlStreamAttribute *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributeFunc_namespaceUri(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // namespaceUri()const
        QStringView cppResult = const_cast<const ::QXmlStreamAttribute *>(cppSelf)->namespaceUri();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributeFunc_prefix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // prefix()const
        QStringView cppResult = const_cast<const ::QXmlStreamAttribute *>(cppSelf)->prefix();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributeFunc_qualifiedName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // qualifiedName()const
        QStringView cppResult = const_cast<const ::QXmlStreamAttribute *>(cppSelf)->qualifiedName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributeFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // value()const
        QStringView cppResult = const_cast<const ::QXmlStreamAttribute *>(cppSelf)->value();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttribute__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QXmlStreamAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QXmlStreamAttribute_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QXmlStreamAttribute_methods[] = {
    {"isDefault", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributeFunc_isDefault), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributeFunc_name), METH_NOARGS, nullptr},
    {"namespaceUri", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributeFunc_namespaceUri), METH_NOARGS, nullptr},
    {"prefix", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributeFunc_prefix), METH_NOARGS, nullptr},
    {"qualifiedName", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributeFunc_qualifiedName), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributeFunc_value), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttribute__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QXmlStreamAttribute_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QXmlStreamAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), (pyArg)))) {
                // operator!=(const QXmlStreamAttribute &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QXmlStreamAttribute cppArg0_local;
                ::QXmlStreamAttribute *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), (pyArg)))) {
                // operator==(const QXmlStreamAttribute &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QXmlStreamAttribute cppArg0_local;
                ::QXmlStreamAttribute *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QXmlStreamAttribute_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QXmlStreamAttribute_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QXmlStreamAttribute_Type = nullptr;
static PyTypeObject *Sbk_QXmlStreamAttribute_TypeF(void)
{
    return _Sbk_QXmlStreamAttribute_Type;
}

static PyType_Slot Sbk_QXmlStreamAttribute_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QXmlStreamAttribute_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QXmlStreamAttribute_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QXmlStreamAttribute_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QXmlStreamAttribute_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QXmlStreamAttribute_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QXmlStreamAttribute_spec = {
    "2:PySide6.QtCore.QXmlStreamAttribute",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QXmlStreamAttribute_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QXmlStreamAttribute_PythonToCpp_QXmlStreamAttribute_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QXmlStreamAttribute_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QXmlStreamAttribute_PythonToCpp_QXmlStreamAttribute_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QXmlStreamAttribute_TypeF()))
        return QXmlStreamAttribute_PythonToCpp_QXmlStreamAttribute_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QXmlStreamAttribute_PTR_CppToPython_QXmlStreamAttribute(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QXmlStreamAttribute_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QXmlStreamAttribute_COPY_CppToPython_QXmlStreamAttribute(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QXmlStreamAttribute *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QXmlStreamAttribute_TypeF(), new ::QXmlStreamAttribute(*source), true, true);
}

// Python to C++ copy conversion.
static void QXmlStreamAttribute_PythonToCpp_QXmlStreamAttribute_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QXmlStreamAttribute *>(cppOut) = *reinterpret_cast< ::QXmlStreamAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QXmlStreamAttribute_PythonToCpp_QXmlStreamAttribute_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QXmlStreamAttribute_TypeF()))
        return QXmlStreamAttribute_PythonToCpp_QXmlStreamAttribute_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QXmlStreamAttribute_SignatureStrings[] = {
    "3:PySide6.QtCore.QXmlStreamAttribute(self)",
    "2:PySide6.QtCore.QXmlStreamAttribute(self,namespaceUri:QString,name:QString,value:QString)",
    "1:PySide6.QtCore.QXmlStreamAttribute(self,qualifiedName:QString,value:QString)",
    "0:PySide6.QtCore.QXmlStreamAttribute(self,QXmlStreamAttribute:PySide6.QtCore.QXmlStreamAttribute)",
    "PySide6.QtCore.QXmlStreamAttribute.isDefault(self)->bool",
    "PySide6.QtCore.QXmlStreamAttribute.name(self)->QStringView",
    "PySide6.QtCore.QXmlStreamAttribute.namespaceUri(self)->QStringView",
    "PySide6.QtCore.QXmlStreamAttribute.prefix(self)->QStringView",
    "PySide6.QtCore.QXmlStreamAttribute.qualifiedName(self)->QStringView",
    "PySide6.QtCore.QXmlStreamAttribute.value(self)->QStringView",
    "PySide6.QtCore.QXmlStreamAttribute.__copy__(self)->typing.Self",
    "PySide6.QtCore.QXmlStreamAttribute.__ne__(self,rhs:PySide6.QtCore.QXmlStreamAttribute)->bool",
    "PySide6.QtCore.QXmlStreamAttribute.__eq__(self,rhs:PySide6.QtCore.QXmlStreamAttribute)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QXmlStreamAttribute_SignatureByteSize = 203;
static constexpr uint8_t QXmlStreamAttribute_SignatureBytes[203] = {
    0x78, 0xda, 0x9d, 0x92, 0xcb, 0x0a, 0xc2, 0x30, 0x14, 0x44, 0xf7, 0xfd, 0x12, 0x0b, 0x35, 0xf8,
    0x00, 0x17, 0x5d, 0x08, 0xa2, 0x6b, 0xb1, 0x14, 0xc5, 0x5d, 0x48, 0xdb, 0x5b, 0xbd, 0x90, 0xbe,
    0x92, 0x54, 0xed, 0xdf, 0x5b, 0x6b, 0x5b, 0x10, 0x44, 0x2f, 0x59, 0x4e, 0x32, 0x67, 0x20, 0x33,
    0x59, 0xfa, 0x87, 0x26, 0xc4, 0x04, 0x56, 0x2c, 0x30, 0xdb, 0x42, 0x01, 0x0b, 0xce, 0x99, 0x0c,
    0x8d, 0x02, 0x91, 0x6d, 0x8c, 0x51, 0x18, 0xd5, 0x06, 0x26, 0x1a, 0x64, 0xea, 0x3a, 0x0b, 0xaa,
    0xd5, 0xcb, 0x45, 0x06, 0xba, 0x14, 0x31, 0x1c, 0x15, 0xfa, 0x41, 0x6b, 0xc1, 0xfc, 0xd2, 0x1d,
    0x8e, 0xe2, 0x26, 0x64, 0x3d, 0x2a, 0xd7, 0x99, 0x93, 0xa3, 0xab, 0x5a, 0x48, 0x4c, 0x11, 0x92,
    0xfd, 0x8f, 0xb8, 0x19, 0x39, 0xee, 0xcb, 0x05, 0x81, 0x75, 0x9d, 0xff, 0x1e, 0x86, 0x7a, 0x07,
    0xa9, 0xa8, 0xa5, 0x79, 0xd7, 0x37, 0x5d, 0x47, 0x45, 0x21, 0x29, 0xe0, 0xab, 0xa8, 0x81, 0xe9,
    0x9f, 0x74, 0x42, 0xb8, 0x53, 0xd1, 0xa1, 0x78, 0xcb, 0x88, 0x52, 0x41, 0x8a, 0x0f, 0x4b, 0xf8,
    0x63, 0x1d, 0xcb, 0x8c, 0x6e, 0x4b, 0x4b, 0x96, 0xf3, 0xb8, 0x28, 0x1b, 0xce, 0x07, 0xdc, 0x34,
    0x65, 0x4b, 0xb3, 0xb0, 0x55, 0x34, 0x3c, 0x87, 0x1e, 0xf6, 0xd4, 0x55, 0x53, 0x7e, 0x02, 0x7d,
    0x56, 0xce, 0xa1, 0xb2, 0x0b, 0x7f, 0x02, 0xd1, 0x7d, 0x54, 0xbe
};
#endif

PyTypeObject *init_QXmlStreamAttribute(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX].type;

    Shiboken::AutoDecRef Sbk_QXmlStreamAttribute_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QXmlStreamAttribute_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QXmlStreamAttribute",
        "QXmlStreamAttribute",
        &Sbk_QXmlStreamAttribute_spec,
        &Shiboken::callCppDestructor< ::QXmlStreamAttribute >,
        Sbk_QXmlStreamAttribute_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QXmlStreamAttribute_TypeF(); // references _Sbk_QXmlStreamAttribute_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QXmlStreamAttribute_SignatureStrings);
#else
    InitSignatureBytes(pyType, QXmlStreamAttribute_SignatureBytes, QXmlStreamAttribute_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QXmlStreamAttribute_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QXmlStreamAttribute_PythonToCpp_QXmlStreamAttribute_PTR,
        is_QXmlStreamAttribute_PythonToCpp_QXmlStreamAttribute_PTR_Convertible,
        QXmlStreamAttribute_PTR_CppToPython_QXmlStreamAttribute,
        QXmlStreamAttribute_COPY_CppToPython_QXmlStreamAttribute);

    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamAttribute");
    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamAttribute*");
    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamAttribute&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QXmlStreamAttribute).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QXmlStreamAttribute_PythonToCpp_QXmlStreamAttribute_COPY,
        is_QXmlStreamAttribute_PythonToCpp_QXmlStreamAttribute_COPY_Convertible);

    qRegisterMetaType< ::QXmlStreamAttribute >("QXmlStreamAttribute");

    return pyType;
}
