// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qxmlstreamattributes_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringView>
#include <qxmlstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlStreamAttributes_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QXmlStreamAttributes >()))
        return -1;

    ::QXmlStreamAttributes *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QXmlStreamAttributes", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QXmlStreamAttributes::QXmlStreamAttributes()
    // 1: QXmlStreamAttributes::QXmlStreamAttributes(QXmlStreamAttributes)
    if (numArgs == 0) {
        overloadId = 0; // QXmlStreamAttributes()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QXmlStreamAttributes(QXmlStreamAttributes)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QXmlStreamAttributes()
        {

            // QXmlStreamAttributes()
            cptr = new ::QXmlStreamAttributes();
            break;
        }
        case 1: // QXmlStreamAttributes(const QXmlStreamAttributes &QXmlStreamAttributes)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QXmlStreamAttributes cppArg0_local;
            ::QXmlStreamAttributes *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QXmlStreamAttributes(QXmlStreamAttributes)
                cptr = new ::QXmlStreamAttributes(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QXmlStreamAttributes >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_append(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "append", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamAttributes::append(QXmlStreamAttribute)
    // 1: QXmlStreamAttributes::append(QList<QXmlStreamAttribute>)
    // 2: QXmlStreamAttributes::append(QString,QString,QString)
    // 3: QXmlStreamAttributes::append(QString,QString)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 3; // append(QString,QString)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 2; // append(QString,QString,QString)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), (pyArgs[0])))) {
        overloadId = 0; // append(QXmlStreamAttribute)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], (pyArgs[0])))) {
        overloadId = 1; // append(QList<QXmlStreamAttribute>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "append", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // append(QXmlStreamAttribute arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QXmlStreamAttribute cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QXmlStreamAttribute)
                cppSelf->append(cppArg0);
            }
            break;
        }
        case 1: // append(const QList<QXmlStreamAttribute> &l)
        {
            ::QList<QXmlStreamAttribute> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QList<QXmlStreamAttribute>)
                cppSelf->append(cppArg0);
            }
            break;
        }
        case 2: // append(const QString &namespaceUri, const QString &name, const QString &value)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QString,QString,QString)
                cppSelf->append(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 3: // append(const QString &qualifiedName, const QString &value)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QString,QString)
                cppSelf->append(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_at(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamAttributes::at(qsizetype)const->const QXmlStreamAttribute&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // at(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "at", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // at(qsizetype)const
            const QXmlStreamAttribute & cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->at(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_back(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // back()
        QXmlStreamAttribute & cppResult = cppSelf->back();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_capacity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // capacity()const
        qsizetype cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->capacity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_constData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // constData()const
        const QXmlStreamAttribute * cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->constData();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_constFirst(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // constFirst()const
        const QXmlStreamAttribute & cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->constFirst();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_constLast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // constLast()const
        const QXmlStreamAttribute & cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->constLast();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        qsizetype cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()
        QXmlStreamAttribute * cppResult = cppSelf->data();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_empty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // empty()const
        bool cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->empty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_first(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "first", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamAttributes::first()->QXmlStreamAttribute&
    // 1: QXmlStreamAttributes::first(qsizetype)const->QList<QXmlStreamAttribute>
    if (numArgs == 0) {
        overloadId = 0; // first()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        overloadId = 1; // first(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "first", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // first()
        {

            // first()
            QXmlStreamAttribute & cppResult = cppSelf->first();
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), &cppResult);
            break;
        }
        case 1: // first(qsizetype n) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // first(qsizetype)const
                QList<QXmlStreamAttribute> cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->first(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_fromVector(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QXmlStreamAttributes::fromVector(QList<QXmlStreamAttribute>)->QList<QXmlStreamAttribute>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], (pyArg)))) {
        overloadId = 0; // fromVector(QList<QXmlStreamAttribute>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromVector", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        ::QList<QXmlStreamAttribute> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromVector(QList<QXmlStreamAttribute>)
            QList<QXmlStreamAttribute> cppResult = ::QXmlStreamAttributes::fromVector(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_front(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // front()
        QXmlStreamAttribute & cppResult = cppSelf->front();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_hasAttribute(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "hasAttribute", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamAttributes::hasAttribute(QAnyStringView,QAnyStringView)const->bool
    // 1: QXmlStreamAttributes::hasAttribute(QAnyStringView)const->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // hasAttribute(QAnyStringView)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // hasAttribute(QAnyStringView,QAnyStringView)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "hasAttribute", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // hasAttribute(QAnyStringView namespaceUri, QAnyStringView name) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // hasAttribute(QAnyStringView,QAnyStringView)const
                bool cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->hasAttribute(QAnyStringView(cppArg0), QAnyStringView(cppArg1));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // hasAttribute(QAnyStringView qualifiedName) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // hasAttribute(QAnyStringView)const
                bool cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->hasAttribute(QAnyStringView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_insert(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insert", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamAttributes::insert(qsizetype,QXmlStreamAttribute)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insert(qsizetype,QXmlStreamAttribute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insert", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QXmlStreamAttribute cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insert(qsizetype,QXmlStreamAttribute)
            cppSelf->insert(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_isSharedWith(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamAttributes::isSharedWith(QList<QXmlStreamAttribute>)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], (pyArg)))) {
        overloadId = 0; // isSharedWith(QList<QXmlStreamAttribute>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isSharedWith", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        ::QList<QXmlStreamAttribute> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isSharedWith(QList<QXmlStreamAttribute>)const
            bool cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->isSharedWith(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_last(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "last", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamAttributes::last()->QXmlStreamAttribute&
    // 1: QXmlStreamAttributes::last(qsizetype)const->QList<QXmlStreamAttribute>
    if (numArgs == 0) {
        overloadId = 0; // last()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        overloadId = 1; // last(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "last", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // last()
        {

            // last()
            QXmlStreamAttribute & cppResult = cppSelf->last();
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), &cppResult);
            break;
        }
        case 1: // last(qsizetype n) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // last(qsizetype)const
                QList<QXmlStreamAttribute> cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->last(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // length()const
        qsizetype cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->length();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_maxSize(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxSize()
        qsizetype cppResult = ::QXmlStreamAttributes::maxSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_max_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // max_size()const
        qsizetype cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->max_size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_mid(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "mid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    if (PyArg_ParseTuple(args, "|OO:mid", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamAttributes::mid(qsizetype,qsizetype=)const->QList<QXmlStreamAttribute>
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // mid(qsizetype,qsizetype)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 0; // mid(qsizetype,qsizetype)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_len = Shiboken::String::createStaticString("len");
            if (PyDict_Contains(kwds, key_len) != 0) {
                value = PyDict_GetItem(kwds, key_len);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_len);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "mid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "mid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_len);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "mid", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);
            }
        }
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = -1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mid(qsizetype,qsizetype)const
            QList<QXmlStreamAttribute> cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->mid(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_move(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "move", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamAttributes::move(qsizetype,qsizetype)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // move(qsizetype,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "move", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // move(qsizetype,qsizetype)
            cppSelf->move(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_prepend(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamAttributes::prepend(QXmlStreamAttribute)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), (pyArg)))) {
        overloadId = 0; // prepend(QXmlStreamAttribute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "prepend", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QXmlStreamAttribute cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // prepend(QXmlStreamAttribute)
            cppSelf->prepend(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_push_back(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamAttributes::push_back(QXmlStreamAttribute)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), (pyArg)))) {
        overloadId = 0; // push_back(QXmlStreamAttribute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "push_back", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QXmlStreamAttribute cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // push_back(QXmlStreamAttribute)
            cppSelf->push_back(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_push_front(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamAttributes::push_front(QXmlStreamAttribute)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), (pyArg)))) {
        overloadId = 0; // push_front(QXmlStreamAttribute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "push_front", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QXmlStreamAttribute cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // push_front(QXmlStreamAttribute)
            cppSelf->push_front(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_remove(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    if (PyArg_ParseTuple(args, "|OO:remove", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamAttributes::remove(qsizetype,qsizetype=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // remove(qsizetype,qsizetype)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 0; // remove(qsizetype,qsizetype)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_n = Shiboken::String::createStaticString("n");
            if (PyDict_Contains(kwds, key_n) != 0) {
                value = PyDict_GetItem(kwds, key_n);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_n);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_n);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "remove", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);
            }
        }
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = 1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // remove(qsizetype,qsizetype)
            cppSelf->remove(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_removeAll(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamAttributes::removeAll(QXmlStreamAttribute)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), (pyArg)))) {
        overloadId = 0; // removeAll(QXmlStreamAttribute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAll", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QXmlStreamAttribute cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAll(QXmlStreamAttribute)
            cppSelf->removeAll(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_removeAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamAttributes::removeAt(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // removeAt(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAt(qsizetype)
            cppSelf->removeAt(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_removeFirst(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // removeFirst()
        cppSelf->removeFirst();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_removeLast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // removeLast()
        cppSelf->removeLast();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_removeOne(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamAttributes::removeOne(QXmlStreamAttribute)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), (pyArg)))) {
        overloadId = 0; // removeOne(QXmlStreamAttribute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeOne", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QXmlStreamAttribute cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeOne(QXmlStreamAttribute)
            cppSelf->removeOne(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_reserve(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamAttributes::reserve(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // reserve(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "reserve", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // reserve(qsizetype)
            cppSelf->reserve(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_resize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamAttributes::resize(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // resize(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resize", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resize(qsizetype)
            cppSelf->resize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_resizeForOverwrite(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamAttributes::resizeForOverwrite(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // resizeForOverwrite(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resizeForOverwrite", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeForOverwrite(qsizetype)
            cppSelf->resizeForOverwrite(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_shrink_to_fit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shrink_to_fit()
        cppSelf->shrink_to_fit();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        qsizetype cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_sliced(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sliced", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamAttributes::sliced(qsizetype)const->QList<QXmlStreamAttribute>
    // 1: QXmlStreamAttributes::sliced(qsizetype,qsizetype)const->QList<QXmlStreamAttribute>
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // sliced(qsizetype)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 1; // sliced(qsizetype,qsizetype)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sliced", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // sliced(qsizetype pos) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sliced(qsizetype)const
                QList<QXmlStreamAttribute> cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->sliced(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], &cppResult);
            }
            break;
        }
        case 1: // sliced(qsizetype pos, qsizetype n) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sliced(qsizetype,qsizetype)const
                QList<QXmlStreamAttribute> cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->sliced(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_squeeze(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // squeeze()
        cppSelf->squeeze();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamAttributes::swap(QList<QXmlStreamAttribute>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], (pyArg)))) {
        overloadId = 0; // swap(QList<QXmlStreamAttribute>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        ::QList<QXmlStreamAttribute> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QList<QXmlStreamAttribute>&)
            cppSelf->swap(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_swapItemsAt(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "swapItemsAt", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamAttributes::swapItemsAt(qsizetype,qsizetype)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // swapItemsAt(qsizetype,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "swapItemsAt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swapItemsAt(qsizetype,qsizetype)
            cppSelf->swapItemsAt(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_takeAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamAttributes::takeAt(qsizetype)->QXmlStreamAttribute
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // takeAt(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "takeAt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // takeAt(qsizetype)
            QXmlStreamAttribute cppResult = cppSelf->takeAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_toVector(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toVector()const
        QList<QXmlStreamAttribute> cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->toVector();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc_value(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "value", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamAttributes::value(QAnyStringView,QAnyStringView)const->QStringView
    // 1: QXmlStreamAttributes::value(QAnyStringView)const->QStringView
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // value(QAnyStringView)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // value(QAnyStringView,QAnyStringView)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "value", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // value(QAnyStringView namespaceUri, QAnyStringView name) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // value(QAnyStringView,QAnyStringView)const
                QStringView cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->value(QAnyStringView(cppArg0), QAnyStringView(cppArg1));
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
            }
            break;
        }
        case 1: // value(QAnyStringView qualifiedName) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // value(QAnyStringView)const
                QStringView cppResult = const_cast<const ::QXmlStreamAttributes *>(cppSelf)->value(QAnyStringView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributes__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QXmlStreamAttributes_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QXmlStreamAttributes_methods[] = {
    {"append", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_append), METH_VARARGS, nullptr},
    {"at", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_at), METH_O, nullptr},
    {"back", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_back), METH_NOARGS, nullptr},
    {"capacity", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_capacity), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_clear), METH_NOARGS, nullptr},
    {"constData", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_constData), METH_NOARGS, nullptr},
    {"constFirst", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_constFirst), METH_NOARGS, nullptr},
    {"constLast", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_constLast), METH_NOARGS, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_count), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_data), METH_NOARGS, nullptr},
    {"empty", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_empty), METH_NOARGS, nullptr},
    {"first", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_first), METH_VARARGS, nullptr},
    {"fromVector", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_fromVector), METH_O|METH_STATIC, nullptr},
    {"front", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_front), METH_NOARGS, nullptr},
    {"hasAttribute", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_hasAttribute), METH_VARARGS, nullptr},
    {"insert", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_insert), METH_VARARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_isEmpty), METH_NOARGS, nullptr},
    {"isSharedWith", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_isSharedWith), METH_O, nullptr},
    {"last", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_last), METH_VARARGS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_length), METH_NOARGS, nullptr},
    {"maxSize", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_maxSize), METH_NOARGS|METH_STATIC, nullptr},
    {"max_size", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_max_size), METH_NOARGS, nullptr},
    {"mid", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_mid), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"move", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_move), METH_VARARGS, nullptr},
    {"prepend", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_prepend), METH_O, nullptr},
    {"push_back", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_push_back), METH_O, nullptr},
    {"push_front", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_push_front), METH_O, nullptr},
    {"remove", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_remove), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"removeAll", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_removeAll), METH_O, nullptr},
    {"removeAt", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_removeAt), METH_O, nullptr},
    {"removeFirst", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_removeFirst), METH_NOARGS, nullptr},
    {"removeLast", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_removeLast), METH_NOARGS, nullptr},
    {"removeOne", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_removeOne), METH_O, nullptr},
    {"reserve", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_reserve), METH_O, nullptr},
    {"resize", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_resize), METH_O, nullptr},
    {"resizeForOverwrite", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_resizeForOverwrite), METH_O, nullptr},
    {"shrink_to_fit", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_shrink_to_fit), METH_NOARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_size), METH_NOARGS, nullptr},
    {"sliced", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_sliced), METH_VARARGS, nullptr},
    {"squeeze", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_squeeze), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_swap), METH_O, nullptr},
    {"swapItemsAt", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_swapItemsAt), METH_VARARGS, nullptr},
    {"takeAt", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_takeAt), METH_O, nullptr},
    {"toVector", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_toVector), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributesFunc_value), METH_VARARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamAttributes__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QXmlStreamAttributesFunc___add__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamAttributes::operator+(QList<QXmlStreamAttribute>)->QList<QXmlStreamAttribute>
    // 1: QXmlStreamAttributes::operator+(QList<QXmlStreamAttribute>)const->QList<QXmlStreamAttribute>
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], (pyArg)))) {
        overloadId = 1; // operator+(QList<QXmlStreamAttribute>)const
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], (pyArg)))) {
        overloadId = 0; // operator+(QList<QXmlStreamAttribute>)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // operator+(const QList<QXmlStreamAttribute> &l)
        {
            ::QList<QXmlStreamAttribute> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(QList<QXmlStreamAttribute>)
                QList<QXmlStreamAttribute> cppResult = (*cppSelf) + cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], &cppResult);
            }
            break;
        }
        case 1: // operator+(const QList<QXmlStreamAttribute> &l) const
        {
            ::QList<QXmlStreamAttribute> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(QList<QXmlStreamAttribute>)const
                QList<QXmlStreamAttribute> cppResult = (*cppSelf) + cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamAttributesFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QXmlStreamAttributes::operator<<(QList<QXmlStreamAttribute>)->QList<QXmlStreamAttribute>&
        if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], (pyArg)))) {
            overloadId = 0; // operator<<(QList<QXmlStreamAttribute>)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]);

        // Call function/method
        {
            ::QList<QXmlStreamAttribute> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QList<QXmlStreamAttribute>)
                QList<QXmlStreamAttribute> & cppResult = (*cppSelf) << cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

Py_ssize_t Sbk_QXmlStreamAttributes__len__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return cppSelf->size();
}
PyObject *Sbk_QXmlStreamAttributes__getitem__(PyObject *self, Py_ssize_t _i)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    const Py_ssize_t size = cppSelf->size();
    if (_i < 0 || _i >= size) {
        Shiboken::Errors::setIndexOutOfBounds(_i, 0, size);
        return nullptr;
    }
    QXmlStreamAttributes::const_iterator _item = cppSelf->begin();
    std::advance(_item, _i);
    return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), &*_item);
}
int Sbk_QXmlStreamAttributes__setitem__(PyObject *self, Py_ssize_t _i, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    const Py_ssize_t size = cppSelf->size();
    if (_i < 0 || _i >= size) {
        Shiboken::Errors::setIndexOutOfBounds(_i, 0, size);
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), (pyArg)))) {
        Shiboken::Errors::setSequenceTypeError("QXmlStreamAttribute");
        return -1;
    }
    if (!Shiboken::Object::isValid(pyArg))
        return -1;
    ::QXmlStreamAttribute cppValue;
    pythonToCpp(pyArg, &cppValue);
    QXmlStreamAttributes::iterator _item = cppSelf->begin();
    std::advance(_item, _i);
    *_item = cppValue;
    return {};
}
// Rich comparison
static PyObject * Sbk_QXmlStreamAttributes_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), (pyArg)))) {
                // operator!=(const QXmlStreamAttributes &arg__1)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QXmlStreamAttributes cppArg0_local;
                ::QXmlStreamAttributes *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                SBK_UNUSED(cppArg0)
                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), (pyArg)))) {
                // operator==(const QXmlStreamAttributes &arg__1)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QXmlStreamAttributes cppArg0_local;
                ::QXmlStreamAttributes *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                SBK_UNUSED(cppArg0)
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QXmlStreamAttributes_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QXmlStreamAttributes_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QXmlStreamAttributes_Type = nullptr;
static PyTypeObject *Sbk_QXmlStreamAttributes_TypeF(void)
{
    return _Sbk_QXmlStreamAttributes_Type;
}

static PyType_Slot Sbk_QXmlStreamAttributes_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QXmlStreamAttributes_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QXmlStreamAttributes_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QXmlStreamAttributes_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QXmlStreamAttributes_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QXmlStreamAttributes_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports sequence protocol
    {Py_sq_ass_item,    reinterpret_cast<void *>(Sbk_QXmlStreamAttributes__setitem__)},
    {Py_sq_length,      reinterpret_cast<void *>(Sbk_QXmlStreamAttributes__len__)},
    {Py_sq_item,        reinterpret_cast<void *>(Sbk_QXmlStreamAttributes__getitem__)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QXmlStreamAttributesFunc___lshift__)},
    {Py_nb_add,         reinterpret_cast<void *>(Sbk_QXmlStreamAttributesFunc___add__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QXmlStreamAttributes_spec = {
    "2:PySide6.QtCore.QXmlStreamAttributes",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QXmlStreamAttributes_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QXmlStreamAttributes_PythonToCpp_QXmlStreamAttributes_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QXmlStreamAttributes_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QXmlStreamAttributes_PythonToCpp_QXmlStreamAttributes_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QXmlStreamAttributes_TypeF()))
        return QXmlStreamAttributes_PythonToCpp_QXmlStreamAttributes_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QXmlStreamAttributes_PTR_CppToPython_QXmlStreamAttributes(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QXmlStreamAttributes_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QXmlStreamAttributes_COPY_CppToPython_QXmlStreamAttributes(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QXmlStreamAttributes *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QXmlStreamAttributes_TypeF(), new ::QXmlStreamAttributes(*source), true, true);
}

// Python to C++ copy conversion.
static void QXmlStreamAttributes_PythonToCpp_QXmlStreamAttributes_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QXmlStreamAttributes *>(cppOut) = *reinterpret_cast< ::QXmlStreamAttributes *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QXmlStreamAttributes_PythonToCpp_QXmlStreamAttributes_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QXmlStreamAttributes_TypeF()))
        return QXmlStreamAttributes_PythonToCpp_QXmlStreamAttributes_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QXmlStreamAttributes_SignatureStrings[] = {
    "1:PySide6.QtCore.QXmlStreamAttributes(self)",
    "0:PySide6.QtCore.QXmlStreamAttributes(self,QXmlStreamAttributes:PySide6.QtCore.QXmlStreamAttributes)",
    "3:PySide6.QtCore.QXmlStreamAttributes.append(self,arg__1:PySide6.QtCore.QXmlStreamAttribute)",
    "2:PySide6.QtCore.QXmlStreamAttributes.append(self,l:QList[PySide6.QtCore.QXmlStreamAttribute])",
    "1:PySide6.QtCore.QXmlStreamAttributes.append(self,namespaceUri:QString,name:QString,value:QString)",
    "0:PySide6.QtCore.QXmlStreamAttributes.append(self,qualifiedName:QString,value:QString)",
    "PySide6.QtCore.QXmlStreamAttributes.at(self,i:qsizetype)->PySide6.QtCore.QXmlStreamAttribute",
    "PySide6.QtCore.QXmlStreamAttributes.back(self)->PySide6.QtCore.QXmlStreamAttribute",
    "PySide6.QtCore.QXmlStreamAttributes.capacity(self)->qsizetype",
    "PySide6.QtCore.QXmlStreamAttributes.clear(self)",
    "PySide6.QtCore.QXmlStreamAttributes.constData(self)->PySide6.QtCore.QXmlStreamAttribute",
    "PySide6.QtCore.QXmlStreamAttributes.constFirst(self)->PySide6.QtCore.QXmlStreamAttribute",
    "PySide6.QtCore.QXmlStreamAttributes.constLast(self)->PySide6.QtCore.QXmlStreamAttribute",
    "PySide6.QtCore.QXmlStreamAttributes.count(self)->qsizetype",
    "PySide6.QtCore.QXmlStreamAttributes.data(self)->PySide6.QtCore.QXmlStreamAttribute",
    "PySide6.QtCore.QXmlStreamAttributes.empty(self)->bool",
    "1:PySide6.QtCore.QXmlStreamAttributes.first(self)->PySide6.QtCore.QXmlStreamAttribute",
    "0:PySide6.QtCore.QXmlStreamAttributes.first(self,n:qsizetype)->QList[PySide6.QtCore.QXmlStreamAttribute]",
    "PySide6.QtCore.QXmlStreamAttributes.fromVector(vector:QList[PySide6.QtCore.QXmlStreamAttribute])->QList[PySide6.QtCore.QXmlStreamAttribute]",
    "PySide6.QtCore.QXmlStreamAttributes.front(self)->PySide6.QtCore.QXmlStreamAttribute",
    "1:PySide6.QtCore.QXmlStreamAttributes.hasAttribute(self,namespaceUri:QString,name:QString)->bool",
    "0:PySide6.QtCore.QXmlStreamAttributes.hasAttribute(self,qualifiedName:QString)->bool",
    "PySide6.QtCore.QXmlStreamAttributes.insert(self,arg__1:qsizetype,arg__2:PySide6.QtCore.QXmlStreamAttribute)",
    "PySide6.QtCore.QXmlStreamAttributes.isEmpty(self)->bool",
    "PySide6.QtCore.QXmlStreamAttributes.isSharedWith(self,other:QList[PySide6.QtCore.QXmlStreamAttribute])->bool",
    "1:PySide6.QtCore.QXmlStreamAttributes.last(self)->PySide6.QtCore.QXmlStreamAttribute",
    "0:PySide6.QtCore.QXmlStreamAttributes.last(self,n:qsizetype)->QList[PySide6.QtCore.QXmlStreamAttribute]",
    "PySide6.QtCore.QXmlStreamAttributes.length(self)->qsizetype",
    "PySide6.QtCore.QXmlStreamAttributes.maxSize()->qsizetype",
    "PySide6.QtCore.QXmlStreamAttributes.max_size(self)->qsizetype",
    "PySide6.QtCore.QXmlStreamAttributes.mid(self,pos:qsizetype,len:qsizetype=-1)->QList[PySide6.QtCore.QXmlStreamAttribute]",
    "PySide6.QtCore.QXmlStreamAttributes.move(self,from:qsizetype,to:qsizetype)",
    "PySide6.QtCore.QXmlStreamAttributes.prepend(self,arg__1:PySide6.QtCore.QXmlStreamAttribute)",
    "PySide6.QtCore.QXmlStreamAttributes.push_back(self,arg__1:PySide6.QtCore.QXmlStreamAttribute)",
    "PySide6.QtCore.QXmlStreamAttributes.push_front(self,arg__1:PySide6.QtCore.QXmlStreamAttribute)",
    "PySide6.QtCore.QXmlStreamAttributes.remove(self,i:qsizetype,n:qsizetype=1)",
    "PySide6.QtCore.QXmlStreamAttributes.removeAll(self,arg__1:PySide6.QtCore.QXmlStreamAttribute)",
    "PySide6.QtCore.QXmlStreamAttributes.removeAt(self,i:qsizetype)",
    "PySide6.QtCore.QXmlStreamAttributes.removeFirst(self)",
    "PySide6.QtCore.QXmlStreamAttributes.removeLast(self)",
    "PySide6.QtCore.QXmlStreamAttributes.removeOne(self,arg__1:PySide6.QtCore.QXmlStreamAttribute)",
    "PySide6.QtCore.QXmlStreamAttributes.reserve(self,size:qsizetype)",
    "PySide6.QtCore.QXmlStreamAttributes.resize(self,size:qsizetype)",
    "PySide6.QtCore.QXmlStreamAttributes.resizeForOverwrite(self,size:qsizetype)",
    "PySide6.QtCore.QXmlStreamAttributes.shrink_to_fit(self)",
    "PySide6.QtCore.QXmlStreamAttributes.size(self)->qsizetype",
    "1:PySide6.QtCore.QXmlStreamAttributes.sliced(self,pos:qsizetype)->QList[PySide6.QtCore.QXmlStreamAttribute]",
    "0:PySide6.QtCore.QXmlStreamAttributes.sliced(self,pos:qsizetype,n:qsizetype)->QList[PySide6.QtCore.QXmlStreamAttribute]",
    "PySide6.QtCore.QXmlStreamAttributes.squeeze(self)",
    "PySide6.QtCore.QXmlStreamAttributes.swap(self,other:QList[PySide6.QtCore.QXmlStreamAttribute])",
    "PySide6.QtCore.QXmlStreamAttributes.swapItemsAt(self,i:qsizetype,j:qsizetype)",
    "PySide6.QtCore.QXmlStreamAttributes.takeAt(self,i:qsizetype)->PySide6.QtCore.QXmlStreamAttribute",
    "PySide6.QtCore.QXmlStreamAttributes.toVector(self)->QList[PySide6.QtCore.QXmlStreamAttribute]",
    "1:PySide6.QtCore.QXmlStreamAttributes.value(self,namespaceUri:QString,name:QString)->QStringView",
    "0:PySide6.QtCore.QXmlStreamAttributes.value(self,qualifiedName:QString)->QStringView",
    "PySide6.QtCore.QXmlStreamAttributes.__copy__(self)->typing.Self",
    "1:PySide6.QtCore.QXmlStreamAttributes.__add__(self,l:QList[PySide6.QtCore.QXmlStreamAttribute])->QList[PySide6.QtCore.QXmlStreamAttribute]",
    "0:PySide6.QtCore.QXmlStreamAttributes.__add__(self,l:QList[PySide6.QtCore.QXmlStreamAttribute])->QList[PySide6.QtCore.QXmlStreamAttribute]",
    "PySide6.QtCore.QXmlStreamAttributes.__lshift__(self,l:QList[PySide6.QtCore.QXmlStreamAttribute])->QList[PySide6.QtCore.QXmlStreamAttribute]",
    "PySide6.QtCore.QXmlStreamAttributes.__ne__(self,arg__1:PySide6.QtCore.QXmlStreamAttributes)->bool",
    "PySide6.QtCore.QXmlStreamAttributes.__eq__(self,arg__1:PySide6.QtCore.QXmlStreamAttributes)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QXmlStreamAttributes_SignatureByteSize = 637;
static constexpr uint8_t QXmlStreamAttributes_SignatureBytes[637] = {
    0x78, 0xda, 0xcd, 0x58, 0x5d, 0x8b, 0xda, 0x40, 0x14, 0x7d, 0xf7, 0x97, 0x18, 0x70, 0xc5, 0x6c,
    0xa1, 0x0f, 0xc2, 0x16, 0xa4, 0xed, 0x42, 0x61, 0xe9, 0x56, 0xa4, 0xdb, 0x42, 0x59, 0x86, 0x31,
    0xb9, 0x31, 0x53, 0x27, 0x33, 0x71, 0xe6, 0x46, 0x6b, 0x7f, 0x7d, 0xa3, 0x26, 0x31, 0xd2, 0xb4,
    0x7b, 0x27, 0x26, 0xa5, 0x4f, 0x3a, 0x71, 0xce, 0xb9, 0x77, 0xce, 0xdc, 0xaf, 0xe8, 0x4f, 0x3f,
    0xed, 0x17, 0x22, 0x84, 0xd7, 0xe3, 0x39, 0xbe, 0xd5, 0x06, 0xc6, 0xf3, 0xaf, 0x89, 0x5c, 0xa0,
    0x01, 0x9e, 0xcc, 0x10, 0x8d, 0x58, 0x66, 0x08, 0x76, 0x68, 0x41, 0x46, 0xde, 0x60, 0x42, 0xde,
    0x3b, 0x6a, 0xfa, 0x85, 0x82, 0xf6, 0x06, 0xaf, 0x28, 0xdb, 0xc6, 0x3c, 0x4d, 0x41, 0x85, 0x27,
    0x5b, 0xdc, 0xac, 0x18, 0xf3, 0x09, 0x30, 0x6f, 0x70, 0xeb, 0x4c, 0x2e, 0xa7, 0xf3, 0x07, 0x61,
    0xf1, 0xdb, 0xcb, 0xb8, 0x67, 0x6f, 0xe0, 0x3b, 0xd3, 0x2b, 0x9e, 0x80, 0x4d, 0x79, 0x00, 0x9f,
    0x8d, 0x98, 0xce, 0xf3, 0xad, 0x42, 0xad, 0x8e, 0x0f, 0xab, 0xc5, 0x96, 0xcb, 0xac, 0x5a, 0x11,
    0xef, 0xe0, 0xc2, 0xc4, 0x26, 0xe3, 0x52, 0x44, 0x02, 0xc2, 0x8f, 0x7f, 0xa1, 0x25, 0x91, 0xe2,
    0x89, 0x50, 0x4c, 0x37, 0x56, 0xfc, 0x04, 0xdc, 0xa7, 0xe0, 0xdd, 0xbc, 0x79, 0x19, 0x49, 0x22,
    0x5f, 0xf2, 0x60, 0x7d, 0x0a, 0xb3, 0xce, 0x28, 0x03, 0x9e, 0x0b, 0x2b, 0x70, 0x5f, 0xd2, 0x56,
    0x5e, 0xd3, 0xd0, 0x12, 0xb8, 0x29, 0x02, 0x9f, 0xb4, 0x5f, 0x2b, 0x8b, 0xef, 0x38, 0xf2, 0xae,
    0x4f, 0x71, 0xe0, 0xbd, 0x17, 0xc6, 0x62, 0x1f, 0xc4, 0x0f, 0xbc, 0x07, 0xde, 0x4c, 0x61, 0x3b,
    0xcd, 0xc3, 0xee, 0xe5, 0x83, 0x24, 0x3d, 0x47, 0xc0, 0x52, 0x6b, 0x49, 0x4c, 0xd2, 0xc8, 0x51,
    0xf1, 0x89, 0x23, 0xeb, 0x48, 0x5d, 0x64, 0x11, 0xb9, 0xc8, 0x90, 0x0e, 0x1d, 0x19, 0x9d, 0x3c,
    0x41, 0x80, 0xda, 0x0c, 0xb7, 0xc7, 0x0f, 0x87, 0x22, 0xd6, 0x83, 0x2f, 0xca, 0x45, 0x48, 0xda,
    0xf5, 0xc4, 0xdc, 0x56, 0x2b, 0x62, 0x25, 0x2d, 0xef, 0x7f, 0xd2, 0xd2, 0x40, 0x63, 0x1d, 0x2d,
    0x49, 0x29, 0x94, 0x42, 0x59, 0x30, 0x78, 0xd1, 0xb3, 0xaa, 0x10, 0x38, 0x3d, 0xb8, 0x25, 0x35,
    0x31, 0x92, 0x2d, 0xfb, 0xfe, 0xb7, 0xc0, 0xa7, 0xe1, 0x16, 0x31, 0x37, 0x10, 0x7e, 0x11, 0x18,
    0x9f, 0x3c, 0xd5, 0x18, 0x83, 0x5b, 0xfc, 0x38, 0x64, 0x99, 0xe4, 0x3d, 0x24, 0x59, 0x45, 0xda,
    0x6b, 0x8e, 0x49, 0x50, 0xab, 0x42, 0x23, 0xe7, 0x3a, 0x97, 0xf0, 0x1f, 0x8b, 0x7c, 0xff, 0xb0,
    0x0d, 0x90, 0x1d, 0x00, 0x2d, 0xcd, 0x8a, 0x62, 0x24, 0x48, 0xb5, 0xad, 0x85, 0x5e, 0x7e, 0x92,
    0xf3, 0xea, 0xee, 0xc6, 0xef, 0x5c, 0xaa, 0x44, 0x6f, 0x8b, 0x1c, 0x3a, 0x14, 0xa6, 0x9a, 0x65,
    0xd4, 0xb5, 0x0b, 0x22, 0x51, 0xa5, 0x06, 0x5a, 0x0d, 0x7e, 0x24, 0xee, 0xcc, 0xc6, 0xac, 0x9a,
    0x43, 0x7a, 0x61, 0x3f, 0x17, 0xc3, 0xae, 0xe9, 0x0d, 0x9c, 0x55, 0xae, 0x0d, 0x68, 0xf5, 0x14,
    0xb8, 0xf3, 0x5d, 0xa8, 0x66, 0x52, 0xf6, 0xe8, 0xe8, 0xac, 0x61, 0x96, 0x74, 0x80, 0xd7, 0xe6,
    0x21, 0x07, 0xd4, 0x79, 0xd8, 0x71, 0x00, 0x3d, 0x2a, 0xe8, 0x49, 0x87, 0xbc, 0x1b, 0x94, 0x37,
    0x76, 0xd0, 0xc0, 0x5d, 0x89, 0xaa, 0x12, 0x5c, 0x81, 0xbf, 0xd7, 0xe6, 0x71, 0x0b, 0x66, 0x67,
    0x04, 0x5e, 0xc1, 0x65, 0xe3, 0xbc, 0x19, 0xae, 0x19, 0x6a, 0x16, 0x09, 0x17, 0x89, 0x9b, 0x6b,
    0x19, 0xad, 0x77, 0x58, 0x29, 0x02, 0x68, 0x2a, 0x68, 0x4e, 0xf5, 0x6b, 0x72, 0x9d, 0xad, 0x5e,
    0x5b, 0x8c, 0xdd, 0x64, 0x00, 0xa5, 0x40, 0x34, 0xc4, 0x8e, 0xa7, 0xed, 0xda, 0x36, 0x99, 0xfe,
    0x03, 0x42, 0x62, 0x1b, 0xd2, 0x77, 0xf4, 0xdd, 0x35, 0x68, 0x90, 0xaf, 0x1b, 0xeb, 0x40, 0x67,
    0xb3, 0x3f, 0xea, 0x62, 0x08, 0x2e, 0x22, 0x8c, 0x7e, 0x3b, 0xb4, 0x08, 0x3c, 0xbe, 0x43, 0xd3,
    0xa7, 0xcf, 0xe2, 0xdb, 0x93, 0x80, 0x1d, 0x31, 0xec, 0x6a, 0x06, 0xfe, 0x34, 0x7d, 0xd6, 0x49,
    0x29, 0x94, 0x8c, 0x05, 0x3a, 0xdd, 0x33, 0x56, 0x6a, 0x92, 0x2b, 0x9e, 0xc3, 0xc7, 0x8b, 0x7c,
    0x45, 0x3c, 0x35, 0x63, 0x3c, 0x0c, 0x0b, 0x02, 0xa7, 0xbf, 0x47, 0xba, 0x4f, 0xcb, 0x7f, 0xe2,
    0x0a, 0xcd, 0x11, 0x69, 0x63, 0x11, 0xe1, 0xff, 0xe1, 0x8b, 0x82, 0xd2, 0x0f, 0x72, 0xcf, 0xb2,
    0x2e, 0x2f, 0x09, 0x8c, 0xc1, 0xa6, 0xbd, 0x85, 0x5f, 0xb9, 0x70, 0x8a, 0x35
};
#endif

PyTypeObject *init_QXmlStreamAttributes(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX].type;

    Shiboken::AutoDecRef Sbk_QXmlStreamAttributes_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QXmlStreamAttributes_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QXmlStreamAttributes",
        "QXmlStreamAttributes",
        &Sbk_QXmlStreamAttributes_spec,
        &Shiboken::callCppDestructor< ::QXmlStreamAttributes >,
        Sbk_QXmlStreamAttributes_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QXmlStreamAttributes_TypeF(); // references _Sbk_QXmlStreamAttributes_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QXmlStreamAttributes_SignatureStrings);
#else
    InitSignatureBytes(pyType, QXmlStreamAttributes_SignatureBytes, QXmlStreamAttributes_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QXmlStreamAttributes_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QXmlStreamAttributes_PythonToCpp_QXmlStreamAttributes_PTR,
        is_QXmlStreamAttributes_PythonToCpp_QXmlStreamAttributes_PTR_Convertible,
        QXmlStreamAttributes_PTR_CppToPython_QXmlStreamAttributes,
        QXmlStreamAttributes_COPY_CppToPython_QXmlStreamAttributes);

    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamAttributes");
    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamAttributes*");
    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamAttributes&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QXmlStreamAttributes).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QXmlStreamAttributes_PythonToCpp_QXmlStreamAttributes_COPY,
        is_QXmlStreamAttributes_PythonToCpp_QXmlStreamAttributes_COPY_Convertible);

    qRegisterMetaType< ::QXmlStreamAttributes >("QXmlStreamAttributes");

    return pyType;
}
