// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qxmlstreamentityresolver_wrapper.h"

// Argument includes
#include <QString>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QXmlStreamEntityResolverWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QXmlStreamEntityResolverWrapper::QXmlStreamEntityResolverWrapper()
{
}

::QString QXmlStreamEntityResolverWrapper::resolveEntity(const ::QString & publicId, const ::QString & systemId)
{
    if (m_PyMethodCache[0])
        return this->::QXmlStreamEntityResolver::resolveEntity(publicId, systemId);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QString();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resolveEntity";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QXmlStreamEntityResolver::resolveEntity(publicId, systemId);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &publicId),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &systemId)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &publicId),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &systemId)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QXmlStreamEntityResolver", funcName);
        return ::QString();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QXmlStreamEntityResolver", funcName, "QString", Py_TYPE(pyResult)->tp_name);
        return ::QString();
    }
    ::QString cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QString QXmlStreamEntityResolverWrapper::resolveUndeclaredEntity(const ::QString & name)
{
    if (m_PyMethodCache[1])
        return this->::QXmlStreamEntityResolver::resolveUndeclaredEntity(name);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QString();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resolveUndeclaredEntity";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QXmlStreamEntityResolver::resolveUndeclaredEntity(name);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QXmlStreamEntityResolver", funcName);
        return ::QString();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QXmlStreamEntityResolver", funcName, "QString", Py_TYPE(pyResult)->tp_name);
        return ::QString();
    }
    ::QString cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QXmlStreamEntityResolverWrapper::~QXmlStreamEntityResolverWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlStreamEntityResolver_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QXmlStreamEntityResolver >()))
        return -1;

    QXmlStreamEntityResolverWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QXmlStreamEntityResolver()
        cptr = new QXmlStreamEntityResolverWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QXmlStreamEntityResolver >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QXmlStreamEntityResolverFunc_resolveEntity(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamEntityResolver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "resolveEntity", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamEntityResolver::resolveEntity(QString,QString)->QString
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // resolveEntity(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "resolveEntity", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resolveEntity(QString,QString)
            QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QXmlStreamEntityResolver::resolveEntity(cppArg0, cppArg1)
                : cppSelf->resolveEntity(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamEntityResolverFunc_resolveUndeclaredEntity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamEntityResolver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamEntityResolver::resolveUndeclaredEntity(QString)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // resolveUndeclaredEntity(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resolveUndeclaredEntity", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resolveUndeclaredEntity(QString)
            QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QXmlStreamEntityResolver::resolveUndeclaredEntity(cppArg0)
                : cppSelf->resolveUndeclaredEntity(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QXmlStreamEntityResolver_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QXmlStreamEntityResolver_methods[] = {
    {"resolveEntity", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamEntityResolverFunc_resolveEntity), METH_VARARGS, nullptr},
    {"resolveUndeclaredEntity", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamEntityResolverFunc_resolveUndeclaredEntity), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QXmlStreamEntityResolver_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QXmlStreamEntityResolver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QXmlStreamEntityResolverWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QXmlStreamEntityResolver_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QXmlStreamEntityResolver_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QXmlStreamEntityResolver_Type = nullptr;
static PyTypeObject *Sbk_QXmlStreamEntityResolver_TypeF(void)
{
    return _Sbk_QXmlStreamEntityResolver_Type;
}

static PyType_Slot Sbk_QXmlStreamEntityResolver_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QXmlStreamEntityResolver_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QXmlStreamEntityResolver_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QXmlStreamEntityResolver_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QXmlStreamEntityResolver_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QXmlStreamEntityResolver_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QXmlStreamEntityResolver_spec = {
    "2:PySide6.QtCore.QXmlStreamEntityResolver",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QXmlStreamEntityResolver_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QXmlStreamEntityResolver_PythonToCpp_QXmlStreamEntityResolver_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QXmlStreamEntityResolver_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QXmlStreamEntityResolver_PythonToCpp_QXmlStreamEntityResolver_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QXmlStreamEntityResolver_TypeF()))
        return QXmlStreamEntityResolver_PythonToCpp_QXmlStreamEntityResolver_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QXmlStreamEntityResolver_PTR_CppToPython_QXmlStreamEntityResolver(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QXmlStreamEntityResolver *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QXmlStreamEntityResolver_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QXmlStreamEntityResolver_SignatureStrings[] = {
    "PySide6.QtCore.QXmlStreamEntityResolver(self)",
    "PySide6.QtCore.QXmlStreamEntityResolver.resolveEntity(self,publicId:QString,systemId:QString)->QString",
    "PySide6.QtCore.QXmlStreamEntityResolver.resolveUndeclaredEntity(self,name:QString)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QXmlStreamEntityResolver_SignatureByteSize = 115;
static constexpr uint8_t QXmlStreamEntityResolver_SignatureBytes[115] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce, 0x2f, 0x4a,
    0xd5, 0x0b, 0x8c, 0xc8, 0xcd, 0x09, 0x2e, 0x29, 0x4a, 0x4d, 0xcc, 0x75, 0xcd, 0x2b, 0xc9, 0x2c,
    0xa9, 0x0c, 0x4a, 0x2d, 0xce, 0xcf, 0x29, 0x4b, 0x2d, 0xd2, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4,
    0x0a, 0x20, 0x4e, 0xb5, 0x5e, 0x11, 0x84, 0x01, 0x11, 0x05, 0xeb, 0xd5, 0x29, 0x28, 0x4d, 0xca,
    0xc9, 0x4c, 0xf6, 0x4c, 0xb1, 0x0a, 0x04, 0xea, 0xc8, 0xcc, 0x4b, 0xd7, 0x29, 0xae, 0x2c, 0x2e,
    0x49, 0xcd, 0x45, 0x08, 0x68, 0xea, 0xda, 0x41, 0x59, 0xa4, 0x5a, 0x13, 0x9a, 0x97, 0x92, 0x9a,
    0x9c, 0x93, 0x58, 0x94, 0x9a, 0x82, 0x6c, 0x61, 0x5e, 0x62, 0x6e, 0x2a, 0x16, 0xb3, 0x01, 0xa7,
    0xe2, 0x5a, 0x2d
};
#endif

PyTypeObject *init_QXmlStreamEntityResolver(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX].type;

    Shiboken::AutoDecRef Sbk_QXmlStreamEntityResolver_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QXmlStreamEntityResolver_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QXmlStreamEntityResolver",
        "QXmlStreamEntityResolver*",
        &Sbk_QXmlStreamEntityResolver_spec,
        &Shiboken::callCppDestructor< QXmlStreamEntityResolver >,
        Sbk_QXmlStreamEntityResolver_Type_bases.object(),
        0);
    auto *pyType = Sbk_QXmlStreamEntityResolver_TypeF(); // references _Sbk_QXmlStreamEntityResolver_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QXmlStreamEntityResolver_SignatureStrings);
#else
    InitSignatureBytes(pyType, QXmlStreamEntityResolver_SignatureBytes, QXmlStreamEntityResolver_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QXmlStreamEntityResolver_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QXmlStreamEntityResolver_PythonToCpp_QXmlStreamEntityResolver_PTR,
        is_QXmlStreamEntityResolver_PythonToCpp_QXmlStreamEntityResolver_PTR_Convertible,
        QXmlStreamEntityResolver_PTR_CppToPython_QXmlStreamEntityResolver);

    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamEntityResolver");
    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamEntityResolver*");
    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamEntityResolver&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QXmlStreamEntityResolver).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QXmlStreamEntityResolverWrapper).name());

    qRegisterMetaType< ::QXmlStreamEntityResolver *>();

    return pyType;
}
