// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qxmlstreamwriter_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QString>
#include <qbytearray.h>
#include <qiodevice.h>
#include <qxmlstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlStreamWriter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QXmlStreamWriter >()))
        return -1;

    ::QXmlStreamWriter *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QXmlStreamWriter", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QXmlStreamWriter::QXmlStreamWriter()
    // 1: QXmlStreamWriter::QXmlStreamWriter(QByteArray*)
    // 2: QXmlStreamWriter::QXmlStreamWriter(QIODevice*)
    if (numArgs == 0) {
        overloadId = 0; // QXmlStreamWriter()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QXmlStreamWriter(QIODevice*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QXmlStreamWriter(QByteArray*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QXmlStreamWriter()
        {

            // QXmlStreamWriter()
            cptr = new ::QXmlStreamWriter();
            break;
        }
        case 1: // QXmlStreamWriter(QByteArray *array)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QXmlStreamWriter(QByteArray*)
                cptr = new ::QXmlStreamWriter(cppArg0);
            }
            break;
        }
        case 2: // QXmlStreamWriter(QIODevice *device)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QXmlStreamWriter(QIODevice*)
                cptr = new ::QXmlStreamWriter(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QXmlStreamWriter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QXmlStreamWriterFunc_autoFormatting(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoFormatting()const
        bool cppResult = const_cast<const ::QXmlStreamWriter *>(cppSelf)->autoFormatting();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamWriterFunc_autoFormattingIndent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoFormattingIndent()const
        int cppResult = const_cast<const ::QXmlStreamWriter *>(cppSelf)->autoFormattingIndent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamWriterFunc_device(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // device()const
        QIODevice * cppResult = const_cast<const ::QXmlStreamWriter *>(cppSelf)->device();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamWriterFunc_hasError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasError()const
        bool cppResult = const_cast<const ::QXmlStreamWriter *>(cppSelf)->hasError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamWriterFunc_setAutoFormatting(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::setAutoFormatting(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoFormatting(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoFormatting", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoFormatting(bool)
            cppSelf->setAutoFormatting(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_setAutoFormattingIndent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::setAutoFormattingIndent(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setAutoFormattingIndent(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoFormattingIndent", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoFormattingIndent(int)
            cppSelf->setAutoFormattingIndent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_setDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::setDevice(QIODevice*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDevice", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDevice(QIODevice*)
            cppSelf->setDevice(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeAttribute(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeAttribute", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeAttribute(QAnyStringView,QAnyStringView,QAnyStringView)
    // 1: QXmlStreamWriter::writeAttribute(QAnyStringView,QAnyStringView)
    // 2: QXmlStreamWriter::writeAttribute(QXmlStreamAttribute)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), (pyArgs[0])))) {
        overloadId = 2; // writeAttribute(QXmlStreamAttribute)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // writeAttribute(QAnyStringView,QAnyStringView)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 0; // writeAttribute(QAnyStringView,QAnyStringView,QAnyStringView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeAttribute", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // writeAttribute(QAnyStringView namespaceUri, QAnyStringView name, QAnyStringView value)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeAttribute(QAnyStringView,QAnyStringView,QAnyStringView)
                cppSelf->writeAttribute(QAnyStringView(cppArg0), QAnyStringView(cppArg1), QAnyStringView(cppArg2));
            }
            break;
        }
        case 1: // writeAttribute(QAnyStringView qualifiedName, QAnyStringView value)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeAttribute(QAnyStringView,QAnyStringView)
                cppSelf->writeAttribute(QAnyStringView(cppArg0), QAnyStringView(cppArg1));
            }
            break;
        }
        case 2: // writeAttribute(const QXmlStreamAttribute &attribute)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QXmlStreamAttribute cppArg0_local;
            ::QXmlStreamAttribute *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // writeAttribute(QXmlStreamAttribute)
                cppSelf->writeAttribute(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeAttributes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeAttributes(QXmlStreamAttributes)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), (pyArg)))) {
        overloadId = 0; // writeAttributes(QXmlStreamAttributes)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "writeAttributes", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QXmlStreamAttributes cppArg0_local;
        ::QXmlStreamAttributes *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // writeAttributes(QXmlStreamAttributes)
            cppSelf->writeAttributes(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeCDATA(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeCDATA(QAnyStringView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // writeCDATA(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "writeCDATA", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeCDATA(QAnyStringView)
            cppSelf->writeCDATA(QAnyStringView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeCharacters(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeCharacters(QAnyStringView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // writeCharacters(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "writeCharacters", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeCharacters(QAnyStringView)
            cppSelf->writeCharacters(QAnyStringView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeComment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeComment(QAnyStringView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // writeComment(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "writeComment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeComment(QAnyStringView)
            cppSelf->writeComment(QAnyStringView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeCurrentToken(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeCurrentToken(QXmlStreamReader)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), (pyArg)))) {
        overloadId = 0; // writeCurrentToken(QXmlStreamReader)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "writeCurrentToken", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QXmlStreamReader *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeCurrentToken(QXmlStreamReader)
            cppSelf->writeCurrentToken(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeDTD(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeDTD(QAnyStringView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // writeDTD(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "writeDTD", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeDTD(QAnyStringView)
            cppSelf->writeDTD(QAnyStringView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeDefaultNamespace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeDefaultNamespace(QAnyStringView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // writeDefaultNamespace(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "writeDefaultNamespace", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeDefaultNamespace(QAnyStringView)
            cppSelf->writeDefaultNamespace(QAnyStringView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeEmptyElement(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeEmptyElement", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeEmptyElement(QAnyStringView,QAnyStringView)
    // 1: QXmlStreamWriter::writeEmptyElement(QAnyStringView)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // writeEmptyElement(QAnyStringView)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // writeEmptyElement(QAnyStringView,QAnyStringView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeEmptyElement", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // writeEmptyElement(QAnyStringView namespaceUri, QAnyStringView name)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeEmptyElement(QAnyStringView,QAnyStringView)
                cppSelf->writeEmptyElement(QAnyStringView(cppArg0), QAnyStringView(cppArg1));
            }
            break;
        }
        case 1: // writeEmptyElement(QAnyStringView qualifiedName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeEmptyElement(QAnyStringView)
                cppSelf->writeEmptyElement(QAnyStringView(cppArg0));
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeEndDocument(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // writeEndDocument()
        cppSelf->writeEndDocument();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeEndElement(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // writeEndElement()
        cppSelf->writeEndElement();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeEntityReference(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeEntityReference(QAnyStringView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // writeEntityReference(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "writeEntityReference", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeEntityReference(QAnyStringView)
            cppSelf->writeEntityReference(QAnyStringView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeNamespace(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "writeNamespace", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    if (PyArg_ParseTuple(args, "|OO:writeNamespace", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeNamespace(QAnyStringView,QAnyStringView=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // writeNamespace(QAnyStringView,QAnyStringView)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // writeNamespace(QAnyStringView,QAnyStringView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeNamespace", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_prefix = Shiboken::String::createStaticString("prefix");
            if (PyDict_Contains(kwds, key_prefix) != 0) {
                value = PyDict_GetItem(kwds, key_prefix);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_prefix);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "writeNamespace", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QAnyStringView_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "writeNamespace", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_prefix);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "writeNamespace", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeNamespace(QAnyStringView,QAnyStringView)
            cppSelf->writeNamespace(QAnyStringView(cppArg0), QAnyStringView(cppArg1));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeProcessingInstruction(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "writeProcessingInstruction", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    if (PyArg_ParseTuple(args, "|OO:writeProcessingInstruction", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeProcessingInstruction(QAnyStringView,QAnyStringView=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // writeProcessingInstruction(QAnyStringView,QAnyStringView)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // writeProcessingInstruction(QAnyStringView,QAnyStringView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeProcessingInstruction", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_data = Shiboken::String::createStaticString("data");
            if (PyDict_Contains(kwds, key_data) != 0) {
                value = PyDict_GetItem(kwds, key_data);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_data);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "writeProcessingInstruction", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QAnyStringView_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "writeProcessingInstruction", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_data);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "writeProcessingInstruction", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeProcessingInstruction(QAnyStringView,QAnyStringView)
            cppSelf->writeProcessingInstruction(QAnyStringView(cppArg0), QAnyStringView(cppArg1));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeStartDocument(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeStartDocument", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeStartDocument()
    // 1: QXmlStreamWriter::writeStartDocument(QAnyStringView)
    // 2: QXmlStreamWriter::writeStartDocument(QAnyStringView,bool)
    if (numArgs == 0) {
        overloadId = 0; // writeStartDocument()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // writeStartDocument(QAnyStringView)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 2; // writeStartDocument(QAnyStringView,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeStartDocument", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // writeStartDocument()
        {

            // writeStartDocument()
            cppSelf->writeStartDocument();
            break;
        }
        case 1: // writeStartDocument(QAnyStringView version)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeStartDocument(QAnyStringView)
                cppSelf->writeStartDocument(QAnyStringView(cppArg0));
            }
            break;
        }
        case 2: // writeStartDocument(QAnyStringView version, bool standalone)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            bool cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeStartDocument(QAnyStringView,bool)
                cppSelf->writeStartDocument(QAnyStringView(cppArg0), cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeStartElement(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeStartElement", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeStartElement(QAnyStringView,QAnyStringView)
    // 1: QXmlStreamWriter::writeStartElement(QAnyStringView)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // writeStartElement(QAnyStringView)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // writeStartElement(QAnyStringView,QAnyStringView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeStartElement", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // writeStartElement(QAnyStringView namespaceUri, QAnyStringView name)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeStartElement(QAnyStringView,QAnyStringView)
                cppSelf->writeStartElement(QAnyStringView(cppArg0), QAnyStringView(cppArg1));
            }
            break;
        }
        case 1: // writeStartElement(QAnyStringView qualifiedName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeStartElement(QAnyStringView)
                cppSelf->writeStartElement(QAnyStringView(cppArg0));
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeTextElement(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeTextElement", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeTextElement(QAnyStringView,QAnyStringView,QAnyStringView)
    // 1: QXmlStreamWriter::writeTextElement(QAnyStringView,QAnyStringView)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // writeTextElement(QAnyStringView,QAnyStringView)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 0; // writeTextElement(QAnyStringView,QAnyStringView,QAnyStringView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeTextElement", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // writeTextElement(QAnyStringView namespaceUri, QAnyStringView name, QAnyStringView text)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeTextElement(QAnyStringView,QAnyStringView,QAnyStringView)
                cppSelf->writeTextElement(QAnyStringView(cppArg0), QAnyStringView(cppArg1), QAnyStringView(cppArg2));
            }
            break;
        }
        case 1: // writeTextElement(QAnyStringView qualifiedName, QAnyStringView text)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeTextElement(QAnyStringView,QAnyStringView)
                cppSelf->writeTextElement(QAnyStringView(cppArg0), QAnyStringView(cppArg1));
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QXmlStreamWriter_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QXmlStreamWriter_methods[] = {
    {"autoFormatting", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_autoFormatting), METH_NOARGS, nullptr},
    {"autoFormattingIndent", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_autoFormattingIndent), METH_NOARGS, nullptr},
    {"device", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_device), METH_NOARGS, nullptr},
    {"hasError", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_hasError), METH_NOARGS, nullptr},
    {"setAutoFormatting", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_setAutoFormatting), METH_O, nullptr},
    {"setAutoFormattingIndent", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_setAutoFormattingIndent), METH_O, nullptr},
    {"setDevice", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_setDevice), METH_O, nullptr},
    {"writeAttribute", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeAttribute), METH_VARARGS, nullptr},
    {"writeAttributes", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeAttributes), METH_O, nullptr},
    {"writeCDATA", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeCDATA), METH_O, nullptr},
    {"writeCharacters", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeCharacters), METH_O, nullptr},
    {"writeComment", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeComment), METH_O, nullptr},
    {"writeCurrentToken", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeCurrentToken), METH_O, nullptr},
    {"writeDTD", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeDTD), METH_O, nullptr},
    {"writeDefaultNamespace", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeDefaultNamespace), METH_O, nullptr},
    {"writeEmptyElement", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeEmptyElement), METH_VARARGS, nullptr},
    {"writeEndDocument", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeEndDocument), METH_NOARGS, nullptr},
    {"writeEndElement", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeEndElement), METH_NOARGS, nullptr},
    {"writeEntityReference", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeEntityReference), METH_O, nullptr},
    {"writeNamespace", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeNamespace), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"writeProcessingInstruction", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeProcessingInstruction), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"writeStartDocument", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeStartDocument), METH_VARARGS, nullptr},
    {"writeStartElement", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeStartElement), METH_VARARGS, nullptr},
    {"writeTextElement", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeTextElement), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QXmlStreamWriter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QXmlStreamWriter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QXmlStreamWriter_Type = nullptr;
static PyTypeObject *Sbk_QXmlStreamWriter_TypeF(void)
{
    return _Sbk_QXmlStreamWriter_Type;
}

static PyType_Slot Sbk_QXmlStreamWriter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QXmlStreamWriter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QXmlStreamWriter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QXmlStreamWriter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QXmlStreamWriter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QXmlStreamWriter_spec = {
    "2:PySide6.QtCore.QXmlStreamWriter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QXmlStreamWriter_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QXmlStreamWriter_PythonToCpp_QXmlStreamWriter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QXmlStreamWriter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QXmlStreamWriter_PythonToCpp_QXmlStreamWriter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QXmlStreamWriter_TypeF()))
        return QXmlStreamWriter_PythonToCpp_QXmlStreamWriter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QXmlStreamWriter_PTR_CppToPython_QXmlStreamWriter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QXmlStreamWriter_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QXmlStreamWriter_SignatureStrings[] = {
    "2:PySide6.QtCore.QXmlStreamWriter(self)",
    "1:PySide6.QtCore.QXmlStreamWriter(self,array:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "0:PySide6.QtCore.QXmlStreamWriter(self,device:PySide6.QtCore.QIODevice)",
    "PySide6.QtCore.QXmlStreamWriter.autoFormatting(self)->bool",
    "PySide6.QtCore.QXmlStreamWriter.autoFormattingIndent(self)->int",
    "PySide6.QtCore.QXmlStreamWriter.device(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtCore.QXmlStreamWriter.hasError(self)->bool",
    "PySide6.QtCore.QXmlStreamWriter.setAutoFormatting(self,arg__1:bool)",
    "PySide6.QtCore.QXmlStreamWriter.setAutoFormattingIndent(self,spacesOrTabs:int)",
    "PySide6.QtCore.QXmlStreamWriter.setDevice(self,device:PySide6.QtCore.QIODevice)",
    "2:PySide6.QtCore.QXmlStreamWriter.writeAttribute(self,namespaceUri:QString,name:QString,value:QString)",
    "1:PySide6.QtCore.QXmlStreamWriter.writeAttribute(self,qualifiedName:QString,value:QString)",
    "0:PySide6.QtCore.QXmlStreamWriter.writeAttribute(self,attribute:PySide6.QtCore.QXmlStreamAttribute)",
    "PySide6.QtCore.QXmlStreamWriter.writeAttributes(self,attributes:PySide6.QtCore.QXmlStreamAttributes)",
    "PySide6.QtCore.QXmlStreamWriter.writeCDATA(self,text:QString)",
    "PySide6.QtCore.QXmlStreamWriter.writeCharacters(self,text:QString)",
    "PySide6.QtCore.QXmlStreamWriter.writeComment(self,text:QString)",
    "PySide6.QtCore.QXmlStreamWriter.writeCurrentToken(self,reader:PySide6.QtCore.QXmlStreamReader)",
    "PySide6.QtCore.QXmlStreamWriter.writeDTD(self,dtd:QString)",
    "PySide6.QtCore.QXmlStreamWriter.writeDefaultNamespace(self,namespaceUri:QString)",
    "1:PySide6.QtCore.QXmlStreamWriter.writeEmptyElement(self,namespaceUri:QString,name:QString)",
    "0:PySide6.QtCore.QXmlStreamWriter.writeEmptyElement(self,qualifiedName:QString)",
    "PySide6.QtCore.QXmlStreamWriter.writeEndDocument(self)",
    "PySide6.QtCore.QXmlStreamWriter.writeEndElement(self)",
    "PySide6.QtCore.QXmlStreamWriter.writeEntityReference(self,name:QString)",
    "PySide6.QtCore.QXmlStreamWriter.writeNamespace(self,namespaceUri:QString,prefix:QString={})",
    "PySide6.QtCore.QXmlStreamWriter.writeProcessingInstruction(self,target:QString,data:QString={})",
    "2:PySide6.QtCore.QXmlStreamWriter.writeStartDocument(self)",
    "1:PySide6.QtCore.QXmlStreamWriter.writeStartDocument(self,version:QString)",
    "0:PySide6.QtCore.QXmlStreamWriter.writeStartDocument(self,version:QString,standalone:bool)",
    "1:PySide6.QtCore.QXmlStreamWriter.writeStartElement(self,namespaceUri:QString,name:QString)",
    "0:PySide6.QtCore.QXmlStreamWriter.writeStartElement(self,qualifiedName:QString)",
    "1:PySide6.QtCore.QXmlStreamWriter.writeTextElement(self,namespaceUri:QString,name:QString,text:QString)",
    "0:PySide6.QtCore.QXmlStreamWriter.writeTextElement(self,qualifiedName:QString,text:QString)",
    nullptr}; // Sentinel
#else
static constexpr size_t QXmlStreamWriter_SignatureByteSize = 505;
static constexpr uint8_t QXmlStreamWriter_SignatureBytes[505] = {
    0x78, 0xda, 0xb5, 0x95, 0x5f, 0x6f, 0x9b, 0x30, 0x14, 0xc5, 0xdf, 0xf3, 0x29, 0xf6, 0xb8, 0x54,
    0x0c, 0x25, 0x7d, 0xd8, 0x03, 0xd2, 0x26, 0xb1, 0x92, 0x4a, 0x7d, 0x69, 0x9b, 0x86, 0x6a, 0x95,
    0xaa, 0xaa, 0xba, 0x81, 0x4b, 0x6b, 0x15, 0xec, 0xec, 0xfa, 0x92, 0x15, 0x4d, 0xfb, 0xee, 0x73,
    0x48, 0x20, 0x7f, 0x19, 0x06, 0xa9, 0x4f, 0x91, 0x83, 0xcf, 0xcf, 0xc7, 0xd7, 0xc7, 0xd7, 0xe7,
    0xde, 0x6d, 0x31, 0x13, 0x31, 0x7e, 0x75, 0xa7, 0x7c, 0xa1, 0x08, 0xdd, 0xe9, 0x43, 0x96, 0xce,
    0x98, 0x10, 0xb2, 0x9f, 0x24, 0x18, 0xe9, 0xb3, 0xc6, 0x34, 0x19, 0x0e, 0xc6, 0x56, 0xf3, 0x1c,
    0x20, 0x82, 0xc2, 0xe3, 0x62, 0x21, 0xe4, 0x8b, 0x7b, 0x2f, 0x85, 0x92, 0x8f, 0x87, 0xba, 0x1f,
    0x05, 0xa3, 0xbf, 0x9a, 0xe6, 0x7c, 0x8a, 0x5e, 0x81, 0xce, 0x9e, 0x86, 0x83, 0x91, 0x1d, 0x3c,
    0xc6, 0xa5, 0x88, 0xf0, 0x68, 0xee, 0xd5, 0x4d, 0x50, 0x7e, 0x18, 0x0e, 0x5a, 0x28, 0x2e, 0xe4,
    0xac, 0x2e, 0x15, 0x65, 0xc0, 0x6c, 0xfc, 0xad, 0x77, 0xf6, 0xe5, 0xfb, 0x5c, 0xa9, 0xb4, 0xa3,
    0xf4, 0x4a, 0xc6, 0x28, 0xb9, 0x02, 0x08, 0xc9, 0xad, 0xfa, 0xb5, 0xf7, 0x4a, 0xd1, 0xb4, 0x85,
    0x56, 0xcc, 0x2b, 0xe8, 0x09, 0x91, 0xa2, 0x4e, 0xde, 0x35, 0xb2, 0x7f, 0xbc, 0x73, 0x73, 0x56,
    0x2f, 0xcf, 0xcf, 0x63, 0x6f, 0x85, 0x18, 0x76, 0x67, 0xec, 0x94, 0xc0, 0xd1, 0x0b, 0x88, 0x50,
    0xdf, 0x50, 0x08, 0x73, 0xed, 0x99, 0x6a, 0x58, 0xe1, 0x82, 0x6d, 0x45, 0xda, 0x4f, 0xf6, 0xbc,
    0x2d, 0x21, 0xee, 0xef, 0xd5, 0x8f, 0xcf, 0x4c, 0x62, 0x9e, 0xf3, 0x06, 0x2b, 0x21, 0xc3, 0xd2,
    0xdb, 0x3d, 0x09, 0x6f, 0x6a, 0xa6, 0x1b, 0xdf, 0xe5, 0x9f, 0xf5, 0x60, 0x09, 0x69, 0x5e, 0x8f,
    0x2c, 0x52, 0x7e, 0x72, 0x99, 0x5f, 0x39, 0xa4, 0x22, 0x11, 0x18, 0x5f, 0xff, 0x07, 0x3d, 0xea,
    0x85, 0x86, 0x6a, 0xd8, 0xac, 0xae, 0x15, 0xed, 0x55, 0xdf, 0x5f, 0x41, 0x1f, 0x2c, 0xa1, 0x2d,
    0xd6, 0xd0, 0x96, 0x8b, 0x5c, 0x04, 0x7e, 0xe8, 0xaf, 0xf9, 0x8c, 0xef, 0xbc, 0x2d, 0x83, 0x9d,
    0xda, 0xf4, 0x05, 0x88, 0xcc, 0x50, 0xf7, 0x47, 0xa8, 0x2c, 0xab, 0xf3, 0xd9, 0x47, 0x9f, 0x13,
    0x19, 0x7d, 0xa8, 0xde, 0x50, 0xae, 0x21, 0x66, 0x46, 0x8c, 0xd4, 0x5c, 0xa3, 0xbb, 0xf2, 0xbb,
    0x25, 0x3e, 0x08, 0x83, 0x4d, 0xf2, 0x39, 0xee, 0xe8, 0x2c, 0xc0, 0x04, 0xf2, 0x94, 0xaf, 0xab,
    0x6c, 0x37, 0x47, 0xdd, 0x3a, 0xcf, 0x93, 0x6c, 0xc1, 0xc5, 0x24, 0xc5, 0x6d, 0xc5, 0x5a, 0x6f,
    0x8e, 0x75, 0xa0, 0x8f, 0xd9, 0x27, 0xaf, 0x8b, 0xe5, 0xe6, 0x27, 0x32, 0x0e, 0x54, 0x94, 0xd7,
    0x30, 0x7b, 0xd9, 0xae, 0x05, 0x6b, 0x15, 0x0b, 0x2e, 0xee, 0x30, 0x41, 0x13, 0x85, 0xdd, 0x42,
    0x77, 0x34, 0x6d, 0x71, 0x54, 0xce, 0x82, 0x30, 0x11, 0xef, 0xd5, 0xf0, 0xdb, 0x9f, 0xbf, 0x96,
    0xec, 0x5b, 0x52, 0xa6, 0xf5, 0xea, 0xb2, 0x21, 0x6b, 0xa6, 0x3c, 0x62, 0xf3, 0xe6, 0x6e, 0x52,
    0x6f, 0x1a, 0x3c, 0xd6, 0xb9, 0x77, 0x62, 0x60, 0xd8, 0xe3, 0x5b, 0xf6, 0xd4, 0x99, 0xe1, 0xf0,
    0x41, 0xd1, 0xc7, 0x7d, 0xa5, 0xce, 0xd2, 0x5c, 0x6a, 0xe3, 0xb0, 0x73, 0x8c, 0xda, 0x51, 0x8e,
    0x66, 0x90, 0x31, 0xa4, 0x4a, 0xe2, 0xe6, 0x4d, 0xeb, 0xe2, 0xf2, 0x83, 0xd2, 0x7f, 0xcc, 0x6e,
    0x48, 0xbf, 0xa5, 0xd7, 0xd0, 0x74, 0xb2, 0x6e, 0x56, 0x0f, 0x9a, 0xdf, 0xa8, 0xe7, 0x3a, 0xa7,
    0xdf, 0xb8, 0x7d, 0xf6, 0x3f, 0xe3, 0x08, 0xcc, 0x3a
};
#endif

PyTypeObject *init_QXmlStreamWriter(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX].type;

    Shiboken::AutoDecRef Sbk_QXmlStreamWriter_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QXmlStreamWriter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QXmlStreamWriter",
        "QXmlStreamWriter*",
        &Sbk_QXmlStreamWriter_spec,
        &Shiboken::callCppDestructor< ::QXmlStreamWriter >,
        Sbk_QXmlStreamWriter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QXmlStreamWriter_TypeF(); // references _Sbk_QXmlStreamWriter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QXmlStreamWriter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QXmlStreamWriter_SignatureBytes, QXmlStreamWriter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QXmlStreamWriter_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QXmlStreamWriter_PythonToCpp_QXmlStreamWriter_PTR,
        is_QXmlStreamWriter_PythonToCpp_QXmlStreamWriter_PTR_Convertible,
        QXmlStreamWriter_PTR_CppToPython_QXmlStreamWriter);

    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamWriter");
    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamWriter*");
    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamWriter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QXmlStreamWriter).name());

    qRegisterMetaType< ::QXmlStreamWriter *>();

    return pyType;
}
