// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdbus_python.h"

// main header
#include "qdbusargument_wrapper.h"

// Argument includes
#include <QHash>
#include <QList>
#include <QMap>
#include <QString>
#include <QStringList>
#include <QtDBus/qdbusargument.h>
#include <QtDBus/qdbusextratypes.h>
#include <QtDBus/qdbusunixfiledescriptor.h>
#include <qbytearray.h>
#include <qdatetime.h>
#include <qline.h>
#include <qmetatype.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDBusArgument_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDBusArgument >()))
        return -1;

    ::QDBusArgument *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDBusArgument", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDBusArgument::QDBusArgument()
    // 1: QDBusArgument::QDBusArgument(QDBusArgument)
    if (numArgs == 0) {
        overloadId = 0; // QDBusArgument()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDBusArgument(QDBusArgument)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDBusArgument()
        {

            // QDBusArgument()
            cptr = new ::QDBusArgument();
            break;
        }
        case 1: // QDBusArgument(const QDBusArgument &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDBusArgument cppArg0_local;
            ::QDBusArgument *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusArgument(QDBusArgument)
                cptr = new ::QDBusArgument(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDBusArgument >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDBusArgumentFunc_appendVariant(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusArgument::appendVariant(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // appendVariant(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "appendVariant", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // appendVariant(QVariant)
            cppSelf->appendVariant(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusArgumentFunc_asVariant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // asVariant()const
        QVariant cppResult = const_cast<const ::QDBusArgument *>(cppSelf)->asVariant();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusArgumentFunc_atEnd(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // atEnd()const
        bool cppResult = const_cast<const ::QDBusArgument *>(cppSelf)->atEnd();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusArgumentFunc_beginArray(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "beginArray", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusArgument::beginArray()const
    // 1: QDBusArgument::beginArray(QMetaType)
    // 2: QDBusArgument::beginArray(int)
    if (numArgs == 0) {
        overloadId = 0; // beginArray()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 2; // beginArray(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[0])))) {
        overloadId = 1; // beginArray(QMetaType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "beginArray", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // beginArray() const
        {

            // beginArray()const
            const_cast<const ::QDBusArgument *>(cppSelf)->beginArray();
            break;
        }
        case 1: // beginArray(QMetaType elementMetaType)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QMetaType cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // beginArray(QMetaType)
                cppSelf->beginArray(cppArg0);
            }
            break;
        }
        case 2: // beginArray(int elementMetaTypeId)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // beginArray(int)
                cppSelf->beginArray(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusArgumentFunc_beginMap(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 1)
        return Shiboken::returnWrongArguments(args, "beginMap", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]);

    if (PyArg_UnpackTuple(args, "beginMap", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusArgument::beginMap()const
    // 1: QDBusArgument::beginMap(QMetaType,QMetaType)
    // 2: QDBusArgument::beginMap(int,int)
    if (numArgs == 0) {
        overloadId = 0; // beginMap()const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 2; // beginMap(int,int)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[1])))) {
        overloadId = 1; // beginMap(QMetaType,QMetaType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "beginMap", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // beginMap() const
        {

            // beginMap()const
            const_cast<const ::QDBusArgument *>(cppSelf)->beginMap();
            break;
        }
        case 1: // beginMap(QMetaType keyMetaType, QMetaType valueMetaType)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QMetaType cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMetaType cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // beginMap(QMetaType,QMetaType)
                cppSelf->beginMap(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // beginMap(int keyMetaTypeId, int valueMetaTypeId)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // beginMap(int,int)
                cppSelf->beginMap(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusArgumentFunc_beginMapEntry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // beginMapEntry()
        cppSelf->beginMapEntry();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusArgumentFunc_beginStructure(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // beginStructure()
        cppSelf->beginStructure();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusArgumentFunc_currentSignature(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentSignature()const
        QString cppResult = const_cast<const ::QDBusArgument *>(cppSelf)->currentSignature();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusArgumentFunc_currentType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentType()const
        QDBusArgument::ElementType cppResult = const_cast<const ::QDBusArgument *>(cppSelf)->currentType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_ElementType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusArgumentFunc_endArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // endArray()
        cppSelf->endArray();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusArgumentFunc_endMap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // endMap()
        cppSelf->endMap();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusArgumentFunc_endMapEntry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // endMapEntry()
        cppSelf->endMapEntry();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusArgumentFunc_endStructure(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // endStructure()
        cppSelf->endStructure();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusArgumentFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusArgument::swap(QDBusArgument&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QDBusArgument&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDBusArgument cppArg0_local;
        ::QDBusArgument *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QDBusArgument&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusArgument__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDBusArgument_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDBusArgument_EnumFlagInfo[] = {
    "ElementType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDBusArgument_methods[] = {
    {"appendVariant", reinterpret_cast<PyCFunction>(Sbk_QDBusArgumentFunc_appendVariant), METH_O, nullptr},
    {"asVariant", reinterpret_cast<PyCFunction>(Sbk_QDBusArgumentFunc_asVariant), METH_NOARGS, nullptr},
    {"atEnd", reinterpret_cast<PyCFunction>(Sbk_QDBusArgumentFunc_atEnd), METH_NOARGS, nullptr},
    {"beginArray", reinterpret_cast<PyCFunction>(Sbk_QDBusArgumentFunc_beginArray), METH_VARARGS, nullptr},
    {"beginMap", reinterpret_cast<PyCFunction>(Sbk_QDBusArgumentFunc_beginMap), METH_VARARGS, nullptr},
    {"beginMapEntry", reinterpret_cast<PyCFunction>(Sbk_QDBusArgumentFunc_beginMapEntry), METH_NOARGS, nullptr},
    {"beginStructure", reinterpret_cast<PyCFunction>(Sbk_QDBusArgumentFunc_beginStructure), METH_NOARGS, nullptr},
    {"currentSignature", reinterpret_cast<PyCFunction>(Sbk_QDBusArgumentFunc_currentSignature), METH_NOARGS, nullptr},
    {"currentType", reinterpret_cast<PyCFunction>(Sbk_QDBusArgumentFunc_currentType), METH_NOARGS, nullptr},
    {"endArray", reinterpret_cast<PyCFunction>(Sbk_QDBusArgumentFunc_endArray), METH_NOARGS, nullptr},
    {"endMap", reinterpret_cast<PyCFunction>(Sbk_QDBusArgumentFunc_endMap), METH_NOARGS, nullptr},
    {"endMapEntry", reinterpret_cast<PyCFunction>(Sbk_QDBusArgumentFunc_endMapEntry), METH_NOARGS, nullptr},
    {"endStructure", reinterpret_cast<PyCFunction>(Sbk_QDBusArgumentFunc_endStructure), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QDBusArgumentFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDBusArgument__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QDBusArgumentFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QDBusArgument::operator<<(bool)->QDBusArgument&
        // 1: QDBusArgument::operator<<(QByteArray)->QDBusArgument&
        // 2: QDBusArgument::operator<<(QDBusObjectPath)->QDBusArgument&
        // 3: QDBusArgument::operator<<(QDBusSignature)->QDBusArgument&
        // 4: QDBusArgument::operator<<(QDBusUnixFileDescriptor)->QDBusArgument&
        // 5: QDBusArgument::operator<<(QDBusVariant)->QDBusArgument&
        // 6: QDBusArgument::operator<<(QDate)->QDBusArgument&
        // 7: QDBusArgument::operator<<(QDateTime)->QDBusArgument&
        // 8: QDBusArgument::operator<<(QHash<QString,QVariant>)->QDBusArgument&
        // 9: QDBusArgument::operator<<(QLine)->QDBusArgument&
        // 10: QDBusArgument::operator<<(QLineF)->QDBusArgument&
        // 11: QDBusArgument::operator<<(QList<QVariant>)->QDBusArgument&
        // 12: QDBusArgument::operator<<(QMap<QString,QVariant>)->QDBusArgument&
        // 13: QDBusArgument::operator<<(QPoint)->QDBusArgument&
        // 14: QDBusArgument::operator<<(QPointF)->QDBusArgument&
        // 15: QDBusArgument::operator<<(QRect)->QDBusArgument&
        // 16: QDBusArgument::operator<<(QRectF)->QDBusArgument&
        // 17: QDBusArgument::operator<<(QSize)->QDBusArgument&
        // 18: QDBusArgument::operator<<(QSizeF)->QDBusArgument&
        // 19: QDBusArgument::operator<<(QString)->QDBusArgument&
        // 20: QDBusArgument::operator<<(QStringList)->QDBusArgument&
        // 21: QDBusArgument::operator<<(QTime)->QDBusArgument&
        // 22: QDBusArgument::operator<<(double)->QDBusArgument&
        // 23: QDBusArgument::operator<<(int)->QDBusArgument&
        // 24: QDBusArgument::operator<<(qlonglong)->QDBusArgument&
        // 25: QDBusArgument::operator<<(qulonglong)->QDBusArgument&
        // 26: QDBusArgument::operator<<(short)->QDBusArgument&
        // 27: QDBusArgument::operator<<(uchar)->QDBusArgument&
        // 28: QDBusArgument::operator<<(uint)->QDBusArgument&
        // 29: QDBusArgument::operator<<(ushort)->QDBusArgument&
        if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArg)))) {
            overloadId = 29; // operator<<(ushort)
        } else if (!isReverse
            && SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArg)))) {
            overloadId = 27; // operator<<(uchar)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qulonglong>(), (pyArg)))) {
            overloadId = 25; // operator<<(qulonglong)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
            overloadId = 28; // operator<<(uint)
        } else if (!isReverse
            && PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
            overloadId = 22; // operator<<(double)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArg)))) {
            overloadId = 21; // operator<<(QDBusArgument&,QTime)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
            overloadId = 20; // operator<<(QStringList)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
            overloadId = 17; // operator<<(QDBusArgument&,QSize)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
            overloadId = 18; // operator<<(QDBusArgument&,QSizeF)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArg)))) {
            overloadId = 15; // operator<<(QDBusArgument&,QRect)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
            overloadId = 16; // operator<<(QDBusArgument&,QRectF)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
            overloadId = 13; // operator<<(QDBusArgument&,QPoint)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
            overloadId = 14; // operator<<(QDBusArgument&,QPointF)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), (pyArg)))) {
            overloadId = 9; // operator<<(QDBusArgument&,QLine)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), (pyArg)))) {
            overloadId = 10; // operator<<(QDBusArgument&,QLineF)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDBusTypeConverters[SBK_QtDBus_QList_QVariant_IDX], (pyArg)))) {
            overloadId = 11; // operator<<(QDBusArgument&,QList<QVariant>)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
            overloadId = 19; // operator<<(QString)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDBusTypeConverters[SBK_QtDBus_QMap_QString_QVariant_IDX], (pyArg)))) {
            overloadId = 12; // operator<<(QDBusArgument&,QMap<QString,QVariant>)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDBusTypeConverters[SBK_QtDBus_QHash_QString_QVariant_IDX], (pyArg)))) {
            overloadId = 8; // operator<<(QDBusArgument&,QHash<QString,QVariant>)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
            overloadId = 7; // operator<<(QDBusArgument&,QDateTime)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
            overloadId = 6; // operator<<(QDBusArgument&,QDate)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]), (pyArg)))) {
            overloadId = 5; // operator<<(QDBusVariant)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), (pyArg)))) {
            overloadId = 4; // operator<<(QDBusUnixFileDescriptor)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]), (pyArg)))) {
            overloadId = 3; // operator<<(QDBusSignature)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]), (pyArg)))) {
            overloadId = 2; // operator<<(QDBusObjectPath)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
            overloadId = 1; // operator<<(QByteArray)
        } else if (!isReverse
            && PyBool_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
            overloadId = 0; // operator<<(bool)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qlonglong>(), (pyArg)))) {
            overloadId = 24; // operator<<(qlonglong)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
            overloadId = 23; // operator<<(int)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArg)))) {
            overloadId = 26; // operator<<(short)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]);

        // Call function/method
        switch (overloadId) {
            case 0: // operator<<(bool arg)
            {
                bool cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(bool)
                    QDBusArgument & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 1: // operator<<(const QByteArray &arg)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QByteArray cppArg0_local;
                ::QByteArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QByteArray)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 2: // operator<<(const QDBusObjectPath &arg)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDBusObjectPath cppArg0_local;
                ::QDBusObjectPath *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusObjectPath)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 3: // operator<<(const QDBusSignature &arg)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDBusSignature *cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusSignature)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 4: // operator<<(const QDBusUnixFileDescriptor &arg)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDBusUnixFileDescriptor cppArg0_local;
                ::QDBusUnixFileDescriptor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusUnixFileDescriptor)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 5: // operator<<(const QDBusVariant &arg)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDBusVariant cppArg0_local;
                ::QDBusVariant *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusVariant)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 6: // operator<<(const QDate &date)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDate cppArg0_local;
                ::QDate *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusArgument&,QDate)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 7: // operator<<(const QDateTime &dt)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDateTime cppArg0_local;
                ::QDateTime *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusArgument&,QDateTime)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 8: // operator<<(const QHash<QString,QVariant> &map)
            {
                ::QHash<QString,QVariant> cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusArgument&,QHash<QString,QVariant>)
                    QDBusArgument & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 9: // operator<<(const QLine &line)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLine cppArg0_local;
                ::QLine *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusArgument&,QLine)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 10: // operator<<(const QLineF &line)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLineF cppArg0_local;
                ::QLineF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusArgument&,QLineF)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 11: // operator<<(const QList<QVariant> &list)
            {
                ::QList<QVariant> cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusArgument&,QList<QVariant>)
                    QDBusArgument & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 12: // operator<<(const QMap<QString,QVariant> &map)
            {
                ::QMap<QString,QVariant> cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusArgument&,QMap<QString,QVariant>)
                    QDBusArgument & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 13: // operator<<(const QPoint &pt)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPoint cppArg0_local;
                ::QPoint *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusArgument&,QPoint)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 14: // operator<<(const QPointF &pt)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPointF cppArg0_local;
                ::QPointF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusArgument&,QPointF)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 15: // operator<<(const QRect &rect)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRect cppArg0_local;
                ::QRect *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusArgument&,QRect)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 16: // operator<<(const QRectF &rect)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRectF cppArg0_local;
                ::QRectF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusArgument&,QRectF)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 17: // operator<<(const QSize &size)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSize cppArg0_local;
                ::QSize *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusArgument&,QSize)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 18: // operator<<(const QSizeF &size)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSizeF cppArg0_local;
                ::QSizeF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusArgument&,QSizeF)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 19: // operator<<(const QString &arg)
            {
                ::QString cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QString)
                    QDBusArgument & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 20: // operator<<(const QStringList &arg)
            {
                ::QStringList cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QStringList)
                    QDBusArgument & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 21: // operator<<(const QTime &time)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTime cppArg0_local;
                ::QTime *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDBusArgument&,QTime)
                    QDBusArgument & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 22: // operator<<(double arg)
            {
                double cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(double)
                    QDBusArgument & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 23: // operator<<(int arg)
            {
                int cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(int)
                    QDBusArgument & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 24: // operator<<(qlonglong arg)
            {
                qlonglong cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(qlonglong)
                    QDBusArgument & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 25: // operator<<(qulonglong arg)
            {
                qulonglong cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(qulonglong)
                    QDBusArgument & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 26: // operator<<(short arg)
            {
                short cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(short)
                    QDBusArgument & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 27: // operator<<(uchar arg)
            {
                uchar cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(uchar)
                    QDBusArgument & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 28: // operator<<(uint arg)
            {
                uint cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(uint)
                    QDBusArgument & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 29: // operator<<(ushort arg)
            {
                ushort cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(ushort)
                    QDBusArgument & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusArgumentFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QDBusArgument::operator>>(QByteArray&)const->const QDBusArgument&
        // 1: QDBusArgument::operator>>(QDBusObjectPath&)const->const QDBusArgument&
        // 2: QDBusArgument::operator>>(QDBusSignature&)const->const QDBusArgument&
        // 3: QDBusArgument::operator>>(QDBusUnixFileDescriptor&)const->const QDBusArgument&
        // 4: QDBusArgument::operator>>(QDBusVariant&)const->const QDBusArgument&
        // 5: QDBusArgument::operator>>(QDate&)->const QDBusArgument&
        // 6: QDBusArgument::operator>>(QDateTime&)->const QDBusArgument&
        // 7: QDBusArgument::operator>>(QLine&)->const QDBusArgument&
        // 8: QDBusArgument::operator>>(QLineF&)->const QDBusArgument&
        // 9: QDBusArgument::operator>>(QPoint&)->const QDBusArgument&
        // 10: QDBusArgument::operator>>(QPointF&)->const QDBusArgument&
        // 11: QDBusArgument::operator>>(QRect&)->const QDBusArgument&
        // 12: QDBusArgument::operator>>(QRectF&)->const QDBusArgument&
        // 13: QDBusArgument::operator>>(QSize&)->const QDBusArgument&
        // 14: QDBusArgument::operator>>(QSizeF&)->const QDBusArgument&
        // 15: QDBusArgument::operator>>(QString&)const->const QDBusArgument&
        // 16: QDBusArgument::operator>>(QStringList&)const->const QDBusArgument&
        // 17: QDBusArgument::operator>>(QTime&)->const QDBusArgument&
        // 18: QDBusArgument::operator>>(QVariant&)->const QDBusArgument&
        // 19: QDBusArgument::operator>>(bool&)const->const QDBusArgument&
        // 20: QDBusArgument::operator>>(double&)const->const QDBusArgument&
        // 21: QDBusArgument::operator>>(int&)const->const QDBusArgument&
        // 22: QDBusArgument::operator>>(qlonglong&)const->const QDBusArgument&
        // 23: QDBusArgument::operator>>(qulonglong&)const->const QDBusArgument&
        // 24: QDBusArgument::operator>>(short&)const->const QDBusArgument&
        // 25: QDBusArgument::operator>>(uchar&)const->const QDBusArgument&
        // 26: QDBusArgument::operator>>(uint&)const->const QDBusArgument&
        // 27: QDBusArgument::operator>>(ushort&)const->const QDBusArgument&
        if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArg)))) {
            overloadId = 27; // operator>>(ushort&)const
        } else if (!isReverse
            && SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArg)))) {
            overloadId = 25; // operator>>(uchar&)const
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qulonglong>(), (pyArg)))) {
            overloadId = 23; // operator>>(qulonglong&)const
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
            overloadId = 26; // operator>>(uint&)const
        } else if (!isReverse
            && PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
            overloadId = 20; // operator>>(double&)const
        } else if (!isReverse
            && PyBool_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
            overloadId = 19; // operator>>(bool&)const
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qlonglong>(), (pyArg)))) {
            overloadId = 22; // operator>>(qlonglong&)const
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
            overloadId = 21; // operator>>(int&)const
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArg)))) {
            overloadId = 24; // operator>>(short&)const
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArg)))) {
            overloadId = 17; // operator>>(QDBusArgument,QTime&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
            overloadId = 16; // operator>>(QStringList&)const
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
            overloadId = 15; // operator>>(QString&)const
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
            overloadId = 13; // operator>>(QDBusArgument,QSize&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
            overloadId = 14; // operator>>(QDBusArgument,QSizeF&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArg)))) {
            overloadId = 11; // operator>>(QDBusArgument,QRect&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
            overloadId = 12; // operator>>(QDBusArgument,QRectF&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
            overloadId = 9; // operator>>(QDBusArgument,QPoint&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
            overloadId = 10; // operator>>(QDBusArgument,QPointF&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), (pyArg)))) {
            overloadId = 7; // operator>>(QDBusArgument,QLine&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), (pyArg)))) {
            overloadId = 8; // operator>>(QDBusArgument,QLineF&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
            overloadId = 6; // operator>>(QDBusArgument,QDateTime&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
            overloadId = 5; // operator>>(QDBusArgument,QDate&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]), (pyArg)))) {
            overloadId = 4; // operator>>(QDBusVariant&)const
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), (pyArg)))) {
            overloadId = 3; // operator>>(QDBusUnixFileDescriptor&)const
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]), (pyArg)))) {
            overloadId = 2; // operator>>(QDBusSignature&)const
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]), (pyArg)))) {
            overloadId = 1; // operator>>(QDBusObjectPath&)const
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QByteArray&)const
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
            overloadId = 18; // operator>>(QDBusArgument,QVariant&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]);

        // Call function/method
        switch (overloadId) {
            case 0: // operator>>(QByteArray &arg) const
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QByteArray cppArg0_local;
                ::QByteArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QByteArray&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 1: // operator>>(QDBusObjectPath &arg) const
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDBusObjectPath cppArg0_local;
                ::QDBusObjectPath *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusObjectPath&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 2: // operator>>(QDBusSignature &arg) const
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDBusSignature *cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusSignature&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 3: // operator>>(QDBusUnixFileDescriptor &arg) const
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDBusUnixFileDescriptor cppArg0_local;
                ::QDBusUnixFileDescriptor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusUnixFileDescriptor&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 4: // operator>>(QDBusVariant &arg) const
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDBusVariant cppArg0_local;
                ::QDBusVariant *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusVariant&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 5: // operator>>(QDate &date)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDate cppArg0_local;
                ::QDate *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusArgument,QDate&)
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 6: // operator>>(QDateTime &dt)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDateTime cppArg0_local;
                ::QDateTime *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusArgument,QDateTime&)
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 7: // operator>>(QLine &line)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLine cppArg0_local;
                ::QLine *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusArgument,QLine&)
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 8: // operator>>(QLineF &line)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLineF cppArg0_local;
                ::QLineF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusArgument,QLineF&)
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 9: // operator>>(QPoint &pt)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPoint cppArg0_local;
                ::QPoint *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusArgument,QPoint&)
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 10: // operator>>(QPointF &pt)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPointF cppArg0_local;
                ::QPointF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusArgument,QPointF&)
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 11: // operator>>(QRect &rect)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRect cppArg0_local;
                ::QRect *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusArgument,QRect&)
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 12: // operator>>(QRectF &rect)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRectF cppArg0_local;
                ::QRectF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusArgument,QRectF&)
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 13: // operator>>(QSize &size)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSize cppArg0_local;
                ::QSize *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusArgument,QSize&)
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 14: // operator>>(QSizeF &size)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSizeF cppArg0_local;
                ::QSizeF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusArgument,QSizeF&)
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 15: // operator>>(QString &arg) const
            {
                ::QString cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QString&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 16: // operator>>(QStringList &arg) const
            {
                ::QStringList cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QStringList&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 17: // operator>>(QTime &time)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTime cppArg0_local;
                ::QTime *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusArgument,QTime&)
                    const QDBusArgument & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 18: // operator>>(QVariant &v)
            {
                ::QVariant cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDBusArgument,QVariant&)
                    const QDBusArgument & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 19: // operator>>(bool &arg) const
            {
                bool cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(bool&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 20: // operator>>(double &arg) const
            {
                double cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(double&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 21: // operator>>(int &arg) const
            {
                int cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(int&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 22: // operator>>(qlonglong &arg) const
            {
                qlonglong cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(qlonglong&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 23: // operator>>(qulonglong &arg) const
            {
                qulonglong cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(qulonglong&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 24: // operator>>(short &arg) const
            {
                short cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(short&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 25: // operator>>(uchar &arg) const
            {
                uchar cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(uchar&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 26: // operator>>(uint &arg) const
            {
                uint cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(uint&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
            case 27: // operator>>(ushort &arg) const
            {
                ushort cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(ushort&)const
                    const QDBusArgument & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), &cppResult);
                }
                break;
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

} // extern "C"

static int Sbk_QDBusArgument_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDBusArgument_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDBusArgument_Type = nullptr;
static PyTypeObject *Sbk_QDBusArgument_TypeF(void)
{
    return _Sbk_QDBusArgument_Type;
}

static PyType_Slot Sbk_QDBusArgument_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDBusArgument_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDBusArgument_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDBusArgument_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDBusArgument_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QDBusArgumentFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QDBusArgumentFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDBusArgument_spec = {
    "2:PySide6.QtDBus.QDBusArgument",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDBusArgument_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDBusArgument_ElementType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDBusArgument::ElementType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDBusArgument::ElementType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDBusArgument_ElementType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_ElementType_IDX])))
        return Enum_PythonToCpp_QDBusArgument_ElementType;
    return {};
}

static PyObject *QDBusArgument_ElementType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDBusArgument::ElementType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDBusArgument::ElementType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_ElementType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDBusArgument_PythonToCpp_QDBusArgument_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDBusArgument_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDBusArgument_PythonToCpp_QDBusArgument_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusArgument_TypeF()))
        return QDBusArgument_PythonToCpp_QDBusArgument_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDBusArgument_PTR_CppToPython_QDBusArgument(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDBusArgument_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDBusArgument_COPY_CppToPython_QDBusArgument(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDBusArgument *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDBusArgument_TypeF(), new ::QDBusArgument(*source), true, true);
}

// Python to C++ copy conversion.
static void QDBusArgument_PythonToCpp_QDBusArgument_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDBusArgument *>(cppOut) = *reinterpret_cast< ::QDBusArgument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDBusArgument_PythonToCpp_QDBusArgument_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusArgument_TypeF()))
        return QDBusArgument_PythonToCpp_QDBusArgument_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDBusArgument_SignatureStrings[] = {
    "1:PySide6.QtDBus.QDBusArgument(self)",
    "0:PySide6.QtDBus.QDBusArgument(self,other:PySide6.QtDBus.QDBusArgument)",
    "PySide6.QtDBus.QDBusArgument.appendVariant(self,v:QVariant)",
    "PySide6.QtDBus.QDBusArgument.asVariant(self)->QVariant",
    "PySide6.QtDBus.QDBusArgument.atEnd(self)->bool",
    "2:PySide6.QtDBus.QDBusArgument.beginArray(self)",
    "1:PySide6.QtDBus.QDBusArgument.beginArray(self,elementMetaType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])",
    "0:PySide6.QtDBus.QDBusArgument.beginArray(self,elementMetaTypeId:int)",
    "2:PySide6.QtDBus.QDBusArgument.beginMap(self)",
    "1:PySide6.QtDBus.QDBusArgument.beginMap(self,keyMetaType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type],valueMetaType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])",
    "0:PySide6.QtDBus.QDBusArgument.beginMap(self,keyMetaTypeId:int,valueMetaTypeId:int)",
    "PySide6.QtDBus.QDBusArgument.beginMapEntry(self)",
    "PySide6.QtDBus.QDBusArgument.beginStructure(self)",
    "PySide6.QtDBus.QDBusArgument.currentSignature(self)->QString",
    "PySide6.QtDBus.QDBusArgument.currentType(self)->PySide6.QtDBus.QDBusArgument.ElementType",
    "PySide6.QtDBus.QDBusArgument.endArray(self)",
    "PySide6.QtDBus.QDBusArgument.endMap(self)",
    "PySide6.QtDBus.QDBusArgument.endMapEntry(self)",
    "PySide6.QtDBus.QDBusArgument.endStructure(self)",
    "PySide6.QtDBus.QDBusArgument.swap(self,other:PySide6.QtDBus.QDBusArgument)",
    "PySide6.QtDBus.QDBusArgument.__copy__(self)->typing.Self",
    "29:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:bool)->PySide6.QtDBus.QDBusArgument",
    "28:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtDBus.QDBusArgument",
    "27:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:PySide6.QtDBus.QDBusObjectPath)->PySide6.QtDBus.QDBusArgument",
    "26:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:PySide6.QtDBus.QDBusSignature)->PySide6.QtDBus.QDBusArgument",
    "25:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:PySide6.QtDBus.QDBusUnixFileDescriptor)->PySide6.QtDBus.QDBusArgument",
    "24:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:PySide6.QtDBus.QDBusVariant)->PySide6.QtDBus.QDBusArgument",
    "23:PySide6.QtDBus.QDBusArgument.__lshift__(self,date:PySide6.QtCore.QDate)->PySide6.QtDBus.QDBusArgument",
    "22:PySide6.QtDBus.QDBusArgument.__lshift__(self,dt:PySide6.QtCore.QDateTime)->PySide6.QtDBus.QDBusArgument",
    "21:PySide6.QtDBus.QDBusArgument.__lshift__(self,map:QHash[QString, QVariant])->PySide6.QtDBus.QDBusArgument",
    "20:PySide6.QtDBus.QDBusArgument.__lshift__(self,line:PySide6.QtCore.QLine)->PySide6.QtDBus.QDBusArgument",
    "19:PySide6.QtDBus.QDBusArgument.__lshift__(self,line:typing.Union[PySide6.QtCore.QLineF, PySide6.QtCore.QLine])->PySide6.QtDBus.QDBusArgument",
    "18:PySide6.QtDBus.QDBusArgument.__lshift__(self,list:QList[QVariant])->PySide6.QtDBus.QDBusArgument",
    "17:PySide6.QtDBus.QDBusArgument.__lshift__(self,map:QMap[QString, QVariant])->PySide6.QtDBus.QDBusArgument",
    "16:PySide6.QtDBus.QDBusArgument.__lshift__(self,pt:PySide6.QtCore.QPoint)->PySide6.QtDBus.QDBusArgument",
    "15:PySide6.QtDBus.QDBusArgument.__lshift__(self,pt:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint])->PySide6.QtDBus.QDBusArgument",
    "14:PySide6.QtDBus.QDBusArgument.__lshift__(self,rect:PySide6.QtCore.QRect)->PySide6.QtDBus.QDBusArgument",
    "13:PySide6.QtDBus.QDBusArgument.__lshift__(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])->PySide6.QtDBus.QDBusArgument",
    "12:PySide6.QtDBus.QDBusArgument.__lshift__(self,size:PySide6.QtCore.QSize)->PySide6.QtDBus.QDBusArgument",
    "11:PySide6.QtDBus.QDBusArgument.__lshift__(self,size:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])->PySide6.QtDBus.QDBusArgument",
    "10:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:QString)->PySide6.QtDBus.QDBusArgument",
    "9:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:QStringList)->PySide6.QtDBus.QDBusArgument",
    "8:PySide6.QtDBus.QDBusArgument.__lshift__(self,time:PySide6.QtCore.QTime)->PySide6.QtDBus.QDBusArgument",
    "7:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:double)->PySide6.QtDBus.QDBusArgument",
    "6:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:int)->PySide6.QtDBus.QDBusArgument",
    "5:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:qlonglong)->PySide6.QtDBus.QDBusArgument",
    "4:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:qulonglong)->PySide6.QtDBus.QDBusArgument",
    "3:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:short)->PySide6.QtDBus.QDBusArgument",
    "2:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:uchar)->PySide6.QtDBus.QDBusArgument",
    "1:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:uint)->PySide6.QtDBus.QDBusArgument",
    "0:PySide6.QtDBus.QDBusArgument.__lshift__(self,arg:ushort)->PySide6.QtDBus.QDBusArgument",
    "27:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtDBus.QDBusArgument",
    "26:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:PySide6.QtDBus.QDBusObjectPath)->PySide6.QtDBus.QDBusArgument",
    "25:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:PySide6.QtDBus.QDBusSignature)->PySide6.QtDBus.QDBusArgument",
    "24:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:PySide6.QtDBus.QDBusUnixFileDescriptor)->PySide6.QtDBus.QDBusArgument",
    "23:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:PySide6.QtDBus.QDBusVariant)->PySide6.QtDBus.QDBusArgument",
    "22:PySide6.QtDBus.QDBusArgument.__rshift__(self,date:PySide6.QtCore.QDate)->PySide6.QtDBus.QDBusArgument",
    "21:PySide6.QtDBus.QDBusArgument.__rshift__(self,dt:PySide6.QtCore.QDateTime)->PySide6.QtDBus.QDBusArgument",
    "20:PySide6.QtDBus.QDBusArgument.__rshift__(self,line:PySide6.QtCore.QLine)->PySide6.QtDBus.QDBusArgument",
    "19:PySide6.QtDBus.QDBusArgument.__rshift__(self,line:typing.Union[PySide6.QtCore.QLineF, PySide6.QtCore.QLine])->PySide6.QtDBus.QDBusArgument",
    "18:PySide6.QtDBus.QDBusArgument.__rshift__(self,pt:PySide6.QtCore.QPoint)->PySide6.QtDBus.QDBusArgument",
    "17:PySide6.QtDBus.QDBusArgument.__rshift__(self,pt:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint])->PySide6.QtDBus.QDBusArgument",
    "16:PySide6.QtDBus.QDBusArgument.__rshift__(self,rect:PySide6.QtCore.QRect)->PySide6.QtDBus.QDBusArgument",
    "15:PySide6.QtDBus.QDBusArgument.__rshift__(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])->PySide6.QtDBus.QDBusArgument",
    "14:PySide6.QtDBus.QDBusArgument.__rshift__(self,size:PySide6.QtCore.QSize)->PySide6.QtDBus.QDBusArgument",
    "13:PySide6.QtDBus.QDBusArgument.__rshift__(self,size:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])->PySide6.QtDBus.QDBusArgument",
    "12:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:QString)->PySide6.QtDBus.QDBusArgument",
    "11:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:QStringList)->PySide6.QtDBus.QDBusArgument",
    "10:PySide6.QtDBus.QDBusArgument.__rshift__(self,time:PySide6.QtCore.QTime)->PySide6.QtDBus.QDBusArgument",
    "9:PySide6.QtDBus.QDBusArgument.__rshift__(self,v:QVariant)->PySide6.QtDBus.QDBusArgument",
    "8:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:bool)->PySide6.QtDBus.QDBusArgument",
    "7:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:double)->PySide6.QtDBus.QDBusArgument",
    "6:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:int)->PySide6.QtDBus.QDBusArgument",
    "5:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:qlonglong)->PySide6.QtDBus.QDBusArgument",
    "4:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:qulonglong)->PySide6.QtDBus.QDBusArgument",
    "3:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:short)->PySide6.QtDBus.QDBusArgument",
    "2:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:uchar)->PySide6.QtDBus.QDBusArgument",
    "1:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:uint)->PySide6.QtDBus.QDBusArgument",
    "0:PySide6.QtDBus.QDBusArgument.__rshift__(self,arg:ushort)->PySide6.QtDBus.QDBusArgument",
    nullptr}; // Sentinel
#else
static constexpr size_t QDBusArgument_SignatureByteSize = 800;
static constexpr uint8_t QDBusArgument_SignatureBytes[800] = {
    0x78, 0xda, 0xcd, 0x59, 0x51, 0x6f, 0xda, 0x30, 0x10, 0x7e, 0xe7, 0x57, 0xf0, 0xb8, 0x4e, 0x59,
    0x84, 0xa1, 0x94, 0x36, 0x0f, 0x93, 0xda, 0xb5, 0xd5, 0x26, 0xad, 0x5a, 0x19, 0xdd, 0x5e, 0xaa,
    0x0a, 0x99, 0xe0, 0x06, 0x6f, 0x69, 0x92, 0x5e, 0x9c, 0x6e, 0xd9, 0xaf, 0x9f, 0x4d, 0xc9, 0x60,
    0x83, 0xe5, 0x7c, 0x26, 0xd1, 0xf6, 0x00, 0x28, 0xc7, 0xdd, 0x7d, 0xbe, 0x3b, 0xdf, 0xf9, 0x33,
    0xb0, 0xe0, 0xba, 0x9c, 0xc8, 0xb9, 0x38, 0xf2, 0xc7, 0xea, 0xfc, 0xac, 0xc8, 0xfd, 0xb1, 0x79,
    0x3f, 0x85, 0xa8, 0x78, 0x10, 0x89, 0x7a, 0x91, 0x8b, 0xf8, 0xfe, 0xa0, 0xd3, 0xc3, 0x95, 0xbc,
    0x54, 0x2d, 0x04, 0xd4, 0xea, 0x1d, 0x74, 0xea, 0xbe, 0xf5, 0x79, 0x96, 0x89, 0x64, 0xfe, 0x99,
    0x83, 0xe4, 0x95, 0xcf, 0xa7, 0x60, 0xbc, 0x7a, 0xc6, 0x6c, 0xf3, 0x4d, 0xbb, 0x83, 0x57, 0xaf,
    0x2b, 0x3b, 0xc4, 0x4c, 0x5d, 0x24, 0xf3, 0xca, 0x64, 0x96, 0xa6, 0x71, 0xa7, 0x5f, 0x1b, 0x81,
    0x3f, 0x13, 0x91, 0x4c, 0x4e, 0x01, 0x78, 0xb9, 0xca, 0x0c, 0x23, 0xe9, 0x7b, 0x22, 0x16, 0x46,
    0x7e, 0x25, 0x14, 0xbf, 0x29, 0x33, 0x11, 0xa8, 0x32, 0x93, 0x49, 0xe4, 0x7f, 0x4a, 0x64, 0x9a,
    0xdc, 0xae, 0x3d, 0xbd, 0x49, 0x41, 0xf8, 0xe3, 0x4a, 0xcb, 0xeb, 0xfe, 0xed, 0x1b, 0xdf, 0xbc,
    0xdd, 0x61, 0xf5, 0xc1, 0x56, 0xf1, 0x6e, 0x1e, 0x48, 0x93, 0x61, 0x9b, 0xd8, 0xaf, 0x78, 0x46,
    0x88, 0xbc, 0xd2, 0xf6, 0xbe, 0x8a, 0xb2, 0xd9, 0x98, 0xbd, 0x27, 0x1e, 0x17, 0xe2, 0x5f, 0xe4,
    0x71, 0x57, 0x4c, 0xcf, 0x19, 0xfc, 0x7d, 0x4d, 0x55, 0x56, 0xad, 0x3c, 0x5e, 0x24, 0x0a, 0xaa,
    0x2d, 0x85, 0x1b, 0x4c, 0x14, 0x14, 0xa1, 0x2a, 0x40, 0xd8, 0x58, 0x84, 0x05, 0x80, 0xfe, 0x9c,
    0xc8, 0x28, 0xe1, 0x6b, 0x1b, 0xdd, 0x21, 0xda, 0x8b, 0xce, 0x99, 0x95, 0xb1, 0x89, 0xa7, 0xb2,
    0xab, 0xd5, 0xbf, 0x78, 0xde, 0x59, 0x46, 0xbf, 0xde, 0xb1, 0xee, 0xf4, 0xcd, 0x36, 0xc2, 0x74,
    0xd7, 0xdb, 0xce, 0x42, 0xd3, 0x3a, 0x99, 0x5a, 0x9d, 0x94, 0xca, 0xfc, 0x5b, 0x55, 0xfb, 0xbd,
    0x87, 0xdd, 0x74, 0x1a, 0xa6, 0x59, 0x39, 0x9d, 0x56, 0x59, 0x5d, 0x6d, 0xe0, 0x89, 0x7e, 0xea,
    0xf4, 0x4f, 0x02, 0xc4, 0x36, 0xce, 0x17, 0xf2, 0x5e, 0xad, 0xac, 0x3d, 0x0e, 0x51, 0x60, 0x86,
    0x17, 0x52, 0x9c, 0x4e, 0xff, 0x98, 0xee, 0xb7, 0xb6, 0xb1, 0xce, 0x4a, 0x25, 0x96, 0x55, 0xf4,
    0xba, 0xe1, 0x82, 0xc3, 0xcb, 0x3b, 0x74, 0x05, 0x23, 0xfa, 0x0a, 0x76, 0x19, 0x7c, 0x98, 0x7d,
    0x11, 0xa1, 0xba, 0xe6, 0x6a, 0x81, 0x22, 0x1e, 0x35, 0x83, 0xf8, 0xab, 0x7d, 0x50, 0xc0, 0x61,
    0x33, 0x80, 0x3a, 0xe3, 0xdf, 0x2f, 0x65, 0x2c, 0xce, 0x45, 0x1e, 0x82, 0xcc, 0x54, 0x0a, 0x28,
    0xf2, 0x61, 0x33, 0xc8, 0xd5, 0x89, 0x8b, 0xc1, 0x0d, 0x68, 0x70, 0x73, 0xae, 0x44, 0xf0, 0xe7,
    0x0e, 0x3a, 0xd7, 0x42, 0x14, 0xa8, 0x4f, 0x04, 0x52, 0x3b, 0x61, 0x6e, 0xe4, 0x03, 0x0e, 0xc5,
    0x68, 0x50, 0x0f, 0x3c, 0x0b, 0xc6, 0x6f, 0x79, 0xbe, 0xb8, 0x5d, 0x4d, 0x53, 0xaf, 0x5b, 0x11,
    0x0f, 0xbc, 0x17, 0x7a, 0x34, 0xac, 0x58, 0x26, 0xdb, 0xf9, 0x7b, 0xaf, 0x85, 0x18, 0x10, 0x3b,
    0x71, 0x00, 0xaa, 0xed, 0x7b, 0x83, 0x7a, 0xb9, 0x7d, 0x9a, 0x1a, 0x31, 0x1a, 0x36, 0x3b, 0xa6,
    0xae, 0x26, 0x57, 0x81, 0x76, 0x9d, 0xab, 0x5b, 0xeb, 0xd4, 0xb2, 0x91, 0x43, 0x19, 0xf5, 0xc1,
    0xe1, 0x50, 0x45, 0x46, 0x9c, 0x2f, 0xd9, 0xf6, 0xe6, 0xbc, 0x4e, 0x25, 0xde, 0x6d, 0x6c, 0x48,
    0xc6, 0xa9, 0x2d, 0xe1, 0x12, 0x74, 0x47, 0x0d, 0x97, 0x72, 0x3c, 0x6a, 0xe2, 0xa8, 0x01, 0x3d,
    0xad, 0xb7, 0xe2, 0xfe, 0xa8, 0x85, 0x28, 0xd0, 0xc0, 0x01, 0xa8, 0x36, 0x70, 0x83, 0xba, 0x23,
    0x6e, 0x23, 0xc6, 0xc3, 0x26, 0x4e, 0xa2, 0x5c, 0xfe, 0xd8, 0x6e, 0xd9, 0x89, 0x16, 0xa2, 0x40,
    0xcc, 0x01, 0xa8, 0x36, 0x6c, 0x83, 0xba, 0x23, 0x6c, 0x23, 0xc6, 0xc3, 0xee, 0xd1, 0x0f, 0x96,
    0x55, 0x27, 0x61, 0xae, 0x4f, 0x9c, 0x3d, 0x9b, 0x89, 0x80, 0x79, 0x27, 0x8e, 0x1a, 0xa5, 0x4f,
    0x88, 0xad, 0x72, 0xd9, 0x1c, 0x1b, 0x0e, 0xac, 0x66, 0x9e, 0x16, 0xb3, 0x18, 0x75, 0xec, 0x40,
    0x5e, 0x2c, 0x66, 0x89, 0x03, 0x43, 0x79, 0x8c, 0xd3, 0x24, 0x32, 0x2f, 0xcc, 0xb7, 0x03, 0x07,
    0x79, 0x2c, 0x6c, 0x9d, 0x0f, 0xe8, 0xce, 0xf3, 0x45, 0x0a, 0x38, 0x95, 0xa1, 0xfb, 0x2d, 0x0c,
    0xe1, 0x45, 0x1b, 0xc7, 0xc1, 0xaf, 0x45, 0xfd, 0x1c, 0xda, 0xb1, 0xb0, 0xcb, 0x03, 0xba, 0x91,
    0xa1, 0xed, 0x0b, 0xc2, 0x11, 0x7d, 0x05, 0x7b, 0x5e, 0x10, 0x86, 0xcd, 0x20, 0xda, 0x5f, 0x10,
    0x0e, 0x9b, 0x01, 0x74, 0xb8, 0x20, 0x0c, 0x9a, 0x41, 0xb6, 0xbd, 0x20, 0xf4, 0x69, 0x70, 0xee,
    0x17, 0x04, 0x46, 0x04, 0xda, 0xe3, 0x82, 0xd0, 0xa3, 0x41, 0xb5, 0x48, 0xda, 0xe1, 0xbf, 0x22,
    0xed, 0xd0, 0x0c, 0xcb, 0x1d, 0x91, 0x71, 0xda, 0x64, 0xb9, 0xc4, 0x61, 0xe4, 0xce, 0x72, 0x87,
    0x0e, 0x40, 0xed, 0xb1, 0x5c, 0xe2, 0x80, 0x72, 0x67, 0xb9, 0x03, 0x07, 0xa0, 0xf6, 0x58, 0x6e,
    0x9f, 0x3e, 0x1d, 0x2d, 0x59, 0x2e, 0x63, 0xce, 0xae, 0x6d, 0x68, 0x2e, 0x23, 0x0e, 0x25, 0x67,
    0x9e, 0x4b, 0x9c, 0x49, 0x1b, 0xff, 0xde, 0xec, 0x4b, 0xd4, 0xc1, 0xe9, 0x07, 0x4f, 0x07, 0x3a,
    0xd3, 0x10, 0x2f, 0x87, 0x56, 0x78, 0x39, 0xb4, 0xc8, 0xcb, 0xa1, 0x4d, 0x5e, 0x0e, 0x2d, 0xf1,
    0x72, 0x68, 0x89, 0x97, 0x43, 0x3b, 0xbc, 0x1c, 0x1c, 0x79, 0xf9, 0x4f, 0x11, 0x7f, 0x6e, 0x21
};
#endif

PyTypeObject *init_QDBusArgument(PyObject *module)
{
    if (SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX].type != nullptr)
        return SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX].type;

    Shiboken::AutoDecRef Sbk_QDBusArgument_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDBusArgument_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDBusArgument",
        "QDBusArgument",
        &Sbk_QDBusArgument_spec,
        &Shiboken::callCppDestructor< ::QDBusArgument >,
        Sbk_QDBusArgument_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDBusArgument_TypeF(); // references _Sbk_QDBusArgument_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDBusArgument_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDBusArgument_SignatureBytes, QDBusArgument_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDBusArgument_PropertyStrings);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDBusArgument_PythonToCpp_QDBusArgument_PTR,
        is_QDBusArgument_PythonToCpp_QDBusArgument_PTR_Convertible,
        QDBusArgument_PTR_CppToPython_QDBusArgument,
        QDBusArgument_COPY_CppToPython_QDBusArgument);

    Shiboken::Conversions::registerConverterName(converter, "QDBusArgument");
    Shiboken::Conversions::registerConverterName(converter, "QDBusArgument*");
    Shiboken::Conversions::registerConverterName(converter, "QDBusArgument&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDBusArgument).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDBusArgument_PythonToCpp_QDBusArgument_COPY,
        is_QDBusArgument_PythonToCpp_QDBusArgument_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDBusArgument_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ElementType'.
    const char *ElementType_Initializer[] = {
        "BasicType",
        "VariantType",
        "ArrayType",
        "StructureType",
        "MapType",
        "MapEntryType",
        "UnknownType",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t ElementType_InitializerValues[] = {
        int8_t(QDBusArgument::ElementType::BasicType),     //  0x00  0
        int8_t(QDBusArgument::ElementType::VariantType),   //  0x01  1
        int8_t(QDBusArgument::ElementType::ArrayType),     //  0x02  2
        int8_t(QDBusArgument::ElementType::StructureType), //  0x03  3
        int8_t(QDBusArgument::ElementType::MapType),       //  0x04  4
        int8_t(QDBusArgument::ElementType::MapEntryType),  //  0x05  5
        int8_t(QDBusArgument::ElementType::UnknownType)    // -0x01 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDBusArgument_TypeF(),
        "2:PySide6.QtDBus.QDBusArgument.ElementType",
        ElementType_Initializer, ElementType_InitializerValues);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusArgument_ElementType_IDX].type = EType;
    // Register converter for enum 'QDBusArgument::ElementType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDBusArgument_ElementType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDBusArgument_ElementType,
            is_Enum_PythonToCpp_QDBusArgument_ElementType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDBusArgument::ElementType");
        Shiboken::Conversions::registerConverterAlias(converter, "ElementType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ElementType' enum.

    qRegisterMetaType< ::QDBusArgument >("QDBusArgument");
    qRegisterMetaType< ::QDBusArgument::ElementType >("QDBusArgument::ElementType");

    return pyType;
}
