// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdbus_python.h"

// main header
#include "qdbusconnectioninterface_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtDBus/qdbusconnection.h>
#include <QtDBus/qdbusconnectioninterface.h>
#include <QtDBus/qdbuserror.h>
#include <QtDBus/qdbusmessage.h>
#include <QtDBus/qdbuspendingcall.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qtdbushelper.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QDBusConnectionInterfaceFunc_activatableServiceNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnectionInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activatableServiceNames()const
        QtDBusHelper::QDBusReply* cppResult = new QtDBusHelper::QDBusReply(const_cast<const ::QDBusConnectionInterface *>(cppSelf)->activatableServiceNames());
        pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QtDBusHelper_QDBusReply_IDX]), cppResult, true, true);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionInterfaceFunc_connectNotify(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnectionInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::connectNotify(QMetaMethod)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArg)))) {
        overloadId = 0; // connectNotify(QMetaMethod)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "connectNotify", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMetaMethod cppArg0_local;
        ::QMetaMethod *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // connectNotify(QMetaMethod)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QDBusConnectionInterface::connectNotify(*cppArg0)
                : cppSelf->connectNotify(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusConnectionInterfaceFunc_disconnectNotify(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnectionInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::disconnectNotify(QMetaMethod)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArg)))) {
        overloadId = 0; // disconnectNotify(QMetaMethod)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "disconnectNotify", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMetaMethod cppArg0_local;
        ::QMetaMethod *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // disconnectNotify(QMetaMethod)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QDBusConnectionInterface::disconnectNotify(*cppArg0)
                : cppSelf->disconnectNotify(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusConnectionInterfaceFunc_isServiceRegistered(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnectionInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusConnectionInterface::isServiceRegistered(QString)const->QtDBusHelper::QDBusReply
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // isServiceRegistered(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isServiceRegistered", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isServiceRegistered(QString)const
            QtDBusHelper::QDBusReply* cppResult = new QtDBusHelper::QDBusReply(const_cast<const ::QDBusConnectionInterface *>(cppSelf)->isServiceRegistered(cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QtDBusHelper_QDBusReply_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionInterfaceFunc_registerService(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnectionInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "registerService", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusConnectionInterface::registerService(QString,QDBusConnectionInterface::ServiceQueueOptions,QDBusConnectionInterface::ServiceReplacementOptions)->QtDBusHelper::QDBusReply
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_ServiceQueueOptions_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_ServiceReplacementOptions_IDX])))->converter, (pyArgs[2])))) {
        overloadId = 0; // registerService(QString,QDBusConnectionInterface::ServiceQueueOptions,QDBusConnectionInterface::ServiceReplacementOptions)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "registerService", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QDBusConnectionInterface::ServiceQueueOptions cppArg1{QDBusConnectionInterface::DontQueueService};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QDBusConnectionInterface::ServiceReplacementOptions cppArg2{QDBusConnectionInterface::DontAllowReplacement};
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // registerService(QString,QDBusConnectionInterface::ServiceQueueOptions,QDBusConnectionInterface::ServiceReplacementOptions)
            QtDBusHelper::QDBusReply* cppResult = new QtDBusHelper::QDBusReply(cppSelf->registerService(cppArg0, cppArg1, cppArg2));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QtDBusHelper_QDBusReply_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionInterfaceFunc_registeredServiceNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnectionInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // registeredServiceNames()const
        QtDBusHelper::QDBusReply* cppResult = new QtDBusHelper::QDBusReply(const_cast<const ::QDBusConnectionInterface *>(cppSelf)->registeredServiceNames());
        pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QtDBusHelper_QDBusReply_IDX]), cppResult, true, true);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionInterfaceFunc_serviceOwner(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnectionInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusConnectionInterface::serviceOwner(QString)const->QtDBusHelper::QDBusReply
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // serviceOwner(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "serviceOwner", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // serviceOwner(QString)const
            QtDBusHelper::QDBusReply* cppResult = new QtDBusHelper::QDBusReply(const_cast<const ::QDBusConnectionInterface *>(cppSelf)->serviceOwner(cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QtDBusHelper_QDBusReply_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionInterfaceFunc_servicePid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnectionInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusConnectionInterface::servicePid(QString)const->QtDBusHelper::QDBusReply
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // servicePid(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "servicePid", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // servicePid(QString)const
            QtDBusHelper::QDBusReply* cppResult = new QtDBusHelper::QDBusReply(const_cast<const ::QDBusConnectionInterface *>(cppSelf)->servicePid(cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QtDBusHelper_QDBusReply_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionInterfaceFunc_serviceUid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnectionInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusConnectionInterface::serviceUid(QString)const->QtDBusHelper::QDBusReply
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // serviceUid(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "serviceUid", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // serviceUid(QString)const
            QtDBusHelper::QDBusReply* cppResult = new QtDBusHelper::QDBusReply(const_cast<const ::QDBusConnectionInterface *>(cppSelf)->serviceUid(cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QtDBusHelper_QDBusReply_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionInterfaceFunc_startService(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnectionInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusConnectionInterface::startService(QString)->QtDBusHelper::QDBusReply
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // startService(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "startService", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // startService(QString)
            QtDBusHelper::QDBusReply* cppResult = new QtDBusHelper::QDBusReply(cppSelf->startService(cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QtDBusHelper_QDBusReply_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionInterfaceFunc_unregisterService(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnectionInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusConnectionInterface::unregisterService(QString)->QtDBusHelper::QDBusReply
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // unregisterService(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "unregisterService", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // unregisterService(QString)
            QtDBusHelper::QDBusReply* cppResult = new QtDBusHelper::QDBusReply(cppSelf->unregisterService(cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QtDBusHelper_QDBusReply_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDBusConnectionInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDBusConnectionInterface_EnumFlagInfo[] = {
    "RegisterServiceReply:Enum",
    "ServiceQueueOptions:Enum",
    "ServiceReplacementOptions:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDBusConnectionInterface_methods[] = {
    {"activatableServiceNames", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionInterfaceFunc_activatableServiceNames), METH_NOARGS, nullptr},
    {"connectNotify", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionInterfaceFunc_connectNotify), METH_O, nullptr},
    {"disconnectNotify", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionInterfaceFunc_disconnectNotify), METH_O, nullptr},
    {"isServiceRegistered", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionInterfaceFunc_isServiceRegistered), METH_O, nullptr},
    {"registerService", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionInterfaceFunc_registerService), METH_VARARGS, nullptr},
    {"registeredServiceNames", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionInterfaceFunc_registeredServiceNames), METH_NOARGS, nullptr},
    {"serviceOwner", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionInterfaceFunc_serviceOwner), METH_O, nullptr},
    {"servicePid", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionInterfaceFunc_servicePid), METH_O, nullptr},
    {"serviceUid", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionInterfaceFunc_serviceUid), METH_O, nullptr},
    {"startService", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionInterfaceFunc_startService), METH_O, nullptr},
    {"unregisterService", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionInterfaceFunc_unregisterService), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDBusConnectionInterface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDBusConnectionInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDBusConnectionInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDBusConnectionInterface_Type = nullptr;
static PyTypeObject *Sbk_QDBusConnectionInterface_TypeF(void)
{
    return _Sbk_QDBusConnectionInterface_Type;
}

static PyType_Slot Sbk_QDBusConnectionInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(SbkDeallocWrapperWithPrivateDtor)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDBusConnectionInterface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDBusConnectionInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDBusConnectionInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDBusConnectionInterface_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDBusConnectionInterface_spec = {
    "2:PySide6.QtDBus.QDBusConnectionInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDBusConnectionInterface_slots
};

} //extern "C"

static void *Sbk_QDBusConnectionInterface_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QDBusConnectionInterface *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDBusConnectionInterface_ServiceQueueOptions(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDBusConnectionInterface::ServiceQueueOptions>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDBusConnectionInterface::ServiceQueueOptions *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDBusConnectionInterface_ServiceQueueOptions_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_ServiceQueueOptions_IDX])))
        return Enum_PythonToCpp_QDBusConnectionInterface_ServiceQueueOptions;
    return {};
}

static PyObject *QDBusConnectionInterface_ServiceQueueOptions_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDBusConnectionInterface::ServiceQueueOptions>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDBusConnectionInterface::ServiceQueueOptions *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_ServiceQueueOptions_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QDBusConnectionInterface_ServiceReplacementOptions(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDBusConnectionInterface::ServiceReplacementOptions>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDBusConnectionInterface::ServiceReplacementOptions *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDBusConnectionInterface_ServiceReplacementOptions_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_ServiceReplacementOptions_IDX])))
        return Enum_PythonToCpp_QDBusConnectionInterface_ServiceReplacementOptions;
    return {};
}

static PyObject *QDBusConnectionInterface_ServiceReplacementOptions_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDBusConnectionInterface::ServiceReplacementOptions>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDBusConnectionInterface::ServiceReplacementOptions *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_ServiceReplacementOptions_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QDBusConnectionInterface_RegisterServiceReply(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDBusConnectionInterface::RegisterServiceReply>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDBusConnectionInterface::RegisterServiceReply *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDBusConnectionInterface_RegisterServiceReply_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_RegisterServiceReply_IDX])))
        return Enum_PythonToCpp_QDBusConnectionInterface_RegisterServiceReply;
    return {};
}

static PyObject *QDBusConnectionInterface_RegisterServiceReply_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDBusConnectionInterface::RegisterServiceReply>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDBusConnectionInterface::RegisterServiceReply *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_RegisterServiceReply_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDBusConnectionInterface_PythonToCpp_QDBusConnectionInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDBusConnectionInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDBusConnectionInterface_PythonToCpp_QDBusConnectionInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusConnectionInterface_TypeF()))
        return QDBusConnectionInterface_PythonToCpp_QDBusConnectionInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDBusConnectionInterface_PTR_CppToPython_QDBusConnectionInterface(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QDBusConnectionInterface *>(const_cast<void *>(cppIn)), Sbk_QDBusConnectionInterface_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDBusConnectionInterface_SignatureStrings[] = {
    "PySide6.QtDBus.QDBusConnectionInterface.activatableServiceNames(self)->PySide6.QtDBus.QDBusReply",
    "PySide6.QtDBus.QDBusConnectionInterface.connectNotify(self,arg__1:PySide6.QtCore.QMetaMethod)",
    "PySide6.QtDBus.QDBusConnectionInterface.disconnectNotify(self,arg__1:PySide6.QtCore.QMetaMethod)",
    "PySide6.QtDBus.QDBusConnectionInterface.isServiceRegistered(self,arg__1:QString)->PySide6.QtDBus.QDBusReply",
    "PySide6.QtDBus.QDBusConnectionInterface.registerService(self,arg__1:QString,arg__2:PySide6.QtDBus.QDBusConnectionInterface.ServiceQueueOptions,arg__3:PySide6.QtDBus.QDBusConnectionInterface.ServiceReplacementOptions)->PySide6.QtDBus.QDBusReply",
    "PySide6.QtDBus.QDBusConnectionInterface.registeredServiceNames(self)->PySide6.QtDBus.QDBusReply",
    "PySide6.QtDBus.QDBusConnectionInterface.serviceOwner(self,arg__1:QString)->PySide6.QtDBus.QDBusReply",
    "PySide6.QtDBus.QDBusConnectionInterface.servicePid(self,arg__1:QString)->PySide6.QtDBus.QDBusReply",
    "PySide6.QtDBus.QDBusConnectionInterface.serviceUid(self,arg__1:QString)->PySide6.QtDBus.QDBusReply",
    "PySide6.QtDBus.QDBusConnectionInterface.startService(self,arg__1:QString)->PySide6.QtDBus.QDBusReply",
    "PySide6.QtDBus.QDBusConnectionInterface.unregisterService(self,arg__1:QString)->PySide6.QtDBus.QDBusReply",
    nullptr}; // Sentinel
#else
static constexpr size_t QDBusConnectionInterface_SignatureByteSize = 230;
static constexpr uint8_t QDBusConnectionInterface_SignatureBytes[230] = {
    0x78, 0xda, 0xb5, 0x92, 0xc1, 0xaa, 0xc2, 0x30, 0x10, 0x45, 0xf7, 0x7e, 0x89, 0x82, 0x16, 0x54,
    0x70, 0xe1, 0xe2, 0x2d, 0xf4, 0x6d, 0x5c, 0xa8, 0x8d, 0xc5, 0xb5, 0xc4, 0xe6, 0xb6, 0x0e, 0xd4,
    0x44, 0x92, 0xa9, 0xd2, 0xbf, 0xb7, 0x7d, 0x0d, 0x88, 0x20, 0xd2, 0x07, 0xcd, 0x22, 0x81, 0x99,
    0xc0, 0x39, 0xcc, 0xe4, 0xc6, 0x55, 0x42, 0x0a, 0x8b, 0x48, 0xf0, 0xef, 0xaa, 0x74, 0x91, 0x68,
    0xee, 0xb5, 0xd1, 0x1a, 0x29, 0x93, 0xd1, 0x1b, 0xcd, 0xb0, 0x99, 0x4c, 0x11, 0xc9, 0xba, 0xbe,
    0x4b, 0x96, 0xe7, 0x02, 0x09, 0xec, 0x9d, 0x52, 0xec, 0xe4, 0x15, 0x6e, 0xe8, 0x50, 0x64, 0xa3,
    0xc9, 0x4f, 0xfc, 0x01, 0x73, 0xc0, 0xad, 0xa8, 0x06, 0x71, 0x47, 0x41, 0xda, 0xf6, 0x76, 0x86,
    0x29, 0xab, 0xfe, 0xb0, 0x63, 0x69, 0xf3, 0xd3, 0x69, 0xba, 0x7c, 0x11, 0xd6, 0xc6, 0x22, 0x12,
    0x5b, 0xb0, 0xac, 0xcf, 0xc5, 0xa8, 0x51, 0x67, 0xba, 0x22, 0x17, 0x56, 0x40, 0xce, 0xaf, 0xe5,
    0x80, 0x9c, 0x5c, 0xdd, 0x85, 0x7a, 0x73, 0x88, 0x84, 0x2d, 0xe9, 0xbc, 0x97, 0x55, 0x59, 0xaf,
    0xf0, 0xc6, 0x4f, 0x9e, 0xb6, 0x9c, 0x2d, 0xbb, 0x22, 0x3d, 0x4a, 0x94, 0x28, 0xb1, 0xbf, 0x35,
    0x6f, 0xae, 0x45, 0xcc, 0xff, 0x8b, 0x68, 0x46, 0xa9, 0xcb, 0x2b, 0x34, 0x7b, 0x50, 0xaf, 0x33,
    0x43, 0x85, 0x89, 0x9f, 0x6b, 0xa9, 0xfb, 0x87, 0x86, 0x0d, 0xf6, 0x71, 0x5e, 0x12, 0x93, 0x0a,
    0xad, 0x38, 0x86, 0x54, 0xb0, 0xb4, 0xfc, 0x25, 0x7b, 0xbd, 0x48, 0x4a, 0xdd, 0x21, 0xe5, 0x5f,
    0x4d, 0x4f, 0xff, 0xeb, 0xc1, 0xc6
};
#endif

PyTypeObject *init_QDBusConnectionInterface(PyObject *module)
{
    if (SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX].type != nullptr)
        return SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_QDBusConnectionInterface_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]))));

    _Sbk_QDBusConnectionInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDBusConnectionInterface",
        "QDBusConnectionInterface*",
        &Sbk_QDBusConnectionInterface_spec,
        nullptr,
        Sbk_QDBusConnectionInterface_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDBusConnectionInterface_TypeF(); // references _Sbk_QDBusConnectionInterface_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDBusConnectionInterface_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDBusConnectionInterface_SignatureBytes, QDBusConnectionInterface_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDBusConnectionInterface_PropertyStrings);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDBusConnectionInterface_PythonToCpp_QDBusConnectionInterface_PTR,
        is_QDBusConnectionInterface_PythonToCpp_QDBusConnectionInterface_PTR_Convertible,
        QDBusConnectionInterface_PTR_CppToPython_QDBusConnectionInterface);

    Shiboken::Conversions::registerConverterName(converter, "QDBusConnectionInterface");
    Shiboken::Conversions::registerConverterName(converter, "QDBusConnectionInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QDBusConnectionInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDBusConnectionInterface).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QDBusConnectionInterface_TypeF(), &Sbk_QDBusConnectionInterface_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDBusConnectionInterface_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ServiceQueueOptions'.
    const char *ServiceQueueOptions_Initializer[] = {
        "DontQueueService",
        "QueueService",
        "ReplaceExistingService",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ServiceQueueOptions_InitializerValues[] = {
        uint8_t(QDBusConnectionInterface::ServiceQueueOptions::DontQueueService),      //  0x00  0
        uint8_t(QDBusConnectionInterface::ServiceQueueOptions::QueueService),          //  0x01  1
        uint8_t(QDBusConnectionInterface::ServiceQueueOptions::ReplaceExistingService) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDBusConnectionInterface_TypeF(),
        "2:PySide6.QtDBus.QDBusConnectionInterface.ServiceQueueOptions",
        ServiceQueueOptions_Initializer, ServiceQueueOptions_InitializerValues);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_ServiceQueueOptions_IDX].type = EType;
    // Register converter for enum 'QDBusConnectionInterface::ServiceQueueOptions'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDBusConnectionInterface_ServiceQueueOptions_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDBusConnectionInterface_ServiceQueueOptions,
            is_Enum_PythonToCpp_QDBusConnectionInterface_ServiceQueueOptions_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDBusConnectionInterface::ServiceQueueOptions");
        Shiboken::Conversions::registerConverterAlias(converter, "ServiceQueueOptions");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ServiceQueueOptions' enum.

    // Initialization of enum 'ServiceReplacementOptions'.
    const char *ServiceReplacementOptions_Initializer[] = {
        "DontAllowReplacement",
        "AllowReplacement",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ServiceReplacementOptions_InitializerValues[] = {
        uint8_t(QDBusConnectionInterface::ServiceReplacementOptions::DontAllowReplacement), //  0x00  0
        uint8_t(QDBusConnectionInterface::ServiceReplacementOptions::AllowReplacement)      //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDBusConnectionInterface_TypeF(),
        "2:PySide6.QtDBus.QDBusConnectionInterface.ServiceReplacementOptions",
        ServiceReplacementOptions_Initializer, ServiceReplacementOptions_InitializerValues);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_ServiceReplacementOptions_IDX].type = EType;
    // Register converter for enum 'QDBusConnectionInterface::ServiceReplacementOptions'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDBusConnectionInterface_ServiceReplacementOptions_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDBusConnectionInterface_ServiceReplacementOptions,
            is_Enum_PythonToCpp_QDBusConnectionInterface_ServiceReplacementOptions_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDBusConnectionInterface::ServiceReplacementOptions");
        Shiboken::Conversions::registerConverterAlias(converter, "ServiceReplacementOptions");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ServiceReplacementOptions' enum.

    // Initialization of enum 'RegisterServiceReply'.
    const char *RegisterServiceReply_Initializer[] = {
        "ServiceNotRegistered",
        "ServiceRegistered",
        "ServiceQueued",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RegisterServiceReply_InitializerValues[] = {
        uint8_t(QDBusConnectionInterface::RegisterServiceReply::ServiceNotRegistered), //  0x00  0
        uint8_t(QDBusConnectionInterface::RegisterServiceReply::ServiceRegistered),    //  0x01  1
        uint8_t(QDBusConnectionInterface::RegisterServiceReply::ServiceQueued)         //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDBusConnectionInterface_TypeF(),
        "2:PySide6.QtDBus.QDBusConnectionInterface.RegisterServiceReply",
        RegisterServiceReply_Initializer, RegisterServiceReply_InitializerValues);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_RegisterServiceReply_IDX].type = EType;
    // Register converter for enum 'QDBusConnectionInterface::RegisterServiceReply'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDBusConnectionInterface_RegisterServiceReply_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDBusConnectionInterface_RegisterServiceReply,
            is_Enum_PythonToCpp_QDBusConnectionInterface_RegisterServiceReply_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDBusConnectionInterface::RegisterServiceReply");
        Shiboken::Conversions::registerConverterAlias(converter, "RegisterServiceReply");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'RegisterServiceReply' enum.

    PySide::Signal::registerSignals(pyType, &::QDBusConnectionInterface::staticMetaObject);
    qRegisterMetaType< ::QDBusConnectionInterface::ServiceQueueOptions >("QDBusConnectionInterface::ServiceQueueOptions");
    qRegisterMetaType< ::QDBusConnectionInterface::ServiceReplacementOptions >("QDBusConnectionInterface::ServiceReplacementOptions");
    qRegisterMetaType< ::QDBusConnectionInterface::RegisterServiceReply >("QDBusConnectionInterface::RegisterServiceReply");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QDBusConnectionInterface::staticMetaObject, sizeof(::QDBusConnectionInterface));

    return pyType;
}
