// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdbus_python.h"

// main header
#include "qdbusmessage_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtDBus/qdbuserror.h>
#include <QtDBus/qdbusmessage.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDBusMessage_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDBusMessage >()))
        return -1;

    ::QDBusMessage *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDBusMessage", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDBusMessage::QDBusMessage()
    // 1: QDBusMessage::QDBusMessage(QDBusMessage)
    if (numArgs == 0) {
        overloadId = 0; // QDBusMessage()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDBusMessage(QDBusMessage)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDBusMessage()
        {

            // QDBusMessage()
            cptr = new ::QDBusMessage();
            break;
        }
        case 1: // QDBusMessage(const QDBusMessage &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDBusMessage cppArg0_local;
            ::QDBusMessage *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusMessage(QDBusMessage)
                cptr = new ::QDBusMessage(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDBusMessage >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDBusMessageFunc_arguments(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // arguments()const
        QList<QVariant> cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->arguments();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtDBusTypeConverters[SBK_QtDBus_QList_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_autoStartService(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoStartService()const
        bool cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->autoStartService();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_createError(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createError", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QDBusMessage::createError(QDBusError::ErrorType,QString)->QDBusMessage
    // 1: static QDBusMessage::createError(QDBusError)->QDBusMessage
    // 2: static QDBusMessage::createError(QString,QString)->QDBusMessage
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 2; // createError(QString,QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusError_IDX]), (pyArgs[0])))) {
        overloadId = 1; // createError(QDBusError)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusError_ErrorType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // createError(QDBusError::ErrorType,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createError", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // createError(QDBusError::ErrorType type, const QString &msg)
        {
            ::QDBusError::ErrorType cppArg0{QDBusError::NoError};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // createError(QDBusError::ErrorType,QString)
                QDBusMessage cppResult = ::QDBusMessage::createError(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 1: // createError(const QDBusError &err)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDBusError cppArg0_local;
            ::QDBusError *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // createError(QDBusError)
                QDBusMessage cppResult = ::QDBusMessage::createError(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 2: // createError(const QString &name, const QString &msg)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // createError(QString,QString)
                QDBusMessage cppResult = ::QDBusMessage::createError(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_createErrorReply(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createErrorReply", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusMessage::createErrorReply(QDBusError::ErrorType,QString)const->QDBusMessage
    // 1: QDBusMessage::createErrorReply(QDBusError)const->QDBusMessage
    // 2: QDBusMessage::createErrorReply(QString,QString)const->QDBusMessage
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 2; // createErrorReply(QString,QString)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusError_IDX]), (pyArgs[0])))) {
        overloadId = 1; // createErrorReply(QDBusError)const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusError_ErrorType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // createErrorReply(QDBusError::ErrorType,QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createErrorReply", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // createErrorReply(QDBusError::ErrorType type, const QString &msg) const
        {
            ::QDBusError::ErrorType cppArg0{QDBusError::NoError};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // createErrorReply(QDBusError::ErrorType,QString)const
                QDBusMessage cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->createErrorReply(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 1: // createErrorReply(const QDBusError &err) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDBusError cppArg0_local;
            ::QDBusError *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // createErrorReply(QDBusError)const
                QDBusMessage cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->createErrorReply(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 2: // createErrorReply(const QString &name, const QString &msg) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // createErrorReply(QString,QString)const
                QDBusMessage cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->createErrorReply(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_createMethodCall(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createMethodCall", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QDBusMessage::createMethodCall(QString,QString,QString,QString)->QDBusMessage
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
        overloadId = 0; // createMethodCall(QString,QString,QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createMethodCall", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QString cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createMethodCall(QString,QString,QString,QString)
            QDBusMessage cppResult = ::QDBusMessage::createMethodCall(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_createReply(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "createReply", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);

    if (PyArg_ParseTuple(args, "|O:createReply", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusMessage::createReply(const QList<QVariant>&=)const->QDBusMessage
    // 1: QDBusMessage::createReply(QVariant)const->QDBusMessage
    if (numArgs == 0) {
        overloadId = 0; // createReply(QList<QVariant>)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[0])))) {
        overloadId = 1; // createReply(QVariant)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDBusTypeConverters[SBK_QtDBus_QList_QVariant_IDX], (pyArgs[0])))) {
        overloadId = 0; // createReply(QList<QVariant>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createReply", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // createReply(const QList<QVariant> &arguments) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_arguments = Shiboken::String::createStaticString("arguments");
                if (PyDict_Contains(kwds, key_arguments) != 0) {
                    value = PyDict_GetItem(kwds, key_arguments);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_arguments);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "createReply", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDBusTypeConverters[SBK_QtDBus_QList_QVariant_IDX], (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "createReply", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_arguments);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "createReply", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);
                }
            }
            ::QList<QVariant> cppArg0 = QList<QVariant>();
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // createReply(QList<QVariant>)const
                QDBusMessage cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->createReply(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 1: // createReply(const QVariant &argument) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "createReply", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);
            }
            ::QVariant cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // createReply(QVariant)const
                QDBusMessage cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->createReply(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_createSignal(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createSignal", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QDBusMessage::createSignal(QString,QString,QString)->QDBusMessage
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // createSignal(QString,QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createSignal", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createSignal(QString,QString,QString)
            QDBusMessage cppResult = ::QDBusMessage::createSignal(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_createTargetedSignal(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createTargetedSignal", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QDBusMessage::createTargetedSignal(QString,QString,QString,QString)->QDBusMessage
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
        overloadId = 0; // createTargetedSignal(QString,QString,QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createTargetedSignal", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QString cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createTargetedSignal(QString,QString,QString,QString)
            QDBusMessage cppResult = ::QDBusMessage::createTargetedSignal(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_errorMessage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorMessage()const
        QString cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->errorMessage();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_errorName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorName()const
        QString cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->errorName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_interface(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // interface()const
        QString cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->interface();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_isDelayedReply(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDelayedReply()const
        bool cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->isDelayedReply();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_isInteractiveAuthorizationAllowed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isInteractiveAuthorizationAllowed()const
        bool cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->isInteractiveAuthorizationAllowed();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_isReplyRequired(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isReplyRequired()const
        bool cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->isReplyRequired();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_member(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // member()const
        QString cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->member();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_path(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // path()const
        QString cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->path();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_service(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // service()const
        QString cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->service();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_setArguments(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusMessage::setArguments(QList<QVariant>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDBusTypeConverters[SBK_QtDBus_QList_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setArguments(QList<QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setArguments", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);

    // Call function/method
    {
        ::QList<QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setArguments(QList<QVariant>)
            cppSelf->setArguments(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusMessageFunc_setAutoStartService(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusMessage::setAutoStartService(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoStartService(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoStartService", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoStartService(bool)
            cppSelf->setAutoStartService(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusMessageFunc_setDelayedReply(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusMessage::setDelayedReply(bool)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDelayedReply(bool)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDelayedReply", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDelayedReply(bool)const
            const_cast<const ::QDBusMessage *>(cppSelf)->setDelayedReply(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusMessageFunc_setInteractiveAuthorizationAllowed(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusMessage::setInteractiveAuthorizationAllowed(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setInteractiveAuthorizationAllowed(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInteractiveAuthorizationAllowed", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInteractiveAuthorizationAllowed(bool)
            cppSelf->setInteractiveAuthorizationAllowed(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusMessageFunc_signature(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // signature()const
        QString cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->signature();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessageFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusMessage::swap(QDBusMessage&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QDBusMessage&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDBusMessage cppArg0_local;
        ::QDBusMessage *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QDBusMessage&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusMessageFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QDBusMessage::MessageType cppResult = const_cast<const ::QDBusMessage *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_MessageType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusMessage__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDBusMessage_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDBusMessage_EnumFlagInfo[] = {
    "MessageType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDBusMessage_methods[] = {
    {"arguments", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_arguments), METH_NOARGS, nullptr},
    {"autoStartService", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_autoStartService), METH_NOARGS, nullptr},
    {"createError", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_createError), METH_VARARGS|METH_STATIC, nullptr},
    {"createErrorReply", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_createErrorReply), METH_VARARGS, nullptr},
    {"createMethodCall", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_createMethodCall), METH_VARARGS|METH_STATIC, nullptr},
    {"createReply", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_createReply), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"createSignal", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_createSignal), METH_VARARGS|METH_STATIC, nullptr},
    {"createTargetedSignal", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_createTargetedSignal), METH_VARARGS|METH_STATIC, nullptr},
    {"errorMessage", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_errorMessage), METH_NOARGS, nullptr},
    {"errorName", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_errorName), METH_NOARGS, nullptr},
    {"interface", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_interface), METH_NOARGS, nullptr},
    {"isDelayedReply", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_isDelayedReply), METH_NOARGS, nullptr},
    {"isInteractiveAuthorizationAllowed", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_isInteractiveAuthorizationAllowed), METH_NOARGS, nullptr},
    {"isReplyRequired", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_isReplyRequired), METH_NOARGS, nullptr},
    {"member", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_member), METH_NOARGS, nullptr},
    {"path", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_path), METH_NOARGS, nullptr},
    {"service", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_service), METH_NOARGS, nullptr},
    {"setArguments", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_setArguments), METH_O, nullptr},
    {"setAutoStartService", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_setAutoStartService), METH_O, nullptr},
    {"setDelayedReply", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_setDelayedReply), METH_O, nullptr},
    {"setInteractiveAuthorizationAllowed", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_setInteractiveAuthorizationAllowed), METH_O, nullptr},
    {"signature", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_signature), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_swap), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QDBusMessageFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDBusMessage__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QDBusMessageFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QDBusMessage::operator<<(QVariant)->QDBusMessage&
        if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
            overloadId = 0; // operator<<(QVariant)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]);

        // Call function/method
        {
            ::QVariant cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QVariant)
                QDBusMessage & cppResult = (*cppSelf) << cppArg0;
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

} // extern "C"

static int Sbk_QDBusMessage_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDBusMessage_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QDBusMessage__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDBusMessage_Type = nullptr;
static PyTypeObject *Sbk_QDBusMessage_TypeF(void)
{
    return _Sbk_QDBusMessage_Type;
}

static PyType_Slot Sbk_QDBusMessage_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QDBusMessage__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDBusMessage_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDBusMessage_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDBusMessage_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDBusMessage_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QDBusMessageFunc___lshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDBusMessage_spec = {
    "2:PySide6.QtDBus.QDBusMessage",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDBusMessage_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDBusMessage_MessageType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDBusMessage::MessageType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDBusMessage::MessageType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDBusMessage_MessageType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_MessageType_IDX])))
        return Enum_PythonToCpp_QDBusMessage_MessageType;
    return {};
}

static PyObject *QDBusMessage_MessageType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDBusMessage::MessageType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDBusMessage::MessageType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_MessageType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDBusMessage_PythonToCpp_QDBusMessage_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDBusMessage_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDBusMessage_PythonToCpp_QDBusMessage_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusMessage_TypeF()))
        return QDBusMessage_PythonToCpp_QDBusMessage_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDBusMessage_PTR_CppToPython_QDBusMessage(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDBusMessage_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDBusMessage_COPY_CppToPython_QDBusMessage(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDBusMessage *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDBusMessage_TypeF(), new ::QDBusMessage(*source), true, true);
}

// Python to C++ copy conversion.
static void QDBusMessage_PythonToCpp_QDBusMessage_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDBusMessage *>(cppOut) = *reinterpret_cast< ::QDBusMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDBusMessage_PythonToCpp_QDBusMessage_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusMessage_TypeF()))
        return QDBusMessage_PythonToCpp_QDBusMessage_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDBusMessage_SignatureStrings[] = {
    "1:PySide6.QtDBus.QDBusMessage(self)",
    "0:PySide6.QtDBus.QDBusMessage(self,other:PySide6.QtDBus.QDBusMessage)",
    "PySide6.QtDBus.QDBusMessage.arguments(self)->QList[QVariant]",
    "PySide6.QtDBus.QDBusMessage.autoStartService(self)->bool",
    "2:PySide6.QtDBus.QDBusMessage.createError(type:PySide6.QtDBus.QDBusError.ErrorType,msg:QString)->PySide6.QtDBus.QDBusMessage",
    "1:PySide6.QtDBus.QDBusMessage.createError(err:typing.Union[PySide6.QtDBus.QDBusError, PySide6.QtDBus.QDBusMessage])->PySide6.QtDBus.QDBusMessage",
    "0:PySide6.QtDBus.QDBusMessage.createError(name:QString,msg:QString)->PySide6.QtDBus.QDBusMessage",
    "2:PySide6.QtDBus.QDBusMessage.createErrorReply(self,type:PySide6.QtDBus.QDBusError.ErrorType,msg:QString)->PySide6.QtDBus.QDBusMessage",
    "1:PySide6.QtDBus.QDBusMessage.createErrorReply(self,err:typing.Union[PySide6.QtDBus.QDBusError, PySide6.QtDBus.QDBusMessage])->PySide6.QtDBus.QDBusMessage",
    "0:PySide6.QtDBus.QDBusMessage.createErrorReply(self,name:QString,msg:QString)->PySide6.QtDBus.QDBusMessage",
    "PySide6.QtDBus.QDBusMessage.createMethodCall(destination:QString,path:QString,interface:QString,method:QString)->PySide6.QtDBus.QDBusMessage",
    "1:PySide6.QtDBus.QDBusMessage.createReply(self,arguments:QList[QVariant]=QList<QVariant>())->PySide6.QtDBus.QDBusMessage",
    "0:PySide6.QtDBus.QDBusMessage.createReply(self,argument:QVariant)->PySide6.QtDBus.QDBusMessage",
    "PySide6.QtDBus.QDBusMessage.createSignal(path:QString,interface:QString,name:QString)->PySide6.QtDBus.QDBusMessage",
    "PySide6.QtDBus.QDBusMessage.createTargetedSignal(service:QString,path:QString,interface:QString,name:QString)->PySide6.QtDBus.QDBusMessage",
    "PySide6.QtDBus.QDBusMessage.errorMessage(self)->QString",
    "PySide6.QtDBus.QDBusMessage.errorName(self)->QString",
    "PySide6.QtDBus.QDBusMessage.interface(self)->QString",
    "PySide6.QtDBus.QDBusMessage.isDelayedReply(self)->bool",
    "PySide6.QtDBus.QDBusMessage.isInteractiveAuthorizationAllowed(self)->bool",
    "PySide6.QtDBus.QDBusMessage.isReplyRequired(self)->bool",
    "PySide6.QtDBus.QDBusMessage.member(self)->QString",
    "PySide6.QtDBus.QDBusMessage.path(self)->QString",
    "PySide6.QtDBus.QDBusMessage.service(self)->QString",
    "PySide6.QtDBus.QDBusMessage.setArguments(self,arguments:QList[QVariant])",
    "PySide6.QtDBus.QDBusMessage.setAutoStartService(self,enable:bool)",
    "PySide6.QtDBus.QDBusMessage.setDelayedReply(self,enable:bool)",
    "PySide6.QtDBus.QDBusMessage.setInteractiveAuthorizationAllowed(self,enable:bool)",
    "PySide6.QtDBus.QDBusMessage.signature(self)->QString",
    "PySide6.QtDBus.QDBusMessage.swap(self,other:PySide6.QtDBus.QDBusMessage)",
    "PySide6.QtDBus.QDBusMessage.type(self)->PySide6.QtDBus.QDBusMessage.MessageType",
    "PySide6.QtDBus.QDBusMessage.__copy__(self)->typing.Self",
    "PySide6.QtDBus.QDBusMessage.__lshift__(self,arg:QVariant)->PySide6.QtDBus.QDBusMessage",
    nullptr}; // Sentinel
#else
static constexpr size_t QDBusMessage_SignatureByteSize = 479;
static constexpr uint8_t QDBusMessage_SignatureBytes[479] = {
    0x78, 0xda, 0xcd, 0x56, 0x5f, 0x4f, 0xdb, 0x30, 0x10, 0x7f, 0xef, 0xa7, 0xe0, 0x31, 0x95, 0xba,
    0x08, 0xf6, 0xc0, 0x43, 0x34, 0x90, 0x3a, 0xd8, 0xc3, 0x24, 0x40, 0x84, 0xb0, 0xbd, 0x54, 0xa8,
    0x72, 0x93, 0x6b, 0x6a, 0xc9, 0xb1, 0xc3, 0xf9, 0x02, 0xca, 0x3e, 0xfd, 0xec, 0xb4, 0x29, 0x29,
    0x2b, 0x4e, 0x0c, 0x95, 0xd8, 0x4b, 0x22, 0x2b, 0xf7, 0xfb, 0x73, 0x77, 0xb6, 0x2f, 0x27, 0xd1,
    0x6d, 0x9d, 0xf0, 0x0c, 0x4e, 0xc3, 0x98, 0x2e, 0xbf, 0x57, 0x3a, 0x8c, 0xed, 0xf3, 0x1a, 0xb4,
    0x66, 0x39, 0x04, 0x1a, 0xc4, 0x72, 0x3c, 0x3a, 0xee, 0x8d, 0x99, 0x28, 0x5a, 0x01, 0xba, 0xc2,
    0xc6, 0x23, 0xc7, 0xc7, 0x90, 0x61, 0x5e, 0x15, 0x20, 0x49, 0xaf, 0x15, 0xbf, 0x9c, 0xc7, 0x57,
    0x5c, 0xd3, 0x2c, 0xfe, 0xcd, 0x90, 0x33, 0x49, 0x0f, 0x6e, 0x70, 0x45, 0x2a, 0x21, 0x86, 0x94,
    0x00, 0x3e, 0xf1, 0x14, 0x5a, 0x8e, 0x85, 0x52, 0x62, 0xf4, 0xd5, 0x65, 0x2a, 0x4c, 0x11, 0x18,
    0xc1, 0x0f, 0x44, 0x85, 0x01, 0xd5, 0x25, 0xec, 0x0d, 0x6e, 0x3e, 0x87, 0xcd, 0xf3, 0xde, 0xc4,
    0x4c, 0x0a, 0x9d, 0x47, 0x71, 0x42, 0xc8, 0x65, 0x6e, 0x54, 0x1c, 0xf4, 0xa3, 0x93, 0xc1, 0xe2,
    0x80, 0x18, 0x19, 0x03, 0x86, 0x32, 0xfc, 0x25, 0xb9, 0x92, 0xb3, 0x37, 0x8d, 0x4c, 0x8e, 0x1c,
    0x9c, 0x0f, 0x3d, 0x86, 0x8e, 0x07, 0x1b, 0x92, 0xac, 0x80, 0x36, 0x4b, 0x8f, 0x8c, 0x07, 0x97,
    0xfb, 0x0e, 0x4a, 0x51, 0xaf, 0xf7, 0xce, 0x67, 0x16, 0xbe, 0x63, 0xe3, 0x7f, 0x6b, 0x41, 0xc7,
    0xda, 0x3b, 0x9b, 0xd1, 0x2f, 0x74, 0x0d, 0xb4, 0x52, 0xd9, 0x05, 0x13, 0x22, 0xc8, 0x40, 0x13,
    0x97, 0x8c, 0x4c, 0xe6, 0x5b, 0xa9, 0x92, 0xd1, 0x6a, 0xbb, 0xe0, 0x92, 0x00, 0x97, 0x2c, 0xed,
    0x38, 0x69, 0xd0, 0x07, 0x6c, 0x49, 0x27, 0xe5, 0xed, 0x8d, 0x10, 0xbd, 0xba, 0x0a, 0xce, 0x9a,
    0xf5, 0xb7, 0x76, 0x7d, 0x1e, 0x8c, 0x0f, 0x50, 0xf0, 0x3d, 0xc2, 0x51, 0xab, 0xf0, 0xe1, 0x22,
    0x27, 0x3c, 0x97, 0x4c, 0x04, 0x3d, 0xc5, 0xec, 0xf6, 0xf8, 0xc3, 0x92, 0xf7, 0x26, 0x0b, 0x20,
    0xc8, 0x36, 0xd2, 0x7a, 0x7d, 0x31, 0x0e, 0xed, 0xeb, 0x81, 0xac, 0x80, 0xdd, 0xc5, 0x3b, 0x93,
    0xc4, 0xdc, 0xeb, 0x6b, 0xd6, 0x7e, 0xdc, 0x8d, 0xf1, 0xe0, 0x03, 0xda, 0x66, 0xe1, 0x05, 0xd2,
    0x97, 0x20, 0x58, 0x0d, 0xd9, 0x4b, 0xff, 0xdb, 0xb9, 0xe1, 0x86, 0xfd, 0xb4, 0x6a, 0x2c, 0x25,
    0xfe, 0x04, 0xd3, 0xca, 0x1c, 0x02, 0xe4, 0x7f, 0x9a, 0x93, 0x33, 0x15, 0x42, 0x3d, 0x43, 0xe6,
    0xc1, 0xd4, 0x28, 0xdf, 0xc1, 0x63, 0xc5, 0xd1, 0x03, 0x57, 0x40, 0xb1, 0x00, 0xf4, 0x49, 0xd5,
    0xb6, 0xdc, 0x27, 0x5e, 0xef, 0xce, 0xd2, 0x61, 0x10, 0x9a, 0xee, 0xcc, 0xf1, 0xb7, 0x0f, 0xf1,
    0xb8, 0x97, 0x68, 0xdf, 0x4c, 0x9f, 0x80, 0x64, 0x0b, 0x01, 0x91, 0x2d, 0x4f, 0x2f, 0xc3, 0x3f,
    0x9d, 0xf5, 0x42, 0x0f, 0x69, 0xb0, 0x07, 0xa1, 0x3d, 0x86, 0x54, 0xa1, 0x5f, 0x39, 0x9f, 0x59,
    0x79, 0x90, 0x9f, 0x2b, 0x3b, 0x5f, 0x5b, 0x61, 0x57, 0xdc, 0xe6, 0x6d, 0x47, 0xad, 0x93, 0x6f,
    0x3e, 0x4f, 0x55, 0x59, 0xcf, 0xe7, 0x2d, 0xe7, 0x66, 0x68, 0x26, 0x66, 0xd5, 0x83, 0x13, 0x7a,
    0xc5, 0x97, 0xb4, 0x41, 0xda, 0xdd, 0x31, 0xf4, 0x92, 0xfd, 0x0b, 0x3d, 0x58, 0xcb, 0x44
};
#endif

PyTypeObject *init_QDBusMessage(PyObject *module)
{
    if (SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX].type != nullptr)
        return SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX].type;

    Shiboken::AutoDecRef Sbk_QDBusMessage_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDBusMessage_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDBusMessage",
        "QDBusMessage",
        &Sbk_QDBusMessage_spec,
        &Shiboken::callCppDestructor< ::QDBusMessage >,
        Sbk_QDBusMessage_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDBusMessage_TypeF(); // references _Sbk_QDBusMessage_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDBusMessage_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDBusMessage_SignatureBytes, QDBusMessage_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDBusMessage_PropertyStrings);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDBusMessage_PythonToCpp_QDBusMessage_PTR,
        is_QDBusMessage_PythonToCpp_QDBusMessage_PTR_Convertible,
        QDBusMessage_PTR_CppToPython_QDBusMessage,
        QDBusMessage_COPY_CppToPython_QDBusMessage);

    Shiboken::Conversions::registerConverterName(converter, "QDBusMessage");
    Shiboken::Conversions::registerConverterName(converter, "QDBusMessage*");
    Shiboken::Conversions::registerConverterName(converter, "QDBusMessage&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDBusMessage).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDBusMessage_PythonToCpp_QDBusMessage_COPY,
        is_QDBusMessage_PythonToCpp_QDBusMessage_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDBusMessage_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'MessageType'.
    const char *MessageType_Initializer[] = {
        "InvalidMessage",
        "MethodCallMessage",
        "ReplyMessage",
        "ErrorMessage",
        "SignalMessage",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MessageType_InitializerValues[] = {
        uint8_t(QDBusMessage::MessageType::InvalidMessage),    //  0x00  0
        uint8_t(QDBusMessage::MessageType::MethodCallMessage), //  0x01  1
        uint8_t(QDBusMessage::MessageType::ReplyMessage),      //  0x02  2
        uint8_t(QDBusMessage::MessageType::ErrorMessage),      //  0x03  3
        uint8_t(QDBusMessage::MessageType::SignalMessage)      //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDBusMessage_TypeF(),
        "2:PySide6.QtDBus.QDBusMessage.MessageType",
        MessageType_Initializer, MessageType_InitializerValues);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_MessageType_IDX].type = EType;
    // Register converter for enum 'QDBusMessage::MessageType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDBusMessage_MessageType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDBusMessage_MessageType,
            is_Enum_PythonToCpp_QDBusMessage_MessageType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDBusMessage::MessageType");
        Shiboken::Conversions::registerConverterAlias(converter, "MessageType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'MessageType' enum.

    qRegisterMetaType< ::QDBusMessage >("QDBusMessage");
    qRegisterMetaType< ::QDBusMessage::MessageType >("QDBusMessage::MessageType");

    return pyType;
}
