// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdbus_python.h"

// main header
#include "qdbusobjectpath_wrapper.h"

// Argument includes
#include <QString>
#include <QtCore/qlatin1stringview.h>
#include <QtDBus/qdbusextratypes.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDBusObjectPath_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDBusObjectPath >()))
        return -1;

    ::QDBusObjectPath *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDBusObjectPath", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDBusObjectPath::QDBusObjectPath()
    // 1: QDBusObjectPath::QDBusObjectPath(QLatin1String)
    // 2: QDBusObjectPath::QDBusObjectPath(QDBusObjectPath)
    // 3: QDBusObjectPath::QDBusObjectPath(QString)
    // 4: QDBusObjectPath::QDBusObjectPath(const char*)
    if (numArgs == 0) {
        overloadId = 0; // QDBusObjectPath()
    } else if (numArgs == 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        overloadId = 4; // QDBusObjectPath(const char*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 3; // QDBusObjectPath(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QDBusObjectPath(QDBusObjectPath)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], (pyArgs[0])))) {
        overloadId = 1; // QDBusObjectPath(QLatin1String)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDBusObjectPath()
        {

            // QDBusObjectPath()
            cptr = new ::QDBusObjectPath();
            break;
        }
        case 1: // QDBusObjectPath(QLatin1String path)
        {
            ::QLatin1String cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusObjectPath(QLatin1String)
                cptr = new ::QDBusObjectPath(cppArg0);
            }
            break;
        }
        case 2: // QDBusObjectPath(const QDBusObjectPath &QDBusObjectPath)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDBusObjectPath cppArg0_local;
            ::QDBusObjectPath *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusObjectPath(QDBusObjectPath)
                cptr = new ::QDBusObjectPath(*cppArg0);
            }
            break;
        }
        case 3: // QDBusObjectPath(const QString &path)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusObjectPath(QString)
                cptr = new ::QDBusObjectPath(cppArg0);
            }
            break;
        }
        case 4: // QDBusObjectPath(const char *path)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusObjectPath(const char*)
                cptr = new ::QDBusObjectPath(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDBusObjectPath >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDBusObjectPathFunc_path(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusObjectPath *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // path()const
        QString cppResult = const_cast<const ::QDBusObjectPath *>(cppSelf)->path();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusObjectPathFunc_setPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusObjectPath *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusObjectPath::setPath(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPath", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPath(QString)
            cppSelf->setPath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusObjectPathFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusObjectPath *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusObjectPath::swap(QDBusObjectPath&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QDBusObjectPath&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDBusObjectPath cppArg0_local;
        ::QDBusObjectPath *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QDBusObjectPath&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusObjectPath__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDBusObjectPath *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDBusObjectPath_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDBusObjectPath_methods[] = {
    {"path", reinterpret_cast<PyCFunction>(Sbk_QDBusObjectPathFunc_path), METH_NOARGS, nullptr},
    {"setPath", reinterpret_cast<PyCFunction>(Sbk_QDBusObjectPathFunc_setPath), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QDBusObjectPathFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDBusObjectPath__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QDBusObjectPath_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDBusObjectPath *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]), (pyArg)))) {
                // operator!=(const QDBusObjectPath &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDBusObjectPath cppArg0_local;
                ::QDBusObjectPath *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]), (pyArg)))) {
                // operator<(const QDBusObjectPath &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDBusObjectPath cppArg0_local;
                ::QDBusObjectPath *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]), (pyArg)))) {
                // operator==(const QDBusObjectPath &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDBusObjectPath cppArg0_local;
                ::QDBusObjectPath *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QDBusObjectPath_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusObjectPath *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QDBusObjectPath_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDBusObjectPath_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDBusObjectPath_Type = nullptr;
static PyTypeObject *Sbk_QDBusObjectPath_TypeF(void)
{
    return _Sbk_QDBusObjectPath_Type;
}

static PyType_Slot Sbk_QDBusObjectPath_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QDBusObjectPath_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDBusObjectPath_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDBusObjectPath_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QDBusObjectPath_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDBusObjectPath_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDBusObjectPath_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDBusObjectPath_spec = {
    "2:PySide6.QtDBus.QDBusObjectPath",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDBusObjectPath_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDBusObjectPath_PythonToCpp_QDBusObjectPath_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDBusObjectPath_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDBusObjectPath_PythonToCpp_QDBusObjectPath_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusObjectPath_TypeF()))
        return QDBusObjectPath_PythonToCpp_QDBusObjectPath_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDBusObjectPath_PTR_CppToPython_QDBusObjectPath(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDBusObjectPath_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDBusObjectPath_COPY_CppToPython_QDBusObjectPath(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDBusObjectPath *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDBusObjectPath_TypeF(), new ::QDBusObjectPath(*source), true, true);
}

// Python to C++ copy conversion.
static void QDBusObjectPath_PythonToCpp_QDBusObjectPath_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDBusObjectPath *>(cppOut) = *reinterpret_cast< ::QDBusObjectPath *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDBusObjectPath_PythonToCpp_QDBusObjectPath_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusObjectPath_TypeF()))
        return QDBusObjectPath_PythonToCpp_QDBusObjectPath_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDBusObjectPath_SignatureStrings[] = {
    "4:PySide6.QtDBus.QDBusObjectPath(self)",
    "3:PySide6.QtDBus.QDBusObjectPath(self,path:QLatin1String)",
    "2:PySide6.QtDBus.QDBusObjectPath(self,QDBusObjectPath:PySide6.QtDBus.QDBusObjectPath)",
    "1:PySide6.QtDBus.QDBusObjectPath(self,path:QString)",
    "0:PySide6.QtDBus.QDBusObjectPath(self,path:char*)",
    "PySide6.QtDBus.QDBusObjectPath.path(self)->QString",
    "PySide6.QtDBus.QDBusObjectPath.setPath(self,path:QString)",
    "PySide6.QtDBus.QDBusObjectPath.swap(self,other:PySide6.QtDBus.QDBusObjectPath)",
    "PySide6.QtDBus.QDBusObjectPath.__copy__(self)->typing.Self",
    "PySide6.QtDBus.QDBusObjectPath.__ne__(self,rhs:PySide6.QtDBus.QDBusObjectPath)->bool",
    "PySide6.QtDBus.QDBusObjectPath.__lt__(self,rhs:PySide6.QtDBus.QDBusObjectPath)->bool",
    "PySide6.QtDBus.QDBusObjectPath.__eq__(self,rhs:PySide6.QtDBus.QDBusObjectPath)->bool",
    "PySide6.QtDBus.QDBusObjectPath.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QDBusObjectPath_SignatureByteSize = 186;
static constexpr uint8_t QDBusObjectPath_SignatureBytes[186] = {
    0x78, 0xda, 0xb5, 0x90, 0x41, 0x0a, 0xc2, 0x30, 0x10, 0x45, 0xf7, 0x39, 0x89, 0x91, 0x36, 0x58,
    0x15, 0x17, 0x5d, 0xb8, 0x10, 0x97, 0x82, 0x2d, 0x3d, 0x40, 0x48, 0x6b, 0x34, 0x91, 0x92, 0xc4,
    0x64, 0x44, 0x7a, 0x7b, 0x2b, 0xb6, 0x0a, 0x82, 0x4e, 0x5d, 0x74, 0x13, 0x92, 0x30, 0xef, 0xcf,
    0xe3, 0x2f, 0xd3, 0xac, 0x29, 0xf4, 0x41, 0xae, 0x58, 0x0e, 0xdb, 0xcd, 0x35, 0xb0, 0xfc, 0x71,
    0xee, 0xcb, 0xb3, 0xac, 0x20, 0x13, 0xa0, 0x26, 0x41, 0xd6, 0x47, 0x4a, 0x16, 0x43, 0xc6, 0x22,
    0xd7, 0xde, 0xd2, 0x7c, 0x27, 0x40, 0x9b, 0xa4, 0x00, 0xaf, 0xcd, 0x89, 0x92, 0xf9, 0x20, 0xf2,
    0xe3, 0x13, 0x61, 0x28, 0x49, 0xfe, 0xf0, 0xe9, 0x4d, 0x66, 0xc3, 0x99, 0x4a, 0x09, 0x3f, 0xa5,
    0xe4, 0xf7, 0x3c, 0x73, 0xaf, 0x7e, 0xe2, 0x75, 0xb7, 0x05, 0x43, 0x82, 0xfc, 0xaa, 0x87, 0x91,
    0x37, 0xe1, 0x9e, 0x98, 0x05, 0x25, 0x3d, 0xda, 0x10, 0x12, 0xc7, 0x79, 0x65, 0x5d, 0xc3, 0x79,
    0xef, 0x0f, 0x8d, 0x6b, 0x2d, 0x58, 0xd1, 0xbe, 0x70, 0xd4, 0xc8, 0x0e, 0x8c, 0xbc, 0x0a, 0x98,
    0x49, 0xbc, 0x2e, 0xad, 0xad, 0xf1, 0xd0, 0x1a, 0x46, 0x08, 0x95, 0x97, 0x11, 0x42, 0x95, 0x08,
    0xea, 0xdd, 0x9c, 0x36, 0x40, 0xee, 0xd4, 0x24, 0x24, 0x69
};
#endif

PyTypeObject *init_QDBusObjectPath(PyObject *module)
{
    if (SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX].type != nullptr)
        return SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX].type;

    Shiboken::AutoDecRef Sbk_QDBusObjectPath_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDBusObjectPath_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDBusObjectPath",
        "QDBusObjectPath",
        &Sbk_QDBusObjectPath_spec,
        &Shiboken::callCppDestructor< ::QDBusObjectPath >,
        Sbk_QDBusObjectPath_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDBusObjectPath_TypeF(); // references _Sbk_QDBusObjectPath_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDBusObjectPath_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDBusObjectPath_SignatureBytes, QDBusObjectPath_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDBusObjectPath_PropertyStrings);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusObjectPath_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDBusObjectPath_PythonToCpp_QDBusObjectPath_PTR,
        is_QDBusObjectPath_PythonToCpp_QDBusObjectPath_PTR_Convertible,
        QDBusObjectPath_PTR_CppToPython_QDBusObjectPath,
        QDBusObjectPath_COPY_CppToPython_QDBusObjectPath);

    Shiboken::Conversions::registerConverterName(converter, "QDBusObjectPath");
    Shiboken::Conversions::registerConverterName(converter, "QDBusObjectPath*");
    Shiboken::Conversions::registerConverterName(converter, "QDBusObjectPath&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDBusObjectPath).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDBusObjectPath_PythonToCpp_QDBusObjectPath_COPY,
        is_QDBusObjectPath_PythonToCpp_QDBusObjectPath_COPY_Convertible);

    qRegisterMetaType< ::QDBusObjectPath >("QDBusObjectPath");

    return pyType;
}
