// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdbus_python.h"

// main header
#include "qdbuspendingcall_wrapper.h"

// Argument includes
#include <QtDBus/qdbuserror.h>
#include <QtDBus/qdbusmessage.h>
#include <QtDBus/qdbuspendingcall.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDBusPendingCall_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDBusPendingCall >()))
        return -1;

    ::QDBusPendingCall *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDBusPendingCall", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDBusPendingCall::QDBusPendingCall(QDBusPendingCall)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QDBusPendingCall(QDBusPendingCall)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QDBusPendingCall *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QDBusPendingCall(QDBusPendingCall)
            cptr = new ::QDBusPendingCall(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDBusPendingCall >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDBusPendingCallFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusPendingCall *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QDBusError cppResult = const_cast<const ::QDBusPendingCall *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusError_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusPendingCallFunc_fromCompletedCall(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDBusPendingCall::fromCompletedCall(QDBusMessage)->QDBusPendingCall
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), (pyArg)))) {
        overloadId = 0; // fromCompletedCall(QDBusMessage)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromCompletedCall", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDBusMessage cppArg0_local;
        ::QDBusMessage *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // fromCompletedCall(QDBusMessage)
            QDBusPendingCall* cppResult = new QDBusPendingCall(::QDBusPendingCall::fromCompletedCall(*cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusPendingCallFunc_fromError(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDBusPendingCall::fromError(QDBusError)->QDBusPendingCall
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusError_IDX]), (pyArg)))) {
        overloadId = 0; // fromError(QDBusError)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromError", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDBusError cppArg0_local;
        ::QDBusError *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // fromError(QDBusError)
            QDBusPendingCall* cppResult = new QDBusPendingCall(::QDBusPendingCall::fromError(*cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusPendingCallFunc_isError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusPendingCall *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isError()const
        bool cppResult = const_cast<const ::QDBusPendingCall *>(cppSelf)->isError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusPendingCallFunc_isFinished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusPendingCall *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFinished()const
        bool cppResult = const_cast<const ::QDBusPendingCall *>(cppSelf)->isFinished();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusPendingCallFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusPendingCall *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QDBusPendingCall *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusPendingCallFunc_reply(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusPendingCall *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reply()const
        QDBusMessage cppResult = const_cast<const ::QDBusPendingCall *>(cppSelf)->reply();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusPendingCallFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusPendingCall *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusPendingCall::swap(QDBusPendingCall&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QDBusPendingCall&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDBusPendingCall *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QDBusPendingCall&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusPendingCallFunc_waitForFinished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusPendingCall *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // waitForFinished()
        cppSelf->waitForFinished();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QDBusPendingCall_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDBusPendingCall_methods[] = {
    {"error", reinterpret_cast<PyCFunction>(Sbk_QDBusPendingCallFunc_error), METH_NOARGS, nullptr},
    {"fromCompletedCall", reinterpret_cast<PyCFunction>(Sbk_QDBusPendingCallFunc_fromCompletedCall), METH_O|METH_STATIC, nullptr},
    {"fromError", reinterpret_cast<PyCFunction>(Sbk_QDBusPendingCallFunc_fromError), METH_O|METH_STATIC, nullptr},
    {"isError", reinterpret_cast<PyCFunction>(Sbk_QDBusPendingCallFunc_isError), METH_NOARGS, nullptr},
    {"isFinished", reinterpret_cast<PyCFunction>(Sbk_QDBusPendingCallFunc_isFinished), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QDBusPendingCallFunc_isValid), METH_NOARGS, nullptr},
    {"reply", reinterpret_cast<PyCFunction>(Sbk_QDBusPendingCallFunc_reply), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QDBusPendingCallFunc_swap), METH_O, nullptr},
    {"waitForFinished", reinterpret_cast<PyCFunction>(Sbk_QDBusPendingCallFunc_waitForFinished), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QDBusPendingCall_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDBusPendingCall_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDBusPendingCall_Type = nullptr;
static PyTypeObject *Sbk_QDBusPendingCall_TypeF(void)
{
    return _Sbk_QDBusPendingCall_Type;
}

static PyType_Slot Sbk_QDBusPendingCall_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDBusPendingCall_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDBusPendingCall_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDBusPendingCall_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDBusPendingCall_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDBusPendingCall_spec = {
    "2:PySide6.QtDBus.QDBusPendingCall",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDBusPendingCall_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDBusPendingCall_PythonToCpp_QDBusPendingCall_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDBusPendingCall_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDBusPendingCall_PythonToCpp_QDBusPendingCall_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusPendingCall_TypeF()))
        return QDBusPendingCall_PythonToCpp_QDBusPendingCall_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDBusPendingCall_PTR_CppToPython_QDBusPendingCall(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDBusPendingCall_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDBusPendingCall_SignatureStrings[] = {
    "PySide6.QtDBus.QDBusPendingCall(self,other:PySide6.QtDBus.QDBusPendingCall)",
    "PySide6.QtDBus.QDBusPendingCall.error(self)->PySide6.QtDBus.QDBusError",
    "PySide6.QtDBus.QDBusPendingCall.fromCompletedCall(message:PySide6.QtDBus.QDBusMessage)->PySide6.QtDBus.QDBusPendingCall",
    "PySide6.QtDBus.QDBusPendingCall.fromError(error:typing.Union[PySide6.QtDBus.QDBusError, PySide6.QtDBus.QDBusMessage])->PySide6.QtDBus.QDBusPendingCall",
    "PySide6.QtDBus.QDBusPendingCall.isError(self)->bool",
    "PySide6.QtDBus.QDBusPendingCall.isFinished(self)->bool",
    "PySide6.QtDBus.QDBusPendingCall.isValid(self)->bool",
    "PySide6.QtDBus.QDBusPendingCall.reply(self)->PySide6.QtDBus.QDBusMessage",
    "PySide6.QtDBus.QDBusPendingCall.swap(self,other:PySide6.QtDBus.QDBusPendingCall)",
    "PySide6.QtDBus.QDBusPendingCall.waitForFinished(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QDBusPendingCall_SignatureByteSize = 193;
static constexpr uint8_t QDBusPendingCall_SignatureBytes[193] = {
    0x78, 0xda, 0xad, 0x52, 0xbd, 0x0a, 0xc2, 0x30, 0x10, 0xde, 0xfb, 0x14, 0x8e, 0x16, 0x6a, 0x46,
    0x87, 0x0e, 0x0e, 0x56, 0xbb, 0x09, 0x2d, 0xa2, 0x8b, 0x38, 0x44, 0x72, 0x6d, 0x0f, 0xd2, 0x24,
    0x24, 0x91, 0xd2, 0xb7, 0xd7, 0xa6, 0x0a, 0x0a, 0xfd, 0x85, 0x2e, 0x59, 0xee, 0xfb, 0xbb, 0xef,
    0x92, 0xd4, 0x67, 0x64, 0xb0, 0x25, 0xa9, 0x3d, 0xec, 0x9f, 0x86, 0xa4, 0xcd, 0x9b, 0x80, 0x60,
    0x28, 0xf2, 0x88, 0x72, 0xbe, 0x36, 0xc0, 0xb3, 0x40, 0xda, 0x02, 0x74, 0x98, 0x0c, 0x43, 0x7d,
    0x6f, 0x04, 0x40, 0x40, 0x6b, 0xa9, 0x9d, 0xa2, 0xbf, 0xd9, 0x75, 0x81, 0x8f, 0x0d, 0x60, 0x54,
    0x26, 0xd3, 0xb2, 0x8c, 0x64, 0xa9, 0x38, 0x58, 0x60, 0x2e, 0x64, 0x09, 0xc6, 0xd0, 0x1c, 0x3a,
    0x13, 0x9e, 0xda, 0x59, 0x8f, 0xe3, 0x8f, 0xee, 0x24, 0x5f, 0x97, 0x70, 0xed, 0x16, 0x09, 0x6d,
    0xad, 0xde, 0x23, 0x72, 0x11, 0x28, 0xc5, 0xad, 0x77, 0x9d, 0x60, 0x35, 0x90, 0xea, 0xbe, 0x40,
    0x2c, 0x6c, 0x7d, 0xbe, 0xbd, 0x3e, 0xa4, 0x9c, 0xc2, 0x89, 0x51, 0xa0, 0x29, 0x80, 0xcd, 0xa4,
    0x5d, 0x29, 0xc7, 0x79, 0x1c, 0x0d, 0x8a, 0xd7, 0x43, 0x47, 0xff, 0x54, 0x31, 0x2a, 0x64, 0x2a,
    0xaa, 0x16, 0xfd, 0x8e, 0x15, 0x45, 0x1b, 0x4b, 0xfd, 0xdf, 0x84, 0xf7, 0x02, 0x28, 0x55, 0x14,
    0xc7
};
#endif

PyTypeObject *init_QDBusPendingCall(PyObject *module)
{
    if (SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX].type != nullptr)
        return SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX].type;

    Shiboken::AutoDecRef Sbk_QDBusPendingCall_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDBusPendingCall_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDBusPendingCall",
        "QDBusPendingCall*",
        &Sbk_QDBusPendingCall_spec,
        &Shiboken::callCppDestructor< ::QDBusPendingCall >,
        Sbk_QDBusPendingCall_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDBusPendingCall_TypeF(); // references _Sbk_QDBusPendingCall_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDBusPendingCall_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDBusPendingCall_SignatureBytes, QDBusPendingCall_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDBusPendingCall_PropertyStrings);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDBusPendingCall_PythonToCpp_QDBusPendingCall_PTR,
        is_QDBusPendingCall_PythonToCpp_QDBusPendingCall_PTR_Convertible,
        QDBusPendingCall_PTR_CppToPython_QDBusPendingCall);

    Shiboken::Conversions::registerConverterName(converter, "QDBusPendingCall");
    Shiboken::Conversions::registerConverterName(converter, "QDBusPendingCall*");
    Shiboken::Conversions::registerConverterName(converter, "QDBusPendingCall&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDBusPendingCall).name());

    qRegisterMetaType< ::QDBusPendingCall *>();

    return pyType;
}
