// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdbus_python.h"

// main header
#include "qdbussignature_wrapper.h"

// Argument includes
#include <QString>
#include <QtCore/qlatin1stringview.h>
#include <QtDBus/qdbusextratypes.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDBusSignature_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDBusSignature >()))
        return -1;

    ::QDBusSignature *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDBusSignature", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDBusSignature::QDBusSignature()
    // 1: QDBusSignature::QDBusSignature(QLatin1String)
    // 2: QDBusSignature::QDBusSignature(QString)
    // 3: QDBusSignature::QDBusSignature(const char*)
    if (numArgs == 0) {
        overloadId = 0; // QDBusSignature()
    } else if (numArgs == 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        overloadId = 3; // QDBusSignature(const char*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 2; // QDBusSignature(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], (pyArgs[0])))) {
        overloadId = 1; // QDBusSignature(QLatin1String)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDBusSignature()
        {

            // QDBusSignature()
            cptr = new ::QDBusSignature();
            break;
        }
        case 1: // QDBusSignature(QLatin1String signature)
        {
            ::QLatin1String cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusSignature(QLatin1String)
                cptr = new ::QDBusSignature(cppArg0);
            }
            break;
        }
        case 2: // QDBusSignature(const QString &signature)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusSignature(QString)
                cptr = new ::QDBusSignature(cppArg0);
            }
            break;
        }
        case 3: // QDBusSignature(const char *signature)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusSignature(const char*)
                cptr = new ::QDBusSignature(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDBusSignature >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDBusSignatureFunc_setSignature(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusSignature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusSignature::setSignature(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setSignature(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSignature", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSignature(QString)
            cppSelf->setSignature(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusSignatureFunc_signature(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusSignature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // signature()const
        QString cppResult = const_cast<const ::QDBusSignature *>(cppSelf)->signature();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusSignatureFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusSignature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusSignature::swap(QDBusSignature&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QDBusSignature&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDBusSignature *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QDBusSignature&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QDBusSignature_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDBusSignature_methods[] = {
    {"setSignature", reinterpret_cast<PyCFunction>(Sbk_QDBusSignatureFunc_setSignature), METH_O, nullptr},
    {"signature", reinterpret_cast<PyCFunction>(Sbk_QDBusSignatureFunc_signature), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QDBusSignatureFunc_swap), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QDBusSignature_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDBusSignature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]), (pyArg)))) {
                // operator!=(const QDBusSignature &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDBusSignature *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]), (pyArg)))) {
                // operator<(const QDBusSignature &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDBusSignature *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]), (pyArg)))) {
                // operator==(const QDBusSignature &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDBusSignature *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QDBusSignature_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusSignature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QDBusSignature_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDBusSignature_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDBusSignature_Type = nullptr;
static PyTypeObject *Sbk_QDBusSignature_TypeF(void)
{
    return _Sbk_QDBusSignature_Type;
}

static PyType_Slot Sbk_QDBusSignature_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QDBusSignature_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDBusSignature_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDBusSignature_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QDBusSignature_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDBusSignature_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDBusSignature_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDBusSignature_spec = {
    "2:PySide6.QtDBus.QDBusSignature",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDBusSignature_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDBusSignature_PythonToCpp_QDBusSignature_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDBusSignature_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDBusSignature_PythonToCpp_QDBusSignature_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusSignature_TypeF()))
        return QDBusSignature_PythonToCpp_QDBusSignature_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDBusSignature_PTR_CppToPython_QDBusSignature(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDBusSignature_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDBusSignature_SignatureStrings[] = {
    "3:PySide6.QtDBus.QDBusSignature(self)",
    "2:PySide6.QtDBus.QDBusSignature(self,signature:QLatin1String)",
    "1:PySide6.QtDBus.QDBusSignature(self,signature:QString)",
    "0:PySide6.QtDBus.QDBusSignature(self,signature:char*)",
    "PySide6.QtDBus.QDBusSignature.setSignature(self,signature:QString)",
    "PySide6.QtDBus.QDBusSignature.signature(self)->QString",
    "PySide6.QtDBus.QDBusSignature.swap(self,other:PySide6.QtDBus.QDBusSignature)",
    "PySide6.QtDBus.QDBusSignature.__ne__(self,rhs:PySide6.QtDBus.QDBusSignature)->bool",
    "PySide6.QtDBus.QDBusSignature.__lt__(self,rhs:PySide6.QtDBus.QDBusSignature)->bool",
    "PySide6.QtDBus.QDBusSignature.__eq__(self,rhs:PySide6.QtDBus.QDBusSignature)->bool",
    "PySide6.QtDBus.QDBusSignature.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QDBusSignature_SignatureByteSize = 160;
static constexpr uint8_t QDBusSignature_SignatureBytes[160] = {
    0x78, 0xda, 0x33, 0xb6, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x71,
    0x2a, 0x2d, 0xd6, 0x0b, 0x04, 0x91, 0xc1, 0x99, 0xe9, 0x79, 0x89, 0x25, 0xa5, 0x45, 0xa9, 0x1a,
    0xc5, 0xa9, 0x39, 0x69, 0x9a, 0x5c, 0x46, 0x44, 0xa8, 0xd2, 0x29, 0x86, 0x71, 0xad, 0x02, 0x7d,
    0x12, 0x4b, 0x32, 0xf3, 0x0c, 0x83, 0x4b, 0x8a, 0x32, 0xf3, 0xd2, 0x35, 0xb9, 0x0c, 0x49, 0xd4,
    0x0d, 0xd3, 0x67, 0x40, 0x9a, 0xbe, 0xe4, 0x8c, 0xc4, 0x22, 0x2d, 0x4d, 0x2e, 0xbc, 0x7a, 0xf4,
    0x8a, 0x53, 0x4b, 0x08, 0x5b, 0x4c, 0xc0, 0x08, 0xd4, 0xc0, 0xd1, 0xb5, 0x83, 0xea, 0x23, 0xa4,
    0xad, 0x3c, 0xb1, 0x00, 0x62, 0x63, 0x7e, 0x49, 0x46, 0x6a, 0x11, 0x7e, 0xbf, 0x11, 0x72, 0x43,
    0x7c, 0x7c, 0x5e, 0x6a, 0x7c, 0x3c, 0xc4, 0xb8, 0xa2, 0x8c, 0x62, 0x02, 0x86, 0xe9, 0xda, 0x25,
    0xe5, 0xe7, 0xe7, 0x10, 0x34, 0x32, 0xa7, 0x84, 0xea, 0x46, 0xa6, 0x16, 0x52, 0xdd, 0xc8, 0x8c,
    0xc4, 0xe2, 0x0c, 0xa8, 0xa1, 0x40, 0x2d, 0x99, 0x79, 0x25, 0x5c, 0x00, 0xab, 0x7c, 0xfb, 0x84
};
#endif

PyTypeObject *init_QDBusSignature(PyObject *module)
{
    if (SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX].type != nullptr)
        return SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX].type;

    Shiboken::AutoDecRef Sbk_QDBusSignature_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDBusSignature_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDBusSignature",
        "QDBusSignature*",
        &Sbk_QDBusSignature_spec,
        &Shiboken::callCppDestructor< ::QDBusSignature >,
        Sbk_QDBusSignature_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDBusSignature_TypeF(); // references _Sbk_QDBusSignature_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDBusSignature_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDBusSignature_SignatureBytes, QDBusSignature_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDBusSignature_PropertyStrings);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusSignature_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDBusSignature_PythonToCpp_QDBusSignature_PTR,
        is_QDBusSignature_PythonToCpp_QDBusSignature_PTR_Convertible,
        QDBusSignature_PTR_CppToPython_QDBusSignature);

    Shiboken::Conversions::registerConverterName(converter, "QDBusSignature");
    Shiboken::Conversions::registerConverterName(converter, "QDBusSignature*");
    Shiboken::Conversions::registerConverterName(converter, "QDBusSignature&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDBusSignature).name());

    qRegisterMetaType< ::QDBusSignature *>();

    return pyType;
}
