// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdbus_python.h"

// main header
#include "qdbusunixfiledescriptor_wrapper.h"

// Argument includes
#include <QtDBus/qdbusunixfiledescriptor.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDBusUnixFileDescriptor_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDBusUnixFileDescriptor >()))
        return -1;

    ::QDBusUnixFileDescriptor *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDBusUnixFileDescriptor", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDBusUnixFileDescriptor::QDBusUnixFileDescriptor()
    // 1: QDBusUnixFileDescriptor::QDBusUnixFileDescriptor(QDBusUnixFileDescriptor)
    // 2: QDBusUnixFileDescriptor::QDBusUnixFileDescriptor(int)
    if (numArgs == 0) {
        overloadId = 0; // QDBusUnixFileDescriptor()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 2; // QDBusUnixFileDescriptor(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDBusUnixFileDescriptor(QDBusUnixFileDescriptor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDBusUnixFileDescriptor()
        {

            // QDBusUnixFileDescriptor()
            cptr = new ::QDBusUnixFileDescriptor();
            break;
        }
        case 1: // QDBusUnixFileDescriptor(const QDBusUnixFileDescriptor &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDBusUnixFileDescriptor cppArg0_local;
            ::QDBusUnixFileDescriptor *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusUnixFileDescriptor(QDBusUnixFileDescriptor)
                cptr = new ::QDBusUnixFileDescriptor(*cppArg0);
            }
            break;
        }
        case 2: // QDBusUnixFileDescriptor(int fileDescriptor)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusUnixFileDescriptor(int)
                cptr = new ::QDBusUnixFileDescriptor(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDBusUnixFileDescriptor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDBusUnixFileDescriptorFunc_fileDescriptor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusUnixFileDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileDescriptor()const
        int cppResult = const_cast<const ::QDBusUnixFileDescriptor *>(cppSelf)->fileDescriptor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusUnixFileDescriptorFunc_giveFileDescriptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusUnixFileDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusUnixFileDescriptor::giveFileDescriptor(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // giveFileDescriptor(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "giveFileDescriptor", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // giveFileDescriptor(int)
            cppSelf->giveFileDescriptor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusUnixFileDescriptorFunc_isSupported(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSupported()
        bool cppResult = ::QDBusUnixFileDescriptor::isSupported();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusUnixFileDescriptorFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusUnixFileDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QDBusUnixFileDescriptor *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusUnixFileDescriptorFunc_setFileDescriptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusUnixFileDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusUnixFileDescriptor::setFileDescriptor(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setFileDescriptor(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFileDescriptor", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFileDescriptor(int)
            cppSelf->setFileDescriptor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusUnixFileDescriptorFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusUnixFileDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusUnixFileDescriptor::swap(QDBusUnixFileDescriptor&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QDBusUnixFileDescriptor&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDBusUnixFileDescriptor cppArg0_local;
        ::QDBusUnixFileDescriptor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QDBusUnixFileDescriptor&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusUnixFileDescriptorFunc_takeFileDescriptor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusUnixFileDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // takeFileDescriptor()
        int cppResult = cppSelf->takeFileDescriptor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusUnixFileDescriptor__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDBusUnixFileDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDBusUnixFileDescriptor_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDBusUnixFileDescriptor_methods[] = {
    {"fileDescriptor", reinterpret_cast<PyCFunction>(Sbk_QDBusUnixFileDescriptorFunc_fileDescriptor), METH_NOARGS, nullptr},
    {"giveFileDescriptor", reinterpret_cast<PyCFunction>(Sbk_QDBusUnixFileDescriptorFunc_giveFileDescriptor), METH_O, nullptr},
    {"isSupported", reinterpret_cast<PyCFunction>(Sbk_QDBusUnixFileDescriptorFunc_isSupported), METH_NOARGS|METH_STATIC, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QDBusUnixFileDescriptorFunc_isValid), METH_NOARGS, nullptr},
    {"setFileDescriptor", reinterpret_cast<PyCFunction>(Sbk_QDBusUnixFileDescriptorFunc_setFileDescriptor), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QDBusUnixFileDescriptorFunc_swap), METH_O, nullptr},
    {"takeFileDescriptor", reinterpret_cast<PyCFunction>(Sbk_QDBusUnixFileDescriptorFunc_takeFileDescriptor), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDBusUnixFileDescriptor__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QDBusUnixFileDescriptor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDBusUnixFileDescriptor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDBusUnixFileDescriptor_Type = nullptr;
static PyTypeObject *Sbk_QDBusUnixFileDescriptor_TypeF(void)
{
    return _Sbk_QDBusUnixFileDescriptor_Type;
}

static PyType_Slot Sbk_QDBusUnixFileDescriptor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDBusUnixFileDescriptor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDBusUnixFileDescriptor_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDBusUnixFileDescriptor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDBusUnixFileDescriptor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDBusUnixFileDescriptor_spec = {
    "2:PySide6.QtDBus.QDBusUnixFileDescriptor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDBusUnixFileDescriptor_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDBusUnixFileDescriptor_PythonToCpp_QDBusUnixFileDescriptor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDBusUnixFileDescriptor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDBusUnixFileDescriptor_PythonToCpp_QDBusUnixFileDescriptor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusUnixFileDescriptor_TypeF()))
        return QDBusUnixFileDescriptor_PythonToCpp_QDBusUnixFileDescriptor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDBusUnixFileDescriptor_PTR_CppToPython_QDBusUnixFileDescriptor(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDBusUnixFileDescriptor_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDBusUnixFileDescriptor_COPY_CppToPython_QDBusUnixFileDescriptor(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDBusUnixFileDescriptor *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDBusUnixFileDescriptor_TypeF(), new ::QDBusUnixFileDescriptor(*source), true, true);
}

// Python to C++ copy conversion.
static void QDBusUnixFileDescriptor_PythonToCpp_QDBusUnixFileDescriptor_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDBusUnixFileDescriptor *>(cppOut) = *reinterpret_cast< ::QDBusUnixFileDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDBusUnixFileDescriptor_PythonToCpp_QDBusUnixFileDescriptor_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusUnixFileDescriptor_TypeF()))
        return QDBusUnixFileDescriptor_PythonToCpp_QDBusUnixFileDescriptor_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDBusUnixFileDescriptor_SignatureStrings[] = {
    "2:PySide6.QtDBus.QDBusUnixFileDescriptor(self)",
    "1:PySide6.QtDBus.QDBusUnixFileDescriptor(self,other:PySide6.QtDBus.QDBusUnixFileDescriptor)",
    "0:PySide6.QtDBus.QDBusUnixFileDescriptor(self,fileDescriptor:int)",
    "PySide6.QtDBus.QDBusUnixFileDescriptor.fileDescriptor(self)->int",
    "PySide6.QtDBus.QDBusUnixFileDescriptor.giveFileDescriptor(self,fileDescriptor:int)",
    "PySide6.QtDBus.QDBusUnixFileDescriptor.isSupported()->bool",
    "PySide6.QtDBus.QDBusUnixFileDescriptor.isValid(self)->bool",
    "PySide6.QtDBus.QDBusUnixFileDescriptor.setFileDescriptor(self,fileDescriptor:int)",
    "PySide6.QtDBus.QDBusUnixFileDescriptor.swap(self,other:PySide6.QtDBus.QDBusUnixFileDescriptor)",
    "PySide6.QtDBus.QDBusUnixFileDescriptor.takeFileDescriptor(self)->int",
    "PySide6.QtDBus.QDBusUnixFileDescriptor.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QDBusUnixFileDescriptor_SignatureByteSize = 173;
static constexpr uint8_t QDBusUnixFileDescriptor_SignatureBytes[173] = {
    0x78, 0xda, 0x33, 0xb2, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x71,
    0x2a, 0x2d, 0xd6, 0x0b, 0x04, 0x91, 0xa1, 0x79, 0x99, 0x15, 0x6e, 0x99, 0x39, 0xa9, 0x2e, 0xa9,
    0xc5, 0xc9, 0x45, 0x99, 0x05, 0x25, 0xf9, 0x45, 0x1a, 0xc5, 0xa9, 0x39, 0x69, 0x9a, 0x5c, 0x86,
    0xa4, 0x28, 0xd7, 0xc9, 0x2f, 0xc9, 0x48, 0x2d, 0x22, 0x52, 0x87, 0x26, 0x97, 0x01, 0x49, 0x66,
    0xa7, 0xa1, 0x88, 0x59, 0x65, 0xe6, 0x95, 0x68, 0x72, 0x11, 0xa7, 0x5f, 0x2f, 0x0d, 0x8b, 0xcf,
    0x74, 0xed, 0x80, 0x26, 0x10, 0x6b, 0x40, 0x7a, 0x66, 0x59, 0x2a, 0x95, 0xdd, 0x94, 0x59, 0x1c,
    0x5c, 0x5a, 0x50, 0x90, 0x5f, 0x54, 0x92, 0x9a, 0xa2, 0x01, 0x74, 0x4c, 0x52, 0x7e, 0x7e, 0x0e,
    0xf1, 0x5a, 0xc3, 0x12, 0x73, 0x32, 0x53, 0x60, 0xfe, 0x20, 0x45, 0x6b, 0x71, 0x6a, 0x09, 0x95,
    0xfd, 0x51, 0x5c, 0x9e, 0x58, 0x40, 0x4e, 0xe4, 0x13, 0x69, 0x7c, 0x49, 0x62, 0x36, 0xb6, 0x90,
    0x27, 0x2d, 0xfa, 0xe2, 0xe3, 0x93, 0xf3, 0x0b, 0x2a, 0xe3, 0xe3, 0x61, 0x5a, 0x4b, 0x2a, 0x0b,
    0x32, 0xf3, 0xd2, 0xf5, 0x82, 0x81, 0x3c, 0x2e, 0x00, 0x78, 0xe8, 0x1d, 0xaf
};
#endif

PyTypeObject *init_QDBusUnixFileDescriptor(PyObject *module)
{
    if (SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX].type != nullptr)
        return SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX].type;

    Shiboken::AutoDecRef Sbk_QDBusUnixFileDescriptor_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDBusUnixFileDescriptor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDBusUnixFileDescriptor",
        "QDBusUnixFileDescriptor",
        &Sbk_QDBusUnixFileDescriptor_spec,
        &Shiboken::callCppDestructor< ::QDBusUnixFileDescriptor >,
        Sbk_QDBusUnixFileDescriptor_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDBusUnixFileDescriptor_TypeF(); // references _Sbk_QDBusUnixFileDescriptor_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDBusUnixFileDescriptor_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDBusUnixFileDescriptor_SignatureBytes, QDBusUnixFileDescriptor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDBusUnixFileDescriptor_PropertyStrings);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDBusUnixFileDescriptor_PythonToCpp_QDBusUnixFileDescriptor_PTR,
        is_QDBusUnixFileDescriptor_PythonToCpp_QDBusUnixFileDescriptor_PTR_Convertible,
        QDBusUnixFileDescriptor_PTR_CppToPython_QDBusUnixFileDescriptor,
        QDBusUnixFileDescriptor_COPY_CppToPython_QDBusUnixFileDescriptor);

    Shiboken::Conversions::registerConverterName(converter, "QDBusUnixFileDescriptor");
    Shiboken::Conversions::registerConverterName(converter, "QDBusUnixFileDescriptor*");
    Shiboken::Conversions::registerConverterName(converter, "QDBusUnixFileDescriptor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDBusUnixFileDescriptor).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDBusUnixFileDescriptor_PythonToCpp_QDBusUnixFileDescriptor_COPY,
        is_QDBusUnixFileDescriptor_PythonToCpp_QDBusUnixFileDescriptor_COPY_Convertible);

    qRegisterMetaType< ::QDBusUnixFileDescriptor >("QDBusUnixFileDescriptor");

    return pyType;
}
