// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdbus_python.h"

// main header
#include "qdbusvariant_wrapper.h"

// Argument includes
#include <QtDBus/qdbusextratypes.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDBusVariant_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDBusVariant >()))
        return -1;

    ::QDBusVariant *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDBusVariant", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDBusVariant::QDBusVariant()
    // 1: QDBusVariant::QDBusVariant(QDBusVariant)
    // 2: QDBusVariant::QDBusVariant(QVariant)
    if (numArgs == 0) {
        overloadId = 0; // QDBusVariant()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDBusVariant(QDBusVariant)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[0])))) {
        overloadId = 2; // QDBusVariant(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDBusVariant()
        {

            // QDBusVariant()
            cptr = new ::QDBusVariant();
            break;
        }
        case 1: // QDBusVariant(const QDBusVariant &QDBusVariant)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDBusVariant cppArg0_local;
            ::QDBusVariant *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusVariant(QDBusVariant)
                cptr = new ::QDBusVariant(*cppArg0);
            }
            break;
        }
        case 2: // QDBusVariant(const QVariant &variant)
        {
            ::QVariant cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusVariant(QVariant)
                cptr = new ::QDBusVariant(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDBusVariant >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDBusVariantFunc_setVariant(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusVariant *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusVariant::setVariant(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setVariant(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVariant", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVariant(QVariant)
            cppSelf->setVariant(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusVariantFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusVariant *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusVariant::swap(QDBusVariant&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QDBusVariant&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDBusVariant cppArg0_local;
        ::QDBusVariant *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QDBusVariant&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusVariantFunc_variant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusVariant *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // variant()const
        QVariant cppResult = const_cast<const ::QDBusVariant *>(cppSelf)->variant();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusVariant__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDBusVariant *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDBusVariant_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDBusVariant_methods[] = {
    {"setVariant", reinterpret_cast<PyCFunction>(Sbk_QDBusVariantFunc_setVariant), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QDBusVariantFunc_swap), METH_O, nullptr},
    {"variant", reinterpret_cast<PyCFunction>(Sbk_QDBusVariantFunc_variant), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDBusVariant__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QDBusVariant_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDBusVariant *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]), (pyArg)))) {
                // operator==(const QDBusVariant &v2)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDBusVariant cppArg0_local;
                ::QDBusVariant *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QDBusVariant_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDBusVariant_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDBusVariant_Type = nullptr;
static PyTypeObject *Sbk_QDBusVariant_TypeF(void)
{
    return _Sbk_QDBusVariant_Type;
}

static PyType_Slot Sbk_QDBusVariant_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDBusVariant_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDBusVariant_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QDBusVariant_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDBusVariant_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDBusVariant_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDBusVariant_spec = {
    "2:PySide6.QtDBus.QDBusVariant",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDBusVariant_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDBusVariant_PythonToCpp_QDBusVariant_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDBusVariant_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDBusVariant_PythonToCpp_QDBusVariant_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusVariant_TypeF()))
        return QDBusVariant_PythonToCpp_QDBusVariant_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDBusVariant_PTR_CppToPython_QDBusVariant(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDBusVariant_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDBusVariant_COPY_CppToPython_QDBusVariant(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDBusVariant *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDBusVariant_TypeF(), new ::QDBusVariant(*source), true, true);
}

// Python to C++ copy conversion.
static void QDBusVariant_PythonToCpp_QDBusVariant_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDBusVariant *>(cppOut) = *reinterpret_cast< ::QDBusVariant *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDBusVariant_PythonToCpp_QDBusVariant_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusVariant_TypeF()))
        return QDBusVariant_PythonToCpp_QDBusVariant_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDBusVariant_SignatureStrings[] = {
    "2:PySide6.QtDBus.QDBusVariant(self)",
    "1:PySide6.QtDBus.QDBusVariant(self,QDBusVariant:PySide6.QtDBus.QDBusVariant)",
    "0:PySide6.QtDBus.QDBusVariant(self,variant:QVariant)",
    "PySide6.QtDBus.QDBusVariant.setVariant(self,variant:QVariant)",
    "PySide6.QtDBus.QDBusVariant.swap(self,other:PySide6.QtDBus.QDBusVariant)",
    "PySide6.QtDBus.QDBusVariant.variant(self)->QVariant",
    "PySide6.QtDBus.QDBusVariant.__copy__(self)->typing.Self",
    "PySide6.QtDBus.QDBusVariant.__eq__(self,v2:PySide6.QtDBus.QDBusVariant)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QDBusVariant_SignatureByteSize = 133;
static constexpr uint8_t QDBusVariant_SignatureBytes[133] = {
    0x78, 0xda, 0x33, 0xb2, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x71,
    0x2a, 0x2d, 0xd6, 0x0b, 0x04, 0x91, 0x61, 0x89, 0x45, 0x99, 0x89, 0x79, 0x25, 0x1a, 0xc5, 0xa9,
    0x39, 0x69, 0x9a, 0x5c, 0x86, 0x04, 0xd5, 0xe8, 0x20, 0x8b, 0xe0, 0x53, 0xad, 0xc9, 0x65, 0x40,
    0xd8, 0xb0, 0x32, 0xa8, 0x39, 0x81, 0x70, 0x4d, 0x78, 0xb4, 0xe8, 0x15, 0xa7, 0x96, 0x50, 0xa2,
    0xbb, 0x3c, 0xb1, 0x00, 0xa2, 0x2f, 0xbf, 0x24, 0x23, 0xb5, 0x08, 0xbf, 0xdb, 0xf1, 0x19, 0x54,
    0x86, 0x1c, 0x64, 0xba, 0x76, 0x30, 0xdb, 0xf1, 0xea, 0x89, 0x8f, 0x4f, 0xce, 0x2f, 0xa8, 0x8c,
    0x8f, 0x87, 0x69, 0x2a, 0xa9, 0x2c, 0xc8, 0xcc, 0x4b, 0xd7, 0x0b, 0x06, 0xf2, 0x08, 0xe8, 0x4b,
    0x2d, 0x84, 0xea, 0xd2, 0x29, 0x33, 0xc2, 0xeb, 0x66, 0x5d, 0xbb, 0xa4, 0xfc, 0xfc, 0x1c, 0x2e,
    0x00, 0x82, 0x2e, 0xaa, 0xcf
};
#endif

PyTypeObject *init_QDBusVariant(PyObject *module)
{
    if (SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX].type != nullptr)
        return SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX].type;

    Shiboken::AutoDecRef Sbk_QDBusVariant_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDBusVariant_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDBusVariant",
        "QDBusVariant",
        &Sbk_QDBusVariant_spec,
        &Shiboken::callCppDestructor< ::QDBusVariant >,
        Sbk_QDBusVariant_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDBusVariant_TypeF(); // references _Sbk_QDBusVariant_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDBusVariant_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDBusVariant_SignatureBytes, QDBusVariant_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDBusVariant_PropertyStrings);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusVariant_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDBusVariant_PythonToCpp_QDBusVariant_PTR,
        is_QDBusVariant_PythonToCpp_QDBusVariant_PTR_Convertible,
        QDBusVariant_PTR_CppToPython_QDBusVariant,
        QDBusVariant_COPY_CppToPython_QDBusVariant);

    Shiboken::Conversions::registerConverterName(converter, "QDBusVariant");
    Shiboken::Conversions::registerConverterName(converter, "QDBusVariant*");
    Shiboken::Conversions::registerConverterName(converter, "QDBusVariant&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDBusVariant).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDBusVariant_PythonToCpp_QDBusVariant_COPY,
        is_QDBusVariant_PythonToCpp_QDBusVariant_COPY_Convertible);

    qRegisterMetaType< ::QDBusVariant >("QDBusVariant");

    return pyType;
}
