// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdatavisualization_python.h"

// main header
#include "q3dcamera_wrapper.h"

// Argument includes
#include <QtDataVisualization/q3dcamera.h>
#include <QtDataVisualization/q3dobject.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qvectornd.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void Q3DCameraWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

Q3DCameraWrapper::Q3DCameraWrapper(::QObject * parent) : Q3DCamera(parent)
{
}

void Q3DCameraWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DCamera", funcName);
        return;
    }
}

void Q3DCameraWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DCamera", funcName);
        return;
    }
}

void Q3DCameraWrapper::copyValuesFrom(const ::Q3DObject & source)
{
    if (m_PyMethodCache[2]) {
        return this->::Q3DCamera::copyValuesFrom(source);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "copyValuesFrom";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::Q3DCamera::copyValuesFrom(source);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DObject_IDX]), &source)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DObject_IDX]), &source)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DCamera", funcName);
        return;
    }
}

void Q3DCameraWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DCamera", funcName);
        return;
    }
}

void Q3DCameraWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DCamera", funcName);
        return;
    }
}

bool Q3DCameraWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DCamera", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("Q3DCamera", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool Q3DCameraWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[6])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DCamera", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("Q3DCamera", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void Q3DCameraWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[7]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DCamera", funcName);
        return;
    }
}

const QMetaObject *Q3DCameraWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Q3DCamera::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int Q3DCameraWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Q3DCamera::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *Q3DCameraWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< Q3DCameraWrapper *>(this));
    return Q3DCamera::qt_metacast(_clname);
}

Q3DCameraWrapper::~Q3DCameraWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Q3DCamera_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Q3DCamera >()))
        return -1;

    Q3DCameraWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:Q3DCamera", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Q3DCamera::Q3DCamera(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // Q3DCamera(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // Q3DCamera(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Q3DCamera(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) Q3DCameraWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new Q3DCameraWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Q3DCamera >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Q3DCameraFunc_cameraPreset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cameraPreset()const
        Q3DCamera::CameraPreset cppResult = const_cast<const ::Q3DCamera *>(cppSelf)->cameraPreset();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_CameraPreset_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DCameraFunc_copyValuesFrom(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DObject::copyValuesFrom(Q3DObject)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DObject_IDX]), (pyArg)))) {
        overloadId = 0; // copyValuesFrom(Q3DObject)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "copyValuesFrom", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Q3DObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // copyValuesFrom(Q3DObject)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Q3DCamera::copyValuesFrom(*cppArg0)
                : cppSelf->copyValuesFrom(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DCameraFunc_maxZoomLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxZoomLevel()const
        float cppResult = const_cast<const ::Q3DCamera *>(cppSelf)->maxZoomLevel();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DCameraFunc_minZoomLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minZoomLevel()const
        float cppResult = const_cast<const ::Q3DCamera *>(cppSelf)->minZoomLevel();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DCameraFunc_setCameraPosition(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setCameraPosition", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setCameraPosition", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Q3DCamera::setCameraPosition(float,float,float=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setCameraPosition(float,float,float)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
            overloadId = 0; // setCameraPosition(float,float,float)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setCameraPosition", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_zoom = Shiboken::String::createStaticString("zoom");
            if (PyDict_Contains(kwds, key_zoom) != 0) {
                value = PyDict_GetItem(kwds, key_zoom);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_zoom);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setCameraPosition", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "setCameraPosition", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_zoom);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setCameraPosition", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);
            }
        }
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2 = 100.0f;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraPosition(float,float,float)
            cppSelf->setCameraPosition(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DCameraFunc_setCameraPreset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DCamera::setCameraPreset(Q3DCamera::CameraPreset)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_CameraPreset_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setCameraPreset(Q3DCamera::CameraPreset)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCameraPreset", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);

    // Call function/method
    {
        ::Q3DCamera::CameraPreset cppArg0{Q3DCamera::CameraPresetFrontLow};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraPreset(Q3DCamera::CameraPreset)
            cppSelf->setCameraPreset(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DCameraFunc_setMaxZoomLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DCamera::setMaxZoomLevel(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMaxZoomLevel(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxZoomLevel", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxZoomLevel(float)
            cppSelf->setMaxZoomLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DCameraFunc_setMinZoomLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DCamera::setMinZoomLevel(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMinZoomLevel(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinZoomLevel", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinZoomLevel(float)
            cppSelf->setMinZoomLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DCameraFunc_setTarget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DCamera::setTarget(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setTarget(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTarget", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTarget(QVector3D)
            cppSelf->setTarget(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DCameraFunc_setWrapXRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DCamera::setWrapXRotation(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setWrapXRotation(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWrapXRotation", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWrapXRotation(bool)
            cppSelf->setWrapXRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DCameraFunc_setWrapYRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DCamera::setWrapYRotation(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setWrapYRotation(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWrapYRotation", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWrapYRotation(bool)
            cppSelf->setWrapYRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DCameraFunc_setXRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DCamera::setXRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setXRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setXRotation", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setXRotation(float)
            cppSelf->setXRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DCameraFunc_setYRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DCamera::setYRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setYRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setYRotation", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setYRotation(float)
            cppSelf->setYRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DCameraFunc_setZoomLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DCamera::setZoomLevel(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setZoomLevel(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setZoomLevel", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setZoomLevel(float)
            cppSelf->setZoomLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DCameraFunc_target(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // target()const
        QVector3D cppResult = const_cast<const ::Q3DCamera *>(cppSelf)->target();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DCameraFunc_wrapXRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wrapXRotation()const
        bool cppResult = const_cast<const ::Q3DCamera *>(cppSelf)->wrapXRotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DCameraFunc_wrapYRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wrapYRotation()const
        bool cppResult = const_cast<const ::Q3DCamera *>(cppSelf)->wrapYRotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DCameraFunc_xRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // xRotation()const
        float cppResult = const_cast<const ::Q3DCamera *>(cppSelf)->xRotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DCameraFunc_yRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // yRotation()const
        float cppResult = const_cast<const ::Q3DCamera *>(cppSelf)->yRotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DCameraFunc_zoomLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // zoomLevel()const
        float cppResult = const_cast<const ::Q3DCamera *>(cppSelf)->zoomLevel();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Q3DCamera_PropertyStrings[] = {
    "cameraPreset::",
    "maxZoomLevel::",
    "minZoomLevel::",
    "target::",
    "wrapXRotation::",
    "wrapYRotation::",
    "xRotation::",
    "yRotation::",
    "zoomLevel::",
    nullptr // Sentinel
};

static const char *Sbk_Q3DCamera_EnumFlagInfo[] = {
    "CameraPreset:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Q3DCamera_methods[] = {
    {"cameraPreset", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_cameraPreset), METH_NOARGS, nullptr},
    {"copyValuesFrom", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_copyValuesFrom), METH_O, nullptr},
    {"maxZoomLevel", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_maxZoomLevel), METH_NOARGS, nullptr},
    {"minZoomLevel", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_minZoomLevel), METH_NOARGS, nullptr},
    {"setCameraPosition", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_setCameraPosition), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setCameraPreset", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_setCameraPreset), METH_O, nullptr},
    {"setMaxZoomLevel", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_setMaxZoomLevel), METH_O, nullptr},
    {"setMinZoomLevel", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_setMinZoomLevel), METH_O, nullptr},
    {"setTarget", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_setTarget), METH_O, nullptr},
    {"setWrapXRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_setWrapXRotation), METH_O, nullptr},
    {"setWrapYRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_setWrapYRotation), METH_O, nullptr},
    {"setXRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_setXRotation), METH_O, nullptr},
    {"setYRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_setYRotation), METH_O, nullptr},
    {"setZoomLevel", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_setZoomLevel), METH_O, nullptr},
    {"target", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_target), METH_NOARGS, nullptr},
    {"wrapXRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_wrapXRotation), METH_NOARGS, nullptr},
    {"wrapYRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_wrapYRotation), METH_NOARGS, nullptr},
    {"xRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_xRotation), METH_NOARGS, nullptr},
    {"yRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_yRotation), METH_NOARGS, nullptr},
    {"zoomLevel", reinterpret_cast<PyCFunction>(Sbk_Q3DCameraFunc_zoomLevel), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Q3DCamera_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Q3DCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<Q3DCameraWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Q3DCamera_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Q3DCamera_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Q3DCamera_Type = nullptr;
static PyTypeObject *Sbk_Q3DCamera_TypeF(void)
{
    return _Sbk_Q3DCamera_Type;
}

static PyType_Slot Sbk_Q3DCamera_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Q3DCamera_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Q3DCamera_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Q3DCamera_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Q3DCamera_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Q3DCamera_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Q3DCamera_spec = {
    "2:PySide6.QtDataVisualization.Q3DCamera",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Q3DCamera_slots
};

} //extern "C"

static void *Sbk_Q3DCamera_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Q3DCamera *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Q3DCamera_CameraPreset(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Q3DCamera::CameraPreset>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Q3DCamera::CameraPreset *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Q3DCamera_CameraPreset_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_CameraPreset_IDX])))
        return Enum_PythonToCpp_Q3DCamera_CameraPreset;
    return {};
}

static PyObject *Q3DCamera_CameraPreset_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Q3DCamera::CameraPreset>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Q3DCamera::CameraPreset *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_CameraPreset_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Q3DCamera_PythonToCpp_Q3DCamera_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Q3DCamera_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Q3DCamera_PythonToCpp_Q3DCamera_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Q3DCamera_TypeF()))
        return Q3DCamera_PythonToCpp_Q3DCamera_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Q3DCamera_PTR_CppToPython_Q3DCamera(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Q3DCamera *>(const_cast<void *>(cppIn)), Sbk_Q3DCamera_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Q3DCamera_SignatureStrings[] = {
    "PySide6.QtDataVisualization.Q3DCamera(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,xRotation:float=None,yRotation:float=None,zoomLevel:float=None,cameraPreset:Q3DCamera.CameraPreset=None,wrapXRotation:bool=None,wrapYRotation:bool=None,target:QVector3D=None,minZoomLevel:float=None,maxZoomLevel:float=None)",
    "PySide6.QtDataVisualization.Q3DCamera.cameraPreset(self)->PySide6.QtDataVisualization.Q3DCamera.CameraPreset",
    "PySide6.QtDataVisualization.Q3DCamera.copyValuesFrom(self,source:PySide6.QtDataVisualization.Q3DObject)",
    "PySide6.QtDataVisualization.Q3DCamera.maxZoomLevel(self)->float",
    "PySide6.QtDataVisualization.Q3DCamera.minZoomLevel(self)->float",
    "PySide6.QtDataVisualization.Q3DCamera.setCameraPosition(self,horizontal:float,vertical:float,zoom:float=100.0f)",
    "PySide6.QtDataVisualization.Q3DCamera.setCameraPreset(self,preset:PySide6.QtDataVisualization.Q3DCamera.CameraPreset)",
    "PySide6.QtDataVisualization.Q3DCamera.setMaxZoomLevel(self,zoomLevel:float)",
    "PySide6.QtDataVisualization.Q3DCamera.setMinZoomLevel(self,zoomLevel:float)",
    "PySide6.QtDataVisualization.Q3DCamera.setTarget(self,target:PySide6.QtGui.QVector3D)",
    "PySide6.QtDataVisualization.Q3DCamera.setWrapXRotation(self,isEnabled:bool)",
    "PySide6.QtDataVisualization.Q3DCamera.setWrapYRotation(self,isEnabled:bool)",
    "PySide6.QtDataVisualization.Q3DCamera.setXRotation(self,rotation:float)",
    "PySide6.QtDataVisualization.Q3DCamera.setYRotation(self,rotation:float)",
    "PySide6.QtDataVisualization.Q3DCamera.setZoomLevel(self,zoomLevel:float)",
    "PySide6.QtDataVisualization.Q3DCamera.target(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtDataVisualization.Q3DCamera.wrapXRotation(self)->bool",
    "PySide6.QtDataVisualization.Q3DCamera.wrapYRotation(self)->bool",
    "PySide6.QtDataVisualization.Q3DCamera.xRotation(self)->float",
    "PySide6.QtDataVisualization.Q3DCamera.yRotation(self)->float",
    "PySide6.QtDataVisualization.Q3DCamera.zoomLevel(self)->float",
    nullptr}; // Sentinel
#else
static constexpr size_t Q3DCamera_SignatureByteSize = 386;
static constexpr uint8_t Q3DCamera_SignatureBytes[386] = {
    0x78, 0xda, 0xad, 0x54, 0x4d, 0x53, 0x83, 0x30, 0x10, 0xbd, 0xfb, 0x4b, 0xac, 0x83, 0x4c, 0x9d,
    0xce, 0x78, 0x60, 0xa6, 0x5e, 0x8a, 0x7a, 0xf0, 0xa3, 0x54, 0x9d, 0x2a, 0xde, 0x52, 0xba, 0xd5,
    0x38, 0x21, 0xcb, 0x24, 0xa1, 0x2d, 0xfc, 0x7a, 0x0b, 0x41, 0x48, 0x91, 0x19, 0x89, 0xed, 0x91,
    0x47, 0xde, 0xcb, 0xee, 0x7b, 0xd9, 0x0d, 0xb2, 0x67, 0xba, 0x84, 0x4b, 0x77, 0xa6, 0x7c, 0xa2,
    0xc8, 0x9c, 0xca, 0x94, 0x30, 0x9a, 0x13, 0x45, 0x91, 0xbb, 0xb3, 0x91, 0x3f, 0x21, 0x31, 0x08,
    0x72, 0x2a, 0x81, 0xad, 0x9c, 0x84, 0x08, 0xe0, 0xca, 0x0b, 0x6a, 0xc6, 0x04, 0x05, 0xb8, 0xb3,
    0xe9, 0xe2, 0x0b, 0x22, 0x35, 0xe6, 0x29, 0x63, 0x89, 0x12, 0xce, 0x99, 0x77, 0x07, 0xd9, 0x06,
    0xc5, 0x72, 0xca, 0x59, 0x36, 0x7e, 0x44, 0x0e, 0xce, 0xf6, 0x09, 0x55, 0xa9, 0xe8, 0xad, 0x18,
    0x12, 0xa5, 0xc1, 0xac, 0x0b, 0xcc, 0x11, 0xe3, 0x7b, 0x58, 0x03, 0x33, 0xc1, 0xa8, 0xac, 0x21,
    0x10, 0x20, 0x41, 0x79, 0x75, 0x4d, 0xee, 0xc4, 0x80, 0xf5, 0xc1, 0x8d, 0x20, 0xc9, 0x5b, 0x2d,
    0xbb, 0x40, 0x64, 0x0d, 0x1e, 0x76, 0xe0, 0x8a, 0x88, 0x8f, 0x42, 0x72, 0xbe, 0xab, 0x1f, 0xc5,
    0xc8, 0xd7, 0x68, 0x4c, 0xf9, 0x7b, 0x57, 0x19, 0x31, 0xd9, 0x76, 0xe1, 0x83, 0x93, 0xa0, 0x8f,
    0x85, 0xae, 0xd9, 0x45, 0xe9, 0xe7, 0xe0, 0xfc, 0xaa, 0x1f, 0xd3, 0x6c, 0xb4, 0xef, 0x65, 0x98,
    0x64, 0x73, 0xc2, 0x52, 0x90, 0x37, 0x02, 0x63, 0x1d, 0x9f, 0xc4, 0x54, 0x44, 0xe0, 0xfd, 0x21,
    0xa0, 0xd3, 0xec, 0xdb, 0x94, 0xe9, 0xc9, 0x4f, 0x53, 0xa5, 0x35, 0x7d, 0xf9, 0x86, 0xd7, 0xff,
    0xe1, 0xef, 0x1c, 0xa9, 0xdc, 0x41, 0x49, 0x8b, 0x7f, 0xba, 0xd5, 0x4f, 0x14, 0x34, 0x47, 0xae,
    0x48, 0x15, 0x94, 0xb3, 0x06, 0xa1, 0x68, 0x54, 0x7f, 0x16, 0xcf, 0xac, 0x8a, 0xf0, 0x62, 0x38,
    0x74, 0x87, 0xab, 0x81, 0xf5, 0x7d, 0x4d, 0x8e, 0x4e, 0xa2, 0x5f, 0xa6, 0x7d, 0x98, 0x16, 0xb7,
    0x3e, 0xb4, 0x8d, 0x6e, 0x8f, 0x8a, 0x8d, 0x56, 0xdb, 0xf4, 0x03, 0xb4, 0x5e, 0xca, 0x11, 0xd2,
    0x2a, 0xd5, 0x38, 0x35, 0xdc, 0xdb, 0x94, 0xba, 0xf5, 0x70, 0x59, 0x88, 0xbe, 0x9a, 0x73, 0xac,
    0xb5, 0xa9, 0xbc, 0xe6, 0x64, 0xc1, 0x60, 0x59, 0x8e, 0xaf, 0xa5, 0x56, 0x78, 0x24, 0xad, 0x56,
    0x4d, 0x62, 0x6f, 0x81, 0x59, 0xe8, 0x84, 0x47, 0xd2, 0x39, 0x4e, 0x8a, 0xaa, 0x89, 0x70, 0x6f,
    0x25, 0xed, 0xa5, 0xd7, 0x53, 0x6b, 0xf3, 0x2b, 0xb9, 0x9d, 0x64, 0xe1, 0xb2, 0x05, 0x3f, 0x3c,
    0x80, 0xbf, 0x6d, 0x73, 0x6d, 0x96, 0x49, 0x76, 0x08, 0x39, 0xef, 0x5e, 0x63, 0xdf, 0xc2, 0x08,
    0xb4, 0x68
};
#endif

PyTypeObject *init_Q3DCamera(PyObject *module)
{
    if (SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX].type != nullptr)
        return SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX].type;

    Shiboken::AutoDecRef Sbk_Q3DCamera_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DObject_IDX]))));

    _Sbk_Q3DCamera_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "Q3DCamera",
        "Q3DCamera*",
        &Sbk_Q3DCamera_spec,
        &Shiboken::callCppDestructor< Q3DCamera >,
        Sbk_Q3DCamera_Type_bases.object(),
        0);
    auto *pyType = Sbk_Q3DCamera_TypeF(); // references _Sbk_Q3DCamera_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Q3DCamera_SignatureStrings);
#else
    InitSignatureBytes(pyType, Q3DCamera_SignatureBytes, Q3DCamera_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Q3DCamera_PropertyStrings);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Q3DCamera_PythonToCpp_Q3DCamera_PTR,
        is_Q3DCamera_PythonToCpp_Q3DCamera_PTR_Convertible,
        Q3DCamera_PTR_CppToPython_Q3DCamera);

    Shiboken::Conversions::registerConverterName(converter, "Q3DCamera");
    Shiboken::Conversions::registerConverterName(converter, "Q3DCamera*");
    Shiboken::Conversions::registerConverterName(converter, "Q3DCamera&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Q3DCamera).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(Q3DCameraWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Q3DCamera_TypeF(), &Sbk_Q3DCamera_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Q3DCamera_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'CameraPreset'.
    const char *CameraPreset_Initializer[] = {
        "CameraPresetNone",
        "CameraPresetFrontLow",
        "CameraPresetFront",
        "CameraPresetFrontHigh",
        "CameraPresetLeftLow",
        "CameraPresetLeft",
        "CameraPresetLeftHigh",
        "CameraPresetRightLow",
        "CameraPresetRight",
        "CameraPresetRightHigh",
        "CameraPresetBehindLow",
        "CameraPresetBehind",
        "CameraPresetBehindHigh",
        "CameraPresetIsometricLeft",
        "CameraPresetIsometricLeftHigh",
        "CameraPresetIsometricRight",
        "CameraPresetIsometricRightHigh",
        "CameraPresetDirectlyAbove",
        "CameraPresetDirectlyAboveCW45",
        "CameraPresetDirectlyAboveCCW45",
        "CameraPresetFrontBelow",
        "CameraPresetLeftBelow",
        "CameraPresetRightBelow",
        "CameraPresetBehindBelow",
        "CameraPresetDirectlyBelow",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t CameraPreset_InitializerValues[] = {
        int8_t(Q3DCamera::CameraPreset::CameraPresetNone),               // -0x01 -1
        int8_t(Q3DCamera::CameraPreset::CameraPresetFrontLow),           //  0x00  0
        int8_t(Q3DCamera::CameraPreset::CameraPresetFront),              //  0x01  1
        int8_t(Q3DCamera::CameraPreset::CameraPresetFrontHigh),          //  0x02  2
        int8_t(Q3DCamera::CameraPreset::CameraPresetLeftLow),            //  0x03  3
        int8_t(Q3DCamera::CameraPreset::CameraPresetLeft),               //  0x04  4
        int8_t(Q3DCamera::CameraPreset::CameraPresetLeftHigh),           //  0x05  5
        int8_t(Q3DCamera::CameraPreset::CameraPresetRightLow),           //  0x06  6
        int8_t(Q3DCamera::CameraPreset::CameraPresetRight),              //  0x07  7
        int8_t(Q3DCamera::CameraPreset::CameraPresetRightHigh),          //  0x08  8
        int8_t(Q3DCamera::CameraPreset::CameraPresetBehindLow),          //  0x09  9
        int8_t(Q3DCamera::CameraPreset::CameraPresetBehind),             //  0x0a  10
        int8_t(Q3DCamera::CameraPreset::CameraPresetBehindHigh),         //  0x0b  11
        int8_t(Q3DCamera::CameraPreset::CameraPresetIsometricLeft),      //  0x0c  12
        int8_t(Q3DCamera::CameraPreset::CameraPresetIsometricLeftHigh),  //  0x0d  13
        int8_t(Q3DCamera::CameraPreset::CameraPresetIsometricRight),     //  0x0e  14
        int8_t(Q3DCamera::CameraPreset::CameraPresetIsometricRightHigh), //  0x0f  15
        int8_t(Q3DCamera::CameraPreset::CameraPresetDirectlyAbove),      //  0x10  16
        int8_t(Q3DCamera::CameraPreset::CameraPresetDirectlyAboveCW45),  //  0x11  17
        int8_t(Q3DCamera::CameraPreset::CameraPresetDirectlyAboveCCW45), //  0x12  18
        int8_t(Q3DCamera::CameraPreset::CameraPresetFrontBelow),         //  0x13  19
        int8_t(Q3DCamera::CameraPreset::CameraPresetLeftBelow),          //  0x14  20
        int8_t(Q3DCamera::CameraPreset::CameraPresetRightBelow),         //  0x15  21
        int8_t(Q3DCamera::CameraPreset::CameraPresetBehindBelow),        //  0x16  22
        int8_t(Q3DCamera::CameraPreset::CameraPresetDirectlyBelow)       //  0x17  23
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Q3DCamera_TypeF(),
        "2:PySide6.QtDataVisualization.Q3DCamera.CameraPreset",
        CameraPreset_Initializer, CameraPreset_InitializerValues);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DCamera_CameraPreset_IDX].type = EType;
    // Register converter for enum 'Q3DCamera::CameraPreset'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Q3DCamera_CameraPreset_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Q3DCamera_CameraPreset,
            is_Enum_PythonToCpp_Q3DCamera_CameraPreset_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Q3DCamera::CameraPreset");
        Shiboken::Conversions::registerConverterAlias(converter, "CameraPreset");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CameraPreset' enum.

    PySide::Signal::registerSignals(pyType, &::Q3DCamera::staticMetaObject);
    qRegisterMetaType< ::Q3DCamera::CameraPreset >("Q3DCamera::CameraPreset");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Q3DCamera::staticMetaObject, sizeof(Q3DCameraWrapper));

    return pyType;
}
