// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdatavisualization_python.h"

// main header
#include "q3dtheme_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtDataVisualization/q3dtheme.h>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qfont.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void Q3DThemeWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

Q3DThemeWrapper::Q3DThemeWrapper(::Q3DTheme::Theme themeType, ::QObject * parent) : Q3DTheme(themeType, parent)
{
}

Q3DThemeWrapper::Q3DThemeWrapper(::QObject * parent) : Q3DTheme(parent)
{
}

void Q3DThemeWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DTheme", funcName);
        return;
    }
}

void Q3DThemeWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DTheme", funcName);
        return;
    }
}

void Q3DThemeWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DTheme", funcName);
        return;
    }
}

void Q3DThemeWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DTheme", funcName);
        return;
    }
}

bool Q3DThemeWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DTheme", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("Q3DTheme", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool Q3DThemeWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DTheme", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("Q3DTheme", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void Q3DThemeWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DTheme", funcName);
        return;
    }
}

const QMetaObject *Q3DThemeWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Q3DTheme::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int Q3DThemeWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Q3DTheme::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *Q3DThemeWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< Q3DThemeWrapper *>(this));
    return Q3DTheme::qt_metacast(_clname);
}

Q3DThemeWrapper::~Q3DThemeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Q3DTheme_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Q3DTheme >()))
        return -1;

    Q3DThemeWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:Q3DTheme", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Q3DTheme::Q3DTheme(Q3DTheme::Theme,QObject*=)
    // 1: Q3DTheme::Q3DTheme(QObject*=)
    if (numArgs == 0) {
        overloadId = 1; // Q3DTheme(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Q3DTheme(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_Theme_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // Q3DTheme(Q3DTheme::Theme,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // Q3DTheme(Q3DTheme::Theme,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Q3DTheme(Q3DTheme::Theme themeType, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::Q3DTheme::Theme cppArg0{Q3DTheme::ThemeQt};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Q3DTheme(Q3DTheme::Theme,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) Q3DThemeWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new Q3DThemeWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 1: // Q3DTheme(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Q3DTheme(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) Q3DThemeWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new Q3DThemeWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Q3DTheme >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Q3DThemeFunc_ambientLightStrength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ambientLightStrength()const
        float cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->ambientLightStrength();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_backgroundColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // backgroundColor()const
        QColor cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->backgroundColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_baseColors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // baseColors()const
        QList<QColor> cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->baseColors();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtDataVisualizationTypeConverters[SBK_QtDataVisualization_QList_QColor_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_baseGradients(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // baseGradients()const
        QList<QLinearGradient> cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->baseGradients();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtDataVisualizationTypeConverters[SBK_QtDataVisualization_QList_QLinearGradient_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_colorStyle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // colorStyle()const
        Q3DTheme::ColorStyle cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->colorStyle();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_ColorStyle_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_font(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // font()const
        QFont cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->font();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_gridLineColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // gridLineColor()const
        QColor cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->gridLineColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_highlightLightStrength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // highlightLightStrength()const
        float cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->highlightLightStrength();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_isBackgroundEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isBackgroundEnabled()const
        bool cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->isBackgroundEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_isGridEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isGridEnabled()const
        bool cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->isGridEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_isLabelBackgroundEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLabelBackgroundEnabled()const
        bool cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->isLabelBackgroundEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_isLabelBorderEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLabelBorderEnabled()const
        bool cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->isLabelBorderEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_labelBackgroundColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelBackgroundColor()const
        QColor cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->labelBackgroundColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_labelTextColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelTextColor()const
        QColor cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->labelTextColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_lightColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lightColor()const
        QColor cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->lightColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_lightStrength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lightStrength()const
        float cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->lightStrength();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_multiHighlightColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // multiHighlightColor()const
        QColor cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->multiHighlightColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_multiHighlightGradient(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // multiHighlightGradient()const
        QLinearGradient cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->multiHighlightGradient();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_setAmbientLightStrength(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setAmbientLightStrength(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setAmbientLightStrength(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAmbientLightStrength", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAmbientLightStrength(float)
            cppSelf->setAmbientLightStrength(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setBackgroundColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setBackgroundColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setBackgroundColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBackgroundColor", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackgroundColor(QColor)
            cppSelf->setBackgroundColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setBackgroundEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setBackgroundEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setBackgroundEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBackgroundEnabled", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackgroundEnabled(bool)
            cppSelf->setBackgroundEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setBaseColors(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setBaseColors(QList<QColor>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDataVisualizationTypeConverters[SBK_QtDataVisualization_QList_QColor_IDX], (pyArg)))) {
        overloadId = 0; // setBaseColors(QList<QColor>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBaseColors", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        ::QList<QColor> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBaseColors(QList<QColor>)
            cppSelf->setBaseColors(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setBaseGradients(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setBaseGradients(QList<QLinearGradient>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDataVisualizationTypeConverters[SBK_QtDataVisualization_QList_QLinearGradient_IDX], (pyArg)))) {
        overloadId = 0; // setBaseGradients(QList<QLinearGradient>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBaseGradients", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        ::QList<QLinearGradient> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBaseGradients(QList<QLinearGradient>)
            cppSelf->setBaseGradients(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setColorStyle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setColorStyle(Q3DTheme::ColorStyle)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_ColorStyle_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setColorStyle(Q3DTheme::ColorStyle)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColorStyle", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        ::Q3DTheme::ColorStyle cppArg0{Q3DTheme::ColorStyleUniform};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColorStyle(Q3DTheme::ColorStyle)
            cppSelf->setColorStyle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setFont(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setFont(QFont)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFont", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setFont(QFont)
            cppSelf->setFont(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setGridEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setGridEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setGridEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGridEnabled", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGridEnabled(bool)
            cppSelf->setGridEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setGridLineColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setGridLineColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setGridLineColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGridLineColor", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setGridLineColor(QColor)
            cppSelf->setGridLineColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setHighlightLightStrength(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setHighlightLightStrength(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setHighlightLightStrength(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHighlightLightStrength", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHighlightLightStrength(float)
            cppSelf->setHighlightLightStrength(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setLabelBackgroundColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setLabelBackgroundColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setLabelBackgroundColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelBackgroundColor", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelBackgroundColor(QColor)
            cppSelf->setLabelBackgroundColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setLabelBackgroundEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setLabelBackgroundEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setLabelBackgroundEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelBackgroundEnabled", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelBackgroundEnabled(bool)
            cppSelf->setLabelBackgroundEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setLabelBorderEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setLabelBorderEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setLabelBorderEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelBorderEnabled", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelBorderEnabled(bool)
            cppSelf->setLabelBorderEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setLabelTextColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setLabelTextColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setLabelTextColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelTextColor", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelTextColor(QColor)
            cppSelf->setLabelTextColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setLightColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setLightColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setLightColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLightColor", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLightColor(QColor)
            cppSelf->setLightColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setLightStrength(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setLightStrength(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setLightStrength(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLightStrength", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLightStrength(float)
            cppSelf->setLightStrength(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setMultiHighlightColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setMultiHighlightColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setMultiHighlightColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMultiHighlightColor", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setMultiHighlightColor(QColor)
            cppSelf->setMultiHighlightColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setMultiHighlightGradient(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setMultiHighlightGradient(QLinearGradient)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), (pyArg)))) {
        overloadId = 0; // setMultiHighlightGradient(QLinearGradient)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMultiHighlightGradient", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLinearGradient cppArg0_local;
        ::QLinearGradient *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setMultiHighlightGradient(QLinearGradient)
            cppSelf->setMultiHighlightGradient(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setSingleHighlightColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setSingleHighlightColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setSingleHighlightColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSingleHighlightColor", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSingleHighlightColor(QColor)
            cppSelf->setSingleHighlightColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setSingleHighlightGradient(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setSingleHighlightGradient(QLinearGradient)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), (pyArg)))) {
        overloadId = 0; // setSingleHighlightGradient(QLinearGradient)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSingleHighlightGradient", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLinearGradient cppArg0_local;
        ::QLinearGradient *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSingleHighlightGradient(QLinearGradient)
            cppSelf->setSingleHighlightGradient(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setType(Q3DTheme::Theme)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_Theme_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setType(Q3DTheme::Theme)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setType", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        ::Q3DTheme::Theme cppArg0{Q3DTheme::ThemeQt};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setType(Q3DTheme::Theme)
            cppSelf->setType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_setWindowColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DTheme::setWindowColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setWindowColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWindowColor", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setWindowColor(QColor)
            cppSelf->setWindowColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DThemeFunc_singleHighlightColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // singleHighlightColor()const
        QColor cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->singleHighlightColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_singleHighlightGradient(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // singleHighlightGradient()const
        QLinearGradient cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->singleHighlightGradient();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        Q3DTheme::Theme cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_Theme_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DThemeFunc_windowColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // windowColor()const
        QColor cppResult = const_cast<const ::Q3DTheme *>(cppSelf)->windowColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Q3DTheme_PropertyStrings[] = {
    "ambientLightStrength::",
    "backgroundColor::",
    "backgroundEnabled:isBackgroundEnabled:",
    "baseColors::",
    "baseGradients::",
    "colorStyle::",
    "font::",
    "gridEnabled:isGridEnabled:",
    "gridLineColor::",
    "highlightLightStrength::",
    "labelBackgroundColor::",
    "labelBackgroundEnabled:isLabelBackgroundEnabled:",
    "labelBorderEnabled:isLabelBorderEnabled:",
    "labelTextColor::",
    "lightColor::",
    "lightStrength::",
    "multiHighlightColor::",
    "multiHighlightGradient::",
    "singleHighlightColor::",
    "singleHighlightGradient::",
    "type::",
    "windowColor::",
    nullptr // Sentinel
};

static const char *Sbk_Q3DTheme_EnumFlagInfo[] = {
    "ColorStyle:Enum",
    "Theme:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Q3DTheme_methods[] = {
    {"ambientLightStrength", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_ambientLightStrength), METH_NOARGS, nullptr},
    {"backgroundColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_backgroundColor), METH_NOARGS, nullptr},
    {"baseColors", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_baseColors), METH_NOARGS, nullptr},
    {"baseGradients", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_baseGradients), METH_NOARGS, nullptr},
    {"colorStyle", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_colorStyle), METH_NOARGS, nullptr},
    {"font", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_font), METH_NOARGS, nullptr},
    {"gridLineColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_gridLineColor), METH_NOARGS, nullptr},
    {"highlightLightStrength", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_highlightLightStrength), METH_NOARGS, nullptr},
    {"isBackgroundEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_isBackgroundEnabled), METH_NOARGS, nullptr},
    {"isGridEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_isGridEnabled), METH_NOARGS, nullptr},
    {"isLabelBackgroundEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_isLabelBackgroundEnabled), METH_NOARGS, nullptr},
    {"isLabelBorderEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_isLabelBorderEnabled), METH_NOARGS, nullptr},
    {"labelBackgroundColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_labelBackgroundColor), METH_NOARGS, nullptr},
    {"labelTextColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_labelTextColor), METH_NOARGS, nullptr},
    {"lightColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_lightColor), METH_NOARGS, nullptr},
    {"lightStrength", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_lightStrength), METH_NOARGS, nullptr},
    {"multiHighlightColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_multiHighlightColor), METH_NOARGS, nullptr},
    {"multiHighlightGradient", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_multiHighlightGradient), METH_NOARGS, nullptr},
    {"setAmbientLightStrength", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setAmbientLightStrength), METH_O, nullptr},
    {"setBackgroundColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setBackgroundColor), METH_O, nullptr},
    {"setBackgroundEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setBackgroundEnabled), METH_O, nullptr},
    {"setBaseColors", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setBaseColors), METH_O, nullptr},
    {"setBaseGradients", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setBaseGradients), METH_O, nullptr},
    {"setColorStyle", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setColorStyle), METH_O, nullptr},
    {"setFont", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setFont), METH_O, nullptr},
    {"setGridEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setGridEnabled), METH_O, nullptr},
    {"setGridLineColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setGridLineColor), METH_O, nullptr},
    {"setHighlightLightStrength", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setHighlightLightStrength), METH_O, nullptr},
    {"setLabelBackgroundColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setLabelBackgroundColor), METH_O, nullptr},
    {"setLabelBackgroundEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setLabelBackgroundEnabled), METH_O, nullptr},
    {"setLabelBorderEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setLabelBorderEnabled), METH_O, nullptr},
    {"setLabelTextColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setLabelTextColor), METH_O, nullptr},
    {"setLightColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setLightColor), METH_O, nullptr},
    {"setLightStrength", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setLightStrength), METH_O, nullptr},
    {"setMultiHighlightColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setMultiHighlightColor), METH_O, nullptr},
    {"setMultiHighlightGradient", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setMultiHighlightGradient), METH_O, nullptr},
    {"setSingleHighlightColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setSingleHighlightColor), METH_O, nullptr},
    {"setSingleHighlightGradient", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setSingleHighlightGradient), METH_O, nullptr},
    {"setType", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setType), METH_O, nullptr},
    {"setWindowColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_setWindowColor), METH_O, nullptr},
    {"singleHighlightColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_singleHighlightColor), METH_NOARGS, nullptr},
    {"singleHighlightGradient", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_singleHighlightGradient), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_type), METH_NOARGS, nullptr},
    {"windowColor", reinterpret_cast<PyCFunction>(Sbk_Q3DThemeFunc_windowColor), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Q3DTheme_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Q3DTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<Q3DThemeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Q3DTheme_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Q3DTheme_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Q3DTheme_Type = nullptr;
static PyTypeObject *Sbk_Q3DTheme_TypeF(void)
{
    return _Sbk_Q3DTheme_Type;
}

static PyType_Slot Sbk_Q3DTheme_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Q3DTheme_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Q3DTheme_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Q3DTheme_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Q3DTheme_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Q3DTheme_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Q3DTheme_spec = {
    "2:PySide6.QtDataVisualization.Q3DTheme",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Q3DTheme_slots
};

} //extern "C"

static void *Sbk_Q3DTheme_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Q3DTheme *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Q3DTheme_ColorStyle(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Q3DTheme::ColorStyle>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Q3DTheme::ColorStyle *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Q3DTheme_ColorStyle_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_ColorStyle_IDX])))
        return Enum_PythonToCpp_Q3DTheme_ColorStyle;
    return {};
}

static PyObject *Q3DTheme_ColorStyle_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Q3DTheme::ColorStyle>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Q3DTheme::ColorStyle *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_ColorStyle_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Q3DTheme_Theme(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Q3DTheme::Theme>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Q3DTheme::Theme *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Q3DTheme_Theme_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_Theme_IDX])))
        return Enum_PythonToCpp_Q3DTheme_Theme;
    return {};
}

static PyObject *Q3DTheme_Theme_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Q3DTheme::Theme>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Q3DTheme::Theme *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_Theme_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Q3DTheme_PythonToCpp_Q3DTheme_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Q3DTheme_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Q3DTheme_PythonToCpp_Q3DTheme_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Q3DTheme_TypeF()))
        return Q3DTheme_PythonToCpp_Q3DTheme_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Q3DTheme_PTR_CppToPython_Q3DTheme(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Q3DTheme *>(const_cast<void *>(cppIn)), Sbk_Q3DTheme_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Q3DTheme_SignatureStrings[] = {
    "1:PySide6.QtDataVisualization.Q3DTheme(self,themeType:PySide6.QtDataVisualization.Q3DTheme.Theme,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,type:Q3DTheme.Theme=None,baseColors:QList[PySide6.QtGui.QColor]=None,backgroundColor:QColor=None,windowColor:QColor=None,labelTextColor:QColor=None,labelBackgroundColor:QColor=None,gridLineColor:QColor=None,singleHighlightColor:QColor=None,multiHighlightColor:QColor=None,lightColor:QColor=None,baseGradients:QList[PySide6.QtGui.QLinearGradient]=None,singleHighlightGradient:QLinearGradient=None,multiHighlightGradient:QLinearGradient=None,lightStrength:float=None,ambientLightStrength:float=None,highlightLightStrength:float=None,labelBorderEnabled:bool=None,font:QFont=None,backgroundEnabled:bool=None,gridEnabled:bool=None,labelBackgroundEnabled:bool=None,colorStyle:Q3DTheme.ColorStyle=None)",
    "0:PySide6.QtDataVisualization.Q3DTheme(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,type:Q3DTheme.Theme=None,baseColors:QList[PySide6.QtGui.QColor]=None,backgroundColor:QColor=None,windowColor:QColor=None,labelTextColor:QColor=None,labelBackgroundColor:QColor=None,gridLineColor:QColor=None,singleHighlightColor:QColor=None,multiHighlightColor:QColor=None,lightColor:QColor=None,baseGradients:QList[PySide6.QtGui.QLinearGradient]=None,singleHighlightGradient:QLinearGradient=None,multiHighlightGradient:QLinearGradient=None,lightStrength:float=None,ambientLightStrength:float=None,highlightLightStrength:float=None,labelBorderEnabled:bool=None,font:QFont=None,backgroundEnabled:bool=None,gridEnabled:bool=None,labelBackgroundEnabled:bool=None,colorStyle:Q3DTheme.ColorStyle=None)",
    "PySide6.QtDataVisualization.Q3DTheme.ambientLightStrength(self)->float",
    "PySide6.QtDataVisualization.Q3DTheme.backgroundColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtDataVisualization.Q3DTheme.baseColors(self)->QList[PySide6.QtGui.QColor]",
    "PySide6.QtDataVisualization.Q3DTheme.baseGradients(self)->QList[PySide6.QtGui.QLinearGradient]",
    "PySide6.QtDataVisualization.Q3DTheme.colorStyle(self)->PySide6.QtDataVisualization.Q3DTheme.ColorStyle",
    "PySide6.QtDataVisualization.Q3DTheme.font(self)->PySide6.QtGui.QFont",
    "PySide6.QtDataVisualization.Q3DTheme.gridLineColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtDataVisualization.Q3DTheme.highlightLightStrength(self)->float",
    "PySide6.QtDataVisualization.Q3DTheme.isBackgroundEnabled(self)->bool",
    "PySide6.QtDataVisualization.Q3DTheme.isGridEnabled(self)->bool",
    "PySide6.QtDataVisualization.Q3DTheme.isLabelBackgroundEnabled(self)->bool",
    "PySide6.QtDataVisualization.Q3DTheme.isLabelBorderEnabled(self)->bool",
    "PySide6.QtDataVisualization.Q3DTheme.labelBackgroundColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtDataVisualization.Q3DTheme.labelTextColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtDataVisualization.Q3DTheme.lightColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtDataVisualization.Q3DTheme.lightStrength(self)->float",
    "PySide6.QtDataVisualization.Q3DTheme.multiHighlightColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtDataVisualization.Q3DTheme.multiHighlightGradient(self)->PySide6.QtGui.QLinearGradient",
    "PySide6.QtDataVisualization.Q3DTheme.setAmbientLightStrength(self,strength:float)",
    "PySide6.QtDataVisualization.Q3DTheme.setBackgroundColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtDataVisualization.Q3DTheme.setBackgroundEnabled(self,enabled:bool)",
    "PySide6.QtDataVisualization.Q3DTheme.setBaseColors(self,colors:QList[PySide6.QtGui.QColor])",
    "PySide6.QtDataVisualization.Q3DTheme.setBaseGradients(self,gradients:QList[PySide6.QtGui.QLinearGradient])",
    "PySide6.QtDataVisualization.Q3DTheme.setColorStyle(self,style:PySide6.QtDataVisualization.Q3DTheme.ColorStyle)",
    "PySide6.QtDataVisualization.Q3DTheme.setFont(self,font:typing.Union[PySide6.QtGui.QFont, QString, QStringList])",
    "PySide6.QtDataVisualization.Q3DTheme.setGridEnabled(self,enabled:bool)",
    "PySide6.QtDataVisualization.Q3DTheme.setGridLineColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtDataVisualization.Q3DTheme.setHighlightLightStrength(self,strength:float)",
    "PySide6.QtDataVisualization.Q3DTheme.setLabelBackgroundColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtDataVisualization.Q3DTheme.setLabelBackgroundEnabled(self,enabled:bool)",
    "PySide6.QtDataVisualization.Q3DTheme.setLabelBorderEnabled(self,enabled:bool)",
    "PySide6.QtDataVisualization.Q3DTheme.setLabelTextColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtDataVisualization.Q3DTheme.setLightColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtDataVisualization.Q3DTheme.setLightStrength(self,strength:float)",
    "PySide6.QtDataVisualization.Q3DTheme.setMultiHighlightColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtDataVisualization.Q3DTheme.setMultiHighlightGradient(self,gradient:PySide6.QtGui.QLinearGradient)",
    "PySide6.QtDataVisualization.Q3DTheme.setSingleHighlightColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtDataVisualization.Q3DTheme.setSingleHighlightGradient(self,gradient:PySide6.QtGui.QLinearGradient)",
    "PySide6.QtDataVisualization.Q3DTheme.setType(self,themeType:PySide6.QtDataVisualization.Q3DTheme.Theme)",
    "PySide6.QtDataVisualization.Q3DTheme.setWindowColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtDataVisualization.Q3DTheme.singleHighlightColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtDataVisualization.Q3DTheme.singleHighlightGradient(self)->PySide6.QtGui.QLinearGradient",
    "PySide6.QtDataVisualization.Q3DTheme.type(self)->PySide6.QtDataVisualization.Q3DTheme.Theme",
    "PySide6.QtDataVisualization.Q3DTheme.windowColor(self)->PySide6.QtGui.QColor",
    nullptr}; // Sentinel
#else
static constexpr size_t Q3DTheme_SignatureByteSize = 727;
static constexpr uint8_t Q3DTheme_SignatureBytes[727] = {
    0x78, 0xda, 0xed, 0x58, 0xcf, 0x6f, 0xd3, 0x30, 0x14, 0xbe, 0xf3, 0x57, 0xf4, 0x48, 0x51, 0x88,
    0x98, 0x40, 0x3b, 0x44, 0x1a, 0x12, 0xeb, 0x58, 0x27, 0x91, 0x31, 0x42, 0xcb, 0x76, 0x40, 0x3b,
    0x38, 0x8d, 0x9b, 0x1a, 0x5c, 0xbb, 0x4a, 0x1c, 0x95, 0xf2, 0xd7, 0xcf, 0x4e, 0xe6, 0xe6, 0x97,
    0x6d, 0x39, 0x49, 0x39, 0x44, 0xec, 0xd0, 0xaa, 0xf2, 0x7b, 0xfe, 0x6c, 0xbf, 0xf7, 0xbd, 0xf7,
    0xb9, 0x3e, 0xf3, 0xbe, 0x1d, 0x16, 0x28, 0x82, 0xe7, 0x6e, 0xc0, 0xae, 0x00, 0x03, 0xf7, 0x28,
    0xcd, 0x00, 0x46, 0x7f, 0x01, 0x43, 0x94, 0xb8, 0xc1, 0xfb, 0xab, 0xe5, 0x06, 0x6e, 0xe1, 0xeb,
    0x14, 0xe2, 0xb5, 0xc3, 0xc4, 0xcf, 0xe5, 0x61, 0x07, 0xad, 0xe6, 0xb8, 0xf9, 0xb7, 0xb3, 0x03,
    0x09, 0x24, 0xac, 0x32, 0x63, 0x46, 0x13, 0xe8, 0x06, 0x77, 0xe1, 0x2f, 0xb8, 0x62, 0x17, 0x24,
    0xc3, 0x78, 0xc7, 0x12, 0xe7, 0x8d, 0xf7, 0x05, 0x1e, 0xf6, 0x34, 0x89, 0xee, 0x08, 0x3e, 0x5c,
    0x7c, 0xa5, 0x04, 0x3a, 0x4c, 0x2c, 0x54, 0x07, 0x2b, 0x0c, 0x21, 0x48, 0xe1, 0x8c, 0x62, 0x9a,
    0xa4, 0x5e, 0xe0, 0xa3, 0x94, 0xfd, 0x2c, 0xb1, 0xe7, 0x19, 0x72, 0x83, 0xdc, 0xf6, 0x28, 0x7d,
    0x57, 0xbf, 0xe3, 0x84, 0x66, 0x24, 0xca, 0x47, 0xbd, 0xc2, 0x58, 0xd8, 0xf6, 0x88, 0x44, 0x74,
    0xdf, 0x1e, 0xc7, 0x20, 0x84, 0x78, 0x09, 0xff, 0x30, 0x8d, 0xe9, 0xd2, 0x80, 0x19, 0x27, 0x28,
    0xf2, 0x11, 0x81, 0x6d, 0x4b, 0x8a, 0x48, 0x8c, 0xe1, 0x0d, 0x8a, 0x37, 0x98, 0x7f, 0x14, 0xd8,
    0xdb, 0x0c, 0x33, 0x64, 0xb0, 0x6b, 0x86, 0x45, 0x34, 0xe6, 0x09, 0x88, 0x10, 0x8f, 0xb2, 0x26,
    0x20, 0x62, 0x43, 0x20, 0x91, 0x4e, 0x8f, 0xca, 0xfd, 0x48, 0xab, 0xd7, 0xf0, 0x56, 0xed, 0xcd,
    0xec, 0x9b, 0xbb, 0x2c, 0x18, 0xcf, 0x7a, 0xcc, 0x36, 0xde, 0x1a, 0x53, 0xf0, 0x6c, 0x00, 0xdb,
    0x50, 0x78, 0xf9, 0x3a, 0xfb, 0x46, 0xe2, 0x6b, 0x3d, 0x8a, 0xf0, 0x73, 0x96, 0xc0, 0xe4, 0x33,
    0x01, 0x21, 0x86, 0x91, 0x17, 0x52, 0x8a, 0x0b, 0xe3, 0x9a, 0x8a, 0x1d, 0x5d, 0x53, 0xb9, 0x8f,
    0x32, 0xf5, 0x6d, 0x5f, 0x91, 0xa6, 0xf6, 0x68, 0x23, 0xbb, 0x6d, 0x87, 0x95, 0x08, 0xfb, 0x82,
    0x1d, 0x70, 0x85, 0x98, 0xb3, 0xe3, 0x58, 0xee, 0x33, 0x7d, 0xf5, 0xae, 0x43, 0x45, 0xbd, 0x14,
    0xc7, 0x4b, 0x71, 0xfc, 0x57, 0xc5, 0x61, 0x25, 0x1c, 0xaa, 0x58, 0xe4, 0xf5, 0x32, 0x7d, 0xfb,
    0x31, 0x3f, 0xb0, 0x1d, 0x4c, 0x83, 0xde, 0x12, 0x41, 0x55, 0x10, 0xb6, 0x80, 0xb2, 0xb6, 0x24,
    0x96, 0xa1, 0xc4, 0xec, 0x21, 0x8f, 0x04, 0x35, 0xa2, 0x36, 0x78, 0x6a, 0x07, 0x5f, 0xe6, 0xa4,
    0x7d, 0x7a, 0xc3, 0xb4, 0x32, 0x6d, 0x76, 0xcb, 0x08, 0x76, 0x69, 0xc2, 0x2b, 0x28, 0x67, 0x07,
    0x52, 0xeb, 0x0e, 0xc3, 0x93, 0xa5, 0x2e, 0x98, 0x1e, 0x34, 0x42, 0x69, 0x8b, 0xf5, 0x12, 0x45,
    0x90, 0xdf, 0x16, 0x64, 0x5e, 0x56, 0x55, 0x9f, 0xe9, 0xbe, 0xb2, 0xfc, 0xfa, 0x23, 0x55, 0xfb,
    0x44, 0x77, 0x14, 0x55, 0xab, 0x1f, 0x9e, 0xb2, 0xba, 0xb6, 0x9c, 0x00, 0xef, 0x28, 0x0a, 0x27,
    0xc2, 0x1a, 0xc0, 0x22, 0x85, 0x80, 0x0d, 0xdf, 0x94, 0x5a, 0x79, 0x34, 0xb8, 0xf5, 0x06, 0x62,
    0xb7, 0x40, 0x0a, 0xd9, 0x27, 0x5d, 0x33, 0x76, 0xd2, 0x9a, 0x08, 0x4d, 0xad, 0x11, 0x55, 0xbc,
    0x29, 0xd4, 0xc3, 0xe3, 0xd7, 0x1a, 0xae, 0xbc, 0xee, 0x0f, 0xc2, 0xe7, 0x28, 0xdb, 0xaa, 0x33,
    0x09, 0x7c, 0x8e, 0x48, 0xce, 0xf8, 0x56, 0xb8, 0xa7, 0x33, 0x69, 0x38, 0x7d, 0x8f, 0x43, 0x70,
    0xfe, 0x81, 0x7b, 0xdd, 0x83, 0x04, 0x01, 0xc2, 0xaa, 0x0e, 0xc5, 0xdd, 0x8a, 0xb9, 0x73, 0x4c,
    0x43, 0x80, 0x25, 0x9c, 0x04, 0xca, 0x48, 0x8a, 0x62, 0x02, 0xa3, 0x09, 0xe2, 0xdd, 0xb5, 0xcf,
    0x61, 0xaa, 0xc5, 0xe4, 0xc0, 0x8a, 0x3c, 0x76, 0x01, 0xab, 0x09, 0x4c, 0x11, 0x14, 0xe3, 0x45,
    0xae, 0x1b, 0x76, 0x5d, 0x69, 0xb8, 0xd0, 0x77, 0xb9, 0x19, 0xd9, 0x2f, 0x35, 0xab, 0xab, 0x0e,
    0x27, 0x8a, 0xb8, 0x14, 0x74, 0x54, 0x1e, 0xfb, 0xe5, 0xae, 0xa5, 0xfa, 0x14, 0xb7, 0x1c, 0x13,
    0x87, 0x84, 0x6b, 0x25, 0xe7, 0xcf, 0x3f, 0xc4, 0xe1, 0x3b, 0x1c, 0xaf, 0xd9, 0xc9, 0x7b, 0x26,
    0x7b, 0xde, 0xd2, 0xbb, 0xd1, 0x16, 0xc1, 0x8d, 0x5e, 0x6b, 0x7b, 0x77, 0x09, 0x5f, 0x27, 0x31,
    0xa3, 0x8d, 0x92, 0x41, 0xc2, 0x7b, 0x52, 0x48, 0x23, 0xe5, 0x43, 0xd0, 0xea, 0xf2, 0x3b, 0xde,
    0x58, 0xd7, 0x55, 0x76, 0xdc, 0xe7, 0x38, 0x4d, 0x41, 0xdd, 0x6a, 0x6e, 0x20, 0xa3, 0x8d, 0xcd,
    0xad, 0xfe, 0xf6, 0x73, 0x94, 0x36, 0xcf, 0xa8, 0x69, 0xf6, 0x6b, 0x2d, 0x14, 0x0f, 0x14, 0xe3,
    0x8e, 0xde, 0x42, 0xfd, 0xc4, 0xf1, 0x6f, 0xc2, 0x27, 0x1e, 0x8d, 0xfb, 0xbf, 0x21, 0xdb, 0xaf,
    0xf3, 0x50, 0xbe, 0x5a, 0x8d, 0x39, 0x3b, 0x3a, 0xb2, 0x0d, 0xfa, 0xb3, 0x90, 0x1a, 0x12, 0x7e,
    0x9a, 0x7f, 0x0b, 0x4c, 0x66, 0xd9, 0xf6, 0x9d, 0x21, 0xff, 0xb6, 0xc3, 0xde, 0x37, 0x32, 0xab,
    0x0b, 0xc5, 0x13, 0xce, 0xe4, 0x0d, 0xac
};
#endif

PyTypeObject *init_Q3DTheme(PyObject *module)
{
    if (SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX].type != nullptr)
        return SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX].type;

    Shiboken::AutoDecRef Sbk_Q3DTheme_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_Q3DTheme_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "Q3DTheme",
        "Q3DTheme*",
        &Sbk_Q3DTheme_spec,
        &Shiboken::callCppDestructor< Q3DTheme >,
        Sbk_Q3DTheme_Type_bases.object(),
        0);
    auto *pyType = Sbk_Q3DTheme_TypeF(); // references _Sbk_Q3DTheme_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Q3DTheme_SignatureStrings);
#else
    InitSignatureBytes(pyType, Q3DTheme_SignatureBytes, Q3DTheme_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Q3DTheme_PropertyStrings);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Q3DTheme_PythonToCpp_Q3DTheme_PTR,
        is_Q3DTheme_PythonToCpp_Q3DTheme_PTR_Convertible,
        Q3DTheme_PTR_CppToPython_Q3DTheme);

    Shiboken::Conversions::registerConverterName(converter, "Q3DTheme");
    Shiboken::Conversions::registerConverterName(converter, "Q3DTheme*");
    Shiboken::Conversions::registerConverterName(converter, "Q3DTheme&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Q3DTheme).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(Q3DThemeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Q3DTheme_TypeF(), &Sbk_Q3DTheme_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Q3DTheme_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ColorStyle'.
    const char *ColorStyle_Initializer[] = {
        "ColorStyleUniform",
        "ColorStyleObjectGradient",
        "ColorStyleRangeGradient",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ColorStyle_InitializerValues[] = {
        uint8_t(Q3DTheme::ColorStyle::ColorStyleUniform),        //  0x00  0
        uint8_t(Q3DTheme::ColorStyle::ColorStyleObjectGradient), //  0x01  1
        uint8_t(Q3DTheme::ColorStyle::ColorStyleRangeGradient)   //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Q3DTheme_TypeF(),
        "2:PySide6.QtDataVisualization.Q3DTheme.ColorStyle",
        ColorStyle_Initializer, ColorStyle_InitializerValues);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_ColorStyle_IDX].type = EType;
    // Register converter for enum 'Q3DTheme::ColorStyle'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Q3DTheme_ColorStyle_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Q3DTheme_ColorStyle,
            is_Enum_PythonToCpp_Q3DTheme_ColorStyle_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Q3DTheme::ColorStyle");
        Shiboken::Conversions::registerConverterAlias(converter, "ColorStyle");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ColorStyle' enum.

    // Initialization of enum 'Theme'.
    const char *Theme_Initializer[] = {
        "ThemeQt",
        "ThemePrimaryColors",
        "ThemeDigia",
        "ThemeStoneMoss",
        "ThemeArmyBlue",
        "ThemeRetro",
        "ThemeEbony",
        "ThemeIsabelle",
        "ThemeUserDefined",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Theme_InitializerValues[] = {
        uint8_t(Q3DTheme::Theme::ThemeQt),            //  0x00  0
        uint8_t(Q3DTheme::Theme::ThemePrimaryColors), //  0x01  1
        uint8_t(Q3DTheme::Theme::ThemeDigia),         //  0x02  2
        uint8_t(Q3DTheme::Theme::ThemeStoneMoss),     //  0x03  3
        uint8_t(Q3DTheme::Theme::ThemeArmyBlue),      //  0x04  4
        uint8_t(Q3DTheme::Theme::ThemeRetro),         //  0x05  5
        uint8_t(Q3DTheme::Theme::ThemeEbony),         //  0x06  6
        uint8_t(Q3DTheme::Theme::ThemeIsabelle),      //  0x07  7
        uint8_t(Q3DTheme::Theme::ThemeUserDefined)    //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Q3DTheme_TypeF(),
        "2:PySide6.QtDataVisualization.Q3DTheme.Theme",
        Theme_Initializer, Theme_InitializerValues);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_Theme_IDX].type = EType;
    // Register converter for enum 'Q3DTheme::Theme'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Q3DTheme_Theme_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Q3DTheme_Theme,
            is_Enum_PythonToCpp_Q3DTheme_Theme_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Q3DTheme::Theme");
        Shiboken::Conversions::registerConverterAlias(converter, "Theme");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Theme' enum.

    PySide::Signal::registerSignals(pyType, &::Q3DTheme::staticMetaObject);
    qRegisterMetaType< ::Q3DTheme::ColorStyle >("Q3DTheme::ColorStyle");
    qRegisterMetaType< ::Q3DTheme::Theme >("Q3DTheme::Theme");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Q3DTheme::staticMetaObject, sizeof(Q3DThemeWrapper));

    return pyType;
}
