// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdatavisualization_python.h"

// main header
#include "qabstract3dseries_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtDataVisualization/q3dtheme.h>
#include <QtDataVisualization/qabstract3dseries.h>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qquaternion.h>
#include <QtGui/qvectornd.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstract3DSeriesWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QAbstract3DSeriesWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstract3DSeries", funcName);
        return;
    }
}

void QAbstract3DSeriesWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstract3DSeries", funcName);
        return;
    }
}

void QAbstract3DSeriesWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstract3DSeries", funcName);
        return;
    }
}

void QAbstract3DSeriesWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstract3DSeries", funcName);
        return;
    }
}

bool QAbstract3DSeriesWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstract3DSeries", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstract3DSeries", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAbstract3DSeriesWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstract3DSeries", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstract3DSeries", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstract3DSeriesWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstract3DSeries", funcName);
        return;
    }
}

const QMetaObject *QAbstract3DSeriesWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QAbstract3DSeries::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAbstract3DSeriesWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QAbstract3DSeries::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAbstract3DSeriesWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAbstract3DSeriesWrapper *>(this));
    return QAbstract3DSeries::qt_metacast(_clname);
}

QAbstract3DSeriesWrapper::~QAbstract3DSeriesWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QAbstract3DSeriesFunc_baseColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // baseColor()const
        QColor cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->baseColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_baseGradient(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // baseGradient()const
        QLinearGradient cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->baseGradient();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_colorStyle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // colorStyle()const
        Q3DTheme::ColorStyle cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->colorStyle();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_ColorStyle_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_isItemLabelVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isItemLabelVisible()const
        bool cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->isItemLabelVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_isMeshSmooth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isMeshSmooth()const
        bool cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->isMeshSmooth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_isVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isVisible()const
        bool cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->isVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_itemLabel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // itemLabel()const
        QString cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->itemLabel();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_itemLabelFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // itemLabelFormat()const
        QString cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->itemLabelFormat();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_mesh(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mesh()const
        QAbstract3DSeries::Mesh cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->mesh();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_Mesh_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_meshRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // meshRotation()const
        QQuaternion cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->meshRotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_multiHighlightColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // multiHighlightColor()const
        QColor cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->multiHighlightColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_multiHighlightGradient(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // multiHighlightGradient()const
        QLinearGradient cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->multiHighlightGradient();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setBaseColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DSeries::setBaseColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setBaseColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBaseColor", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBaseColor(QColor)
            cppSelf->setBaseColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setBaseGradient(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DSeries::setBaseGradient(QLinearGradient)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), (pyArg)))) {
        overloadId = 0; // setBaseGradient(QLinearGradient)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBaseGradient", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLinearGradient cppArg0_local;
        ::QLinearGradient *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBaseGradient(QLinearGradient)
            cppSelf->setBaseGradient(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setColorStyle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DSeries::setColorStyle(Q3DTheme::ColorStyle)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DTheme_ColorStyle_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setColorStyle(Q3DTheme::ColorStyle)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColorStyle", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        ::Q3DTheme::ColorStyle cppArg0{Q3DTheme::ColorStyleUniform};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColorStyle(Q3DTheme::ColorStyle)
            cppSelf->setColorStyle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setItemLabelFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DSeries::setItemLabelFormat(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setItemLabelFormat(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setItemLabelFormat", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItemLabelFormat(QString)
            cppSelf->setItemLabelFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setItemLabelVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DSeries::setItemLabelVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setItemLabelVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setItemLabelVisible", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItemLabelVisible(bool)
            cppSelf->setItemLabelVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setMesh(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DSeries::setMesh(QAbstract3DSeries::Mesh)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_Mesh_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMesh(QAbstract3DSeries::Mesh)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMesh", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        ::QAbstract3DSeries::Mesh cppArg0{QAbstract3DSeries::MeshUserDefined};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMesh(QAbstract3DSeries::Mesh)
            cppSelf->setMesh(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setMeshAxisAndAngle(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setMeshAxisAndAngle", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstract3DSeries::setMeshAxisAndAngle(QVector3D,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // setMeshAxisAndAngle(QVector3D,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setMeshAxisAndAngle", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMeshAxisAndAngle(QVector3D,float)
            cppSelf->setMeshAxisAndAngle(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setMeshRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DSeries::setMeshRotation(QQuaternion)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArg)))) {
        overloadId = 0; // setMeshRotation(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMeshRotation", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuaternion cppArg0_local;
        ::QQuaternion *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setMeshRotation(QQuaternion)
            cppSelf->setMeshRotation(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setMeshSmooth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DSeries::setMeshSmooth(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setMeshSmooth(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMeshSmooth", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMeshSmooth(bool)
            cppSelf->setMeshSmooth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setMultiHighlightColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DSeries::setMultiHighlightColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setMultiHighlightColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMultiHighlightColor", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setMultiHighlightColor(QColor)
            cppSelf->setMultiHighlightColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setMultiHighlightGradient(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DSeries::setMultiHighlightGradient(QLinearGradient)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), (pyArg)))) {
        overloadId = 0; // setMultiHighlightGradient(QLinearGradient)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMultiHighlightGradient", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLinearGradient cppArg0_local;
        ::QLinearGradient *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setMultiHighlightGradient(QLinearGradient)
            cppSelf->setMultiHighlightGradient(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DSeries::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QString)
            cppSelf->setName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setSingleHighlightColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DSeries::setSingleHighlightColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setSingleHighlightColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSingleHighlightColor", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSingleHighlightColor(QColor)
            cppSelf->setSingleHighlightColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setSingleHighlightGradient(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DSeries::setSingleHighlightGradient(QLinearGradient)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), (pyArg)))) {
        overloadId = 0; // setSingleHighlightGradient(QLinearGradient)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSingleHighlightGradient", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLinearGradient cppArg0_local;
        ::QLinearGradient *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSingleHighlightGradient(QLinearGradient)
            cppSelf->setSingleHighlightGradient(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setUserDefinedMesh(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DSeries::setUserDefinedMesh(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setUserDefinedMesh(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUserDefinedMesh", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUserDefinedMesh(QString)
            cppSelf->setUserDefinedMesh(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_setVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DSeries::setVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVisible", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVisible(bool)
            cppSelf->setVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_singleHighlightColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // singleHighlightColor()const
        QColor cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->singleHighlightColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_singleHighlightGradient(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // singleHighlightGradient()const
        QLinearGradient cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->singleHighlightGradient();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QAbstract3DSeries::SeriesType cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_SeriesType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DSeriesFunc_userDefinedMesh(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // userDefinedMesh()const
        QString cppResult = const_cast<const ::QAbstract3DSeries *>(cppSelf)->userDefinedMesh();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAbstract3DSeries_PropertyStrings[] = {
    "baseColor::",
    "baseGradient::",
    "colorStyle::",
    "itemLabel:",
    "itemLabelFormat::",
    "itemLabelVisible:isItemLabelVisible:",
    "mesh::",
    "meshRotation::",
    "meshSmooth:isMeshSmooth:",
    "multiHighlightColor::",
    "multiHighlightGradient::",
    "name::",
    "singleHighlightColor::",
    "singleHighlightGradient::",
    "type:",
    "userDefinedMesh::",
    "visible:isVisible:",
    nullptr // Sentinel
};

static const char *Sbk_QAbstract3DSeries_EnumFlagInfo[] = {
    "Mesh:Enum",
    "SeriesType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstract3DSeries_methods[] = {
    {"baseColor", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_baseColor), METH_NOARGS, nullptr},
    {"baseGradient", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_baseGradient), METH_NOARGS, nullptr},
    {"colorStyle", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_colorStyle), METH_NOARGS, nullptr},
    {"isItemLabelVisible", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_isItemLabelVisible), METH_NOARGS, nullptr},
    {"isMeshSmooth", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_isMeshSmooth), METH_NOARGS, nullptr},
    {"isVisible", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_isVisible), METH_NOARGS, nullptr},
    {"itemLabel", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_itemLabel), METH_NOARGS, nullptr},
    {"itemLabelFormat", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_itemLabelFormat), METH_NOARGS, nullptr},
    {"mesh", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_mesh), METH_NOARGS, nullptr},
    {"meshRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_meshRotation), METH_NOARGS, nullptr},
    {"multiHighlightColor", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_multiHighlightColor), METH_NOARGS, nullptr},
    {"multiHighlightGradient", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_multiHighlightGradient), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_name), METH_NOARGS, nullptr},
    {"setBaseColor", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setBaseColor), METH_O, nullptr},
    {"setBaseGradient", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setBaseGradient), METH_O, nullptr},
    {"setColorStyle", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setColorStyle), METH_O, nullptr},
    {"setItemLabelFormat", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setItemLabelFormat), METH_O, nullptr},
    {"setItemLabelVisible", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setItemLabelVisible), METH_O, nullptr},
    {"setMesh", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setMesh), METH_O, nullptr},
    {"setMeshAxisAndAngle", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setMeshAxisAndAngle), METH_VARARGS, nullptr},
    {"setMeshRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setMeshRotation), METH_O, nullptr},
    {"setMeshSmooth", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setMeshSmooth), METH_O, nullptr},
    {"setMultiHighlightColor", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setMultiHighlightColor), METH_O, nullptr},
    {"setMultiHighlightGradient", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setMultiHighlightGradient), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setName), METH_O, nullptr},
    {"setSingleHighlightColor", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setSingleHighlightColor), METH_O, nullptr},
    {"setSingleHighlightGradient", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setSingleHighlightGradient), METH_O, nullptr},
    {"setUserDefinedMesh", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setUserDefinedMesh), METH_O, nullptr},
    {"setVisible", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_setVisible), METH_O, nullptr},
    {"singleHighlightColor", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_singleHighlightColor), METH_NOARGS, nullptr},
    {"singleHighlightGradient", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_singleHighlightGradient), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_type), METH_NOARGS, nullptr},
    {"userDefinedMesh", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DSeriesFunc_userDefinedMesh), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstract3DSeries_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstract3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstract3DSeriesWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstract3DSeries_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstract3DSeries_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstract3DSeries_Type = nullptr;
static PyTypeObject *Sbk_QAbstract3DSeries_TypeF(void)
{
    return _Sbk_QAbstract3DSeries_Type;
}

static PyType_Slot Sbk_QAbstract3DSeries_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstract3DSeries_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstract3DSeries_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstract3DSeries_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstract3DSeries_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstract3DSeries_spec = {
    "2:PySide6.QtDataVisualization.QAbstract3DSeries",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstract3DSeries_slots
};

} //extern "C"

static void *Sbk_QAbstract3DSeries_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAbstract3DSeries *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAbstract3DSeries_SeriesType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstract3DSeries::SeriesType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstract3DSeries::SeriesType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstract3DSeries_SeriesType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_SeriesType_IDX])))
        return Enum_PythonToCpp_QAbstract3DSeries_SeriesType;
    return {};
}

static PyObject *QAbstract3DSeries_SeriesType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstract3DSeries::SeriesType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstract3DSeries::SeriesType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_SeriesType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstract3DSeries_Mesh(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstract3DSeries::Mesh>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstract3DSeries::Mesh *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstract3DSeries_Mesh_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_Mesh_IDX])))
        return Enum_PythonToCpp_QAbstract3DSeries_Mesh;
    return {};
}

static PyObject *QAbstract3DSeries_Mesh_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstract3DSeries::Mesh>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstract3DSeries::Mesh *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_Mesh_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstract3DSeries_PythonToCpp_QAbstract3DSeries_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstract3DSeries_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstract3DSeries_PythonToCpp_QAbstract3DSeries_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstract3DSeries_TypeF()))
        return QAbstract3DSeries_PythonToCpp_QAbstract3DSeries_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstract3DSeries_PTR_CppToPython_QAbstract3DSeries(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAbstract3DSeries *>(const_cast<void *>(cppIn)), Sbk_QAbstract3DSeries_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstract3DSeries_SignatureStrings[] = {
    "PySide6.QtDataVisualization.QAbstract3DSeries.baseColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtDataVisualization.QAbstract3DSeries.baseGradient(self)->PySide6.QtGui.QLinearGradient",
    "PySide6.QtDataVisualization.QAbstract3DSeries.colorStyle(self)->PySide6.QtDataVisualization.Q3DTheme.ColorStyle",
    "PySide6.QtDataVisualization.QAbstract3DSeries.isItemLabelVisible(self)->bool",
    "PySide6.QtDataVisualization.QAbstract3DSeries.isMeshSmooth(self)->bool",
    "PySide6.QtDataVisualization.QAbstract3DSeries.isVisible(self)->bool",
    "PySide6.QtDataVisualization.QAbstract3DSeries.itemLabel(self)->QString",
    "PySide6.QtDataVisualization.QAbstract3DSeries.itemLabelFormat(self)->QString",
    "PySide6.QtDataVisualization.QAbstract3DSeries.mesh(self)->PySide6.QtDataVisualization.QAbstract3DSeries.Mesh",
    "PySide6.QtDataVisualization.QAbstract3DSeries.meshRotation(self)->PySide6.QtGui.QQuaternion",
    "PySide6.QtDataVisualization.QAbstract3DSeries.multiHighlightColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtDataVisualization.QAbstract3DSeries.multiHighlightGradient(self)->PySide6.QtGui.QLinearGradient",
    "PySide6.QtDataVisualization.QAbstract3DSeries.name(self)->QString",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setBaseColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setBaseGradient(self,gradient:PySide6.QtGui.QLinearGradient)",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setColorStyle(self,style:PySide6.QtDataVisualization.Q3DTheme.ColorStyle)",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setItemLabelFormat(self,format:QString)",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setItemLabelVisible(self,visible:bool)",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setMesh(self,mesh:PySide6.QtDataVisualization.QAbstract3DSeries.Mesh)",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setMeshAxisAndAngle(self,axis:PySide6.QtGui.QVector3D,angle:float)",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setMeshRotation(self,rotation:PySide6.QtGui.QQuaternion)",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setMeshSmooth(self,enable:bool)",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setMultiHighlightColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setMultiHighlightGradient(self,gradient:PySide6.QtGui.QLinearGradient)",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setName(self,name:QString)",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setSingleHighlightColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setSingleHighlightGradient(self,gradient:PySide6.QtGui.QLinearGradient)",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setUserDefinedMesh(self,fileName:QString)",
    "PySide6.QtDataVisualization.QAbstract3DSeries.setVisible(self,visible:bool)",
    "PySide6.QtDataVisualization.QAbstract3DSeries.singleHighlightColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtDataVisualization.QAbstract3DSeries.singleHighlightGradient(self)->PySide6.QtGui.QLinearGradient",
    "PySide6.QtDataVisualization.QAbstract3DSeries.type(self)->PySide6.QtDataVisualization.QAbstract3DSeries.SeriesType",
    "PySide6.QtDataVisualization.QAbstract3DSeries.userDefinedMesh(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstract3DSeries_SignatureByteSize = 509;
static constexpr uint8_t QAbstract3DSeries_SignatureBytes[509] = {
    0x78, 0xda, 0xdd, 0x96, 0xc1, 0x8e, 0x9b, 0x30, 0x10, 0x86, 0xef, 0x7d, 0x8a, 0x1c, 0xbb, 0x92,
    0x8b, 0x54, 0xa5, 0xda, 0x03, 0x87, 0x4a, 0x69, 0x50, 0xd3, 0x95, 0x92, 0x55, 0x58, 0x76, 0x73,
    0xa9, 0x7a, 0x18, 0xc2, 0x84, 0x8c, 0x64, 0xec, 0xca, 0x1e, 0xaa, 0xa6, 0x4f, 0x5f, 0x93, 0x84,
    0xdd, 0x90, 0x0d, 0xab, 0x62, 0xd8, 0x4a, 0xed, 0x21, 0x02, 0x87, 0xf1, 0xf7, 0xe3, 0x19, 0xcf,
    0x8f, 0x97, 0xbb, 0x84, 0x32, 0xbc, 0x0e, 0x62, 0x8e, 0x80, 0x61, 0x45, 0xb6, 0x04, 0x49, 0xbf,
    0x80, 0x49, 0xab, 0x20, 0x9e, 0xa4, 0x96, 0x0d, 0xac, 0x79, 0x1c, 0x25, 0x68, 0x08, 0x6d, 0x90,
    0x82, 0xc5, 0xa9, 0x96, 0xda, 0xbc, 0xb5, 0x28, 0x37, 0x57, 0xef, 0x3e, 0x2e, 0x1f, 0xa7, 0xcf,
    0x4a, 0x0a, 0xe2, 0xfd, 0xb3, 0x37, 0xcb, 0xce, 0xcc, 0x99, 0x81, 0x8c, 0x50, 0x71, 0x0b, 0x76,
    0x4e, 0x0a, 0xc1, 0xd4, 0x41, 0x1d, 0xf9, 0xeb, 0xea, 0x9d, 0x12, 0xde, 0x49, 0x7c, 0x4e, 0xbf,
    0x30, 0x7f, 0x1c, 0xdd, 0x6f, 0xb1, 0xc0, 0x60, 0xfa, 0x38, 0xad, 0xa3, 0x1e, 0xd9, 0x1b, 0xc6,
    0x62, 0x0e, 0x29, 0x4a, 0x17, 0x4a, 0xe9, 0x93, 0x6e, 0xaa, 0xb5, 0xec, 0x0c, 0x5b, 0xa0, 0xdd,
    0x26, 0x85, 0xd6, 0xbc, 0xed, 0x85, 0x19, 0xe0, 0x55, 0xea, 0x55, 0xd5, 0x8c, 0x38, 0x61, 0x43,
    0x2a, 0xf7, 0xc5, 0x7c, 0xd6, 0xa6, 0x00, 0xee, 0x07, 0x2b, 0x5c, 0x72, 0xfe, 0xa8, 0xaa, 0xcf,
    0x66, 0x56, 0x69, 0xf5, 0x10, 0xbb, 0xd3, 0xbc, 0x7f, 0xdc, 0xb2, 0x51, 0xe3, 0x12, 0x18, 0x8d,
    0x72, 0x01, 0x5d, 0xd9, 0xa5, 0x64, 0xfa, 0x42, 0xf9, 0x56, 0xba, 0x1f, 0x0f, 0xdd, 0x62, 0x4d,
    0xfa, 0x6b, 0x36, 0x9b, 0x82, 0x02, 0xfb, 0x95, 0xd4, 0x22, 0x7f, 0x6a, 0xb8, 0x8c, 0xd8, 0x37,
    0x70, 0xc8, 0xbb, 0xef, 0x0e, 0x16, 0x3c, 0x54, 0xc9, 0xfd, 0x7a, 0x29, 0x27, 0x62, 0x14, 0xcf,
    0x1d, 0x54, 0xbd, 0x3f, 0xc8, 0x8a, 0xd1, 0x59, 0xd0, 0x5d, 0x9e, 0xc2, 0xf5, 0x07, 0x17, 0xb5,
    0x02, 0x43, 0xa0, 0xf8, 0x34, 0x60, 0xaa, 0x0d, 0xba, 0x4b, 0x30, 0x93, 0x3a, 0x05, 0x59, 0xe3,
    0x6a, 0x50, 0xa9, 0x2c, 0xe5, 0x0a, 0xb3, 0x11, 0x29, 0xfe, 0x76, 0xe5, 0xb7, 0x9e, 0x46, 0xd2,
    0x45, 0x7e, 0x1c, 0x85, 0x2f, 0xe6, 0xde, 0x43, 0x6a, 0xda, 0x34, 0x3b, 0x61, 0xab, 0xdb, 0xb0,
    0xa3, 0xe1, 0x79, 0xe8, 0xde, 0x5c, 0xe8, 0x6a, 0xb1, 0xd9, 0xdf, 0x87, 0xc7, 0x3c, 0xf6, 0xa1,
    0x9e, 0xba, 0x97, 0xf8, 0x71, 0x18, 0x84, 0x95, 0x87, 0x79, 0x40, 0x17, 0xb5, 0x67, 0x88, 0xaa,
    0xa1, 0xc3, 0xee, 0xb6, 0xe1, 0xa9, 0x39, 0xf9, 0x49, 0x76, 0xa2, 0xb2, 0x89, 0xca, 0xeb, 0x85,
    0x80, 0xfb, 0xe7, 0x7c, 0x07, 0xac, 0x70, 0xcd, 0xda, 0x8c, 0x23, 0x01, 0x55, 0x5c, 0xb8, 0x91,
    0x1a, 0xd8, 0x53, 0xb0, 0xe1, 0x55, 0xc2, 0x1c, 0x47, 0x61, 0xab, 0x65, 0x79, 0xca, 0x9c, 0x7c,
    0x9c, 0x04, 0x2a, 0xe8, 0x53, 0x99, 0x16, 0x13, 0xfc, 0xf7, 0x1d, 0x60, 0xd1, 0x6e, 0xc0, 0xaf,
    0xe7, 0x05, 0xb7, 0xb5, 0x17, 0x8b, 0xca, 0x95, 0x7b, 0xb4, 0x61, 0x42, 0xd5, 0x5e, 0xfc, 0x2f,
    0x0b, 0x73, 0xb6, 0xb4, 0xbf, 0x54, 0x99, 0x07, 0x8b, 0x26, 0xc2, 0x8d, 0xc3, 0x64, 0x4f, 0x6e,
    0xb4, 0x21, 0x89, 0xb7, 0xfd, 0x0a, 0x35, 0x9c, 0x4d, 0xb6, 0x55, 0x7c, 0x98, 0xf3, 0x88, 0x7d,
    0x21, 0xeb, 0x03, 0x1f, 0x48, 0xdc, 0xde, 0x44, 0xbf, 0x13, 0xe2, 0xe1, 0x72, 0xef, 0xe6, 0x77,
    0x94, 0x2c, 0x2f, 0x54, 0xf7, 0xe4, 0x38, 0xf4, 0x1b, 0xaa, 0xa1, 0xee, 0x36
};
#endif

PyTypeObject *init_QAbstract3DSeries(PyObject *module)
{
    if (SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX].type != nullptr)
        return SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstract3DSeries_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QAbstract3DSeries_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstract3DSeries",
        "QAbstract3DSeries*",
        &Sbk_QAbstract3DSeries_spec,
        &Shiboken::callCppDestructor< QAbstract3DSeries >,
        Sbk_QAbstract3DSeries_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAbstract3DSeries_TypeF(); // references _Sbk_QAbstract3DSeries_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstract3DSeries_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstract3DSeries_SignatureBytes, QAbstract3DSeries_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstract3DSeries_PropertyStrings);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstract3DSeries_PythonToCpp_QAbstract3DSeries_PTR,
        is_QAbstract3DSeries_PythonToCpp_QAbstract3DSeries_PTR_Convertible,
        QAbstract3DSeries_PTR_CppToPython_QAbstract3DSeries);

    Shiboken::Conversions::registerConverterName(converter, "QAbstract3DSeries");
    Shiboken::Conversions::registerConverterName(converter, "QAbstract3DSeries*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstract3DSeries&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstract3DSeries).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstract3DSeriesWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAbstract3DSeries_TypeF(), &Sbk_QAbstract3DSeries_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAbstract3DSeries_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SeriesType'.
    const char *SeriesType_Initializer[] = {
        "SeriesTypeNone",
        "SeriesTypeBar",
        "SeriesTypeScatter",
        "SeriesTypeSurface",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SeriesType_InitializerValues[] = {
        uint8_t(QAbstract3DSeries::SeriesType::SeriesTypeNone),    //  0x00  0
        uint8_t(QAbstract3DSeries::SeriesType::SeriesTypeBar),     //  0x01  1
        uint8_t(QAbstract3DSeries::SeriesType::SeriesTypeScatter), //  0x02  2
        uint8_t(QAbstract3DSeries::SeriesType::SeriesTypeSurface)  //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstract3DSeries_TypeF(),
        "2:PySide6.QtDataVisualization.QAbstract3DSeries.SeriesType",
        SeriesType_Initializer, SeriesType_InitializerValues);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_SeriesType_IDX].type = EType;
    // Register converter for enum 'QAbstract3DSeries::SeriesType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstract3DSeries_SeriesType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstract3DSeries_SeriesType,
            is_Enum_PythonToCpp_QAbstract3DSeries_SeriesType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstract3DSeries::SeriesType");
        Shiboken::Conversions::registerConverterAlias(converter, "SeriesType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SeriesType' enum.

    // Initialization of enum 'Mesh'.
    const char *Mesh_Initializer[] = {
        "MeshUserDefined",
        "MeshBar",
        "MeshCube",
        "MeshPyramid",
        "MeshCone",
        "MeshCylinder",
        "MeshBevelBar",
        "MeshBevelCube",
        "MeshSphere",
        "MeshMinimal",
        "MeshArrow",
        "MeshPoint",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Mesh_InitializerValues[] = {
        uint8_t(QAbstract3DSeries::Mesh::MeshUserDefined), //  0x00  0
        uint8_t(QAbstract3DSeries::Mesh::MeshBar),         //  0x01  1
        uint8_t(QAbstract3DSeries::Mesh::MeshCube),        //  0x02  2
        uint8_t(QAbstract3DSeries::Mesh::MeshPyramid),     //  0x03  3
        uint8_t(QAbstract3DSeries::Mesh::MeshCone),        //  0x04  4
        uint8_t(QAbstract3DSeries::Mesh::MeshCylinder),    //  0x05  5
        uint8_t(QAbstract3DSeries::Mesh::MeshBevelBar),    //  0x06  6
        uint8_t(QAbstract3DSeries::Mesh::MeshBevelCube),   //  0x07  7
        uint8_t(QAbstract3DSeries::Mesh::MeshSphere),      //  0x08  8
        uint8_t(QAbstract3DSeries::Mesh::MeshMinimal),     //  0x09  9
        uint8_t(QAbstract3DSeries::Mesh::MeshArrow),       //  0x0a  10
        uint8_t(QAbstract3DSeries::Mesh::MeshPoint)        //  0x0b  11
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstract3DSeries_TypeF(),
        "2:PySide6.QtDataVisualization.QAbstract3DSeries.Mesh",
        Mesh_Initializer, Mesh_InitializerValues);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_Mesh_IDX].type = EType;
    // Register converter for enum 'QAbstract3DSeries::Mesh'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstract3DSeries_Mesh_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstract3DSeries_Mesh,
            is_Enum_PythonToCpp_QAbstract3DSeries_Mesh_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstract3DSeries::Mesh");
        Shiboken::Conversions::registerConverterAlias(converter, "Mesh");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Mesh' enum.

    PySide::Signal::registerSignals(pyType, &::QAbstract3DSeries::staticMetaObject);
    qRegisterMetaType< ::QAbstract3DSeries::SeriesType >("QAbstract3DSeries::SeriesType");
    qRegisterMetaType< ::QAbstract3DSeries::Mesh >("QAbstract3DSeries::Mesh");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAbstract3DSeries::staticMetaObject, sizeof(QAbstract3DSeriesWrapper));

    return pyType;
}
