// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdatavisualization_python.h"

// main header
#include "qbardataitem_wrapper.h"

// Argument includes
#include <QtDataVisualization/qbardataitem.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBarDataItem_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBarDataItem >()))
        return -1;

    ::QBarDataItem *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QBarDataItem", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBarDataItem::QBarDataItem()
    // 1: QBarDataItem::QBarDataItem(QBarDataItem)
    // 2: QBarDataItem::QBarDataItem(float)
    // 3: QBarDataItem::QBarDataItem(float,float)
    if (numArgs == 0) {
        overloadId = 0; // QBarDataItem()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QBarDataItem(float)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
            overloadId = 3; // QBarDataItem(float,float)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QBarDataItem(QBarDataItem)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QBarDataItem()
        {

            // QBarDataItem()
            cptr = new ::QBarDataItem();
            break;
        }
        case 1: // QBarDataItem(const QBarDataItem &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBarDataItem cppArg0_local;
            ::QBarDataItem *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QBarDataItem(QBarDataItem)
                cptr = new ::QBarDataItem(*cppArg0);
            }
            break;
        }
        case 2: // QBarDataItem(float value)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBarDataItem(float)
                cptr = new ::QBarDataItem(cppArg0);
            }
            break;
        }
        case 3: // QBarDataItem(float value, float angle)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBarDataItem(float,float)
                cptr = new ::QBarDataItem(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QBarDataItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QBarDataItemFunc_createExtraData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createExtraData()
        cppSelf->createExtraData();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarDataItemFunc_rotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rotation()const
        float cppResult = const_cast<const ::QBarDataItem *>(cppSelf)->rotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarDataItemFunc_setRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarDataItem::setRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRotation", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotation(float)
            cppSelf->setRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarDataItemFunc_setValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarDataItem::setValue(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setValue(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setValue", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValue(float)
            cppSelf->setValue(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarDataItemFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // value()const
        float cppResult = const_cast<const ::QBarDataItem *>(cppSelf)->value();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarDataItem__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QBarDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QBarDataItem_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBarDataItem_methods[] = {
    {"createExtraData", reinterpret_cast<PyCFunction>(Sbk_QBarDataItemFunc_createExtraData), METH_NOARGS, nullptr},
    {"rotation", reinterpret_cast<PyCFunction>(Sbk_QBarDataItemFunc_rotation), METH_NOARGS, nullptr},
    {"setRotation", reinterpret_cast<PyCFunction>(Sbk_QBarDataItemFunc_setRotation), METH_O, nullptr},
    {"setValue", reinterpret_cast<PyCFunction>(Sbk_QBarDataItemFunc_setValue), METH_O, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QBarDataItemFunc_value), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QBarDataItem__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QBarDataItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBarDataItem_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBarDataItem_Type = nullptr;
static PyTypeObject *Sbk_QBarDataItem_TypeF(void)
{
    return _Sbk_QBarDataItem_Type;
}

static PyType_Slot Sbk_QBarDataItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBarDataItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBarDataItem_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBarDataItem_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBarDataItem_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBarDataItem_spec = {
    "2:PySide6.QtDataVisualization.QBarDataItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBarDataItem_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBarDataItem_PythonToCpp_QBarDataItem_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBarDataItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBarDataItem_PythonToCpp_QBarDataItem_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBarDataItem_TypeF()))
        return QBarDataItem_PythonToCpp_QBarDataItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBarDataItem_PTR_CppToPython_QBarDataItem(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QBarDataItem_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QBarDataItem_COPY_CppToPython_QBarDataItem(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QBarDataItem *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QBarDataItem_TypeF(), new ::QBarDataItem(*source), true, true);
}

// Python to C++ copy conversion.
static void QBarDataItem_PythonToCpp_QBarDataItem_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QBarDataItem *>(cppOut) = *reinterpret_cast< ::QBarDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QBarDataItem_PythonToCpp_QBarDataItem_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QBarDataItem_TypeF()))
        return QBarDataItem_PythonToCpp_QBarDataItem_COPY;
    return {};
}

// Implicit conversions.
static void float_PythonToCpp_QBarDataItem(PyObject *pyIn, void *cppOut)
{
    float cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pyIn, &cppIn);
    *reinterpret_cast<::QBarDataItem *>(cppOut) = ::QBarDataItem(cppIn);
}
static PythonToCppFunc is_float_PythonToCpp_QBarDataItem_Convertible(PyObject *pyIn)
{
    if (PyFloat_Check(pyIn))
        return float_PythonToCpp_QBarDataItem;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBarDataItem_SignatureStrings[] = {
    "3:PySide6.QtDataVisualization.QBarDataItem(self)",
    "2:PySide6.QtDataVisualization.QBarDataItem(self,other:PySide6.QtDataVisualization.QBarDataItem)",
    "1:PySide6.QtDataVisualization.QBarDataItem(self,value:float)",
    "0:PySide6.QtDataVisualization.QBarDataItem(self,value:float,angle:float)",
    "PySide6.QtDataVisualization.QBarDataItem.createExtraData(self)",
    "PySide6.QtDataVisualization.QBarDataItem.rotation(self)->float",
    "PySide6.QtDataVisualization.QBarDataItem.setRotation(self,angle:float)",
    "PySide6.QtDataVisualization.QBarDataItem.setValue(self,val:float)",
    "PySide6.QtDataVisualization.QBarDataItem.value(self)->float",
    "PySide6.QtDataVisualization.QBarDataItem.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QBarDataItem_SignatureByteSize = 172;
static constexpr uint8_t QBarDataItem_SignatureBytes[172] = {
    0x78, 0xda, 0x9d, 0x90, 0x3d, 0x0b, 0xc2, 0x30, 0x14, 0x45, 0xf7, 0xfc, 0x12, 0x03, 0x35, 0xf8,
    0x01, 0x0e, 0x1d, 0x1c, 0x44, 0x07, 0x37, 0x6b, 0xa1, 0x6b, 0x78, 0xd4, 0xd7, 0x1a, 0x88, 0x4d,
    0x49, 0x5f, 0x8b, 0xf5, 0xd7, 0xdb, 0x56, 0x0d, 0x8e, 0x49, 0xc7, 0x77, 0xe1, 0x9c, 0xc7, 0xbd,
    0xdb, 0xf8, 0xd2, 0xa7, 0xea, 0x86, 0x3b, 0x91, 0xd0, 0x11, 0x08, 0x32, 0xd5, 0xb4, 0xa0, 0xd5,
    0x0b, 0x48, 0x99, 0x4a, 0x24, 0x07, 0xb0, 0x63, 0x7a, 0x26, 0x7c, 0x2c, 0x1a, 0xd4, 0x05, 0x67,
    0x9b, 0x30, 0x20, 0x32, 0x74, 0x47, 0xeb, 0xcd, 0x70, 0xb6, 0x0e, 0xf4, 0x77, 0xa0, 0x5b, 0x8c,
    0x0b, 0x6d, 0x80, 0x38, 0x5b, 0xcd, 0x87, 0x23, 0xa8, 0x4a, 0xed, 0x44, 0xbe, 0x1a, 0x91, 0x5b,
    0x04, 0xc2, 0xd3, 0x93, 0x2c, 0x8c, 0xd9, 0x77, 0x24, 0x6f, 0xdc, 0x1a, 0x9a, 0xd2, 0x0f, 0xb7,
    0xdc, 0x4f, 0xef, 0xfd, 0xf1, 0x06, 0xe9, 0xfa, 0x6f, 0x98, 0x59, 0x62, 0xd0, 0x64, 0xe3, 0x12,
    0x6e, 0x94, 0x60, 0x43, 0xe7, 0xf0, 0xf0, 0x12, 0x52, 0xe6, 0xa6, 0xee, 0xa5, 0xfc, 0xe1, 0xd4,
    0xd7, 0xaa, 0x2a, 0x45, 0x3a, 0x5c, 0xec, 0x0d, 0xbb, 0x4c, 0xf4, 0xcf
};
#endif

PyTypeObject *init_QBarDataItem(PyObject *module)
{
    if (SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX].type != nullptr)
        return SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX].type;

    Shiboken::AutoDecRef Sbk_QBarDataItem_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QBarDataItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBarDataItem",
        "QBarDataItem",
        &Sbk_QBarDataItem_spec,
        &Shiboken::callCppDestructor< ::QBarDataItem >,
        Sbk_QBarDataItem_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QBarDataItem_TypeF(); // references _Sbk_QBarDataItem_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBarDataItem_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBarDataItem_SignatureBytes, QBarDataItem_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBarDataItem_PropertyStrings);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBarDataItem_PythonToCpp_QBarDataItem_PTR,
        is_QBarDataItem_PythonToCpp_QBarDataItem_PTR_Convertible,
        QBarDataItem_PTR_CppToPython_QBarDataItem,
        QBarDataItem_COPY_CppToPython_QBarDataItem);

    Shiboken::Conversions::registerConverterName(converter, "QBarDataItem");
    Shiboken::Conversions::registerConverterName(converter, "QBarDataItem*");
    Shiboken::Conversions::registerConverterName(converter, "QBarDataItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBarDataItem).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QBarDataItem_PythonToCpp_QBarDataItem_COPY,
        is_QBarDataItem_PythonToCpp_QBarDataItem_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        float_PythonToCpp_QBarDataItem,
        is_float_PythonToCpp_QBarDataItem_Convertible);

    qRegisterMetaType< ::QBarDataItem >("QBarDataItem");

    return pyType;
}
