// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdatavisualization_python.h"

// main header
#include "qcustom3dvolume_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qcolor.h>
#include <QtGui/qimage.h>
#include <QtGui/qquaternion.h>
#include <QtGui/qvectornd.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QCustom3DVolumeWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QCustom3DVolumeWrapper::QCustom3DVolumeWrapper(::QObject * parent) : QCustom3DVolume(parent)
{
}

QCustom3DVolumeWrapper::QCustom3DVolumeWrapper(const ::QVector3D & position, const ::QVector3D & scaling, const ::QQuaternion & rotation, int textureWidth, int textureHeight, int textureDepth, ::QList<uchar> * textureData, ::QImage::Format textureFormat, const ::QList<unsigned int> & colorTable, ::QObject * parent) : QCustom3DVolume(position, scaling, rotation, textureWidth, textureHeight, textureDepth, textureData, textureFormat, colorTable, parent)
{
}

void QCustom3DVolumeWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCustom3DVolume", funcName);
        return;
    }
}

void QCustom3DVolumeWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCustom3DVolume", funcName);
        return;
    }
}

void QCustom3DVolumeWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCustom3DVolume", funcName);
        return;
    }
}

void QCustom3DVolumeWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCustom3DVolume", funcName);
        return;
    }
}

bool QCustom3DVolumeWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCustom3DVolume", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCustom3DVolume", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QCustom3DVolumeWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCustom3DVolume", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCustom3DVolume", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCustom3DVolumeWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QCustom3DVolume", funcName);
        return;
    }
}

const QMetaObject *QCustom3DVolumeWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QCustom3DVolume::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QCustom3DVolumeWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QCustom3DVolume::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QCustom3DVolumeWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QCustom3DVolumeWrapper *>(this));
    return QCustom3DVolume::qt_metacast(_clname);
}

QCustom3DVolumeWrapper::~QCustom3DVolumeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCustom3DVolume_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCustom3DVolume >()))
        return -1;

    QCustom3DVolumeWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[10];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5 || numArgs == 6 || numArgs == 7 || numArgs == 8)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOOOOO:QCustom3DVolume", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCustom3DVolume::QCustom3DVolume(QObject*=)
    // 1: QCustom3DVolume::QCustom3DVolume(QVector3D,QVector3D,QQuaternion,int,int,int,QList<uchar>*,QImage::Format,QList<uint>,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QCustom3DVolume(QObject*)
    } else if (numArgs >= 9
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDataVisualizationTypeConverters[SBK_QtDataVisualization_QList_uchar_IDX], (pyArgs[6])))
        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_Format_IDX])))->converter, (pyArgs[7])))
        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDataVisualizationTypeConverters[SBK_QtDataVisualization_QList_unsignedint_IDX], (pyArgs[8])))) {
        if (numArgs == 9) {
            overloadId = 1; // QCustom3DVolume(QVector3D,QVector3D,QQuaternion,int,int,int,QList<uchar>*,QImage::Format,QList<uint>,QObject*)
        } else if (numArgs >= 10
            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[9])))) {
            overloadId = 1; // QCustom3DVolume(QVector3D,QVector3D,QQuaternion,int,int,int,QList<uchar>*,QImage::Format,QList<uint>,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QCustom3DVolume(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QCustom3DVolume(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCustom3DVolume(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QCustom3DVolumeWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QCustom3DVolumeWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QCustom3DVolume(const QVector3D &position, const QVector3D &scaling, const QQuaternion &rotation, int textureWidth, int textureHeight, int textureDepth, QList<uchar> *textureData, QImage::Format textureFormat, const QList<unsigned int> &colorTable, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[9] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[9] = value;
                        if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[9]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QVector3D cppArg0_local;
            ::QVector3D *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QVector3D cppArg1_local;
            ::QVector3D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QQuaternion cppArg2_local;
            ::QQuaternion *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            ::QList<uchar> cppArg6_local;
            ::QList<uchar> *cppArg6 = &cppArg6_local;
            if (pythonToCpp[6].isValue())
                pythonToCpp[6](pyArgs[6], &cppArg6_local);
            else
                pythonToCpp[6](pyArgs[6], &cppArg6);

            ::QImage::Format cppArg7{QImage::Format_Invalid};
            pythonToCpp[7](pyArgs[7], &cppArg7);
            ::QList<unsigned int> cppArg8;
            pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return -1;
            ::QObject *cppArg9 = nullptr;
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCustom3DVolume(QVector3D,QVector3D,QQuaternion,int,int,int,QList<uchar>*,QImage::Format,QList<uint>,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QCustom3DVolumeWrapper(*cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QCustom3DVolumeWrapper(*cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[9], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QCustom3DVolume >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QCustom3DVolumeFunc_alphaMultiplier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // alphaMultiplier()const
        float cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->alphaMultiplier();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_colorTable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // colorTable()const
        QList<unsigned int> cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->colorTable();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtDataVisualizationTypeConverters[SBK_QtDataVisualization_QList_unsignedint_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_createTextureData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::createTextureData(QList<QImage*>)->QList<uchar>*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDataVisualizationTypeConverters[SBK_QtDataVisualization_QList_QImagePTR_IDX], (pyArg)))) {
        overloadId = 0; // createTextureData(QList<QImage*>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createTextureData", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        ::QList<QImage*> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createTextureData(QList<QImage*>)
            QList<uchar> * cppResult = cppSelf->createTextureData(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtDataVisualizationTypeConverters[SBK_QtDataVisualization_QList_uchar_IDX], cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_drawSliceFrames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // drawSliceFrames()const
        bool cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->drawSliceFrames();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_drawSlices(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // drawSlices()const
        bool cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->drawSlices();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_preserveOpacity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // preserveOpacity()const
        bool cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->preserveOpacity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_renderSlice(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "renderSlice", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCustom3DVolume::renderSlice(Qt::Axis,int)->QImage
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Axis_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // renderSlice(Qt::Axis,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "renderSlice", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        ::Qt::Axis cppArg0{Qt::XAxis};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // renderSlice(Qt::Axis,int)
            QImage cppResult = cppSelf->renderSlice(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setAlphaMultiplier(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setAlphaMultiplier(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setAlphaMultiplier(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAlphaMultiplier", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAlphaMultiplier(float)
            cppSelf->setAlphaMultiplier(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setColorTable(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setColorTable(QList<uint>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDataVisualizationTypeConverters[SBK_QtDataVisualization_QList_unsignedint_IDX], (pyArg)))) {
        overloadId = 0; // setColorTable(QList<uint>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColorTable", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        ::QList<unsigned int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColorTable(QList<uint>)
            cppSelf->setColorTable(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setDrawSliceFrames(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setDrawSliceFrames(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDrawSliceFrames(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDrawSliceFrames", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDrawSliceFrames(bool)
            cppSelf->setDrawSliceFrames(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setDrawSlices(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setDrawSlices(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDrawSlices(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDrawSlices", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDrawSlices(bool)
            cppSelf->setDrawSlices(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setPreserveOpacity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setPreserveOpacity(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setPreserveOpacity(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPreserveOpacity", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPreserveOpacity(bool)
            cppSelf->setPreserveOpacity(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setSliceFrameColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setSliceFrameColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setSliceFrameColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSliceFrameColor", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSliceFrameColor(QColor)
            cppSelf->setSliceFrameColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setSliceFrameGaps(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setSliceFrameGaps(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setSliceFrameGaps(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSliceFrameGaps", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSliceFrameGaps(QVector3D)
            cppSelf->setSliceFrameGaps(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setSliceFrameThicknesses(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setSliceFrameThicknesses(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setSliceFrameThicknesses(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSliceFrameThicknesses", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSliceFrameThicknesses(QVector3D)
            cppSelf->setSliceFrameThicknesses(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setSliceFrameWidths(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setSliceFrameWidths(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setSliceFrameWidths(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSliceFrameWidths", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSliceFrameWidths(QVector3D)
            cppSelf->setSliceFrameWidths(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setSliceIndexX(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setSliceIndexX(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSliceIndexX(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSliceIndexX", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSliceIndexX(int)
            cppSelf->setSliceIndexX(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setSliceIndexY(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setSliceIndexY(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSliceIndexY(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSliceIndexY", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSliceIndexY(int)
            cppSelf->setSliceIndexY(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setSliceIndexZ(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setSliceIndexZ(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSliceIndexZ(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSliceIndexZ", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSliceIndexZ(int)
            cppSelf->setSliceIndexZ(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setSliceIndices(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setSliceIndices", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCustom3DVolume::setSliceIndices(int,int,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // setSliceIndices(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSliceIndices", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSliceIndices(int,int,int)
            cppSelf->setSliceIndices(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setSubTextureData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setSubTextureData", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCustom3DVolume::setSubTextureData(Qt::Axis,int,QImage)
    // 1: QCustom3DVolume::setSubTextureData(Qt::Axis,int,const uchar*)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Axis_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 3
            && SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[2])))) {
            overloadId = 1; // setSubTextureData(Qt::Axis,int,const uchar*)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), (pyArgs[2])))) {
            overloadId = 0; // setSubTextureData(Qt::Axis,int,QImage)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSubTextureData", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setSubTextureData(Qt::Axis axis, int index, const QImage &image)
        {
            ::Qt::Axis cppArg0{Qt::XAxis};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QImage cppArg2_local;
            ::QImage *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setSubTextureData(Qt::Axis,int,QImage)
                cppSelf->setSubTextureData(cppArg0, cppArg1, *cppArg2);
            }
            break;
        }
        case 1: // setSubTextureData(Qt::Axis axis, int index, const uchar *data)
        {
            ::Qt::Axis cppArg0{Qt::XAxis};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            uchar *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setSubTextureData(Qt::Axis,int,const uchar*)
                cppSelf->setSubTextureData(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setTextureData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setTextureData(QList<uchar>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDataVisualizationTypeConverters[SBK_QtDataVisualization_QList_uchar_IDX], (pyArg)))) {
        overloadId = 0; // setTextureData(QList<uchar>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextureData", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        ::QList<uchar> cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextureData(QList<uchar>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtdatavisualization.cpp (qcustom3dvolume-settexturedata)]
            using VectorType = decltype(cppArg0);
            cppSelf->setTextureData(new VectorType(cppArg0));
            // END of custom code block [file: ../glue/qtdatavisualization.cpp (qcustom3dvolume-settexturedata)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setTextureDepth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setTextureDepth(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setTextureDepth(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextureDepth", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextureDepth(int)
            cppSelf->setTextureDepth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setTextureDimensions(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setTextureDimensions", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCustom3DVolume::setTextureDimensions(int,int,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // setTextureDimensions(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setTextureDimensions", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextureDimensions(int,int,int)
            cppSelf->setTextureDimensions(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setTextureFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setTextureFormat(QImage::Format)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_Format_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTextureFormat(QImage::Format)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextureFormat", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        ::QImage::Format cppArg0{QImage::Format_Invalid};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextureFormat(QImage::Format)
            cppSelf->setTextureFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setTextureHeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setTextureHeight(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setTextureHeight(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextureHeight", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextureHeight(int)
            cppSelf->setTextureHeight(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setTextureWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setTextureWidth(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setTextureWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextureWidth", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextureWidth(int)
            cppSelf->setTextureWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_setUseHighDefShader(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCustom3DVolume::setUseHighDefShader(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setUseHighDefShader(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUseHighDefShader", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUseHighDefShader(bool)
            cppSelf->setUseHighDefShader(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCustom3DVolumeFunc_sliceFrameColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sliceFrameColor()const
        QColor cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->sliceFrameColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_sliceFrameGaps(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sliceFrameGaps()const
        QVector3D cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->sliceFrameGaps();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_sliceFrameThicknesses(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sliceFrameThicknesses()const
        QVector3D cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->sliceFrameThicknesses();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_sliceFrameWidths(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sliceFrameWidths()const
        QVector3D cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->sliceFrameWidths();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_sliceIndexX(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sliceIndexX()const
        int cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->sliceIndexX();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_sliceIndexY(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sliceIndexY()const
        int cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->sliceIndexY();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_sliceIndexZ(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sliceIndexZ()const
        int cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->sliceIndexZ();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_textureData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureData()const
        QList<uchar> * cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->textureData();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtDataVisualizationTypeConverters[SBK_QtDataVisualization_QList_uchar_IDX], cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_textureDataWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureDataWidth()const
        int cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->textureDataWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_textureDepth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureDepth()const
        int cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->textureDepth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_textureFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureFormat()const
        QImage::Format cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->textureFormat();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_Format_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_textureHeight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureHeight()const
        int cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->textureHeight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_textureWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureWidth()const
        int cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->textureWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCustom3DVolumeFunc_useHighDefShader(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // useHighDefShader()const
        bool cppResult = const_cast<const ::QCustom3DVolume *>(cppSelf)->useHighDefShader();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCustom3DVolume_PropertyStrings[] = {
    "alphaMultiplier::",
    "colorTable::",
    "drawSliceFrames::",
    "drawSlices::",
    "preserveOpacity::",
    "sliceFrameColor::",
    "sliceFrameGaps::",
    "sliceFrameThicknesses::",
    "sliceFrameWidths::",
    "sliceIndexX::",
    "sliceIndexY::",
    "sliceIndexZ::",
    "textureData::",
    "textureDepth::",
    "textureHeight::",
    "textureWidth::",
    "useHighDefShader::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCustom3DVolume_methods[] = {
    {"alphaMultiplier", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_alphaMultiplier), METH_NOARGS, nullptr},
    {"colorTable", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_colorTable), METH_NOARGS, nullptr},
    {"createTextureData", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_createTextureData), METH_O, nullptr},
    {"drawSliceFrames", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_drawSliceFrames), METH_NOARGS, nullptr},
    {"drawSlices", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_drawSlices), METH_NOARGS, nullptr},
    {"preserveOpacity", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_preserveOpacity), METH_NOARGS, nullptr},
    {"renderSlice", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_renderSlice), METH_VARARGS, nullptr},
    {"setAlphaMultiplier", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setAlphaMultiplier), METH_O, nullptr},
    {"setColorTable", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setColorTable), METH_O, nullptr},
    {"setDrawSliceFrames", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setDrawSliceFrames), METH_O, nullptr},
    {"setDrawSlices", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setDrawSlices), METH_O, nullptr},
    {"setPreserveOpacity", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setPreserveOpacity), METH_O, nullptr},
    {"setSliceFrameColor", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setSliceFrameColor), METH_O, nullptr},
    {"setSliceFrameGaps", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setSliceFrameGaps), METH_O, nullptr},
    {"setSliceFrameThicknesses", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setSliceFrameThicknesses), METH_O, nullptr},
    {"setSliceFrameWidths", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setSliceFrameWidths), METH_O, nullptr},
    {"setSliceIndexX", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setSliceIndexX), METH_O, nullptr},
    {"setSliceIndexY", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setSliceIndexY), METH_O, nullptr},
    {"setSliceIndexZ", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setSliceIndexZ), METH_O, nullptr},
    {"setSliceIndices", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setSliceIndices), METH_VARARGS, nullptr},
    {"setSubTextureData", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setSubTextureData), METH_VARARGS, nullptr},
    {"setTextureData", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setTextureData), METH_O, nullptr},
    {"setTextureDepth", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setTextureDepth), METH_O, nullptr},
    {"setTextureDimensions", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setTextureDimensions), METH_VARARGS, nullptr},
    {"setTextureFormat", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setTextureFormat), METH_O, nullptr},
    {"setTextureHeight", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setTextureHeight), METH_O, nullptr},
    {"setTextureWidth", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setTextureWidth), METH_O, nullptr},
    {"setUseHighDefShader", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_setUseHighDefShader), METH_O, nullptr},
    {"sliceFrameColor", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_sliceFrameColor), METH_NOARGS, nullptr},
    {"sliceFrameGaps", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_sliceFrameGaps), METH_NOARGS, nullptr},
    {"sliceFrameThicknesses", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_sliceFrameThicknesses), METH_NOARGS, nullptr},
    {"sliceFrameWidths", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_sliceFrameWidths), METH_NOARGS, nullptr},
    {"sliceIndexX", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_sliceIndexX), METH_NOARGS, nullptr},
    {"sliceIndexY", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_sliceIndexY), METH_NOARGS, nullptr},
    {"sliceIndexZ", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_sliceIndexZ), METH_NOARGS, nullptr},
    {"textureData", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_textureData), METH_NOARGS, nullptr},
    {"textureDataWidth", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_textureDataWidth), METH_NOARGS, nullptr},
    {"textureDepth", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_textureDepth), METH_NOARGS, nullptr},
    {"textureFormat", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_textureFormat), METH_NOARGS, nullptr},
    {"textureHeight", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_textureHeight), METH_NOARGS, nullptr},
    {"textureWidth", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_textureWidth), METH_NOARGS, nullptr},
    {"useHighDefShader", reinterpret_cast<PyCFunction>(Sbk_QCustom3DVolumeFunc_useHighDefShader), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QCustom3DVolume_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QCustom3DVolume *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QCustom3DVolumeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QCustom3DVolume_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCustom3DVolume_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCustom3DVolume_Type = nullptr;
static PyTypeObject *Sbk_QCustom3DVolume_TypeF(void)
{
    return _Sbk_QCustom3DVolume_Type;
}

static PyType_Slot Sbk_QCustom3DVolume_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QCustom3DVolume_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCustom3DVolume_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCustom3DVolume_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCustom3DVolume_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCustom3DVolume_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCustom3DVolume_spec = {
    "2:PySide6.QtDataVisualization.QCustom3DVolume",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCustom3DVolume_slots
};

} //extern "C"

static void *Sbk_QCustom3DVolume_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QCustom3DVolume *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCustom3DVolume_PythonToCpp_QCustom3DVolume_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCustom3DVolume_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCustom3DVolume_PythonToCpp_QCustom3DVolume_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCustom3DVolume_TypeF()))
        return QCustom3DVolume_PythonToCpp_QCustom3DVolume_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCustom3DVolume_PTR_CppToPython_QCustom3DVolume(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QCustom3DVolume *>(const_cast<void *>(cppIn)), Sbk_QCustom3DVolume_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCustom3DVolume_SignatureStrings[] = {
    "1:PySide6.QtDataVisualization.QCustom3DVolume(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,textureWidth:int=None,textureHeight:int=None,textureDepth:int=None,sliceIndexX:int=None,sliceIndexY:int=None,sliceIndexZ:int=None,colorTable:QList[unsigned int]=None,textureData:QList[uchar]=None,alphaMultiplier:float=None,preserveOpacity:bool=None,useHighDefShader:bool=None,drawSlices:bool=None,drawSliceFrames:bool=None,sliceFrameColor:QColor=None,sliceFrameWidths:QVector3D=None,sliceFrameGaps:QVector3D=None,sliceFrameThicknesses:QVector3D=None)",
    "0:PySide6.QtDataVisualization.QCustom3DVolume(self,position:PySide6.QtGui.QVector3D,scaling:PySide6.QtGui.QVector3D,rotation:PySide6.QtGui.QQuaternion,textureWidth:int,textureHeight:int,textureDepth:int,textureData:QList[uchar],textureFormat:PySide6.QtGui.QImage.Format,colorTable:QList[unsigned int],parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,textureWidth:int=None,textureHeight:int=None,textureDepth:int=None,sliceIndexX:int=None,sliceIndexY:int=None,sliceIndexZ:int=None,colorTable:QList[unsigned int]=None,textureData:QList[uchar]=None,alphaMultiplier:float=None,preserveOpacity:bool=None,useHighDefShader:bool=None,drawSlices:bool=None,drawSliceFrames:bool=None,sliceFrameColor:QColor=None,sliceFrameWidths:QVector3D=None,sliceFrameGaps:QVector3D=None,sliceFrameThicknesses:QVector3D=None)",
    "PySide6.QtDataVisualization.QCustom3DVolume.alphaMultiplier(self)->float",
    "PySide6.QtDataVisualization.QCustom3DVolume.colorTable(self)->QList[unsigned int]",
    "PySide6.QtDataVisualization.QCustom3DVolume.createTextureData(self,images:QList[PySide6.QtGui.QImage])->QList[uchar]",
    "PySide6.QtDataVisualization.QCustom3DVolume.drawSliceFrames(self)->bool",
    "PySide6.QtDataVisualization.QCustom3DVolume.drawSlices(self)->bool",
    "PySide6.QtDataVisualization.QCustom3DVolume.preserveOpacity(self)->bool",
    "PySide6.QtDataVisualization.QCustom3DVolume.renderSlice(self,axis:PySide6.QtCore.Qt.Axis,index:int)->PySide6.QtGui.QImage",
    "PySide6.QtDataVisualization.QCustom3DVolume.setAlphaMultiplier(self,mult:float)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setColorTable(self,colors:QList[unsigned int])",
    "PySide6.QtDataVisualization.QCustom3DVolume.setDrawSliceFrames(self,enable:bool)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setDrawSlices(self,enable:bool)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setPreserveOpacity(self,enable:bool)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setSliceFrameColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtDataVisualization.QCustom3DVolume.setSliceFrameGaps(self,values:PySide6.QtGui.QVector3D)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setSliceFrameThicknesses(self,values:PySide6.QtGui.QVector3D)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setSliceFrameWidths(self,values:PySide6.QtGui.QVector3D)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setSliceIndexX(self,value:int)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setSliceIndexY(self,value:int)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setSliceIndexZ(self,value:int)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setSliceIndices(self,x:int,y:int,z:int)",
    "1:PySide6.QtDataVisualization.QCustom3DVolume.setSubTextureData(self,axis:PySide6.QtCore.Qt.Axis,index:int,image:PySide6.QtGui.QImage)",
    "0:PySide6.QtDataVisualization.QCustom3DVolume.setSubTextureData(self,axis:PySide6.QtCore.Qt.Axis,index:int,data:uchar*)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setTextureData(self,arg__1:QList[uchar])",
    "PySide6.QtDataVisualization.QCustom3DVolume.setTextureDepth(self,value:int)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setTextureDimensions(self,width:int,height:int,depth:int)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setTextureFormat(self,format:PySide6.QtGui.QImage.Format)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setTextureHeight(self,value:int)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setTextureWidth(self,value:int)",
    "PySide6.QtDataVisualization.QCustom3DVolume.setUseHighDefShader(self,enable:bool)",
    "PySide6.QtDataVisualization.QCustom3DVolume.sliceFrameColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtDataVisualization.QCustom3DVolume.sliceFrameGaps(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtDataVisualization.QCustom3DVolume.sliceFrameThicknesses(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtDataVisualization.QCustom3DVolume.sliceFrameWidths(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtDataVisualization.QCustom3DVolume.sliceIndexX(self)->int",
    "PySide6.QtDataVisualization.QCustom3DVolume.sliceIndexY(self)->int",
    "PySide6.QtDataVisualization.QCustom3DVolume.sliceIndexZ(self)->int",
    "PySide6.QtDataVisualization.QCustom3DVolume.textureData(self)->QList[uchar]",
    "PySide6.QtDataVisualization.QCustom3DVolume.textureDataWidth(self)->int",
    "PySide6.QtDataVisualization.QCustom3DVolume.textureDepth(self)->int",
    "PySide6.QtDataVisualization.QCustom3DVolume.textureFormat(self)->PySide6.QtGui.QImage.Format",
    "PySide6.QtDataVisualization.QCustom3DVolume.textureHeight(self)->int",
    "PySide6.QtDataVisualization.QCustom3DVolume.textureWidth(self)->int",
    "PySide6.QtDataVisualization.QCustom3DVolume.useHighDefShader(self)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QCustom3DVolume_SignatureByteSize = 791;
static constexpr uint8_t QCustom3DVolume_SignatureBytes[791] = {
    0x78, 0xda, 0xed, 0x97, 0x5b, 0x4f, 0xdb, 0x30, 0x14, 0xc7, 0xdf, 0xf7, 0x29, 0xfa, 0x38, 0x50,
    0x16, 0xad, 0x62, 0xe2, 0x21, 0x12, 0x93, 0x50, 0x2b, 0x2e, 0x1a, 0x1b, 0x64, 0x85, 0x6e, 0x30,
    0x21, 0xe4, 0x26, 0xa7, 0x8d, 0x37, 0xc7, 0x8e, 0x6c, 0x87, 0x52, 0x3e, 0xfd, 0x1c, 0xa7, 0x69,
    0x6e, 0xee, 0x58, 0x9c, 0xf2, 0xb4, 0xbd, 0x80, 0xf0, 0x71, 0x7e, 0x27, 0x39, 0x97, 0xff, 0x39,
    0x0c, 0xbd, 0xab, 0xd5, 0x04, 0x87, 0x70, 0xe8, 0xfa, 0x72, 0x8c, 0x24, 0x9a, 0x62, 0x91, 0x22,
    0x82, 0x9f, 0x91, 0xc4, 0x8c, 0xba, 0xfe, 0x28, 0x15, 0x92, 0xc5, 0x07, 0xe3, 0x29, 0x23, 0x69,
    0x0c, 0x6f, 0x05, 0x90, 0xb9, 0x93, 0x20, 0x0e, 0x54, 0x56, 0x9e, 0x1b, 0x31, 0x0e, 0xae, 0x7f,
    0x39, 0xfb, 0x09, 0x81, 0x3c, 0xa2, 0x29, 0x21, 0x89, 0xe4, 0xce, 0xbe, 0xf7, 0x09, 0x56, 0x4b,
    0xc6, 0xc3, 0x4b, 0x4a, 0x56, 0x47, 0x5f, 0x18, 0x05, 0x47, 0xc2, 0x93, 0x4c, 0x39, 0x7c, 0xc3,
    0xa1, 0x8c, 0x3c, 0x4c, 0x65, 0xed, 0xf4, 0x0c, 0xf0, 0x22, 0x92, 0xad, 0xe3, 0x31, 0x24, 0xd5,
    0xcb, 0x82, 0xe0, 0x00, 0xce, 0x69, 0x08, 0x4f, 0xdf, 0x4d, 0x87, 0xb7, 0xa6, 0xc3, 0xbb, 0xf2,
    0x30, 0x60, 0x84, 0xf1, 0x6b, 0x34, 0x23, 0xe0, 0xf9, 0x17, 0x58, 0xc8, 0x1f, 0x29, 0x15, 0x78,
    0x41, 0x21, 0x1c, 0xa8, 0x2b, 0xf7, 0x75, 0xc7, 0x2a, 0x18, 0xc5, 0xa5, 0x20, 0x42, 0x7c, 0x6d,
    0x45, 0x24, 0x89, 0xd0, 0xe7, 0x94, 0x48, 0x9c, 0x10, 0x0c, 0xdc, 0x9b, 0x13, 0x86, 0xd6, 0xf0,
    0x84, 0x83, 0x00, 0xfe, 0x08, 0x97, 0x09, 0x0a, 0xb0, 0x5c, 0x79, 0x33, 0xc6, 0x48, 0x6e, 0x49,
    0x05, 0x9c, 0xa9, 0xaf, 0x1b, 0xc3, 0x7c, 0x12, 0xa1, 0x50, 0x3d, 0x55, 0x9a, 0x42, 0x8e, 0x96,
    0x93, 0xec, 0x55, 0x85, 0xe9, 0xf0, 0x84, 0xa3, 0xb8, 0x66, 0x11, 0x9b, 0xd3, 0x51, 0xf6, 0x29,
    0x9e, 0xaf, 0x7f, 0x35, 0x6d, 0x3a, 0xc2, 0xc2, 0xf3, 0xa7, 0x2a, 0x21, 0x8c, 0x1f, 0x8c, 0x9b,
    0xf6, 0x53, 0x94, 0xfc, 0xc1, 0x7a, 0x1d, 0xe1, 0xe0, 0x17, 0x05, 0x21, 0xa0, 0x79, 0x69, 0xef,
    0xcd, 0x7b, 0x8b, 0x72, 0x61, 0x02, 0x67, 0xd6, 0xca, 0x93, 0xa7, 0x29, 0x76, 0x37, 0x64, 0x47,
    0x04, 0x8a, 0x40, 0x17, 0x5b, 0xed, 0x9c, 0x49, 0x64, 0x02, 0xf8, 0x29, 0x92, 0xc0, 0xa9, 0xb2,
    0xb4, 0x2a, 0xab, 0x5d, 0x54, 0xad, 0x7a, 0xda, 0x9a, 0xe7, 0xc2, 0x70, 0xc2, 0x78, 0x8c, 0x64,
    0xd3, 0xe9, 0x79, 0x8c, 0x16, 0xe0, 0xe6, 0xb6, 0x17, 0xca, 0xe9, 0x7f, 0xa3, 0xfc, 0xc3, 0x8d,
    0xd2, 0xa1, 0x4d, 0xdc, 0x46, 0xa8, 0x74, 0xdb, 0xec, 0xbd, 0xfb, 0xa8, 0x23, 0xd6, 0x09, 0x54,
    0x66, 0xad, 0x60, 0x18, 0x92, 0xd7, 0x8d, 0xc8, 0x41, 0x35, 0xd9, 0x75, 0x99, 0xe9, 0xbc, 0xa7,
    0x71, 0xd6, 0x05, 0x62, 0x9d, 0x75, 0x53, 0x87, 0xdc, 0x97, 0xbe, 0x75, 0x4d, 0x74, 0x72, 0xda,
    0xc8, 0x6a, 0xf1, 0x2d, 0x59, 0x72, 0xed, 0x38, 0xf6, 0x88, 0x46, 0xa9, 0x5a, 0x73, 0x94, 0x10,
    0xa8, 0x72, 0xd6, 0x2f, 0x93, 0x47, 0x10, 0x3d, 0x61, 0xd1, 0x52, 0x06, 0xe9, 0x1e, 0xab, 0x63,
    0x07, 0x67, 0xcd, 0x98, 0xf5, 0xa2, 0xf2, 0x64, 0x0a, 0x6e, 0x27, 0xcf, 0x02, 0xe4, 0xb1, 0xa1,
    0xbe, 0x9c, 0x58, 0xfd, 0x9d, 0x37, 0xe5, 0x5e, 0x57, 0xde, 0xa8, 0x5e, 0x66, 0xb9, 0x58, 0x08,
    0x93, 0x50, 0x74, 0x46, 0x8f, 0x0d, 0xa9, 0x77, 0x80, 0x6a, 0x21, 0xca, 0x82, 0x6e, 0x0f, 0xdc,
    0x01, 0xeb, 0xca, 0x50, 0x0c, 0xbd, 0x80, 0x93, 0xba, 0x48, 0x55, 0xa2, 0xe9, 0xc9, 0x55, 0xa2,
    0x66, 0xa2, 0x7b, 0x93, 0x8d, 0xb7, 0x66, 0x87, 0xe9, 0xcb, 0xce, 0xc0, 0xbf, 0x50, 0x60, 0x3a,
    0x9c, 0x48, 0xae, 0x6e, 0x3a, 0x83, 0xc6, 0xa5, 0xaf, 0x8b, 0x19, 0x3a, 0xfc, 0xa0, 0x6e, 0x4d,
    0x11, 0xc7, 0x48, 0xcd, 0xbb, 0x41, 0xbb, 0xda, 0x4e, 0x09, 0x9b, 0x21, 0x52, 0xe0, 0x0a, 0x50,
    0xbf, 0x0c, 0x4e, 0x6a, 0xe2, 0x99, 0x7f, 0xd2, 0x23, 0x22, 0x29, 0x88, 0x6d, 0x03, 0xbe, 0x87,
    0x8b, 0x8a, 0x02, 0xbf, 0xb2, 0xa7, 0x7c, 0x52, 0xbc, 0x9e, 0x93, 0x7c, 0x54, 0x57, 0xf8, 0xba,
    0xff, 0xed, 0x51, 0xb7, 0xbb, 0x43, 0xdd, 0xed, 0x0a, 0x55, 0x76, 0xa1, 0x56, 0x37, 0x67, 0xa5,
    0x7f, 0x3e, 0xe7, 0xcc, 0xa1, 0xd7, 0x95, 0x9a, 0xce, 0x5a, 0x73, 0xe9, 0xaf, 0x54, 0x35, 0x9f,
    0x5e, 0xc6, 0xc5, 0xae, 0xe3, 0x82, 0xdb, 0xef, 0x35, 0xc2, 0x6c, 0x71, 0xd2, 0xe3, 0x71, 0xbf,
    0x73, 0x48, 0xdb, 0x2e, 0xf9, 0xe2, 0xe1, 0x61, 0x58, 0xdb, 0xc3, 0xac, 0xa1, 0xd9, 0x26, 0xd9,
    0x37, 0xe7, 0x05, 0x0b, 0xc7, 0xa0, 0xe4, 0x84, 0xd1, 0x75, 0xe2, 0x97, 0x9b, 0x0d, 0x3d, 0x2a,
    0x57, 0xf3, 0xb0, 0x58, 0x5d, 0x6d, 0xbd, 0xe4, 0xeb, 0x78, 0xee, 0x61, 0xfe, 0xe2, 0xda, 0x6e,
    0xeb, 0x25, 0x5f, 0xbc, 0x77, 0x14, 0x18, 0xad, 0x27, 0x7d, 0x59, 0x37, 0x8d, 0x75, 0xb9, 0xef,
    0x44, 0x32, 0x8c, 0xa3, 0xf6, 0x0a, 0xa2, 0x6d, 0x96, 0xdc, 0xcd, 0x48, 0x68, 0x63, 0x0b, 0xf9,
    0xb4, 0x24, 0x37, 0x27, 0xc1, 0xce, 0x1d, 0x54, 0x06, 0xc0, 0x2e, 0xd9, 0x15, 0xdd, 0x57, 0x58,
    0x55, 0x04, 0x96, 0x88, 0xdb, 0xfe, 0x88, 0x3b, 0x5b, 0x84, 0x6c, 0x88, 0x51, 0x9f, 0xdd, 0xbf,
    0xc2, 0x2a, 0x5b, 0xa4, 0xc7, 0x3b, 0x6d, 0xb4, 0xcc, 0x9e, 0x51, 0x51, 0x97, 0x2d, 0x0b, 0xf9,
    0x5a, 0x58, 0x6c, 0xe0, 0x15, 0x51, 0xb1, 0x7f, 0xc3, 0x5e, 0x91, 0x4a, 0x4d, 0x22, 0x52, 0xfc,
    0x8f, 0xf3, 0x1b, 0x91, 0xb5, 0x73, 0xbd
};
#endif

PyTypeObject *init_QCustom3DVolume(PyObject *module)
{
    if (SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX].type != nullptr)
        return SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX].type;

    Shiboken::AutoDecRef Sbk_QCustom3DVolume_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DItem_IDX]))));

    _Sbk_QCustom3DVolume_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCustom3DVolume",
        "QCustom3DVolume*",
        &Sbk_QCustom3DVolume_spec,
        &Shiboken::callCppDestructor< QCustom3DVolume >,
        Sbk_QCustom3DVolume_Type_bases.object(),
        0);
    auto *pyType = Sbk_QCustom3DVolume_TypeF(); // references _Sbk_QCustom3DVolume_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCustom3DVolume_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCustom3DVolume_SignatureBytes, QCustom3DVolume_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCustom3DVolume_PropertyStrings);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_QCustom3DVolume_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCustom3DVolume_PythonToCpp_QCustom3DVolume_PTR,
        is_QCustom3DVolume_PythonToCpp_QCustom3DVolume_PTR_Convertible,
        QCustom3DVolume_PTR_CppToPython_QCustom3DVolume);

    Shiboken::Conversions::registerConverterName(converter, "QCustom3DVolume");
    Shiboken::Conversions::registerConverterName(converter, "QCustom3DVolume*");
    Shiboken::Conversions::registerConverterName(converter, "QCustom3DVolume&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCustom3DVolume).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QCustom3DVolumeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QCustom3DVolume_TypeF(), &Sbk_QCustom3DVolume_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QCustom3DVolume::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QCustom3DVolume::staticMetaObject, sizeof(QCustom3DVolumeWrapper));

    return pyType;
}
