// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdatavisualization_python.h"

// main header
#include "qheightmapsurfacedataproxy_wrapper.h"

// Argument includes
#include <QString>
#include <QtDataVisualization/qsurface3dseries.h>
#include <QtDataVisualization/qsurfacedataitem.h>
#include <QtGui/qimage.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsurfacedataproxy.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QHeightMapSurfaceDataProxyWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QHeightMapSurfaceDataProxyWrapper::QHeightMapSurfaceDataProxyWrapper(::QObject * parent) : QHeightMapSurfaceDataProxy(parent)
{
}

QHeightMapSurfaceDataProxyWrapper::QHeightMapSurfaceDataProxyWrapper(const ::QImage & image, ::QObject * parent) : QHeightMapSurfaceDataProxy(image, parent)
{
}

QHeightMapSurfaceDataProxyWrapper::QHeightMapSurfaceDataProxyWrapper(const ::QString & filename, ::QObject * parent) : QHeightMapSurfaceDataProxy(filename, parent)
{
}

void QHeightMapSurfaceDataProxyWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QHeightMapSurfaceDataProxy", funcName);
        return;
    }
}

void QHeightMapSurfaceDataProxyWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QHeightMapSurfaceDataProxy", funcName);
        return;
    }
}

void QHeightMapSurfaceDataProxyWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QHeightMapSurfaceDataProxy", funcName);
        return;
    }
}

void QHeightMapSurfaceDataProxyWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QHeightMapSurfaceDataProxy", funcName);
        return;
    }
}

bool QHeightMapSurfaceDataProxyWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QHeightMapSurfaceDataProxy", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QHeightMapSurfaceDataProxy", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QHeightMapSurfaceDataProxyWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QHeightMapSurfaceDataProxy", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QHeightMapSurfaceDataProxy", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QHeightMapSurfaceDataProxyWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QHeightMapSurfaceDataProxy", funcName);
        return;
    }
}

const QMetaObject *QHeightMapSurfaceDataProxyWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QHeightMapSurfaceDataProxy::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QHeightMapSurfaceDataProxyWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QHeightMapSurfaceDataProxy::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QHeightMapSurfaceDataProxyWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QHeightMapSurfaceDataProxyWrapper *>(this));
    return QHeightMapSurfaceDataProxy::qt_metacast(_clname);
}

QHeightMapSurfaceDataProxyWrapper::~QHeightMapSurfaceDataProxyWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHeightMapSurfaceDataProxy_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHeightMapSurfaceDataProxy >()))
        return -1;

    QHeightMapSurfaceDataProxyWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QHeightMapSurfaceDataProxy", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHeightMapSurfaceDataProxy::QHeightMapSurfaceDataProxy(QObject*=)
    // 1: QHeightMapSurfaceDataProxy::QHeightMapSurfaceDataProxy(QImage,QObject*=)
    // 2: QHeightMapSurfaceDataProxy::QHeightMapSurfaceDataProxy(QString,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QHeightMapSurfaceDataProxy(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QHeightMapSurfaceDataProxy(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QHeightMapSurfaceDataProxy(QString,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QHeightMapSurfaceDataProxy(QString,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QHeightMapSurfaceDataProxy(QImage,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QHeightMapSurfaceDataProxy(QImage,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QHeightMapSurfaceDataProxy(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHeightMapSurfaceDataProxy(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QHeightMapSurfaceDataProxyWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QHeightMapSurfaceDataProxyWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QHeightMapSurfaceDataProxy(const QImage &image, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QImage cppArg0_local;
            ::QImage *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHeightMapSurfaceDataProxy(QImage,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QHeightMapSurfaceDataProxyWrapper(*cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QHeightMapSurfaceDataProxyWrapper(*cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 2: // QHeightMapSurfaceDataProxy(const QString &filename, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHeightMapSurfaceDataProxy(QString,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QHeightMapSurfaceDataProxyWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QHeightMapSurfaceDataProxyWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QHeightMapSurfaceDataProxy >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_autoScaleY(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoScaleY()const
        bool cppResult = const_cast<const ::QHeightMapSurfaceDataProxy *>(cppSelf)->autoScaleY();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_heightMap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // heightMap()const
        QImage cppResult = const_cast<const ::QHeightMapSurfaceDataProxy *>(cppSelf)->heightMap();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_heightMapFile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // heightMapFile()const
        QString cppResult = const_cast<const ::QHeightMapSurfaceDataProxy *>(cppSelf)->heightMapFile();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_maxXValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxXValue()const
        float cppResult = const_cast<const ::QHeightMapSurfaceDataProxy *>(cppSelf)->maxXValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_maxYValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxYValue()const
        float cppResult = const_cast<const ::QHeightMapSurfaceDataProxy *>(cppSelf)->maxYValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_maxZValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxZValue()const
        float cppResult = const_cast<const ::QHeightMapSurfaceDataProxy *>(cppSelf)->maxZValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_minXValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minXValue()const
        float cppResult = const_cast<const ::QHeightMapSurfaceDataProxy *>(cppSelf)->minXValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_minYValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minYValue()const
        float cppResult = const_cast<const ::QHeightMapSurfaceDataProxy *>(cppSelf)->minYValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_minZValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minZValue()const
        float cppResult = const_cast<const ::QHeightMapSurfaceDataProxy *>(cppSelf)->minZValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_setAutoScaleY(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHeightMapSurfaceDataProxy::setAutoScaleY(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoScaleY(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoScaleY", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoScaleY(bool)
            cppSelf->setAutoScaleY(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_setHeightMap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHeightMapSurfaceDataProxy::setHeightMap(QImage)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), (pyArg)))) {
        overloadId = 0; // setHeightMap(QImage)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeightMap", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QImage cppArg0_local;
        ::QImage *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeightMap(QImage)
            cppSelf->setHeightMap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_setHeightMapFile(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHeightMapSurfaceDataProxy::setHeightMapFile(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setHeightMapFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeightMapFile", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeightMapFile(QString)
            cppSelf->setHeightMapFile(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_setMaxXValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHeightMapSurfaceDataProxy::setMaxXValue(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMaxXValue(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxXValue", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxXValue(float)
            cppSelf->setMaxXValue(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_setMaxYValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHeightMapSurfaceDataProxy::setMaxYValue(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMaxYValue(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxYValue", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxYValue(float)
            cppSelf->setMaxYValue(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_setMaxZValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHeightMapSurfaceDataProxy::setMaxZValue(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMaxZValue(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxZValue", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxZValue(float)
            cppSelf->setMaxZValue(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_setMinXValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHeightMapSurfaceDataProxy::setMinXValue(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMinXValue(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinXValue", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinXValue(float)
            cppSelf->setMinXValue(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_setMinYValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHeightMapSurfaceDataProxy::setMinYValue(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMinYValue(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinYValue", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinYValue(float)
            cppSelf->setMinYValue(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_setMinZValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHeightMapSurfaceDataProxy::setMinZValue(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMinZValue(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinZValue", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinZValue(float)
            cppSelf->setMinZValue(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHeightMapSurfaceDataProxyFunc_setValueRanges(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setValueRanges", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHeightMapSurfaceDataProxy::setValueRanges(float,float,float,float)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 0; // setValueRanges(float,float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setValueRanges", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValueRanges(float,float,float,float)
            cppSelf->setValueRanges(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QHeightMapSurfaceDataProxy_PropertyStrings[] = {
    "autoScaleY::",
    "heightMap::",
    "heightMapFile::",
    "maxXValue::",
    "maxYValue::",
    "maxZValue::",
    "minXValue::",
    "minYValue::",
    "minZValue::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHeightMapSurfaceDataProxy_methods[] = {
    {"autoScaleY", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_autoScaleY), METH_NOARGS, nullptr},
    {"heightMap", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_heightMap), METH_NOARGS, nullptr},
    {"heightMapFile", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_heightMapFile), METH_NOARGS, nullptr},
    {"maxXValue", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_maxXValue), METH_NOARGS, nullptr},
    {"maxYValue", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_maxYValue), METH_NOARGS, nullptr},
    {"maxZValue", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_maxZValue), METH_NOARGS, nullptr},
    {"minXValue", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_minXValue), METH_NOARGS, nullptr},
    {"minYValue", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_minYValue), METH_NOARGS, nullptr},
    {"minZValue", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_minZValue), METH_NOARGS, nullptr},
    {"setAutoScaleY", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_setAutoScaleY), METH_O, nullptr},
    {"setHeightMap", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_setHeightMap), METH_O, nullptr},
    {"setHeightMapFile", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_setHeightMapFile), METH_O, nullptr},
    {"setMaxXValue", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_setMaxXValue), METH_O, nullptr},
    {"setMaxYValue", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_setMaxYValue), METH_O, nullptr},
    {"setMaxZValue", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_setMaxZValue), METH_O, nullptr},
    {"setMinXValue", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_setMinXValue), METH_O, nullptr},
    {"setMinYValue", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_setMinYValue), METH_O, nullptr},
    {"setMinZValue", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_setMinZValue), METH_O, nullptr},
    {"setValueRanges", reinterpret_cast<PyCFunction>(Sbk_QHeightMapSurfaceDataProxyFunc_setValueRanges), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QHeightMapSurfaceDataProxy_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QHeightMapSurfaceDataProxyWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QHeightMapSurfaceDataProxy_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHeightMapSurfaceDataProxy_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHeightMapSurfaceDataProxy_Type = nullptr;
static PyTypeObject *Sbk_QHeightMapSurfaceDataProxy_TypeF(void)
{
    return _Sbk_QHeightMapSurfaceDataProxy_Type;
}

static PyType_Slot Sbk_QHeightMapSurfaceDataProxy_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QHeightMapSurfaceDataProxy_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHeightMapSurfaceDataProxy_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHeightMapSurfaceDataProxy_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHeightMapSurfaceDataProxy_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHeightMapSurfaceDataProxy_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHeightMapSurfaceDataProxy_spec = {
    "2:PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHeightMapSurfaceDataProxy_slots
};

} //extern "C"

static void *Sbk_QHeightMapSurfaceDataProxy_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QHeightMapSurfaceDataProxy *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHeightMapSurfaceDataProxy_PythonToCpp_QHeightMapSurfaceDataProxy_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHeightMapSurfaceDataProxy_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHeightMapSurfaceDataProxy_PythonToCpp_QHeightMapSurfaceDataProxy_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHeightMapSurfaceDataProxy_TypeF()))
        return QHeightMapSurfaceDataProxy_PythonToCpp_QHeightMapSurfaceDataProxy_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHeightMapSurfaceDataProxy_PTR_CppToPython_QHeightMapSurfaceDataProxy(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QHeightMapSurfaceDataProxy *>(const_cast<void *>(cppIn)), Sbk_QHeightMapSurfaceDataProxy_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHeightMapSurfaceDataProxy_SignatureStrings[] = {
    "2:PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,heightMap:QImage=None,heightMapFile:QString=None,minXValue:float=None,maxXValue:float=None,minZValue:float=None,maxZValue:float=None,minYValue:float=None,maxYValue:float=None,autoScaleY:bool=None)",
    "1:PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy(self,image:PySide6.QtGui.QImage,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,heightMap:QImage=None,heightMapFile:QString=None,minXValue:float=None,maxXValue:float=None,minZValue:float=None,maxZValue:float=None,minYValue:float=None,maxYValue:float=None,autoScaleY:bool=None)",
    "0:PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy(self,filename:QString,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,heightMap:QImage=None,heightMapFile:QString=None,minXValue:float=None,maxXValue:float=None,minZValue:float=None,maxZValue:float=None,minYValue:float=None,maxYValue:float=None,autoScaleY:bool=None)",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.autoScaleY(self)->bool",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.heightMap(self)->PySide6.QtGui.QImage",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.heightMapFile(self)->QString",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.maxXValue(self)->float",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.maxYValue(self)->float",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.maxZValue(self)->float",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.minXValue(self)->float",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.minYValue(self)->float",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.minZValue(self)->float",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.setAutoScaleY(self,enabled:bool)",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.setHeightMap(self,image:PySide6.QtGui.QImage)",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.setHeightMapFile(self,filename:QString)",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.setMaxXValue(self,max:float)",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.setMaxYValue(self,max:float)",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.setMaxZValue(self,max:float)",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.setMinXValue(self,min:float)",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.setMinYValue(self,min:float)",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.setMinZValue(self,min:float)",
    "PySide6.QtDataVisualization.QHeightMapSurfaceDataProxy.setValueRanges(self,minX:float,maxX:float,minZ:float,maxZ:float)",
    nullptr}; // Sentinel
#else
static constexpr size_t QHeightMapSurfaceDataProxy_SignatureByteSize = 359;
static constexpr uint8_t QHeightMapSurfaceDataProxy_SignatureBytes[359] = {
    0x78, 0xda, 0xe5, 0x95, 0x4f, 0x4f, 0x83, 0x40, 0x10, 0xc5, 0xef, 0x7e, 0x12, 0x6b, 0x90, 0xa8,
    0x07, 0x0f, 0x24, 0x35, 0x31, 0x1a, 0xad, 0x31, 0xb5, 0x45, 0x92, 0xa6, 0x70, 0x1b, 0x60, 0xa0,
    0x6b, 0x96, 0xdd, 0x66, 0x59, 0x62, 0xf1, 0xd3, 0xcb, 0x9f, 0x2e, 0x2d, 0x96, 0x78, 0xe8, 0x6e,
    0x4f, 0xbd, 0x91, 0xc7, 0xe4, 0x37, 0x99, 0xb7, 0xb3, 0x6f, 0xef, 0x9c, 0x79, 0xe9, 0x91, 0x18,
    0xef, 0x6d, 0x57, 0x3e, 0x83, 0x84, 0x05, 0xc9, 0x0b, 0xa0, 0xe4, 0x07, 0x24, 0xe1, 0xcc, 0x76,
    0x27, 0x48, 0xd2, 0x95, 0x9c, 0xc2, 0xda, 0x2b, 0x44, 0x02, 0x11, 0xd6, 0x25, 0x73, 0xc1, 0x37,
    0xe5, 0x65, 0x8e, 0x34, 0xb1, 0xd6, 0x20, 0x90, 0xc9, 0x3d, 0xc4, 0x13, 0x17, 0x68, 0xbb, 0xb3,
    0xf0, 0x0b, 0x23, 0x39, 0x66, 0x05, 0xa5, 0x6b, 0x29, 0xac, 0x2b, 0xe7, 0x1d, 0xcb, 0x6f, 0x2e,
    0xe2, 0x19, 0xa3, 0xe5, 0xf8, 0x83, 0x33, 0xb4, 0x56, 0x8a, 0xeb, 0xb8, 0x6f, 0x19, 0xa4, 0xf8,
    0x47, 0x7d, 0x21, 0x14, 0x1d, 0xd7, 0x93, 0x82, 0xb0, 0xb4, 0xfd, 0x95, 0x11, 0xb6, 0x5c, 0x00,
    0x2d, 0xd0, 0x49, 0x28, 0x07, 0xb9, 0x15, 0x61, 0x33, 0x20, 0x12, 0x16, 0x0c, 0x55, 0x06, 0x43,
    0x95, 0xfe, 0x50, 0xe5, 0xa1, 0x08, 0x85, 0xe4, 0x5e, 0x04, 0x14, 0x7d, 0x27, 0xe4, 0x9c, 0x36,
    0xe2, 0xe8, 0xe2, 0x56, 0xcb, 0x3b, 0x52, 0xcf, 0xbd, 0x47, 0x78, 0x2d, 0x88, 0xdd, 0x9a, 0x71,
    0xe6, 0xb6, 0xde, 0x68, 0xd9, 0x9a, 0x54, 0x33, 0x32, 0xc8, 0xba, 0x39, 0xcf, 0xdc, 0xcc, 0xe3,
    0xac, 0xb4, 0x77, 0xb0, 0xc6, 0xd5, 0xd1, 0xf5, 0x43, 0xcd, 0x3c, 0x96, 0xd6, 0x79, 0xa6, 0x60,
    0x43, 0x5b, 0xaf, 0x0d, 0xaf, 0x0f, 0x44, 0x35, 0xd8, 0x9e, 0xcb, 0xb1, 0xcc, 0xee, 0xd0, 0x14,
    0xaf, 0xf1, 0x59, 0x83, 0xe6, 0x1b, 0xa5, 0x05, 0x06, 0x69, 0x6a, 0x67, 0x4d, 0xd1, 0x7c, 0xa3,
    0x34, 0x83, 0x93, 0xe6, 0x28, 0x1f, 0xfb, 0x5b, 0x6d, 0x55, 0x41, 0x11, 0x52, 0x8c, 0x9b, 0xfb,
    0x32, 0xd2, 0xe0, 0x4e, 0x7a, 0xfb, 0xfd, 0x4f, 0xb2, 0x1b, 0x69, 0xd2, 0xed, 0xf9, 0x41, 0xd6,
    0xe9, 0xe0, 0xa7, 0xbd, 0x95, 0xaf, 0x23, 0xa6, 0x0d, 0x17, 0x4d, 0xa6, 0x7f, 0x02, 0x66, 0x60,
    0x9c, 0xd9, 0xbb, 0x04, 0x75, 0xe6, 0x1a, 0x61, 0xfa, 0x27, 0x60, 0x06, 0xa6, 0x99, 0x0d, 0xef,
    0x13, 0x58, 0x8a, 0x79, 0x47, 0x5d, 0xb6, 0xd8, 0xe6, 0xed, 0x52, 0x9f, 0x55, 0xeb, 0x9d, 0x1a,
    0xa8, 0xbe, 0xbf, 0x40, 0x7b, 0xd0, 0x3f
};
#endif

PyTypeObject *init_QHeightMapSurfaceDataProxy(PyObject *module)
{
    if (SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX].type != nullptr)
        return SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX].type;

    Shiboken::AutoDecRef Sbk_QHeightMapSurfaceDataProxy_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurfaceDataProxy_IDX]))));

    _Sbk_QHeightMapSurfaceDataProxy_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHeightMapSurfaceDataProxy",
        "QHeightMapSurfaceDataProxy*",
        &Sbk_QHeightMapSurfaceDataProxy_spec,
        &Shiboken::callCppDestructor< QHeightMapSurfaceDataProxy >,
        Sbk_QHeightMapSurfaceDataProxy_Type_bases.object(),
        0);
    auto *pyType = Sbk_QHeightMapSurfaceDataProxy_TypeF(); // references _Sbk_QHeightMapSurfaceDataProxy_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHeightMapSurfaceDataProxy_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHeightMapSurfaceDataProxy_SignatureBytes, QHeightMapSurfaceDataProxy_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHeightMapSurfaceDataProxy_PropertyStrings);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_QHeightMapSurfaceDataProxy_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHeightMapSurfaceDataProxy_PythonToCpp_QHeightMapSurfaceDataProxy_PTR,
        is_QHeightMapSurfaceDataProxy_PythonToCpp_QHeightMapSurfaceDataProxy_PTR_Convertible,
        QHeightMapSurfaceDataProxy_PTR_CppToPython_QHeightMapSurfaceDataProxy);

    Shiboken::Conversions::registerConverterName(converter, "QHeightMapSurfaceDataProxy");
    Shiboken::Conversions::registerConverterName(converter, "QHeightMapSurfaceDataProxy*");
    Shiboken::Conversions::registerConverterName(converter, "QHeightMapSurfaceDataProxy&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHeightMapSurfaceDataProxy).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QHeightMapSurfaceDataProxyWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QHeightMapSurfaceDataProxy_TypeF(), &Sbk_QHeightMapSurfaceDataProxy_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QHeightMapSurfaceDataProxy::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QHeightMapSurfaceDataProxy::staticMetaObject, sizeof(QHeightMapSurfaceDataProxyWrapper));

    return pyType;
}
