// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdatavisualization_python.h"

// main header
#include "qitemmodelbardataproxy_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtDataVisualization/qbardataitem.h>
#include <QtDataVisualization/qitemmodelbardataproxy.h>
#include <qabstractitemmodel.h>
#include <qbardataproxy.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qregularexpression.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QItemModelBarDataProxyWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QItemModelBarDataProxyWrapper::QItemModelBarDataProxyWrapper(::QAbstractItemModel * itemModel, ::QObject * parent) : QItemModelBarDataProxy(itemModel, parent)
{
}

QItemModelBarDataProxyWrapper::QItemModelBarDataProxyWrapper(::QAbstractItemModel * itemModel, const ::QString & rowRole, const ::QString & columnRole, const ::QString & valueRole, ::QObject * parent) : QItemModelBarDataProxy(itemModel, rowRole, columnRole, valueRole, parent)
{
}

QItemModelBarDataProxyWrapper::QItemModelBarDataProxyWrapper(::QAbstractItemModel * itemModel, const ::QString & rowRole, const ::QString & columnRole, const ::QString & valueRole, const ::QString & rotationRole, ::QObject * parent) : QItemModelBarDataProxy(itemModel, rowRole, columnRole, valueRole, rotationRole, parent)
{
}

QItemModelBarDataProxyWrapper::QItemModelBarDataProxyWrapper(::QAbstractItemModel * itemModel, const ::QString & rowRole, const ::QString & columnRole, const ::QString & valueRole, const ::QString & rotationRole, const ::QStringList & rowCategories, const ::QStringList & columnCategories, ::QObject * parent) : QItemModelBarDataProxy(itemModel, rowRole, columnRole, valueRole, rotationRole, rowCategories, columnCategories, parent)
{
}

QItemModelBarDataProxyWrapper::QItemModelBarDataProxyWrapper(::QAbstractItemModel * itemModel, const ::QString & rowRole, const ::QString & columnRole, const ::QString & valueRole, const ::QStringList & rowCategories, const ::QStringList & columnCategories, ::QObject * parent) : QItemModelBarDataProxy(itemModel, rowRole, columnRole, valueRole, rowCategories, columnCategories, parent)
{
}

QItemModelBarDataProxyWrapper::QItemModelBarDataProxyWrapper(::QAbstractItemModel * itemModel, const ::QString & valueRole, ::QObject * parent) : QItemModelBarDataProxy(itemModel, valueRole, parent)
{
}

QItemModelBarDataProxyWrapper::QItemModelBarDataProxyWrapper(::QObject * parent) : QItemModelBarDataProxy(parent)
{
}

void QItemModelBarDataProxyWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QItemModelBarDataProxy", funcName);
        return;
    }
}

void QItemModelBarDataProxyWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QItemModelBarDataProxy", funcName);
        return;
    }
}

void QItemModelBarDataProxyWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QItemModelBarDataProxy", funcName);
        return;
    }
}

void QItemModelBarDataProxyWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QItemModelBarDataProxy", funcName);
        return;
    }
}

bool QItemModelBarDataProxyWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QItemModelBarDataProxy", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QItemModelBarDataProxy", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QItemModelBarDataProxyWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QItemModelBarDataProxy", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QItemModelBarDataProxy", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QItemModelBarDataProxyWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QItemModelBarDataProxy", funcName);
        return;
    }
}

const QMetaObject *QItemModelBarDataProxyWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QItemModelBarDataProxy::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QItemModelBarDataProxyWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QItemModelBarDataProxy::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QItemModelBarDataProxyWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QItemModelBarDataProxyWrapper *>(this));
    return QItemModelBarDataProxy::qt_metacast(_clname);
}

QItemModelBarDataProxyWrapper::~QItemModelBarDataProxyWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QItemModelBarDataProxy_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QItemModelBarDataProxy >()))
        return -1;

    QItemModelBarDataProxyWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOOOOOOO:QItemModelBarDataProxy", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::QItemModelBarDataProxy(QAbstractItemModel*,QObject*=)
    // 1: QItemModelBarDataProxy::QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QObject*=)
    // 2: QItemModelBarDataProxy::QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QObject*=)
    // 3: QItemModelBarDataProxy::QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QStringList,QStringList,QObject*=)
    // 4: QItemModelBarDataProxy::QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QStringList,QStringList,QObject*=)
    // 5: QItemModelBarDataProxy::QItemModelBarDataProxy(QAbstractItemModel*,QString,QObject*=)
    // 6: QItemModelBarDataProxy::QItemModelBarDataProxy(QObject*=)
    if (numArgs == 0) {
        overloadId = 6; // QItemModelBarDataProxy(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QItemModelBarDataProxy(QAbstractItemModel*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QItemModelBarDataProxy(QAbstractItemModel*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 5; // QItemModelBarDataProxy(QAbstractItemModel*,QString,QObject*)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))) {
                overloadId = 5; // QItemModelBarDataProxy(QAbstractItemModel*,QString,QObject*)
            } else if (numArgs >= 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QObject*)
                } else if (numArgs >= 6
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[4])))
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[5])))) {
                    if (numArgs == 6) {
                        overloadId = 4; // QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QStringList,QStringList,QObject*)
                    } else if (numArgs >= 7
                        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[6])))) {
                        overloadId = 4; // QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QStringList,QStringList,QObject*)
                    }
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4])))) {
                    overloadId = 1; // QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QObject*)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))) {
                    if (numArgs == 5) {
                        overloadId = 2; // QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QObject*)
                    } else if (numArgs >= 7
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[5])))
                        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[6])))) {
                        if (numArgs == 7) {
                            overloadId = 3; // QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QStringList,QStringList,QObject*)
                        } else if (numArgs >= 8
                            && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[7])))) {
                            overloadId = 3; // QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QStringList,QStringList,QObject*)
                        }
                    } else if (numArgs >= 6
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[5])))) {
                        overloadId = 2; // QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QObject*)
                    }
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 6; // QItemModelBarDataProxy(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QItemModelBarDataProxy(QAbstractItemModel *itemModel, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAbstractItemModel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemModelBarDataProxy(QAbstractItemModel*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QItemModelBarDataProxyWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QItemModelBarDataProxyWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 1: // QItemModelBarDataProxy(QAbstractItemModel *itemModel, const QString &rowRole, const QString &columnRole, const QString &valueRole, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAbstractItemModel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return -1;
            ::QObject *cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QItemModelBarDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QItemModelBarDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[4], self);
            }
            break;
        }
        case 2: // QItemModelBarDataProxy(QAbstractItemModel *itemModel, const QString &rowRole, const QString &columnRole, const QString &valueRole, const QString &rotationRole, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAbstractItemModel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QString cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return -1;
            ::QObject *cppArg5 = nullptr;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QItemModelBarDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QItemModelBarDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[5], self);
            }
            break;
        }
        case 3: // QItemModelBarDataProxy(QAbstractItemModel *itemModel, const QString &rowRole, const QString &columnRole, const QString &valueRole, const QString &rotationRole, const QStringList &rowCategories, const QStringList &columnCategories, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAbstractItemModel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QString cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QStringList cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            ::QStringList cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return -1;
            ::QObject *cppArg7 = nullptr;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QStringList,QStringList,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QItemModelBarDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QItemModelBarDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[7], self);
            }
            break;
        }
        case 4: // QItemModelBarDataProxy(QAbstractItemModel *itemModel, const QString &rowRole, const QString &columnRole, const QString &valueRole, const QStringList &rowCategories, const QStringList &columnCategories, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAbstractItemModel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QStringList cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QStringList cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return -1;
            ::QObject *cppArg6 = nullptr;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemModelBarDataProxy(QAbstractItemModel*,QString,QString,QString,QStringList,QStringList,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QItemModelBarDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QItemModelBarDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[6], self);
            }
            break;
        }
        case 5: // QItemModelBarDataProxy(QAbstractItemModel *itemModel, const QString &valueRole, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAbstractItemModel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QObject *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemModelBarDataProxy(QAbstractItemModel*,QString,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QItemModelBarDataProxyWrapper(cppArg0, cppArg1, cppArg2);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QItemModelBarDataProxyWrapper(cppArg0, cppArg1, cppArg2);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[2], self);
            }
            break;
        }
        case 6: // QItemModelBarDataProxy(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemModelBarDataProxy(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QItemModelBarDataProxyWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QItemModelBarDataProxyWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QItemModelBarDataProxy >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_autoColumnCategories(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoColumnCategories()const
        bool cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->autoColumnCategories();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_autoRowCategories(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoRowCategories()const
        bool cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->autoRowCategories();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_columnCategories(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // columnCategories()const
        QStringList cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->columnCategories();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_columnCategoryIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::columnCategoryIndex(QString)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // columnCategoryIndex(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "columnCategoryIndex", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // columnCategoryIndex(QString)
            int cppResult = cppSelf->columnCategoryIndex(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_columnRole(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // columnRole()const
        QString cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->columnRole();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_columnRolePattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // columnRolePattern()const
        QRegularExpression cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->columnRolePattern();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_columnRoleReplace(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // columnRoleReplace()const
        QString cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->columnRoleReplace();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_itemModel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // itemModel()const
        QAbstractItemModel * cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->itemModel();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_multiMatchBehavior(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // multiMatchBehavior()const
        QItemModelBarDataProxy::MultiMatchBehavior cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->multiMatchBehavior();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_MultiMatchBehavior_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_remap(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "remap", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::remap(QString,QString,QString,QString,QStringList,QStringList)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[5])))) {
        overloadId = 0; // remap(QString,QString,QString,QString,QStringList,QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "remap", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QString cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QStringList cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QStringList cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // remap(QString,QString,QString,QString,QStringList,QStringList)
            cppSelf->remap(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_rotationRole(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rotationRole()const
        QString cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->rotationRole();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_rotationRolePattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rotationRolePattern()const
        QRegularExpression cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->rotationRolePattern();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_rotationRoleReplace(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rotationRoleReplace()const
        QString cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->rotationRoleReplace();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_rowCategories(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rowCategories()const
        QStringList cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->rowCategories();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_rowCategoryIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::rowCategoryIndex(QString)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // rowCategoryIndex(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rowCategoryIndex", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rowCategoryIndex(QString)
            int cppResult = cppSelf->rowCategoryIndex(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_rowRole(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rowRole()const
        QString cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->rowRole();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_rowRolePattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rowRolePattern()const
        QRegularExpression cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->rowRolePattern();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_rowRoleReplace(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rowRoleReplace()const
        QString cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->rowRoleReplace();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setAutoColumnCategories(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setAutoColumnCategories(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoColumnCategories(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoColumnCategories", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoColumnCategories(bool)
            cppSelf->setAutoColumnCategories(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setAutoRowCategories(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setAutoRowCategories(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoRowCategories(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoRowCategories", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoRowCategories(bool)
            cppSelf->setAutoRowCategories(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setColumnCategories(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setColumnCategories(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setColumnCategories(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColumnCategories", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColumnCategories(QStringList)
            cppSelf->setColumnCategories(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setColumnRole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setColumnRole(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setColumnRole(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColumnRole", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColumnRole(QString)
            cppSelf->setColumnRole(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setColumnRolePattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setColumnRolePattern(QRegularExpression)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
        overloadId = 0; // setColumnRolePattern(QRegularExpression)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColumnRolePattern", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRegularExpression cppArg0_local;
        ::QRegularExpression *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setColumnRolePattern(QRegularExpression)
            cppSelf->setColumnRolePattern(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setColumnRoleReplace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setColumnRoleReplace(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setColumnRoleReplace(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColumnRoleReplace", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColumnRoleReplace(QString)
            cppSelf->setColumnRoleReplace(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setItemModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setItemModel(QAbstractItemModel*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), (pyArg)))) {
        overloadId = 0; // setItemModel(QAbstractItemModel*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setItemModel", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractItemModel *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItemModel(QAbstractItemModel*)
            cppSelf->setItemModel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setMultiMatchBehavior(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setMultiMatchBehavior(QItemModelBarDataProxy::MultiMatchBehavior)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_MultiMatchBehavior_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMultiMatchBehavior(QItemModelBarDataProxy::MultiMatchBehavior)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMultiMatchBehavior", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        ::QItemModelBarDataProxy::MultiMatchBehavior cppArg0{QItemModelBarDataProxy::MMBFirst};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMultiMatchBehavior(QItemModelBarDataProxy::MultiMatchBehavior)
            cppSelf->setMultiMatchBehavior(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setRotationRole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setRotationRole(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setRotationRole(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRotationRole", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotationRole(QString)
            cppSelf->setRotationRole(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setRotationRolePattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setRotationRolePattern(QRegularExpression)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
        overloadId = 0; // setRotationRolePattern(QRegularExpression)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRotationRolePattern", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRegularExpression cppArg0_local;
        ::QRegularExpression *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotationRolePattern(QRegularExpression)
            cppSelf->setRotationRolePattern(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setRotationRoleReplace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setRotationRoleReplace(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setRotationRoleReplace(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRotationRoleReplace", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotationRoleReplace(QString)
            cppSelf->setRotationRoleReplace(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setRowCategories(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setRowCategories(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setRowCategories(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRowCategories", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRowCategories(QStringList)
            cppSelf->setRowCategories(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setRowRole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setRowRole(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setRowRole(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRowRole", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRowRole(QString)
            cppSelf->setRowRole(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setRowRolePattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setRowRolePattern(QRegularExpression)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
        overloadId = 0; // setRowRolePattern(QRegularExpression)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRowRolePattern", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRegularExpression cppArg0_local;
        ::QRegularExpression *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRowRolePattern(QRegularExpression)
            cppSelf->setRowRolePattern(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setRowRoleReplace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setRowRoleReplace(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setRowRoleReplace(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRowRoleReplace", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRowRoleReplace(QString)
            cppSelf->setRowRoleReplace(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setUseModelCategories(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setUseModelCategories(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setUseModelCategories(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUseModelCategories", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUseModelCategories(bool)
            cppSelf->setUseModelCategories(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setValueRole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setValueRole(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setValueRole(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setValueRole", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValueRole(QString)
            cppSelf->setValueRole(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setValueRolePattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setValueRolePattern(QRegularExpression)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
        overloadId = 0; // setValueRolePattern(QRegularExpression)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setValueRolePattern", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRegularExpression cppArg0_local;
        ::QRegularExpression *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setValueRolePattern(QRegularExpression)
            cppSelf->setValueRolePattern(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_setValueRoleReplace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelBarDataProxy::setValueRoleReplace(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setValueRoleReplace(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setValueRoleReplace", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValueRoleReplace(QString)
            cppSelf->setValueRoleReplace(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_useModelCategories(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // useModelCategories()const
        bool cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->useModelCategories();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_valueRole(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // valueRole()const
        QString cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->valueRole();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_valueRolePattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // valueRolePattern()const
        QRegularExpression cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->valueRolePattern();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelBarDataProxyFunc_valueRoleReplace(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // valueRoleReplace()const
        QString cppResult = const_cast<const ::QItemModelBarDataProxy *>(cppSelf)->valueRoleReplace();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QItemModelBarDataProxy_PropertyStrings[] = {
    "autoColumnCategories::",
    "autoRowCategories::",
    "columnCategories::",
    "columnRole::",
    "columnRolePattern::",
    "columnRoleReplace::",
    "itemModel::",
    "multiMatchBehavior::",
    "rotationRole::",
    "rotationRolePattern::",
    "rotationRoleReplace::",
    "rowCategories::",
    "rowRole::",
    "rowRolePattern::",
    "rowRoleReplace::",
    "useModelCategories::",
    "valueRole::",
    "valueRolePattern::",
    "valueRoleReplace::",
    nullptr // Sentinel
};

static const char *Sbk_QItemModelBarDataProxy_EnumFlagInfo[] = {
    "MultiMatchBehavior:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QItemModelBarDataProxy_methods[] = {
    {"autoColumnCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_autoColumnCategories), METH_NOARGS, nullptr},
    {"autoRowCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_autoRowCategories), METH_NOARGS, nullptr},
    {"columnCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_columnCategories), METH_NOARGS, nullptr},
    {"columnCategoryIndex", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_columnCategoryIndex), METH_O, nullptr},
    {"columnRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_columnRole), METH_NOARGS, nullptr},
    {"columnRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_columnRolePattern), METH_NOARGS, nullptr},
    {"columnRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_columnRoleReplace), METH_NOARGS, nullptr},
    {"itemModel", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_itemModel), METH_NOARGS, nullptr},
    {"multiMatchBehavior", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_multiMatchBehavior), METH_NOARGS, nullptr},
    {"remap", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_remap), METH_VARARGS, nullptr},
    {"rotationRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_rotationRole), METH_NOARGS, nullptr},
    {"rotationRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_rotationRolePattern), METH_NOARGS, nullptr},
    {"rotationRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_rotationRoleReplace), METH_NOARGS, nullptr},
    {"rowCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_rowCategories), METH_NOARGS, nullptr},
    {"rowCategoryIndex", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_rowCategoryIndex), METH_O, nullptr},
    {"rowRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_rowRole), METH_NOARGS, nullptr},
    {"rowRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_rowRolePattern), METH_NOARGS, nullptr},
    {"rowRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_rowRoleReplace), METH_NOARGS, nullptr},
    {"setAutoColumnCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setAutoColumnCategories), METH_O, nullptr},
    {"setAutoRowCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setAutoRowCategories), METH_O, nullptr},
    {"setColumnCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setColumnCategories), METH_O, nullptr},
    {"setColumnRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setColumnRole), METH_O, nullptr},
    {"setColumnRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setColumnRolePattern), METH_O, nullptr},
    {"setColumnRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setColumnRoleReplace), METH_O, nullptr},
    {"setItemModel", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setItemModel), METH_O, nullptr},
    {"setMultiMatchBehavior", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setMultiMatchBehavior), METH_O, nullptr},
    {"setRotationRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setRotationRole), METH_O, nullptr},
    {"setRotationRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setRotationRolePattern), METH_O, nullptr},
    {"setRotationRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setRotationRoleReplace), METH_O, nullptr},
    {"setRowCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setRowCategories), METH_O, nullptr},
    {"setRowRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setRowRole), METH_O, nullptr},
    {"setRowRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setRowRolePattern), METH_O, nullptr},
    {"setRowRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setRowRoleReplace), METH_O, nullptr},
    {"setUseModelCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setUseModelCategories), METH_O, nullptr},
    {"setValueRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setValueRole), METH_O, nullptr},
    {"setValueRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setValueRolePattern), METH_O, nullptr},
    {"setValueRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_setValueRoleReplace), METH_O, nullptr},
    {"useModelCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_useModelCategories), METH_NOARGS, nullptr},
    {"valueRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_valueRole), METH_NOARGS, nullptr},
    {"valueRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_valueRolePattern), METH_NOARGS, nullptr},
    {"valueRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelBarDataProxyFunc_valueRoleReplace), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QItemModelBarDataProxy_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QItemModelBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QItemModelBarDataProxyWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QItemModelBarDataProxy_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QItemModelBarDataProxy_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QItemModelBarDataProxy_Type = nullptr;
static PyTypeObject *Sbk_QItemModelBarDataProxy_TypeF(void)
{
    return _Sbk_QItemModelBarDataProxy_Type;
}

static PyType_Slot Sbk_QItemModelBarDataProxy_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QItemModelBarDataProxy_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QItemModelBarDataProxy_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QItemModelBarDataProxy_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QItemModelBarDataProxy_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QItemModelBarDataProxy_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QItemModelBarDataProxy_spec = {
    "2:PySide6.QtDataVisualization.QItemModelBarDataProxy",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QItemModelBarDataProxy_slots
};

} //extern "C"

static void *Sbk_QItemModelBarDataProxy_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QItemModelBarDataProxy *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QItemModelBarDataProxy_MultiMatchBehavior(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QItemModelBarDataProxy::MultiMatchBehavior>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QItemModelBarDataProxy::MultiMatchBehavior *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QItemModelBarDataProxy_MultiMatchBehavior_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_MultiMatchBehavior_IDX])))
        return Enum_PythonToCpp_QItemModelBarDataProxy_MultiMatchBehavior;
    return {};
}

static PyObject *QItemModelBarDataProxy_MultiMatchBehavior_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QItemModelBarDataProxy::MultiMatchBehavior>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QItemModelBarDataProxy::MultiMatchBehavior *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_MultiMatchBehavior_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QItemModelBarDataProxy_PythonToCpp_QItemModelBarDataProxy_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QItemModelBarDataProxy_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QItemModelBarDataProxy_PythonToCpp_QItemModelBarDataProxy_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QItemModelBarDataProxy_TypeF()))
        return QItemModelBarDataProxy_PythonToCpp_QItemModelBarDataProxy_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QItemModelBarDataProxy_PTR_CppToPython_QItemModelBarDataProxy(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QItemModelBarDataProxy *>(const_cast<void *>(cppIn)), Sbk_QItemModelBarDataProxy_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QItemModelBarDataProxy_SignatureStrings[] = {
    "6:PySide6.QtDataVisualization.QItemModelBarDataProxy(self,itemModel:PySide6.QtCore.QAbstractItemModel,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,itemModel:QAbstractItemModel=None,rowRole:QString=None,columnRole:QString=None,valueRole:QString=None,rotationRole:QString=None,rowCategories:QStringList=None,columnCategories:QStringList=None,useModelCategories:bool=None,autoRowCategories:bool=None,autoColumnCategories:bool=None,rowRolePattern:QRegularExpression=None,columnRolePattern:QRegularExpression=None,valueRolePattern:QRegularExpression=None,rotationRolePattern:QRegularExpression=None,rowRoleReplace:QString=None,columnRoleReplace:QString=None,valueRoleReplace:QString=None,rotationRoleReplace:QString=None,multiMatchBehavior:QItemModelBarDataProxy.MultiMatchBehavior=None)",
    "5:PySide6.QtDataVisualization.QItemModelBarDataProxy(self,itemModel:PySide6.QtCore.QAbstractItemModel,rowRole:QString,columnRole:QString,valueRole:QString,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,itemModel:QAbstractItemModel=None,rowRole:QString=None,columnRole:QString=None,valueRole:QString=None,rotationRole:QString=None,rowCategories:QStringList=None,columnCategories:QStringList=None,useModelCategories:bool=None,autoRowCategories:bool=None,autoColumnCategories:bool=None,rowRolePattern:QRegularExpression=None,columnRolePattern:QRegularExpression=None,valueRolePattern:QRegularExpression=None,rotationRolePattern:QRegularExpression=None,rowRoleReplace:QString=None,columnRoleReplace:QString=None,valueRoleReplace:QString=None,rotationRoleReplace:QString=None,multiMatchBehavior:QItemModelBarDataProxy.MultiMatchBehavior=None)",
    "4:PySide6.QtDataVisualization.QItemModelBarDataProxy(self,itemModel:PySide6.QtCore.QAbstractItemModel,rowRole:QString,columnRole:QString,valueRole:QString,rotationRole:QString,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,itemModel:QAbstractItemModel=None,rowRole:QString=None,columnRole:QString=None,valueRole:QString=None,rotationRole:QString=None,rowCategories:QStringList=None,columnCategories:QStringList=None,useModelCategories:bool=None,autoRowCategories:bool=None,autoColumnCategories:bool=None,rowRolePattern:QRegularExpression=None,columnRolePattern:QRegularExpression=None,valueRolePattern:QRegularExpression=None,rotationRolePattern:QRegularExpression=None,rowRoleReplace:QString=None,columnRoleReplace:QString=None,valueRoleReplace:QString=None,rotationRoleReplace:QString=None,multiMatchBehavior:QItemModelBarDataProxy.MultiMatchBehavior=None)",
    "3:PySide6.QtDataVisualization.QItemModelBarDataProxy(self,itemModel:PySide6.QtCore.QAbstractItemModel,rowRole:QString,columnRole:QString,valueRole:QString,rotationRole:QString,rowCategories:QStringList,columnCategories:QStringList,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,itemModel:QAbstractItemModel=None,rowRole:QString=None,columnRole:QString=None,valueRole:QString=None,rotationRole:QString=None,rowCategories:QStringList=None,columnCategories:QStringList=None,useModelCategories:bool=None,autoRowCategories:bool=None,autoColumnCategories:bool=None,rowRolePattern:QRegularExpression=None,columnRolePattern:QRegularExpression=None,valueRolePattern:QRegularExpression=None,rotationRolePattern:QRegularExpression=None,rowRoleReplace:QString=None,columnRoleReplace:QString=None,valueRoleReplace:QString=None,rotationRoleReplace:QString=None,multiMatchBehavior:QItemModelBarDataProxy.MultiMatchBehavior=None)",
    "2:PySide6.QtDataVisualization.QItemModelBarDataProxy(self,itemModel:PySide6.QtCore.QAbstractItemModel,rowRole:QString,columnRole:QString,valueRole:QString,rowCategories:QStringList,columnCategories:QStringList,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,itemModel:QAbstractItemModel=None,rowRole:QString=None,columnRole:QString=None,valueRole:QString=None,rotationRole:QString=None,rowCategories:QStringList=None,columnCategories:QStringList=None,useModelCategories:bool=None,autoRowCategories:bool=None,autoColumnCategories:bool=None,rowRolePattern:QRegularExpression=None,columnRolePattern:QRegularExpression=None,valueRolePattern:QRegularExpression=None,rotationRolePattern:QRegularExpression=None,rowRoleReplace:QString=None,columnRoleReplace:QString=None,valueRoleReplace:QString=None,rotationRoleReplace:QString=None,multiMatchBehavior:QItemModelBarDataProxy.MultiMatchBehavior=None)",
    "1:PySide6.QtDataVisualization.QItemModelBarDataProxy(self,itemModel:PySide6.QtCore.QAbstractItemModel,valueRole:QString,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,itemModel:QAbstractItemModel=None,rowRole:QString=None,columnRole:QString=None,valueRole:QString=None,rotationRole:QString=None,rowCategories:QStringList=None,columnCategories:QStringList=None,useModelCategories:bool=None,autoRowCategories:bool=None,autoColumnCategories:bool=None,rowRolePattern:QRegularExpression=None,columnRolePattern:QRegularExpression=None,valueRolePattern:QRegularExpression=None,rotationRolePattern:QRegularExpression=None,rowRoleReplace:QString=None,columnRoleReplace:QString=None,valueRoleReplace:QString=None,rotationRoleReplace:QString=None,multiMatchBehavior:QItemModelBarDataProxy.MultiMatchBehavior=None)",
    "0:PySide6.QtDataVisualization.QItemModelBarDataProxy(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,itemModel:QAbstractItemModel=None,rowRole:QString=None,columnRole:QString=None,valueRole:QString=None,rotationRole:QString=None,rowCategories:QStringList=None,columnCategories:QStringList=None,useModelCategories:bool=None,autoRowCategories:bool=None,autoColumnCategories:bool=None,rowRolePattern:QRegularExpression=None,columnRolePattern:QRegularExpression=None,valueRolePattern:QRegularExpression=None,rotationRolePattern:QRegularExpression=None,rowRoleReplace:QString=None,columnRoleReplace:QString=None,valueRoleReplace:QString=None,rotationRoleReplace:QString=None,multiMatchBehavior:QItemModelBarDataProxy.MultiMatchBehavior=None)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.autoColumnCategories(self)->bool",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.autoRowCategories(self)->bool",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.columnCategories(self)->QStringList",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.columnCategoryIndex(self,category:QString)->int",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.columnRole(self)->QString",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.columnRolePattern(self)->PySide6.QtCore.QRegularExpression",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.columnRoleReplace(self)->QString",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.itemModel(self)->PySide6.QtCore.QAbstractItemModel",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.multiMatchBehavior(self)->PySide6.QtDataVisualization.QItemModelBarDataProxy.MultiMatchBehavior",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.remap(self,rowRole:QString,columnRole:QString,valueRole:QString,rotationRole:QString,rowCategories:QStringList,columnCategories:QStringList)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.rotationRole(self)->QString",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.rotationRolePattern(self)->PySide6.QtCore.QRegularExpression",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.rotationRoleReplace(self)->QString",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.rowCategories(self)->QStringList",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.rowCategoryIndex(self,category:QString)->int",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.rowRole(self)->QString",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.rowRolePattern(self)->PySide6.QtCore.QRegularExpression",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.rowRoleReplace(self)->QString",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setAutoColumnCategories(self,enable:bool)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setAutoRowCategories(self,enable:bool)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setColumnCategories(self,categories:QStringList)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setColumnRole(self,role:QString)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setColumnRolePattern(self,pattern:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setColumnRoleReplace(self,replace:QString)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setItemModel(self,itemModel:PySide6.QtCore.QAbstractItemModel)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setMultiMatchBehavior(self,behavior:PySide6.QtDataVisualization.QItemModelBarDataProxy.MultiMatchBehavior)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setRotationRole(self,role:QString)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setRotationRolePattern(self,pattern:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setRotationRoleReplace(self,replace:QString)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setRowCategories(self,categories:QStringList)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setRowRole(self,role:QString)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setRowRolePattern(self,pattern:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setRowRoleReplace(self,replace:QString)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setUseModelCategories(self,enable:bool)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setValueRole(self,role:QString)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setValueRolePattern(self,pattern:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.setValueRoleReplace(self,replace:QString)",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.useModelCategories(self)->bool",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.valueRole(self)->QString",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.valueRolePattern(self)->PySide6.QtCore.QRegularExpression",
    "PySide6.QtDataVisualization.QItemModelBarDataProxy.valueRoleReplace(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QItemModelBarDataProxy_SignatureByteSize = 696;
static constexpr uint8_t QItemModelBarDataProxy_SignatureBytes[696] = {
    0x78, 0xda, 0xed, 0x58, 0x4d, 0x73, 0xda, 0x30, 0x10, 0xbd, 0xf7, 0x57, 0xf4, 0x58, 0x3a, 0xae,
    0xa7, 0xe9, 0x47, 0x0e, 0xcc, 0xa4, 0x33, 0x09, 0xed, 0x81, 0x69, 0x69, 0xc0, 0x99, 0x70, 0xe9,
    0xf4, 0x20, 0xcc, 0x96, 0xa8, 0x23, 0x24, 0x8f, 0x2c, 0x63, 0xdc, 0x5f, 0x5f, 0x03, 0xb6, 0x91,
    0x2d, 0x39, 0x34, 0xb6, 0xf8, 0x4a, 0x75, 0xb5, 0x96, 0xb7, 0x2b, 0xbd, 0xf7, 0x76, 0x25, 0x2e,
    0xbb, 0xc3, 0xe4, 0x0e, 0x4f, 0xe1, 0xd2, 0x1d, 0x89, 0xcf, 0x48, 0xa0, 0x31, 0x0e, 0x23, 0x44,
    0xf0, 0x1f, 0x24, 0x30, 0xa3, 0xee, 0xa8, 0x2f, 0x60, 0x3e, 0x60, 0x53, 0x20, 0x37, 0x88, 0xaf,
    0x96, 0x87, 0x9c, 0x2d, 0x93, 0x57, 0x21, 0x90, 0x5f, 0x0e, 0xce, 0x97, 0x24, 0x84, 0x1e, 0xe3,
    0xe0, 0x8e, 0xae, 0x27, 0xa1, 0xe0, 0xc8, 0x17, 0xc5, 0x8f, 0x9d, 0x00, 0x71, 0xa0, 0x42, 0x09,
    0xbc, 0x9d, 0xfc, 0x06, 0x5f, 0x5c, 0xd1, 0x88, 0x90, 0x40, 0x70, 0xe7, 0x75, 0xf7, 0x2b, 0x24,
    0x31, 0xe3, 0xd3, 0x5b, 0x4a, 0x92, 0xab, 0xef, 0x8c, 0x82, 0x94, 0x44, 0x45, 0xdd, 0x44, 0x70,
    0x16, 0x7b, 0x8c, 0x40, 0x77, 0x74, 0x27, 0x38, 0xa6, 0xb3, 0xcd, 0x47, 0x9f, 0x91, 0x68, 0x4e,
    0xd5, 0xef, 0x0b, 0x44, 0x22, 0x50, 0x3f, 0x73, 0x26, 0xd6, 0xfb, 0xd5, 0xad, 0xc4, 0x3d, 0x24,
    0x60, 0xc6, 0x38, 0x86, 0x30, 0x5f, 0xfa, 0x86, 0x43, 0x21, 0xe7, 0x79, 0x2c, 0x22, 0x0a, 0x61,
    0x5d, 0xac, 0x14, 0x33, 0x61, 0x2c, 0xab, 0x1d, 0x45, 0x82, 0x79, 0xa5, 0x0c, 0xe5, 0xb5, 0x5e,
    0x15, 0x7e, 0xbb, 0x9c, 0x6d, 0x7b, 0x88, 0x84, 0x00, 0x4e, 0xbb, 0x23, 0x0f, 0x66, 0x11, 0x41,
    0xfc, 0xcb, 0x32, 0xe0, 0x10, 0x86, 0xe9, 0x5e, 0xaa, 0x07, 0xb1, 0x2b, 0xb2, 0x38, 0x9a, 0x5d,
    0x81, 0xf2, 0x61, 0xed, 0x8e, 0x5d, 0x57, 0xe9, 0x41, 0x40, 0x90, 0x5f, 0xcb, 0x91, 0x76, 0xb9,
    0xa8, 0x47, 0xbb, 0x2a, 0x17, 0xa1, 0x0d, 0x98, 0x47, 0x44, 0xe0, 0x01, 0x12, 0xfe, 0xc3, 0x0d,
    0x3c, 0xa0, 0x05, 0x66, 0xbc, 0xab, 0x17, 0xb3, 0x3b, 0x50, 0x22, 0xd7, 0x08, 0x9d, 0x17, 0x1f,
    0x0f, 0x62, 0x8d, 0x8a, 0x7e, 0x35, 0xd2, 0x55, 0x55, 0x6b, 0xfd, 0x64, 0xfd, 0x74, 0x7e, 0x7e,
    0xfa, 0x70, 0xba, 0x7e, 0xd2, 0x09, 0xd6, 0x9a, 0xcc, 0x9a, 0xec, 0xfc, 0x4c, 0xf6, 0xfe, 0xcc,
    0x4c, 0x56, 0xab, 0xd5, 0x47, 0x65, 0x6a, 0xbd, 0x69, 0xbd, 0x79, 0x7e, 0xde, 0x7c, 0x77, 0xca,
    0xde, 0xb4, 0x36, 0xb4, 0x36, 0xfc, 0x3f, 0x6c, 0x78, 0x71, 0x10, 0x1b, 0xda, 0x47, 0x9b, 0x35,
    0xcb, 0x33, 0x30, 0xcb, 0xdb, 0xc6, 0x66, 0xb1, 0x72, 0xb7, 0x72, 0x3f, 0x3b, 0xb9, 0x3f, 0x5d,
    0xec, 0xae, 0x8e, 0xb4, 0xb5, 0x03, 0x3a, 0x6f, 0x3e, 0xad, 0xb8, 0x6b, 0x8a, 0x59, 0x12, 0x49,
    0x5b, 0x40, 0xbf, 0xa6, 0x40, 0x49, 0xbb, 0xad, 0x61, 0x93, 0x3e, 0x9d, 0xc2, 0x72, 0x63, 0x7e,
    0x3f, 0xfb, 0x94, 0x13, 0x94, 0xa6, 0xc2, 0xb4, 0x45, 0x8a, 0x15, 0xe7, 0x95, 0x9a, 0xdb, 0x81,
    0x65, 0x2a, 0xce, 0x31, 0xab, 0x5d, 0x4a, 0xd1, 0x76, 0xbb, 0x6c, 0x99, 0x5c, 0x0d, 0xec, 0xa0,
    0x68, 0x8e, 0x75, 0x95, 0x2b, 0x2d, 0xb3, 0x49, 0x16, 0xd5, 0x49, 0x6a, 0xba, 0x7f, 0x06, 0x53,
    0xcd, 0xd6, 0xa4, 0x24, 0x0e, 0x73, 0x14, 0x6c, 0xc4, 0x75, 0xec, 0x7f, 0x1f, 0x1a, 0xb5, 0x09,
    0x39, 0xbf, 0x01, 0x1d, 0x68, 0x3a, 0xf2, 0x5e, 0xb5, 0xac, 0x69, 0xbe, 0x46, 0x76, 0x11, 0x1b,
    0xef, 0x49, 0x5b, 0xcc, 0xfd, 0x34, 0xa4, 0x4c, 0x7d, 0x66, 0x76, 0x7f, 0x38, 0xfa, 0x62, 0xb3,
    0xcc, 0x85, 0x20, 0xae, 0xeb, 0x06, 0x9f, 0x03, 0x14, 0x4d, 0x52, 0x97, 0xad, 0x86, 0x55, 0xa7,
    0x05, 0xb8, 0x3a, 0x01, 0x4d, 0x20, 0xeb, 0x4b, 0xf6, 0xcd, 0x39, 0xbd, 0xc8, 0x51, 0xc8, 0x24,
    0xed, 0x33, 0xdb, 0xa6, 0xd3, 0x1e, 0x53, 0x16, 0x4c, 0x7a, 0xcd, 0xde, 0x5c, 0xc7, 0x44, 0x12,
    0xa4, 0xe0, 0xee, 0x3d, 0x4d, 0x51, 0x7e, 0xec, 0xd4, 0x90, 0xf3, 0x32, 0xab, 0xe6, 0x67, 0xfb,
    0x72, 0x64, 0x51, 0x39, 0xbc, 0x7c, 0x31, 0x6b, 0x8a, 0xde, 0x2f, 0x8d, 0xb9, 0xa7, 0x3c, 0xbc,
    0x9b, 0x66, 0x1c, 0xe8, 0x47, 0x9e, 0x33, 0xc9, 0xaf, 0x92, 0x46, 0x26, 0x5f, 0xd3, 0xea, 0xbc,
    0xea, 0xf4, 0x30, 0x22, 0x29, 0xaf, 0x66, 0x88, 0x1c, 0x4d, 0x54, 0x5e, 0xcd, 0x94, 0x31, 0x25,
    0x2b, 0x4d, 0x47, 0x31, 0x6b, 0x7c, 0x4f, 0x1a, 0x0e, 0x86, 0x28, 0x8a, 0x4f, 0x88, 0x9d, 0x78,
    0x5f, 0xc4, 0xdc, 0x2b, 0x4f, 0x66, 0x63, 0xfd, 0x7e, 0x9c, 0x5f, 0x05, 0xcd, 0x91, 0x32, 0xae,
    0xbc, 0x9b, 0x8f, 0x4b, 0xcb, 0xb8, 0xf2, 0x6a, 0x36, 0x47, 0x4c, 0xa4, 0x67, 0xa5, 0xc5, 0x3b,
    0x74, 0x51, 0x22, 0xa3, 0xdd, 0x15, 0x64, 0xa1, 0x63, 0x61, 0x5f, 0x17, 0xa8, 0x85, 0xee, 0x90,
    0xa5, 0xfa, 0xff, 0x02, 0x88, 0xdb, 0xe7, 0xe0
};
#endif

PyTypeObject *init_QItemModelBarDataProxy(PyObject *module)
{
    if (SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX].type != nullptr)
        return SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX].type;

    Shiboken::AutoDecRef Sbk_QItemModelBarDataProxy_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataProxy_IDX]))));

    _Sbk_QItemModelBarDataProxy_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QItemModelBarDataProxy",
        "QItemModelBarDataProxy*",
        &Sbk_QItemModelBarDataProxy_spec,
        &Shiboken::callCppDestructor< QItemModelBarDataProxy >,
        Sbk_QItemModelBarDataProxy_Type_bases.object(),
        0);
    auto *pyType = Sbk_QItemModelBarDataProxy_TypeF(); // references _Sbk_QItemModelBarDataProxy_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QItemModelBarDataProxy_SignatureStrings);
#else
    InitSignatureBytes(pyType, QItemModelBarDataProxy_SignatureBytes, QItemModelBarDataProxy_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QItemModelBarDataProxy_PropertyStrings);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QItemModelBarDataProxy_PythonToCpp_QItemModelBarDataProxy_PTR,
        is_QItemModelBarDataProxy_PythonToCpp_QItemModelBarDataProxy_PTR_Convertible,
        QItemModelBarDataProxy_PTR_CppToPython_QItemModelBarDataProxy);

    Shiboken::Conversions::registerConverterName(converter, "QItemModelBarDataProxy");
    Shiboken::Conversions::registerConverterName(converter, "QItemModelBarDataProxy*");
    Shiboken::Conversions::registerConverterName(converter, "QItemModelBarDataProxy&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QItemModelBarDataProxy).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QItemModelBarDataProxyWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QItemModelBarDataProxy_TypeF(), &Sbk_QItemModelBarDataProxy_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QItemModelBarDataProxy_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'MultiMatchBehavior'.
    const char *MultiMatchBehavior_Initializer[] = {
        "MMBFirst",
        "MMBLast",
        "MMBAverage",
        "MMBCumulative",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MultiMatchBehavior_InitializerValues[] = {
        uint8_t(QItemModelBarDataProxy::MultiMatchBehavior::MMBFirst),     //  0x00  0
        uint8_t(QItemModelBarDataProxy::MultiMatchBehavior::MMBLast),      //  0x01  1
        uint8_t(QItemModelBarDataProxy::MultiMatchBehavior::MMBAverage),   //  0x02  2
        uint8_t(QItemModelBarDataProxy::MultiMatchBehavior::MMBCumulative) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QItemModelBarDataProxy_TypeF(),
        "2:PySide6.QtDataVisualization.QItemModelBarDataProxy.MultiMatchBehavior",
        MultiMatchBehavior_Initializer, MultiMatchBehavior_InitializerValues);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_QItemModelBarDataProxy_MultiMatchBehavior_IDX].type = EType;
    // Register converter for enum 'QItemModelBarDataProxy::MultiMatchBehavior'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QItemModelBarDataProxy_MultiMatchBehavior_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QItemModelBarDataProxy_MultiMatchBehavior,
            is_Enum_PythonToCpp_QItemModelBarDataProxy_MultiMatchBehavior_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QItemModelBarDataProxy::MultiMatchBehavior");
        Shiboken::Conversions::registerConverterAlias(converter, "MultiMatchBehavior");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'MultiMatchBehavior' enum.

    PySide::Signal::registerSignals(pyType, &::QItemModelBarDataProxy::staticMetaObject);
    qRegisterMetaType< ::QItemModelBarDataProxy::MultiMatchBehavior >("QItemModelBarDataProxy::MultiMatchBehavior");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QItemModelBarDataProxy::staticMetaObject, sizeof(QItemModelBarDataProxyWrapper));

    return pyType;
}
