// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdatavisualization_python.h"

// main header
#include "qsurface3dseries_wrapper.h"

// Argument includes
#include <QString>
#include <QtDataVisualization/q3dtheme.h>
#include <QtDataVisualization/qabstract3dseries.h>
#include <QtDataVisualization/qsurfacedataproxy.h>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qimage.h>
#include <QtGui/qquaternion.h>
#include <QtGui/qvectornd.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSurface3DSeriesWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSurface3DSeriesWrapper::QSurface3DSeriesWrapper(::QObject * parent) : QSurface3DSeries(parent)
{
}

QSurface3DSeriesWrapper::QSurface3DSeriesWrapper(::QSurfaceDataProxy * dataProxy, ::QObject * parent) : QSurface3DSeries(dataProxy, parent)
{
}

void QSurface3DSeriesWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSurface3DSeries", funcName);
        return;
    }
}

void QSurface3DSeriesWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSurface3DSeries", funcName);
        return;
    }
}

void QSurface3DSeriesWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSurface3DSeries", funcName);
        return;
    }
}

void QSurface3DSeriesWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSurface3DSeries", funcName);
        return;
    }
}

bool QSurface3DSeriesWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSurface3DSeries", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSurface3DSeries", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSurface3DSeriesWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSurface3DSeries", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSurface3DSeries", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSurface3DSeriesWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QSurface3DSeries", funcName);
        return;
    }
}

const QMetaObject *QSurface3DSeriesWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QSurface3DSeries::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSurface3DSeriesWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QSurface3DSeries::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSurface3DSeriesWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QSurface3DSeriesWrapper *>(this));
    return QSurface3DSeries::qt_metacast(_clname);
}

QSurface3DSeriesWrapper::~QSurface3DSeriesWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSurface3DSeries_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSurface3DSeries >()))
        return -1;

    QSurface3DSeriesWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QSurface3DSeries", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSurface3DSeries::QSurface3DSeries(QObject*=)
    // 1: QSurface3DSeries::QSurface3DSeries(QSurfaceDataProxy*,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QSurface3DSeries(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurfaceDataProxy_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QSurface3DSeries(QSurfaceDataProxy*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QSurface3DSeries(QSurfaceDataProxy*,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSurface3DSeries(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSurface3DSeries(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSurface3DSeries(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSurface3DSeriesWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSurface3DSeriesWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QSurface3DSeries(QSurfaceDataProxy *dataProxy, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSurfaceDataProxy *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSurface3DSeries(QSurfaceDataProxy*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSurface3DSeriesWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSurface3DSeriesWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences.
                Shiboken::Object::setParent(self, pyArgs[0]);
                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSurface3DSeries >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QSurface3DSeriesFunc_dataProxy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dataProxy()const
        QSurfaceDataProxy * cppResult = const_cast<const ::QSurface3DSeries *>(cppSelf)->dataProxy();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurfaceDataProxy_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurface3DSeriesFunc_drawMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // drawMode()const
        QFlags<QSurface3DSeries::DrawFlag> cppResult = const_cast<const ::QSurface3DSeries *>(cppSelf)->drawMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QFlags_QSurface3DSeries_DrawFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurface3DSeriesFunc_invalidSelectionPosition(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invalidSelectionPosition()
        QPoint cppResult = ::QSurface3DSeries::invalidSelectionPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurface3DSeriesFunc_isFlatShadingEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFlatShadingEnabled()const
        bool cppResult = const_cast<const ::QSurface3DSeries *>(cppSelf)->isFlatShadingEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurface3DSeriesFunc_isFlatShadingSupported(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFlatShadingSupported()const
        bool cppResult = const_cast<const ::QSurface3DSeries *>(cppSelf)->isFlatShadingSupported();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurface3DSeriesFunc_selectedPoint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedPoint()const
        QPoint cppResult = const_cast<const ::QSurface3DSeries *>(cppSelf)->selectedPoint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurface3DSeriesFunc_setDataProxy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurface3DSeries::setDataProxy(QSurfaceDataProxy*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurfaceDataProxy_IDX]), (pyArg)))) {
        overloadId = 0; // setDataProxy(QSurfaceDataProxy*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDataProxy", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSurfaceDataProxy *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDataProxy(QSurfaceDataProxy*)
            cppSelf->setDataProxy(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurface3DSeriesFunc_setDrawMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurface3DSeries::setDrawMode(QFlags<QSurface3DSeries::DrawFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QFlags_QSurface3DSeries_DrawFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setDrawMode(QFlags<QSurface3DSeries::DrawFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDrawMode", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]);

    // Call function/method
    {
        ::QFlags<QSurface3DSeries::DrawFlag> cppArg0 = QFlags<QSurface3DSeries::DrawFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDrawMode(QFlags<QSurface3DSeries::DrawFlag>)
            cppSelf->setDrawMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurface3DSeriesFunc_setFlatShadingEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurface3DSeries::setFlatShadingEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFlatShadingEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlatShadingEnabled", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlatShadingEnabled(bool)
            cppSelf->setFlatShadingEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurface3DSeriesFunc_setSelectedPoint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurface3DSeries::setSelectedPoint(QPoint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 0; // setSelectedPoint(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSelectedPoint", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPoint cppArg0_local;
        ::QPoint *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectedPoint(QPoint)
            cppSelf->setSelectedPoint(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurface3DSeriesFunc_setTexture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurface3DSeries::setTexture(QImage)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), (pyArg)))) {
        overloadId = 0; // setTexture(QImage)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTexture", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QImage cppArg0_local;
        ::QImage *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTexture(QImage)
            cppSelf->setTexture(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurface3DSeriesFunc_setTextureFile(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurface3DSeries::setTextureFile(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setTextureFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextureFile", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextureFile(QString)
            cppSelf->setTextureFile(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurface3DSeriesFunc_setWireframeColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurface3DSeries::setWireframeColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setWireframeColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWireframeColor", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setWireframeColor(QColor)
            cppSelf->setWireframeColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurface3DSeriesFunc_texture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // texture()const
        QImage cppResult = const_cast<const ::QSurface3DSeries *>(cppSelf)->texture();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurface3DSeriesFunc_textureFile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureFile()const
        QString cppResult = const_cast<const ::QSurface3DSeries *>(cppSelf)->textureFile();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurface3DSeriesFunc_wireframeColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wireframeColor()const
        QColor cppResult = const_cast<const ::QSurface3DSeries *>(cppSelf)->wireframeColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSurface3DSeries_PropertyStrings[] = {
    "dataProxy::",
    "drawMode::",
    "flatShadingEnabled:isFlatShadingEnabled:",
    "flatShadingSupported:isFlatShadingSupported",
    "selectedPoint::",
    "texture::",
    "textureFile::",
    "wireframeColor::",
    nullptr // Sentinel
};

static const char *Sbk_QSurface3DSeries_EnumFlagInfo[] = {
    "DrawFlag:Flag:DrawFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSurface3DSeries_methods[] = {
    {"dataProxy", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_dataProxy), METH_NOARGS, nullptr},
    {"drawMode", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_drawMode), METH_NOARGS, nullptr},
    {"invalidSelectionPosition", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_invalidSelectionPosition), METH_NOARGS|METH_STATIC, nullptr},
    {"isFlatShadingEnabled", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_isFlatShadingEnabled), METH_NOARGS, nullptr},
    {"isFlatShadingSupported", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_isFlatShadingSupported), METH_NOARGS, nullptr},
    {"selectedPoint", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_selectedPoint), METH_NOARGS, nullptr},
    {"setDataProxy", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_setDataProxy), METH_O, nullptr},
    {"setDrawMode", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_setDrawMode), METH_O, nullptr},
    {"setFlatShadingEnabled", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_setFlatShadingEnabled), METH_O, nullptr},
    {"setSelectedPoint", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_setSelectedPoint), METH_O, nullptr},
    {"setTexture", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_setTexture), METH_O, nullptr},
    {"setTextureFile", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_setTextureFile), METH_O, nullptr},
    {"setWireframeColor", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_setWireframeColor), METH_O, nullptr},
    {"texture", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_texture), METH_NOARGS, nullptr},
    {"textureFile", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_textureFile), METH_NOARGS, nullptr},
    {"wireframeColor", reinterpret_cast<PyCFunction>(Sbk_QSurface3DSeriesFunc_wireframeColor), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSurface3DSeries_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSurface3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSurface3DSeriesWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSurface3DSeries_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSurface3DSeries_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSurface3DSeries_Type = nullptr;
static PyTypeObject *Sbk_QSurface3DSeries_TypeF(void)
{
    return _Sbk_QSurface3DSeries_Type;
}

static PyType_Slot Sbk_QSurface3DSeries_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSurface3DSeries_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSurface3DSeries_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSurface3DSeries_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSurface3DSeries_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSurface3DSeries_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSurface3DSeries_spec = {
    "2:PySide6.QtDataVisualization.QSurface3DSeries",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSurface3DSeries_slots
};

} //extern "C"

static void *Sbk_QSurface3DSeries_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QSurface3DSeries *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSurface3DSeries_DrawFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSurface3DSeries::DrawFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSurface3DSeries::DrawFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSurface3DSeries_DrawFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_DrawFlag_IDX])))
        return Enum_PythonToCpp_QSurface3DSeries_DrawFlag;
    return {};
}

static PyObject *QSurface3DSeries_DrawFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSurface3DSeries::DrawFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSurface3DSeries::DrawFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_DrawFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QSurface3DSeries_DrawFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QSurface3DSeries::DrawFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QSurface3DSeries::DrawFlag> *>(cppOut) = value;

}

static PyObject *QSurface3DSeries_DrawFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QSurface3DSeries::DrawFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_DrawFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSurface3DSeries_PythonToCpp_QSurface3DSeries_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSurface3DSeries_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSurface3DSeries_PythonToCpp_QSurface3DSeries_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSurface3DSeries_TypeF()))
        return QSurface3DSeries_PythonToCpp_QSurface3DSeries_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSurface3DSeries_PTR_CppToPython_QSurface3DSeries(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QSurface3DSeries *>(const_cast<void *>(cppIn)), Sbk_QSurface3DSeries_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSurface3DSeries_SignatureStrings[] = {
    "1:PySide6.QtDataVisualization.QSurface3DSeries(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,dataProxy:QSurfaceDataProxy=None,selectedPoint:QPoint=None,flatShadingEnabled:bool=None,flatShadingSupported:bool=None,drawMode:PySide6.QtDataVisualization.QSurface3DSeries.DrawFlag=None,texture:QImage=None,textureFile:QString=None,wireframeColor:QColor=None)",
    "0:PySide6.QtDataVisualization.QSurface3DSeries(self,dataProxy:PySide6.QtDataVisualization.QSurfaceDataProxy,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,dataProxy:QSurfaceDataProxy=None,selectedPoint:QPoint=None,flatShadingEnabled:bool=None,flatShadingSupported:bool=None,drawMode:PySide6.QtDataVisualization.QSurface3DSeries.DrawFlag=None,texture:QImage=None,textureFile:QString=None,wireframeColor:QColor=None)",
    "PySide6.QtDataVisualization.QSurface3DSeries.dataProxy(self)->PySide6.QtDataVisualization.QSurfaceDataProxy",
    "PySide6.QtDataVisualization.QSurface3DSeries.drawMode(self)->PySide6.QtDataVisualization.QSurface3DSeries.DrawFlag",
    "PySide6.QtDataVisualization.QSurface3DSeries.invalidSelectionPosition()->PySide6.QtCore.QPoint",
    "PySide6.QtDataVisualization.QSurface3DSeries.isFlatShadingEnabled(self)->bool",
    "PySide6.QtDataVisualization.QSurface3DSeries.isFlatShadingSupported(self)->bool",
    "PySide6.QtDataVisualization.QSurface3DSeries.selectedPoint(self)->PySide6.QtCore.QPoint",
    "PySide6.QtDataVisualization.QSurface3DSeries.setDataProxy(self,proxy:PySide6.QtDataVisualization.QSurfaceDataProxy)",
    "PySide6.QtDataVisualization.QSurface3DSeries.setDrawMode(self,mode:PySide6.QtDataVisualization.QSurface3DSeries.DrawFlag)",
    "PySide6.QtDataVisualization.QSurface3DSeries.setFlatShadingEnabled(self,enabled:bool)",
    "PySide6.QtDataVisualization.QSurface3DSeries.setSelectedPoint(self,position:PySide6.QtCore.QPoint)",
    "PySide6.QtDataVisualization.QSurface3DSeries.setTexture(self,texture:PySide6.QtGui.QImage)",
    "PySide6.QtDataVisualization.QSurface3DSeries.setTextureFile(self,filename:QString)",
    "PySide6.QtDataVisualization.QSurface3DSeries.setWireframeColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtDataVisualization.QSurface3DSeries.texture(self)->PySide6.QtGui.QImage",
    "PySide6.QtDataVisualization.QSurface3DSeries.textureFile(self)->QString",
    "PySide6.QtDataVisualization.QSurface3DSeries.wireframeColor(self)->PySide6.QtGui.QColor",
    nullptr}; // Sentinel
#else
static constexpr size_t QSurface3DSeries_SignatureByteSize = 484;
static constexpr uint8_t QSurface3DSeries_SignatureBytes[484] = {
    0x78, 0xda, 0xed, 0x94, 0xc1, 0x6e, 0xdb, 0x30, 0x0c, 0x86, 0xef, 0x7d, 0x8a, 0x1c, 0x9b, 0x41,
    0x33, 0x56, 0xac, 0xe8, 0xc1, 0x40, 0x77, 0xa9, 0x97, 0x62, 0xd8, 0xba, 0xc6, 0x73, 0x97, 0x1e,
    0x8a, 0x1e, 0xe8, 0x88, 0xf6, 0x34, 0x28, 0x92, 0x21, 0xcb, 0x4b, 0xbd, 0xa7, 0x1f, 0x23, 0xc5,
    0x89, 0x5d, 0x77, 0xc0, 0xe4, 0x5e, 0x77, 0x92, 0x61, 0x52, 0xdf, 0x2f, 0xfd, 0xa4, 0x78, 0x16,
    0x2f, 0xdb, 0x4c, 0x70, 0xbc, 0x88, 0x52, 0x9b, 0x80, 0x85, 0x95, 0xa8, 0x1b, 0x90, 0xe2, 0x37,
    0x58, 0xa1, 0x55, 0x94, 0x66, 0x8d, 0x29, 0x60, 0x8d, 0xef, 0x93, 0x0c, 0x8d, 0xc0, 0xfa, 0xb4,
    0x46, 0x59, 0xb0, 0x0a, 0x0c, 0x2a, 0xdb, 0xdb, 0x78, 0xa5, 0x0d, 0x46, 0xe9, 0x6d, 0xfe, 0x13,
    0xd7, 0xf6, 0x52, 0x35, 0x52, 0x56, 0xd6, 0xb0, 0x37, 0xf1, 0x67, 0x6c, 0xb7, 0xda, 0xf0, 0x5b,
    0x25, 0xdb, 0xcb, 0xaf, 0x5a, 0x21, 0xe3, 0x24, 0xb0, 0x34, 0xfa, 0xa9, 0x8d, 0x3b, 0x70, 0xd2,
    0xfd, 0xf1, 0x09, 0x84, 0x27, 0x04, 0xf2, 0xa5, 0x16, 0x24, 0x90, 0xba, 0xc5, 0x47, 0x0a, 0x09,
    0x36, 0xfb, 0x01, 0x5c, 0xa8, 0xf2, 0xa3, 0x82, 0x5c, 0x22, 0x8f, 0x73, 0xad, 0xe5, 0x28, 0x98,
    0x35, 0x55, 0xa5, 0x8d, 0x1d, 0x84, 0xb9, 0x81, 0xed, 0x8d, 0xe6, 0x18, 0x74, 0xd5, 0x28, 0xa1,
    0x5d, 0x0b, 0x09, 0xa5, 0x67, 0x58, 0x7c, 0xb2, 0x8d, 0xc1, 0x38, 0xfd, 0xb4, 0x81, 0x12, 0x07,
    0xff, 0x16, 0x42, 0xd2, 0xff, 0xcc, 0x1a, 0x92, 0xf7, 0x81, 0xad, 0x30, 0x58, 0x18, 0xd8, 0xe0,
    0x95, 0x96, 0xda, 0xc4, 0xa9, 0x5b, 0x5c, 0x68, 0x7e, 0xf2, 0x6e, 0x82, 0xe1, 0x47, 0xdf, 0xfe,
    0x65, 0xef, 0xc1, 0xd3, 0xff, 0x85, 0x7a, 0x4d, 0xa1, 0x82, 0xce, 0x70, 0x30, 0xcc, 0x15, 0x6c,
    0xfe, 0xf6, 0x43, 0x50, 0xa1, 0x02, 0xb5, 0xf6, 0x2e, 0x85, 0x48, 0x8d, 0xcc, 0x0a, 0x93, 0x14,
    0xea, 0x17, 0x45, 0x79, 0xe6, 0xaa, 0x4e, 0x19, 0x4b, 0x5d, 0x8b, 0xdd, 0x7a, 0x3a, 0x90, 0xf7,
    0xdd, 0xe5, 0x7a, 0x21, 0x10, 0x5f, 0x2f, 0x46, 0x5d, 0xd3, 0xdd, 0x6e, 0xd7, 0x1d, 0xaf, 0xa0,
    0x1d, 0xda, 0x6c, 0x3a, 0x6f, 0xd0, 0xeb, 0x63, 0xd3, 0x27, 0xdf, 0xba, 0x46, 0x9b, 0x0c, 0xda,
    0x86, 0x55, 0xe1, 0x6f, 0x7c, 0x1e, 0xae, 0xd9, 0x6f, 0x1f, 0xb6, 0x99, 0xfc, 0xdc, 0xc2, 0x95,
    0xff, 0x52, 0x64, 0x86, 0xbd, 0x39, 0x11, 0x4e, 0xcd, 0x46, 0xe5, 0x61, 0xd5, 0xbe, 0x3d, 0xe3,
    0x17, 0xab, 0x14, 0x2e, 0x71, 0xe7, 0xe7, 0x87, 0x87, 0x77, 0x03, 0xe6, 0x08, 0xb9, 0x6e, 0x44,
    0xe4, 0xc7, 0xcd, 0x64, 0xf4, 0x6e, 0x34, 0x79, 0x7c, 0x41, 0x5f, 0x8a, 0x26, 0x52, 0x37, 0xa8,
    0xc2, 0x91, 0xf7, 0x83, 0xa1, 0xe6, 0xa9, 0x6b, 0x37, 0xdf, 0x6c, 0x5b, 0x11, 0x31, 0xfa, 0xae,
    0x68, 0xeb, 0xc3, 0xb3, 0xf3, 0xbb, 0x64, 0x36, 0x4b, 0xbf, 0x10, 0x58, 0x9d, 0x79, 0x6d, 0x36,
    0x7b, 0x96, 0xf4, 0xad, 0xcc, 0xe1, 0xe2, 0x9c, 0xb2, 0x56, 0x60, 0x04, 0x28, 0xdb, 0x4f, 0xf0,
    0x0e, 0xdb, 0xe8, 0x5a, 0xea, 0x1c, 0x64, 0x87, 0xeb, 0x40, 0x8d, 0xaa, 0x45, 0xa9, 0x90, 0xcf,
    0xa8, 0x00, 0x8f, 0x81, 0x77, 0xb2, 0x3d, 0xfb, 0x07, 0x4f, 0xef, 0x68, 0xfc, 0x24, 0xe0, 0xc1,
    0x74, 0x82, 0xee, 0x0f, 0x1a, 0xc6, 0xd9, 0x8e, 0x9d, 0x1e, 0x9f, 0xcf, 0xc5, 0x4e, 0xfe, 0x00,
    0xe5, 0x93, 0x79, 0xdc
};
#endif

PyTypeObject *init_QSurface3DSeries(PyObject *module)
{
    if (SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX].type != nullptr)
        return SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX].type;

    Shiboken::AutoDecRef Sbk_QSurface3DSeries_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QAbstract3DSeries_IDX]))));

    _Sbk_QSurface3DSeries_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSurface3DSeries",
        "QSurface3DSeries*",
        &Sbk_QSurface3DSeries_spec,
        &Shiboken::callCppDestructor< QSurface3DSeries >,
        Sbk_QSurface3DSeries_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSurface3DSeries_TypeF(); // references _Sbk_QSurface3DSeries_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSurface3DSeries_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSurface3DSeries_SignatureBytes, QSurface3DSeries_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSurface3DSeries_PropertyStrings);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSurface3DSeries_PythonToCpp_QSurface3DSeries_PTR,
        is_QSurface3DSeries_PythonToCpp_QSurface3DSeries_PTR_Convertible,
        QSurface3DSeries_PTR_CppToPython_QSurface3DSeries);

    Shiboken::Conversions::registerConverterName(converter, "QSurface3DSeries");
    Shiboken::Conversions::registerConverterName(converter, "QSurface3DSeries*");
    Shiboken::Conversions::registerConverterName(converter, "QSurface3DSeries&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSurface3DSeries).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSurface3DSeriesWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSurface3DSeries_TypeF(), &Sbk_QSurface3DSeries_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSurface3DSeries_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'DrawFlag'.
    const char *DrawFlag_Initializer[] = {
        "DrawWireframe",
        "DrawSurface",
        "DrawSurfaceAndWireframe",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DrawFlag_InitializerValues[] = {
        uint8_t(QSurface3DSeries::DrawFlag::DrawWireframe),          //  0x01  1
        uint8_t(QSurface3DSeries::DrawFlag::DrawSurface),            //  0x02  2
        uint8_t(QSurface3DSeries::DrawFlag::DrawSurfaceAndWireframe) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSurface3DSeries_TypeF(),
        "2:PySide6.QtDataVisualization.QSurface3DSeries.DrawFlag",
        DrawFlag_Initializer, DrawFlag_InitializerValues);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_QSurface3DSeries_DrawFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_QFlags_QSurface3DSeries_DrawFlag_IDX].type =
        EType;
    // Register converter for enum 'QSurface3DSeries::DrawFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSurface3DSeries_DrawFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSurface3DSeries_DrawFlag,
            is_Enum_PythonToCpp_QSurface3DSeries_DrawFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSurface3DSeries::DrawFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "DrawFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QSurface3DSeries_DrawFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QSurface3DSeries_DrawFlag,
            is_Enum_PythonToCpp_QSurface3DSeries_DrawFlag_Convertible);
        // Register converter for flag 'QFlags<QSurface3DSeries::DrawFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QSurface3DSeries::DrawFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QSurface3DSeries::DrawFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'DrawFlag' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QSurface3DSeries::staticMetaObject);
    qRegisterMetaType< ::QSurface3DSeries::DrawFlag >("QSurface3DSeries::DrawFlag");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QSurface3DSeries::staticMetaObject, sizeof(QSurface3DSeriesWrapper));

    return pyType;
}
