// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdesigner_python.h"

// main header
#include "qabstractextensionfactory_wrapper.h"

// Argument includes
#include <QString>
#include <qobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstractExtensionFactoryWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstractExtensionFactoryWrapper::QAbstractExtensionFactoryWrapper()
{
}

::QObject * QAbstractExtensionFactoryWrapper::extension(::QObject * object, const ::QString & iid) const
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractExtensionFactory.extension");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "extension";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractExtensionFactory.extension");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), object),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &iid)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), object),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &iid)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractExtensionFactory", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractExtensionFactory", funcName, Shiboken::SbkType< QObject >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QObject *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QAbstractExtensionFactoryWrapper::~QAbstractExtensionFactoryWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractExtensionFactory_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QAbstractExtensionFactory_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QAbstractExtensionFactory");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAbstractExtensionFactory >()))
        return -1;

    QAbstractExtensionFactoryWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDesignerTypeStructs[SBK_QAbstractExtensionFactory_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QAbstractExtensionFactory()
        cptr = new QAbstractExtensionFactoryWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAbstractExtensionFactory >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAbstractExtensionFactoryFunc_extension(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractExtensionFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QAbstractExtensionFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "extension", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractExtensionFactory::extension(QObject*,QString)const->QObject*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // extension(QObject*,QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "extension", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QAbstractExtensionFactory_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // extension(QObject*,QString)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractExtensionFactory.extension");
                return {};
            }
            QObject * cppResult = const_cast<const ::QAbstractExtensionFactory *>(cppSelf)->extension(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAbstractExtensionFactory_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractExtensionFactory_methods[] = {
    {"extension", reinterpret_cast<PyCFunction>(Sbk_QAbstractExtensionFactoryFunc_extension), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractExtensionFactory_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstractExtensionFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QAbstractExtensionFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractExtensionFactoryWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractExtensionFactory_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractExtensionFactory_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractExtensionFactory_Type = nullptr;
static PyTypeObject *Sbk_QAbstractExtensionFactory_TypeF(void)
{
    return _Sbk_QAbstractExtensionFactory_Type;
}

static PyType_Slot Sbk_QAbstractExtensionFactory_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractExtensionFactory_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractExtensionFactory_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractExtensionFactory_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractExtensionFactory_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractExtensionFactory_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractExtensionFactory_spec = {
    "2:PySide6.QtDesigner.QAbstractExtensionFactory",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractExtensionFactory_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractExtensionFactory_PythonToCpp_QAbstractExtensionFactory_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractExtensionFactory_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractExtensionFactory_PythonToCpp_QAbstractExtensionFactory_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractExtensionFactory_TypeF()))
        return QAbstractExtensionFactory_PythonToCpp_QAbstractExtensionFactory_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractExtensionFactory_PTR_CppToPython_QAbstractExtensionFactory(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QAbstractExtensionFactory *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QAbstractExtensionFactory_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstractExtensionFactory_SignatureStrings[] = {
    "PySide6.QtDesigner.QAbstractExtensionFactory(self)",
    "PySide6.QtDesigner.QAbstractExtensionFactory.extension(self,object:PySide6.QtCore.QObject,iid:QString)->PySide6.QtCore.QObject",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstractExtensionFactory_SignatureByteSize = 104;
static constexpr uint8_t QAbstractExtensionFactory_SignatureBytes[104] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x49, 0x2d, 0xce,
    0x4c, 0xcf, 0x4b, 0x2d, 0xd2, 0x0b, 0x74, 0x4c, 0x2a, 0x2e, 0x29, 0x4a, 0x4c, 0x2e, 0x71, 0xad,
    0x28, 0x49, 0xcd, 0x2b, 0xce, 0xcc, 0xcf, 0x73, 0x03, 0x72, 0xf2, 0x8b, 0x2a, 0x35, 0x8a, 0x53,
    0x73, 0xd2, 0x34, 0xb9, 0x02, 0x48, 0xd0, 0xa2, 0x97, 0x0a, 0x13, 0x00, 0x6b, 0xd6, 0xc9, 0x4f,
    0xca, 0x4a, 0x4d, 0x2e, 0xb1, 0x42, 0x18, 0xe1, 0x9c, 0x5f, 0x94, 0xaa, 0x17, 0xe8, 0x0f, 0x16,
    0xd6, 0xc9, 0xcc, 0x4c, 0xb1, 0x0a, 0x0c, 0x2e, 0x29, 0xca, 0xcc, 0x4b, 0xd7, 0xd4, 0xb5, 0xc3,
    0xae, 0x88, 0x0b, 0x00, 0x38, 0x14, 0x41, 0x4e
};
#endif

PyTypeObject *init_QAbstractExtensionFactory(PyObject *module)
{
    if (SbkPySide6_QtDesignerTypeStructs[SBK_QAbstractExtensionFactory_IDX].type != nullptr)
        return SbkPySide6_QtDesignerTypeStructs[SBK_QAbstractExtensionFactory_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractExtensionFactory_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAbstractExtensionFactory_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractExtensionFactory",
        "QAbstractExtensionFactory*",
        &Sbk_QAbstractExtensionFactory_spec,
        &Shiboken::callCppDestructor< QAbstractExtensionFactory >,
        Sbk_QAbstractExtensionFactory_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAbstractExtensionFactory_TypeF(); // references _Sbk_QAbstractExtensionFactory_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstractExtensionFactory_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstractExtensionFactory_SignatureBytes, QAbstractExtensionFactory_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractExtensionFactory_PropertyStrings);
    SbkPySide6_QtDesignerTypeStructs[SBK_QAbstractExtensionFactory_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractExtensionFactory_PythonToCpp_QAbstractExtensionFactory_PTR,
        is_QAbstractExtensionFactory_PythonToCpp_QAbstractExtensionFactory_PTR_Convertible,
        QAbstractExtensionFactory_PTR_CppToPython_QAbstractExtensionFactory);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractExtensionFactory");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractExtensionFactory*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractExtensionFactory&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractExtensionFactory).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractExtensionFactoryWrapper).name());

    qRegisterMetaType< ::QAbstractExtensionFactory *>();

    return pyType;
}
