// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdesigner_python.h"

// main header
#include "qdesignerformwindowinterface_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtDesigner/abstractformeditor.h>
#include <QtDesigner/abstractformwindow.h>
#include <QtDesigner/abstractformwindowcursor.h>
#include <QtDesigner/abstractformwindowtool.h>
#include <QtGui/qaction.h>
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qundostack.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qgraphicseffect.h>
#include <QtWidgets/qgraphicsproxywidget.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdir.h>
#include <qiodevice.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDesignerFormWindowInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
    SBK_UNUSED(sbkSelf)
    SBK_UNUSED(type)
    SBK_UNUSED(myType)
    Shiboken::Errors::setInstantiateAbstractClassDisabledWrapper("QDesignerFormWindowInterface");
    return -1;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_absoluteDir(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // absoluteDir()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.absoluteDir");
            return {};
        }
        QDir cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->absoluteDir();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_activateResourceFilePaths(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "activateResourceFilePaths", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:activateResourceFilePaths", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::activateResourceFilePaths(QStringList,int*=,QString*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // activateResourceFilePaths(QStringList,int*,QString*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // activateResourceFilePaths(QStringList,int*,QString*)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                overloadId = 0; // activateResourceFilePaths(QStringList,int*,QString*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "activateResourceFilePaths", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_errorCount = Shiboken::String::createStaticString("errorCount");
            if (PyDict_Contains(kwds, key_errorCount) != 0) {
                value = PyDict_GetItem(kwds, key_errorCount);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_errorCount);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "activateResourceFilePaths", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "activateResourceFilePaths", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_errorCount);
            }
            static PyObject *const key_errorMessages = Shiboken::String::createStaticString("errorMessages");
            if (PyDict_Contains(kwds, key_errorMessages) != 0) {
                value = PyDict_GetItem(kwds, key_errorMessages);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_errorMessages);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "activateResourceFilePaths", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "activateResourceFilePaths", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_errorMessages);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "activateResourceFilePaths", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
            }
        }
        ::QStringList cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // activateResourceFilePaths(QStringList,int*,QString*)
            cppSelf->activateResourceFilePaths(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_activeResourceFilePaths(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activeResourceFilePaths()const
        QStringList cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->activeResourceFilePaths();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_addResourceFile(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::addResourceFile(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // addResourceFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addResourceFile", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addResourceFile(QString)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.addResourceFile");
                return {};
            }
            cppSelf->addResourceFile(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_author(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // author()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.author");
            return {};
        }
        QString cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->author();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_beginCommand(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::beginCommand(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // beginCommand(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "beginCommand", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // beginCommand(QString)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.beginCommand");
                return {};
            }
            cppSelf->beginCommand(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_checkContents(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // checkContents()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.checkContents");
            return {};
        }
        QStringList cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->checkContents();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_clearSelection(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "clearSelection", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    if (PyArg_ParseTuple(args, "|O:clearSelection", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::clearSelection(bool=)
    if (numArgs == 0) {
        overloadId = 0; // clearSelection(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // clearSelection(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "clearSelection", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_changePropertyDisplay = Shiboken::String::createStaticString("changePropertyDisplay");
            if (PyDict_Contains(kwds, key_changePropertyDisplay) != 0) {
                value = PyDict_GetItem(kwds, key_changePropertyDisplay);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_changePropertyDisplay);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "clearSelection", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "clearSelection", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_changePropertyDisplay);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "clearSelection", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // clearSelection(bool)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.clearSelection");
                return {};
            }
            cppSelf->clearSelection(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_commandHistory(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // commandHistory()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.commandHistory");
            return {};
        }
        QUndoStack * cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->commandHistory();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QUndoStack_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_comment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // comment()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.comment");
            return {};
        }
        QString cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->comment();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_contents(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contents()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.contents");
            return {};
        }
        QString cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->contents();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_core(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // core()const
        QDesignerFormEditorInterface * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->::QDesignerFormWindowInterface::core()
            : const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->core();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormEditorInterface_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_currentTool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentTool()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.currentTool");
            return {};
        }
        int cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->currentTool();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_cursor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cursor()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.cursor");
            return {};
        }
        QDesignerFormWindowCursorInterface * cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->cursor();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_editWidgets(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // editWidgets()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.editWidgets");
            return {};
        }
        cppSelf->editWidgets();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_emitSelectionChanged(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // emitSelectionChanged()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.emitSelectionChanged");
            return {};
        }
        cppSelf->emitSelectionChanged();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_endCommand(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // endCommand()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.endCommand");
            return {};
        }
        cppSelf->endCommand();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_ensureUniqueObjectName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::ensureUniqueObjectName(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // ensureUniqueObjectName(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "ensureUniqueObjectName", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ensureUniqueObjectName(QObject*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.ensureUniqueObjectName");
                return {};
            }
            cppSelf->ensureUniqueObjectName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_exportMacro(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // exportMacro()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.exportMacro");
            return {};
        }
        QString cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->exportMacro();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_features(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // features()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.features");
            return {};
        }
        QFlags<QDesignerFormWindowInterface::FeatureFlag> cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->features();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QFlags_QDesignerFormWindowInterface_FeatureFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_fileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileName()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.fileName");
            return {};
        }
        QString cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->fileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_findFormWindow(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDesignerFormWindowInterface::findFormWindow(QObject*)->QDesignerFormWindowInterface*
    // 1: static QDesignerFormWindowInterface::findFormWindow(QWidget*)->QDesignerFormWindowInterface*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 1; // findFormWindow(QWidget*)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // findFormWindow(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "findFormWindow", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // findFormWindow(QObject *obj)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QObject *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // findFormWindow(QObject*)
                QDesignerFormWindowInterface * cppResult = ::QDesignerFormWindowInterface::findFormWindow(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), cppResult);
            }
            break;
        }
        case 1: // findFormWindow(QWidget *w)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // findFormWindow(QWidget*)
                QDesignerFormWindowInterface * cppResult = ::QDesignerFormWindowInterface::findFormWindow(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_formContainer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // formContainer()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.formContainer");
            return {};
        }
        QWidget * cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->formContainer();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_grid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // grid()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.grid");
            return {};
        }
        QPoint cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->grid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_hasFeature(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::hasFeature(QFlags<QDesignerFormWindowInterface::FeatureFlag>)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QFlags_QDesignerFormWindowInterface_FeatureFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // hasFeature(QFlags<QDesignerFormWindowInterface::FeatureFlag>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasFeature", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        ::QFlags<QDesignerFormWindowInterface::FeatureFlag> cppArg0 = QFlags<QDesignerFormWindowInterface::FeatureFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasFeature(QFlags<QDesignerFormWindowInterface::FeatureFlag>)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.hasFeature");
                return {};
            }
            bool cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->hasFeature(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_includeHints(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // includeHints()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.includeHints");
            return {};
        }
        QStringList cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->includeHints();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_isDirty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDirty()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.isDirty");
            return {};
        }
        bool cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->isDirty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_isManaged(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::isManaged(QWidget*)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // isManaged(QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isManaged", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isManaged(QWidget*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.isManaged");
                return {};
            }
            bool cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->isManaged(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_layoutDefault(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "layoutDefault", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::layoutDefault(int*,int*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // layoutDefault(int*,int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "layoutDefault", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        int *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // layoutDefault(int*,int*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.layoutDefault");
                return {};
            }
            cppSelf->layoutDefault(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_layoutFunction(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "layoutFunction", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::layoutFunction(QString*,QString*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // layoutFunction(QString*,QString*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "layoutFunction", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        ::QString *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // layoutFunction(QString*,QString*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.layoutFunction");
                return {};
            }
            cppSelf->layoutFunction(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_mainContainer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mainContainer()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.mainContainer");
            return {};
        }
        QWidget * cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->mainContainer();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_manageWidget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::manageWidget(QWidget*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // manageWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "manageWidget", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // manageWidget(QWidget*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.manageWidget");
                return {};
            }
            cppSelf->manageWidget(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_pixmapFunction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pixmapFunction()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.pixmapFunction");
            return {};
        }
        QString cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->pixmapFunction();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_registerTool(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::registerTool(QDesignerFormWindowToolInterface*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowToolInterface_IDX]), (pyArg)))) {
        overloadId = 0; // registerTool(QDesignerFormWindowToolInterface*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "registerTool", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDesignerFormWindowToolInterface *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // registerTool(QDesignerFormWindowToolInterface*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.registerTool");
                return {};
            }
            cppSelf->registerTool(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_removeResourceFile(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::removeResourceFile(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // removeResourceFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeResourceFile", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeResourceFile(QString)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.removeResourceFile");
                return {};
            }
            cppSelf->removeResourceFile(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_resourceFileSaveMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resourceFileSaveMode()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.resourceFileSaveMode");
            return {};
        }
        QDesignerFormWindowInterface::ResourceFileSaveMode cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->resourceFileSaveMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_ResourceFileSaveMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_resourceFiles(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resourceFiles()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.resourceFiles");
            return {};
        }
        QStringList cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->resourceFiles();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_selectWidget(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "selectWidget", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    if (PyArg_ParseTuple(args, "|OO:selectWidget", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::selectWidget(QWidget*,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // selectWidget(QWidget*,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // selectWidget(QWidget*,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "selectWidget", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_select = Shiboken::String::createStaticString("select");
            if (PyDict_Contains(kwds, key_select) != 0) {
                value = PyDict_GetItem(kwds, key_select);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_select);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "selectWidget", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "selectWidget", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_select);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "selectWidget", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectWidget(QWidget*,bool)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.selectWidget");
                return {};
            }
            cppSelf->selectWidget(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_setAuthor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::setAuthor(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setAuthor(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAuthor", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAuthor(QString)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setAuthor");
                return {};
            }
            cppSelf->setAuthor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_setComment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::setComment(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setComment(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setComment", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setComment(QString)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setComment");
                return {};
            }
            cppSelf->setComment(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_setContents(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setContents", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setContents", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::setContents(QString)->bool
    // 1: QDesignerFormWindowInterface::setContents(QIODevice*,QString*=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // setContents(QIODevice*,QString*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 1; // setContents(QIODevice*,QString*)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // setContents(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setContents", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setContents(const QString &contents)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setContents", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setContents(QString)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                    Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setContents");
                    return {};
                }
                bool cppResult = cppSelf->setContents(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // setContents(QIODevice *dev, QString *errorMessage)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_errorMessage = Shiboken::String::createStaticString("errorMessage");
                if (PyDict_Contains(kwds, key_errorMessage) != 0) {
                    value = PyDict_GetItem(kwds, key_errorMessage);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_errorMessage);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setContents", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "setContents", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_errorMessage);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "setContents", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setContents(QIODevice*,QString*)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                    Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setContents");
                    return {};
                }
                bool cppResult = cppSelf->setContents(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_setCurrentTool(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::setCurrentTool(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setCurrentTool(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCurrentTool", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurrentTool(int)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setCurrentTool");
                return {};
            }
            cppSelf->setCurrentTool(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_setDirty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::setDirty(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDirty(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDirty", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDirty(bool)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setDirty");
                return {};
            }
            cppSelf->setDirty(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_setExportMacro(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::setExportMacro(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setExportMacro(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExportMacro", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExportMacro(QString)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setExportMacro");
                return {};
            }
            cppSelf->setExportMacro(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_setFeatures(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::setFeatures(QFlags<QDesignerFormWindowInterface::FeatureFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QFlags_QDesignerFormWindowInterface_FeatureFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setFeatures(QFlags<QDesignerFormWindowInterface::FeatureFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFeatures", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        ::QFlags<QDesignerFormWindowInterface::FeatureFlag> cppArg0 = QFlags<QDesignerFormWindowInterface::FeatureFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFeatures(QFlags<QDesignerFormWindowInterface::FeatureFlag>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setFeatures");
                return {};
            }
            cppSelf->setFeatures(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_setFileName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::setFileName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFileName", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFileName(QString)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setFileName");
                return {};
            }
            cppSelf->setFileName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_setGrid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::setGrid(QPoint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 0; // setGrid(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGrid", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPoint cppArg0_local;
        ::QPoint *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setGrid(QPoint)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setGrid");
                return {};
            }
            cppSelf->setGrid(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_setIncludeHints(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::setIncludeHints(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setIncludeHints(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIncludeHints", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIncludeHints(QStringList)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setIncludeHints");
                return {};
            }
            cppSelf->setIncludeHints(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_setLayoutDefault(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setLayoutDefault", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::setLayoutDefault(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setLayoutDefault(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setLayoutDefault", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLayoutDefault(int,int)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setLayoutDefault");
                return {};
            }
            cppSelf->setLayoutDefault(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_setLayoutFunction(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setLayoutFunction", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::setLayoutFunction(QString,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // setLayoutFunction(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setLayoutFunction", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLayoutFunction(QString,QString)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setLayoutFunction");
                return {};
            }
            cppSelf->setLayoutFunction(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_setMainContainer(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::setMainContainer(QWidget*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // setMainContainer(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMainContainer", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMainContainer(QWidget*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setMainContainer");
                return {};
            }
            cppSelf->setMainContainer(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_setPixmapFunction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::setPixmapFunction(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPixmapFunction(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPixmapFunction", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPixmapFunction(QString)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setPixmapFunction");
                return {};
            }
            cppSelf->setPixmapFunction(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_setResourceFileSaveMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::setResourceFileSaveMode(QDesignerFormWindowInterface::ResourceFileSaveMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_ResourceFileSaveMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setResourceFileSaveMode(QDesignerFormWindowInterface::ResourceFileSaveMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setResourceFileSaveMode", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        ::QDesignerFormWindowInterface::ResourceFileSaveMode cppArg0{QDesignerFormWindowInterface::SaveAllResourceFiles};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setResourceFileSaveMode(QDesignerFormWindowInterface::ResourceFileSaveMode)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.setResourceFileSaveMode");
                return {};
            }
            cppSelf->setResourceFileSaveMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_simplifySelection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::simplifySelection(QList<QWidget*>*)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDesignerTypeConverters[SBK_QtDesigner_QList_QWidgetPTR_IDX], (pyArg)))) {
        overloadId = 0; // simplifySelection(QList<QWidget*>*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "simplifySelection", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        ::QList<QWidget*> cppArg0_local;
        ::QList<QWidget*> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // simplifySelection(QList<QWidget*>*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.simplifySelection");
                return {};
            }
            const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->simplifySelection(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_tool(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::tool(int)const->QDesignerFormWindowToolInterface*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // tool(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "tool", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // tool(int)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.tool");
                return {};
            }
            QDesignerFormWindowToolInterface * cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->tool(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowToolInterface_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_toolCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toolCount()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.toolCount");
            return {};
        }
        int cppResult = const_cast<const ::QDesignerFormWindowInterface *>(cppSelf)->toolCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowInterfaceFunc_unmanageWidget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowInterface::unmanageWidget(QWidget*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // unmanageWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "unmanageWidget", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // unmanageWidget(QWidget*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowInterface.unmanageWidget");
                return {};
            }
            cppSelf->unmanageWidget(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QDesignerFormWindowInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDesignerFormWindowInterface_EnumFlagInfo[] = {
    "FeatureFlag:Flag:Feature",
    "ResourceFileSaveMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDesignerFormWindowInterface_methods[] = {
    {"absoluteDir", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_absoluteDir), METH_NOARGS, nullptr},
    {"activateResourceFilePaths", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_activateResourceFilePaths), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"activeResourceFilePaths", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_activeResourceFilePaths), METH_NOARGS, nullptr},
    {"addResourceFile", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_addResourceFile), METH_O, nullptr},
    {"author", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_author), METH_NOARGS, nullptr},
    {"beginCommand", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_beginCommand), METH_O, nullptr},
    {"checkContents", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_checkContents), METH_NOARGS, nullptr},
    {"clearSelection", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_clearSelection), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"commandHistory", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_commandHistory), METH_NOARGS, nullptr},
    {"comment", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_comment), METH_NOARGS, nullptr},
    {"contents", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_contents), METH_NOARGS, nullptr},
    {"core", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_core), METH_NOARGS, nullptr},
    {"currentTool", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_currentTool), METH_NOARGS, nullptr},
    {"cursor", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_cursor), METH_NOARGS, nullptr},
    {"editWidgets", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_editWidgets), METH_NOARGS, nullptr},
    {"emitSelectionChanged", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_emitSelectionChanged), METH_NOARGS, nullptr},
    {"endCommand", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_endCommand), METH_NOARGS, nullptr},
    {"ensureUniqueObjectName", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_ensureUniqueObjectName), METH_O, nullptr},
    {"exportMacro", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_exportMacro), METH_NOARGS, nullptr},
    {"features", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_features), METH_NOARGS, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_fileName), METH_NOARGS, nullptr},
    {"findFormWindow", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_findFormWindow), METH_O|METH_STATIC, nullptr},
    {"formContainer", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_formContainer), METH_NOARGS, nullptr},
    {"grid", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_grid), METH_NOARGS, nullptr},
    {"hasFeature", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_hasFeature), METH_O, nullptr},
    {"includeHints", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_includeHints), METH_NOARGS, nullptr},
    {"isDirty", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_isDirty), METH_NOARGS, nullptr},
    {"isManaged", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_isManaged), METH_O, nullptr},
    {"layoutDefault", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_layoutDefault), METH_VARARGS, nullptr},
    {"layoutFunction", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_layoutFunction), METH_VARARGS, nullptr},
    {"mainContainer", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_mainContainer), METH_NOARGS, nullptr},
    {"manageWidget", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_manageWidget), METH_O, nullptr},
    {"pixmapFunction", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_pixmapFunction), METH_NOARGS, nullptr},
    {"registerTool", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_registerTool), METH_O, nullptr},
    {"removeResourceFile", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_removeResourceFile), METH_O, nullptr},
    {"resourceFileSaveMode", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_resourceFileSaveMode), METH_NOARGS, nullptr},
    {"resourceFiles", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_resourceFiles), METH_NOARGS, nullptr},
    {"selectWidget", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_selectWidget), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setAuthor", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_setAuthor), METH_O, nullptr},
    {"setComment", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_setComment), METH_O, nullptr},
    {"setContents", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_setContents), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setCurrentTool", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_setCurrentTool), METH_O, nullptr},
    {"setDirty", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_setDirty), METH_O, nullptr},
    {"setExportMacro", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_setExportMacro), METH_O, nullptr},
    {"setFeatures", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_setFeatures), METH_O, nullptr},
    {"setFileName", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_setFileName), METH_O, nullptr},
    {"setGrid", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_setGrid), METH_O, nullptr},
    {"setIncludeHints", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_setIncludeHints), METH_O, nullptr},
    {"setLayoutDefault", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_setLayoutDefault), METH_VARARGS, nullptr},
    {"setLayoutFunction", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_setLayoutFunction), METH_VARARGS, nullptr},
    {"setMainContainer", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_setMainContainer), METH_O, nullptr},
    {"setPixmapFunction", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_setPixmapFunction), METH_O, nullptr},
    {"setResourceFileSaveMode", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_setResourceFileSaveMode), METH_O, nullptr},
    {"simplifySelection", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_simplifySelection), METH_O, nullptr},
    {"tool", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_tool), METH_O, nullptr},
    {"toolCount", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_toolCount), METH_NOARGS, nullptr},
    {"unmanageWidget", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowInterfaceFunc_unmanageWidget), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDesignerFormWindowInterface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDesignerFormWindowInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDesignerFormWindowInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QDesignerFormWindowInterfaceSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QDesignerFormWindowInterface *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDesignerFormWindowInterface_Type = nullptr;
static PyTypeObject *Sbk_QDesignerFormWindowInterface_TypeF(void)
{
    return _Sbk_QDesignerFormWindowInterface_Type;
}

static PyType_Slot Sbk_QDesignerFormWindowInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDesignerFormWindowInterface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDesignerFormWindowInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDesignerFormWindowInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDesignerFormWindowInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDesignerFormWindowInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDesignerFormWindowInterface_spec = {
    "2:PySide6.QtDesigner.QDesignerFormWindowInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDesignerFormWindowInterface_slots
};

} //extern "C"

static void *Sbk_QDesignerFormWindowInterface_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QDesignerFormWindowInterface *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QDesignerFormWindowInterface *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QDesignerFormWindowInterface *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDesignerFormWindowInterface_FeatureFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDesignerFormWindowInterface::FeatureFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDesignerFormWindowInterface::FeatureFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDesignerFormWindowInterface_FeatureFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_FeatureFlag_IDX])))
        return Enum_PythonToCpp_QDesignerFormWindowInterface_FeatureFlag;
    return {};
}

static PyObject *QDesignerFormWindowInterface_FeatureFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDesignerFormWindowInterface::FeatureFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDesignerFormWindowInterface::FeatureFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_FeatureFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QDesignerFormWindowInterface_FeatureFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QDesignerFormWindowInterface::FeatureFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QDesignerFormWindowInterface::FeatureFlag> *>(cppOut) = value;

}

static PyObject *QDesignerFormWindowInterface_FeatureFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QDesignerFormWindowInterface::FeatureFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_FeatureFlag_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QDesignerFormWindowInterface_ResourceFileSaveMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDesignerFormWindowInterface::ResourceFileSaveMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDesignerFormWindowInterface::ResourceFileSaveMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDesignerFormWindowInterface_ResourceFileSaveMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_ResourceFileSaveMode_IDX])))
        return Enum_PythonToCpp_QDesignerFormWindowInterface_ResourceFileSaveMode;
    return {};
}

static PyObject *QDesignerFormWindowInterface_ResourceFileSaveMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDesignerFormWindowInterface::ResourceFileSaveMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDesignerFormWindowInterface::ResourceFileSaveMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_ResourceFileSaveMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDesignerFormWindowInterface_PythonToCpp_QDesignerFormWindowInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDesignerFormWindowInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDesignerFormWindowInterface_PythonToCpp_QDesignerFormWindowInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDesignerFormWindowInterface_TypeF()))
        return QDesignerFormWindowInterface_PythonToCpp_QDesignerFormWindowInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDesignerFormWindowInterface_PTR_CppToPython_QDesignerFormWindowInterface(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QDesignerFormWindowInterface *>(const_cast<void *>(cppIn)), Sbk_QDesignerFormWindowInterface_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDesignerFormWindowInterface_SignatureStrings[] = {
    "PySide6.QtDesigner.QDesignerFormWindowInterface(self,parent:PySide6.QtWidgets.QWidget=nullptr,flags:PySide6.QtCore.Qt.WindowType={})",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.absoluteDir(self)->PySide6.QtCore.QDir",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.activateResourceFilePaths(self,paths:QStringList,errorCount:int*=nullptr,errorMessages:QString*=nullptr)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.activeResourceFilePaths(self)->QStringList",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.addResourceFile(self,path:QString)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.author(self)->QString",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.beginCommand(self,description:QString)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.checkContents(self)->QStringList",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.clearSelection(self,changePropertyDisplay:bool=true)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.commandHistory(self)->PySide6.QtGui.QUndoStack",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.comment(self)->QString",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.contents(self)->QString",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.core(self)->PySide6.QtDesigner.QDesignerFormEditorInterface",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.currentTool(self)->int",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.cursor(self)->PySide6.QtDesigner.QDesignerFormWindowCursorInterface",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.editWidgets(self)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.emitSelectionChanged(self)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.endCommand(self)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.ensureUniqueObjectName(self,object:PySide6.QtCore.QObject)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.exportMacro(self)->QString",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.features(self)->PySide6.QtDesigner.QDesignerFormWindowInterface.FeatureFlag",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.fileName(self)->QString",
    "1:PySide6.QtDesigner.QDesignerFormWindowInterface.findFormWindow(obj:PySide6.QtCore.QObject)->PySide6.QtDesigner.QDesignerFormWindowInterface",
    "0:PySide6.QtDesigner.QDesignerFormWindowInterface.findFormWindow(w:PySide6.QtWidgets.QWidget)->PySide6.QtDesigner.QDesignerFormWindowInterface",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.formContainer(self)->PySide6.QtWidgets.QWidget",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.grid(self)->PySide6.QtCore.QPoint",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.hasFeature(self,f:PySide6.QtDesigner.QDesignerFormWindowInterface.FeatureFlag)->bool",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.includeHints(self)->QStringList",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.isDirty(self)->bool",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.isManaged(self,widget:PySide6.QtWidgets.QWidget)->bool",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.layoutDefault(self,margin:int*,spacing:int*)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.layoutFunction(self,margin:QString*,spacing:QString*)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.mainContainer(self)->PySide6.QtWidgets.QWidget",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.manageWidget(self,widget:PySide6.QtWidgets.QWidget)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.pixmapFunction(self)->QString",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.registerTool(self,tool:PySide6.QtDesigner.QDesignerFormWindowToolInterface)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.removeResourceFile(self,path:QString)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.resourceFileSaveMode(self)->PySide6.QtDesigner.QDesignerFormWindowInterface.ResourceFileSaveMode",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.resourceFiles(self)->QStringList",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.selectWidget(self,w:PySide6.QtWidgets.QWidget,select:bool=true)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.setAuthor(self,author:QString)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.setComment(self,comment:QString)",
    "1:PySide6.QtDesigner.QDesignerFormWindowInterface.setContents(self,contents:QString)->bool",
    "0:PySide6.QtDesigner.QDesignerFormWindowInterface.setContents(self,dev:PySide6.QtCore.QIODevice,errorMessage:QString*=nullptr)->bool",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.setCurrentTool(self,index:int)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.setDirty(self,dirty:bool)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.setExportMacro(self,exportMacro:QString)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.setFeatures(self,f:PySide6.QtDesigner.QDesignerFormWindowInterface.FeatureFlag)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.setFileName(self,fileName:QString)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.setGrid(self,grid:PySide6.QtCore.QPoint)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.setIncludeHints(self,includeHints:QStringList)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.setLayoutDefault(self,margin:int,spacing:int)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.setLayoutFunction(self,margin:QString,spacing:QString)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.setMainContainer(self,mainContainer:PySide6.QtWidgets.QWidget)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.setPixmapFunction(self,pixmapFunction:QString)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.setResourceFileSaveMode(self,behaviour:PySide6.QtDesigner.QDesignerFormWindowInterface.ResourceFileSaveMode)",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.simplifySelection(self,widgets:QList[PySide6.QtWidgets.QWidget])",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.tool(self,index:int)->PySide6.QtDesigner.QDesignerFormWindowToolInterface",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.toolCount(self)->int",
    "PySide6.QtDesigner.QDesignerFormWindowInterface.unmanageWidget(self,widget:PySide6.QtWidgets.QWidget)",
    nullptr}; // Sentinel
#else
static constexpr size_t QDesignerFormWindowInterface_SignatureByteSize = 911;
static constexpr uint8_t QDesignerFormWindowInterface_SignatureBytes[911] = {
    0x78, 0xda, 0xb5, 0x58, 0x5d, 0x6f, 0xda, 0x30, 0x14, 0x7d, 0xdf, 0x2f, 0x29, 0x93, 0x87, 0xba,
    0x97, 0x3d, 0x20, 0x75, 0xd2, 0x04, 0xa5, 0xad, 0x54, 0x56, 0x28, 0xad, 0xfa, 0x30, 0xed, 0xc1,
    0xc4, 0x97, 0xe0, 0x35, 0xb1, 0x33, 0x7f, 0xd0, 0xa2, 0x69, 0xff, 0x7d, 0x37, 0x31, 0x09, 0x21,
    0x81, 0xaa, 0x76, 0xd8, 0x13, 0x4e, 0xb0, 0xcf, 0x3d, 0xbe, 0xbe, 0xb9, 0xe7, 0x24, 0xd3, 0xcd,
    0x9c, 0x33, 0xf8, 0xd2, 0x9f, 0x99, 0x11, 0x68, 0x1e, 0x0b, 0x50, 0xfd, 0x59, 0x39, 0x1a, 0x4b,
    0x95, 0x3e, 0x71, 0xc1, 0xe4, 0xcb, 0x8d, 0x30, 0xa0, 0x96, 0x34, 0x82, 0x33, 0x0d, 0xc9, 0x92,
    0x64, 0x54, 0x81, 0x30, 0x83, 0x69, 0xb5, 0xf6, 0x89, 0xb3, 0x18, 0x8c, 0xee, 0xcf, 0xdc, 0xe0,
    0x42, 0xd8, 0x24, 0xc9, 0x8c, 0x22, 0xcb, 0x84, 0xc6, 0xba, 0x36, 0x6f, 0x28, 0x15, 0xe0, 0x4f,
    0xdf, 0xa1, 0x3e, 0x6c, 0x32, 0xb8, 0xf8, 0xf3, 0xb7, 0xf7, 0x61, 0xea, 0x47, 0xa2, 0x4f, 0x17,
    0x5a, 0x26, 0xd6, 0xc0, 0x88, 0xab, 0x82, 0x50, 0xef, 0xd3, 0xd7, 0x66, 0x0c, 0xfc, 0xcb, 0x1f,
    0x36, 0x32, 0x7c, 0x4d, 0x0d, 0xdc, 0x83, 0x96, 0x56, 0x45, 0x30, 0xe6, 0x09, 0x4c, 0xa9, 0x59,
    0xe9, 0x72, 0xd7, 0x38, 0x1c, 0xcc, 0xe6, 0x46, 0x71, 0x11, 0xdf, 0x72, 0x6d, 0x08, 0x28, 0x25,
    0xd5, 0x50, 0x5a, 0xcc, 0x05, 0x17, 0xe6, 0x63, 0xb5, 0xed, 0xe2, 0xfe, 0x04, 0xb4, 0xa6, 0x31,
    0x54, 0x2b, 0xaa, 0xbf, 0x7b, 0x61, 0xc4, 0x8e, 0xd0, 0xc2, 0xbd, 0xd7, 0x28, 0xf9, 0x43, 0x33,
    0x56, 0xc7, 0xdd, 0xed, 0xb4, 0xa4, 0x1d, 0xc0, 0xd6, 0x9a, 0x95, 0x54, 0x0d, 0x72, 0xde, 0x28,
    0x0b, 0x88, 0xb9, 0x18, 0xca, 0x34, 0xa5, 0x82, 0x39, 0x56, 0x0c, 0x74, 0xa4, 0x78, 0x66, 0xb8,
    0x14, 0xe1, 0xe4, 0xa2, 0x15, 0x44, 0xcf, 0x43, 0x89, 0xd7, 0xc2, 0x9c, 0x24, 0x81, 0x51, 0x02,
    0x54, 0xcd, 0x21, 0x81, 0x28, 0x27, 0xe6, 0x98, 0x46, 0x2b, 0x2a, 0x62, 0x98, 0x2a, 0x99, 0x81,
    0x32, 0x9b, 0x11, 0xd7, 0x59, 0x42, 0x37, 0x83, 0x85, 0x94, 0xc9, 0x85, 0x51, 0x16, 0x02, 0x58,
    0xbb, 0x3c, 0x5c, 0x23, 0x41, 0xa9, 0x36, 0xed, 0x9a, 0xbf, 0xb2, 0xbc, 0x3f, 0x7b, 0xc4, 0x35,
    0x73, 0x43, 0xa3, 0xe7, 0x20, 0x78, 0xcc, 0x47, 0xd7, 0x23, 0x8b, 0x0e, 0xa7, 0x35, 0x00, 0x47,
    0x41, 0x7b, 0x8f, 0x87, 0xd7, 0x5e, 0x32, 0x8e, 0x29, 0xa9, 0xd6, 0xfa, 0xc7, 0xb2, 0x2a, 0xef,
    0x65, 0x0f, 0x78, 0x36, 0x65, 0x48, 0x7c, 0x94, 0x43, 0x60, 0xb4, 0x54, 0xef, 0x25, 0xed, 0x56,
    0x0f, 0x8b, 0x35, 0xe1, 0xd4, 0x01, 0xb7, 0xbe, 0x6d, 0xbc, 0x2e, 0xb0, 0x3f, 0x42, 0xca, 0x4d,
    0x55, 0xba, 0xc3, 0xa2, 0x68, 0x59, 0x28, 0x94, 0x60, 0xf5, 0x87, 0x35, 0x04, 0x40, 0x5b, 0x05,
    0x8f, 0x82, 0xff, 0xb6, 0x70, 0xb7, 0xf8, 0x85, 0x9c, 0xbe, 0xd3, 0x74, 0xdb, 0x8f, 0x64, 0x71,
    0xdd, 0xd2, 0x11, 0x37, 0x2d, 0x20, 0xd4, 0x6b, 0x26, 0x95, 0x99, 0xd0, 0x48, 0xc9, 0xae, 0xa5,
    0xba, 0x04, 0x6a, 0x90, 0xb6, 0xf6, 0x3b, 0xf9, 0xdd, 0xfa, 0xb1, 0x5b, 0x3f, 0x46, 0x9d, 0xf4,
    0x8f, 0x8d, 0xfd, 0xba, 0xca, 0x51, 0x6d, 0x0f, 0x9f, 0x07, 0xfe, 0x48, 0x82, 0xed, 0xee, 0x9f,
    0x61, 0xba, 0x8f, 0xe5, 0xda, 0x7b, 0x87, 0x1f, 0xce, 0xbb, 0xb2, 0x79, 0x39, 0xee, 0x33, 0x02,
    0xe8, 0x78, 0x93, 0xc1, 0x7b, 0xb9, 0x5c, 0x50, 0x8e, 0x13, 0xda, 0xa7, 0xdc, 0x20, 0xe4, 0x0d,
    0x1f, 0x2b, 0xce, 0x8e, 0x59, 0x98, 0xa9, 0x0c, 0xe9, 0x44, 0x2b, 0xaa, 0xb7, 0x45, 0xe5, 0x9e,
    0x9d, 0xe5, 0xa0, 0x43, 0x4d, 0x22, 0xab, 0x5c, 0xb5, 0xbc, 0x49, 0x70, 0x11, 0x25, 0x96, 0xc1,
    0x35, 0x3f, 0x91, 0xc8, 0x72, 0x8d, 0x7e, 0xce, 0x54, 0xc2, 0x17, 0xc6, 0x49, 0x4f, 0xa8, 0xa0,
    0x65, 0x87, 0x23, 0x2f, 0xc5, 0x81, 0xbd, 0x59, 0x5b, 0x41, 0x61, 0x50, 0xe9, 0xa5, 0xc5, 0xb9,
    0x4b, 0x6a, 0x13, 0xa7, 0xa8, 0x24, 0xa5, 0x0a, 0xbd, 0x4c, 0x61, 0x11, 0x89, 0xce, 0x68, 0x84,
    0x59, 0x28, 0x2e, 0x7a, 0x81, 0xe0, 0x63, 0x2b, 0x6a, 0x66, 0x63, 0x8b, 0x5e, 0xba, 0xcc, 0x2a,
    0x42, 0x79, 0xc3, 0x3f, 0x4a, 0x4a, 0x73, 0xe7, 0xf5, 0xdf, 0x6a, 0x3e, 0x2d, 0x8e, 0xc1, 0x2d,
    0x7e, 0xe7, 0x59, 0x78, 0xc7, 0xc8, 0xf8, 0x6b, 0x4a, 0xb3, 0xbd, 0x44, 0x75, 0xe8, 0xf2, 0x0a,
    0xbd, 0xa8, 0xc6, 0x8b, 0xca, 0x25, 0x10, 0x83, 0xa3, 0x77, 0x3e, 0x58, 0xf9, 0xa2, 0x0a, 0xaa,
    0x17, 0x10, 0x3b, 0x95, 0xfb, 0xde, 0xff, 0x14, 0x1e, 0x5d, 0xd5, 0xf0, 0xe6, 0x74, 0x0d, 0x13,
    0xc9, 0x20, 0x54, 0xc3, 0xee, 0x0f, 0x60, 0x75, 0x22, 0x74, 0x92, 0x96, 0xa1, 0x0b, 0x5f, 0xb3,
    0x57, 0x65, 0xc7, 0x0b, 0x8c, 0xb8, 0xd9, 0x5d, 0x2c, 0xba, 0x06, 0xf3, 0x6d, 0xf7, 0xe2, 0x43,
    0xdc, 0x4b, 0x50, 0xf8, 0x01, 0x21, 0xdc, 0xb0, 0xe6, 0xca, 0xc9, 0xd6, 0xa2, 0xef, 0x00, 0xfd,
    0x55, 0xbe, 0x80, 0xac, 0x39, 0x74, 0x52, 0xfa, 0xf5, 0x0a, 0x74, 0xdb, 0xf2, 0xce, 0xbb, 0x43,
    0x33, 0x58, 0xb7, 0x2c, 0xc4, 0xcd, 0xdd, 0x08, 0xd6, 0x3c, 0x82, 0xbd, 0xd7, 0xe3, 0xf6, 0xdb,
    0x71, 0x60, 0xdf, 0xcd, 0x29, 0x34, 0xbc, 0x3c, 0xc1, 0x29, 0xf0, 0x9a, 0xb7, 0xda, 0xa0, 0xfc,
    0xef, 0x24, 0x87, 0xb0, 0x7c, 0x58, 0x54, 0x47, 0x10, 0xd2, 0x65, 0xc3, 0x70, 0x92, 0x9a, 0x03,
    0xed, 0x54, 0x22, 0xe3, 0xba, 0xfd, 0xec, 0x28, 0xf5, 0x41, 0xf1, 0xeb, 0x16, 0x94, 0x94, 0x86,
    0xb4, 0xd3, 0x96, 0xae, 0x4a, 0x47, 0x44, 0x72, 0x6f, 0x34, 0x38, 0x68, 0x8a, 0x82, 0x80, 0x6f,
    0x9a, 0x9e, 0x84, 0xd4, 0x5d, 0x4a, 0xfd, 0xbb, 0x4e, 0x10, 0xfc, 0xed, 0x5b, 0xba, 0x5f, 0x97,
    0xfd, 0x0e, 0xe8, 0x6f, 0x09, 0x7f, 0x53, 0xf7, 0x83, 0xc2, 0x4c, 0x5a, 0xca, 0x4f, 0xf6, 0xcc,
    0xc0, 0x29, 0x25, 0x1a, 0xc3, 0x4d, 0xdb, 0x2a, 0x4d, 0xf6, 0x95, 0xbb, 0xd3, 0x6e, 0xee, 0x8f,
    0x89, 0x1c, 0x59, 0xc0, 0x8a, 0xae, 0x39, 0xfe, 0x39, 0x38, 0x85, 0xd8, 0x05, 0x90, 0xe3, 0x69,
    0x96, 0xf0, 0xe5, 0xa6, 0xf1, 0xdd, 0xc8, 0xf9, 0x20, 0xac, 0xc5, 0xbc, 0x0a, 0x7f, 0x1c, 0xcd,
    0xf5, 0x4f, 0xff, 0x80, 0xe6, 0x40, 0x4f, 0x7c, 0xaf, 0xd2, 0xef, 0x19, 0x98, 0xa0, 0xc8, 0xc5,
    0x27, 0xd2, 0x2e, 0x9f, 0x57, 0xac, 0x08, 0x31, 0x8d, 0xff, 0x00, 0x47, 0x77, 0x89, 0x14
};
#endif

PyTypeObject *init_QDesignerFormWindowInterface(PyObject *module)
{
    if (SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX].type != nullptr)
        return SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_QDesignerFormWindowInterface_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))));

    _Sbk_QDesignerFormWindowInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDesignerFormWindowInterface",
        "QDesignerFormWindowInterface*",
        &Sbk_QDesignerFormWindowInterface_spec,
        &Shiboken::callCppDestructor< ::QDesignerFormWindowInterface >,
        Sbk_QDesignerFormWindowInterface_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QDesignerFormWindowInterface_TypeF(); // references _Sbk_QDesignerFormWindowInterface_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDesignerFormWindowInterface_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDesignerFormWindowInterface_SignatureBytes, QDesignerFormWindowInterface_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDesignerFormWindowInterface_PropertyStrings);
    SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDesignerFormWindowInterface_PythonToCpp_QDesignerFormWindowInterface_PTR,
        is_QDesignerFormWindowInterface_PythonToCpp_QDesignerFormWindowInterface_PTR_Convertible,
        QDesignerFormWindowInterface_PTR_CppToPython_QDesignerFormWindowInterface);

    Shiboken::Conversions::registerConverterName(converter, "QDesignerFormWindowInterface");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerFormWindowInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerFormWindowInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDesignerFormWindowInterface).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QDesignerFormWindowInterface_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QDesignerFormWindowInterface_TypeF(), &Sbk_QDesignerFormWindowInterfaceSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QDesignerFormWindowInterface_TypeF(), &Sbk_QDesignerFormWindowInterface_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDesignerFormWindowInterface_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'FeatureFlag'.
    const char *FeatureFlag_Initializer[] = {
        "EditFeature",
        "GridFeature",
        "TabOrderFeature",
        "DefaultFeature",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FeatureFlag_InitializerValues[] = {
        uint8_t(QDesignerFormWindowInterface::FeatureFlag::EditFeature),     //  0x01  1
        uint8_t(QDesignerFormWindowInterface::FeatureFlag::GridFeature),     //  0x02  2
        uint8_t(QDesignerFormWindowInterface::FeatureFlag::TabOrderFeature), //  0x04  4
        uint8_t(QDesignerFormWindowInterface::FeatureFlag::DefaultFeature)   //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDesignerFormWindowInterface_TypeF(),
        "2:PySide6.QtDesigner.QDesignerFormWindowInterface.FeatureFlag",
        FeatureFlag_Initializer, FeatureFlag_InitializerValues);
    SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_FeatureFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtDesignerTypeStructs[SBK_QFlags_QDesignerFormWindowInterface_FeatureFlag_IDX].type =
        EType;
    // Register converter for enum 'QDesignerFormWindowInterface::FeatureFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDesignerFormWindowInterface_FeatureFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDesignerFormWindowInterface_FeatureFlag,
            is_Enum_PythonToCpp_QDesignerFormWindowInterface_FeatureFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDesignerFormWindowInterface::FeatureFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "FeatureFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QDesignerFormWindowInterface_FeatureFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QDesignerFormWindowInterface_FeatureFlag,
            is_Enum_PythonToCpp_QDesignerFormWindowInterface_FeatureFlag_Convertible);
        // Register converter for flag 'QFlags<QDesignerFormWindowInterface::FeatureFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QDesignerFormWindowInterface::FeatureFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QDesignerFormWindowInterface::Feature");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'FeatureFlag' enum/flags.

    // Initialization of enum 'ResourceFileSaveMode'.
    const char *ResourceFileSaveMode_Initializer[] = {
        "SaveAllResourceFiles",
        "SaveOnlyUsedResourceFiles",
        "DontSaveResourceFiles",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ResourceFileSaveMode_InitializerValues[] = {
        uint8_t(QDesignerFormWindowInterface::ResourceFileSaveMode::SaveAllResourceFiles),      //  0x00  0
        uint8_t(QDesignerFormWindowInterface::ResourceFileSaveMode::SaveOnlyUsedResourceFiles), //  0x01  1
        uint8_t(QDesignerFormWindowInterface::ResourceFileSaveMode::DontSaveResourceFiles)      //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDesignerFormWindowInterface_TypeF(),
        "2:PySide6.QtDesigner.QDesignerFormWindowInterface.ResourceFileSaveMode",
        ResourceFileSaveMode_Initializer, ResourceFileSaveMode_InitializerValues);
    SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_ResourceFileSaveMode_IDX].type = EType;
    // Register converter for enum 'QDesignerFormWindowInterface::ResourceFileSaveMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDesignerFormWindowInterface_ResourceFileSaveMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDesignerFormWindowInterface_ResourceFileSaveMode,
            is_Enum_PythonToCpp_QDesignerFormWindowInterface_ResourceFileSaveMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDesignerFormWindowInterface::ResourceFileSaveMode");
        Shiboken::Conversions::registerConverterAlias(converter, "ResourceFileSaveMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ResourceFileSaveMode' enum.

    PySide::Signal::registerSignals(pyType, &::QDesignerFormWindowInterface::staticMetaObject);
    qRegisterMetaType< ::QDesignerFormWindowInterface::FeatureFlag >("QDesignerFormWindowInterface::FeatureFlag");
    qRegisterMetaType< ::QDesignerFormWindowInterface::ResourceFileSaveMode >("QDesignerFormWindowInterface::ResourceFileSaveMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QDesignerFormWindowInterface::staticMetaObject, sizeof(::QDesignerFormWindowInterface));

    return pyType;
}
