// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdesigner_python.h"

// main header
#include "qdesignerformwindowmanagerinterface_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtDesigner/abstractdnditem.h>
#include <QtDesigner/abstractformeditor.h>
#include <QtDesigner/abstractformwindow.h>
#include <QtDesigner/abstractformwindowmanager.h>
#include <QtGui/qaction.h>
#include <QtGui/qactiongroup.h>
#include <QtGui/qpixmap.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDesignerFormWindowManagerInterfaceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QDesignerFormWindowManagerInterfaceWrapper::QDesignerFormWindowManagerInterfaceWrapper(::QObject * parent) : QDesignerFormWindowManagerInterface(parent)
{
}

::QAction * QDesignerFormWindowManagerInterfaceWrapper::action(::QDesignerFormWindowManagerInterface::Action action) const
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.action");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "action";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.action");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_Action_IDX])))->converter, &action)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_Action_IDX])))->converter, &action)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowManagerInterface", funcName, Shiboken::SbkType< QAction >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QAction *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QActionGroup * QDesignerFormWindowManagerInterfaceWrapper::actionGroup(::QDesignerFormWindowManagerInterface::ActionGroup actionGroup) const
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.actionGroup");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "actionGroup";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.actionGroup");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_ActionGroup_IDX])))->converter, &actionGroup)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_ActionGroup_IDX])))->converter, &actionGroup)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QActionGroup_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowManagerInterface", funcName, Shiboken::SbkType< QActionGroup >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QActionGroup *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QDesignerFormWindowInterface * QDesignerFormWindowManagerInterfaceWrapper::activeFormWindow() const
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.activeFormWindow");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "activeFormWindow";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.activeFormWindow");
        return nullptr;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowManagerInterface", funcName, Shiboken::SbkType< QDesignerFormWindowInterface >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QDesignerFormWindowInterface *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QDesignerFormWindowManagerInterfaceWrapper::addFormWindow(::QDesignerFormWindowInterface * formWindow)
{
    if (m_PyMethodCache[3]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.addFormWindow");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "addFormWindow";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.addFormWindow");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), formWindow)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), formWindow)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return;
    }
}

void QDesignerFormWindowManagerInterfaceWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return;
    }
}

void QDesignerFormWindowManagerInterfaceWrapper::closeAllPreviews()
{
    if (m_PyMethodCache[5]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.closeAllPreviews");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "closeAllPreviews";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.closeAllPreviews");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return;
    }
}

void QDesignerFormWindowManagerInterfaceWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return;
    }
}

::QDesignerFormEditorInterface * QDesignerFormWindowManagerInterfaceWrapper::core() const
{
    if (m_PyMethodCache[7]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.core");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "core";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.core");
        return nullptr;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormEditorInterface_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowManagerInterface", funcName, Shiboken::SbkType< QDesignerFormEditorInterface >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QDesignerFormEditorInterface *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QDesignerFormWindowInterface * QDesignerFormWindowManagerInterfaceWrapper::createFormWindow(::QWidget * parentWidget, ::QFlags<Qt::WindowType> flags)
{
    if (m_PyMethodCache[8]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.createFormWindow");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createFormWindow";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.createFormWindow");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), parentWidget),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, &flags)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), parentWidget),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, &flags)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowManagerInterface", funcName, Shiboken::SbkType< QDesignerFormWindowInterface >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QDesignerFormWindowInterface *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPixmap QDesignerFormWindowManagerInterfaceWrapper::createPreviewPixmap() const
{
    if (m_PyMethodCache[9]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.createPreviewPixmap");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createPreviewPixmap";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.createPreviewPixmap");
        return {};
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowManagerInterface", funcName, Shiboken::SbkType< QPixmap >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QPixmap cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QDesignerFormWindowManagerInterfaceWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[10]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return;
    }
}

void QDesignerFormWindowManagerInterfaceWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[11]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return;
    }
}

void QDesignerFormWindowManagerInterfaceWrapper::dragItems(const ::QList<QDesignerDnDItemInterface*> & item_list)
{
    if (m_PyMethodCache[12]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.dragItems");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragItems";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.dragItems");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtDesignerTypeConverters[SBK_QtDesigner_QList_QDesignerDnDItemInterfacePTR_IDX], &item_list)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtDesignerTypeConverters[SBK_QtDesigner_QList_QDesignerDnDItemInterfacePTR_IDX], &item_list)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return;
    }
}

bool QDesignerFormWindowManagerInterfaceWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[13])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowManagerInterface", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QDesignerFormWindowManagerInterfaceWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[14])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowManagerInterface", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QDesignerFormWindowInterface * QDesignerFormWindowManagerInterfaceWrapper::formWindow(int index) const
{
    if (m_PyMethodCache[15]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.formWindow");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "formWindow";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[15] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.formWindow");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &index)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        index
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowManagerInterface", funcName, Shiboken::SbkType< QDesignerFormWindowInterface >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QDesignerFormWindowInterface *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QDesignerFormWindowManagerInterfaceWrapper::formWindowCount() const
{
    if (m_PyMethodCache[16]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.formWindowCount");
        return 0;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "formWindowCount";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[16] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.formWindowCount");
        return 0;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowManagerInterface", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QDesignerFormWindowManagerInterfaceWrapper::removeFormWindow(::QDesignerFormWindowInterface * formWindow)
{
    if (m_PyMethodCache[17]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.removeFormWindow");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "removeFormWindow";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[17] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.removeFormWindow");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), formWindow)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), formWindow)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return;
    }
}

void QDesignerFormWindowManagerInterfaceWrapper::setActiveFormWindow(::QDesignerFormWindowInterface * formWindow)
{
    if (m_PyMethodCache[18]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.setActiveFormWindow");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setActiveFormWindow";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[18] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.setActiveFormWindow");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), formWindow)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), formWindow)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return;
    }
}

void QDesignerFormWindowManagerInterfaceWrapper::showPluginDialog()
{
    if (m_PyMethodCache[19]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.showPluginDialog");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "showPluginDialog";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[19] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.showPluginDialog");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return;
    }
}

void QDesignerFormWindowManagerInterfaceWrapper::showPreview()
{
    if (m_PyMethodCache[20]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.showPreview");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "showPreview";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[20] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.showPreview");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return;
    }
}

void QDesignerFormWindowManagerInterfaceWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[21]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[21] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerFormWindowManagerInterface", funcName);
        return;
    }
}

const QMetaObject *QDesignerFormWindowManagerInterfaceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QDesignerFormWindowManagerInterface::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QDesignerFormWindowManagerInterfaceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QDesignerFormWindowManagerInterface::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QDesignerFormWindowManagerInterfaceWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QDesignerFormWindowManagerInterfaceWrapper *>(this));
    return QDesignerFormWindowManagerInterface::qt_metacast(_clname);
}

QDesignerFormWindowManagerInterfaceWrapper::~QDesignerFormWindowManagerInterfaceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDesignerFormWindowManagerInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QDesignerFormWindowManagerInterface");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDesignerFormWindowManagerInterface >()))
        return -1;

    QDesignerFormWindowManagerInterfaceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QDesignerFormWindowManagerInterface", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDesignerFormWindowManagerInterface::QDesignerFormWindowManagerInterface(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QDesignerFormWindowManagerInterface(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QDesignerFormWindowManagerInterface(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QDesignerFormWindowManagerInterface(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QDesignerFormWindowManagerInterfaceWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QDesignerFormWindowManagerInterfaceWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QDesignerFormWindowManagerInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_action(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowManagerInterface::action(QDesignerFormWindowManagerInterface::Action)const->QAction*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_Action_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // action(QDesignerFormWindowManagerInterface::Action)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "action", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);

    // Call function/method
    {
        ::QDesignerFormWindowManagerInterface::Action cppArg0 = static_cast< ::QDesignerFormWindowManagerInterface::Action>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // action(QDesignerFormWindowManagerInterface::Action)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.action");
                return {};
            }
            QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->action(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionAdjustSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionAdjustSize()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionAdjustSize();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionBreakLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionBreakLayout()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionBreakLayout();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionCopy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionCopy()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionCopy();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionCut(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionCut()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionCut();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionDelete(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionDelete()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionDelete();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionFormLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionFormLayout()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionFormLayout();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionGridLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionGridLayout()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionGridLayout();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionGroup(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowManagerInterface::actionGroup(QDesignerFormWindowManagerInterface::ActionGroup)const->QActionGroup*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_ActionGroup_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // actionGroup(QDesignerFormWindowManagerInterface::ActionGroup)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "actionGroup", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);

    // Call function/method
    {
        ::QDesignerFormWindowManagerInterface::ActionGroup cppArg0 = static_cast< ::QDesignerFormWindowManagerInterface::ActionGroup>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // actionGroup(QDesignerFormWindowManagerInterface::ActionGroup)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.actionGroup");
                return {};
            }
            QActionGroup * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionGroup(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QActionGroup_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionHorizontalLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionHorizontalLayout()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionHorizontalLayout();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionLower(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionLower()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionLower();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionPaste(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionPaste()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionPaste();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionRaise(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionRaise()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionRaise();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionRedo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionRedo()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionRedo();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionSelectAll(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionSelectAll()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionSelectAll();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionSimplifyLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionSimplifyLayout()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionSimplifyLayout();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionSplitHorizontal(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionSplitHorizontal()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionSplitHorizontal();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionSplitVertical(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionSplitVertical()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionSplitVertical();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionUndo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionUndo()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionUndo();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_actionVerticalLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // actionVerticalLayout()const
        QAction * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->actionVerticalLayout();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_activeFormWindow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activeFormWindow()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.activeFormWindow");
            return {};
        }
        QDesignerFormWindowInterface * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->activeFormWindow();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_addFormWindow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowManagerInterface::addFormWindow(QDesignerFormWindowInterface*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), (pyArg)))) {
        overloadId = 0; // addFormWindow(QDesignerFormWindowInterface*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addFormWindow", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDesignerFormWindowInterface *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addFormWindow(QDesignerFormWindowInterface*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.addFormWindow");
                return {};
            }
            cppSelf->addFormWindow(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_closeAllPreviews(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // closeAllPreviews()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.closeAllPreviews");
            return {};
        }
        cppSelf->closeAllPreviews();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_core(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // core()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.core");
            return {};
        }
        QDesignerFormEditorInterface * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->core();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormEditorInterface_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_createFormWindow(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "createFormWindow", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);

    if (PyArg_ParseTuple(args, "|OO:createFormWindow", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDesignerFormWindowManagerInterface::createFormWindow(QWidget*=,QFlags<Qt::WindowType>=)->QDesignerFormWindowInterface*
    if (numArgs == 0) {
        overloadId = 0; // createFormWindow(QWidget*,QFlags<Qt::WindowType>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // createFormWindow(QWidget*,QFlags<Qt::WindowType>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // createFormWindow(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createFormWindow", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parentWidget = Shiboken::String::createStaticString("parentWidget");
            if (PyDict_Contains(kwds, key_parentWidget) != 0) {
                value = PyDict_GetItem(kwds, key_parentWidget);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parentWidget);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "createFormWindow", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "createFormWindow", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parentWidget);
            }
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "createFormWindow", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "createFormWindow", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "createFormWindow", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::WindowType> cppArg1 = Qt::WindowFlags();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createFormWindow(QWidget*,QFlags<Qt::WindowType>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.createFormWindow");
                return {};
            }
            QDesignerFormWindowInterface * cppResult = cppSelf->createFormWindow(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_createPreviewPixmap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createPreviewPixmap()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.createPreviewPixmap");
            return {};
        }
        QPixmap cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->createPreviewPixmap();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_dragItems(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowManagerInterface::dragItems(QList<QDesignerDnDItemInterface*>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDesignerTypeConverters[SBK_QtDesigner_QList_QDesignerDnDItemInterfacePTR_IDX], (pyArg)))) {
        overloadId = 0; // dragItems(QList<QDesignerDnDItemInterface*>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dragItems", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);

    // Call function/method
    {
        ::QList<QDesignerDnDItemInterface*> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dragItems(QList<QDesignerDnDItemInterface*>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.dragItems");
                return {};
            }
            cppSelf->dragItems(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_formWindow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowManagerInterface::formWindow(int)const->QDesignerFormWindowInterface*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // formWindow(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "formWindow", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // formWindow(int)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.formWindow");
                return {};
            }
            QDesignerFormWindowInterface * cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->formWindow(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_formWindowCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // formWindowCount()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.formWindowCount");
            return {};
        }
        int cppResult = const_cast<const ::QDesignerFormWindowManagerInterface *>(cppSelf)->formWindowCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_removeFormWindow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowManagerInterface::removeFormWindow(QDesignerFormWindowInterface*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), (pyArg)))) {
        overloadId = 0; // removeFormWindow(QDesignerFormWindowInterface*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeFormWindow", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDesignerFormWindowInterface *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeFormWindow(QDesignerFormWindowInterface*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.removeFormWindow");
                return {};
            }
            cppSelf->removeFormWindow(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_setActiveFormWindow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowManagerInterface::setActiveFormWindow(QDesignerFormWindowInterface*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), (pyArg)))) {
        overloadId = 0; // setActiveFormWindow(QDesignerFormWindowInterface*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setActiveFormWindow", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDesignerFormWindowInterface *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActiveFormWindow(QDesignerFormWindowInterface*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.setActiveFormWindow");
                return {};
            }
            cppSelf->setActiveFormWindow(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_showPluginDialog(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // showPluginDialog()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.showPluginDialog");
            return {};
        }
        cppSelf->showPluginDialog();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowManagerInterfaceFunc_showPreview(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // showPreview()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowManagerInterface.showPreview");
            return {};
        }
        cppSelf->showPreview();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QDesignerFormWindowManagerInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDesignerFormWindowManagerInterface_EnumFlagInfo[] = {
    "Action:Enum",
    "ActionGroup:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDesignerFormWindowManagerInterface_methods[] = {
    {"action", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_action), METH_O, nullptr},
    {"actionAdjustSize", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionAdjustSize), METH_NOARGS, nullptr},
    {"actionBreakLayout", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionBreakLayout), METH_NOARGS, nullptr},
    {"actionCopy", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionCopy), METH_NOARGS, nullptr},
    {"actionCut", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionCut), METH_NOARGS, nullptr},
    {"actionDelete", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionDelete), METH_NOARGS, nullptr},
    {"actionFormLayout", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionFormLayout), METH_NOARGS, nullptr},
    {"actionGridLayout", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionGridLayout), METH_NOARGS, nullptr},
    {"actionGroup", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionGroup), METH_O, nullptr},
    {"actionHorizontalLayout", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionHorizontalLayout), METH_NOARGS, nullptr},
    {"actionLower", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionLower), METH_NOARGS, nullptr},
    {"actionPaste", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionPaste), METH_NOARGS, nullptr},
    {"actionRaise", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionRaise), METH_NOARGS, nullptr},
    {"actionRedo", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionRedo), METH_NOARGS, nullptr},
    {"actionSelectAll", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionSelectAll), METH_NOARGS, nullptr},
    {"actionSimplifyLayout", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionSimplifyLayout), METH_NOARGS, nullptr},
    {"actionSplitHorizontal", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionSplitHorizontal), METH_NOARGS, nullptr},
    {"actionSplitVertical", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionSplitVertical), METH_NOARGS, nullptr},
    {"actionUndo", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionUndo), METH_NOARGS, nullptr},
    {"actionVerticalLayout", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_actionVerticalLayout), METH_NOARGS, nullptr},
    {"activeFormWindow", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_activeFormWindow), METH_NOARGS, nullptr},
    {"addFormWindow", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_addFormWindow), METH_O, nullptr},
    {"closeAllPreviews", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_closeAllPreviews), METH_NOARGS, nullptr},
    {"core", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_core), METH_NOARGS, nullptr},
    {"createFormWindow", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_createFormWindow), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"createPreviewPixmap", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_createPreviewPixmap), METH_NOARGS, nullptr},
    {"dragItems", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_dragItems), METH_O, nullptr},
    {"formWindow", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_formWindow), METH_O, nullptr},
    {"formWindowCount", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_formWindowCount), METH_NOARGS, nullptr},
    {"removeFormWindow", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_removeFormWindow), METH_O, nullptr},
    {"setActiveFormWindow", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_setActiveFormWindow), METH_O, nullptr},
    {"showPluginDialog", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_showPluginDialog), METH_NOARGS, nullptr},
    {"showPreview", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowManagerInterfaceFunc_showPreview), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDesignerFormWindowManagerInterface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDesignerFormWindowManagerInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDesignerFormWindowManagerInterfaceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDesignerFormWindowManagerInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDesignerFormWindowManagerInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDesignerFormWindowManagerInterface_Type = nullptr;
static PyTypeObject *Sbk_QDesignerFormWindowManagerInterface_TypeF(void)
{
    return _Sbk_QDesignerFormWindowManagerInterface_Type;
}

static PyType_Slot Sbk_QDesignerFormWindowManagerInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDesignerFormWindowManagerInterface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDesignerFormWindowManagerInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDesignerFormWindowManagerInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDesignerFormWindowManagerInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDesignerFormWindowManagerInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDesignerFormWindowManagerInterface_spec = {
    "2:PySide6.QtDesigner.QDesignerFormWindowManagerInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDesignerFormWindowManagerInterface_slots
};

} //extern "C"

static void *Sbk_QDesignerFormWindowManagerInterface_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QDesignerFormWindowManagerInterface *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDesignerFormWindowManagerInterface_Action(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDesignerFormWindowManagerInterface::Action>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDesignerFormWindowManagerInterface::Action *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDesignerFormWindowManagerInterface_Action_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_Action_IDX])))
        return Enum_PythonToCpp_QDesignerFormWindowManagerInterface_Action;
    return {};
}

static PyObject *QDesignerFormWindowManagerInterface_Action_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDesignerFormWindowManagerInterface::Action>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDesignerFormWindowManagerInterface::Action *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_Action_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QDesignerFormWindowManagerInterface_ActionGroup(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDesignerFormWindowManagerInterface::ActionGroup>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDesignerFormWindowManagerInterface::ActionGroup *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDesignerFormWindowManagerInterface_ActionGroup_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_ActionGroup_IDX])))
        return Enum_PythonToCpp_QDesignerFormWindowManagerInterface_ActionGroup;
    return {};
}

static PyObject *QDesignerFormWindowManagerInterface_ActionGroup_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDesignerFormWindowManagerInterface::ActionGroup>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDesignerFormWindowManagerInterface::ActionGroup *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_ActionGroup_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDesignerFormWindowManagerInterface_PythonToCpp_QDesignerFormWindowManagerInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDesignerFormWindowManagerInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDesignerFormWindowManagerInterface_PythonToCpp_QDesignerFormWindowManagerInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDesignerFormWindowManagerInterface_TypeF()))
        return QDesignerFormWindowManagerInterface_PythonToCpp_QDesignerFormWindowManagerInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDesignerFormWindowManagerInterface_PTR_CppToPython_QDesignerFormWindowManagerInterface(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QDesignerFormWindowManagerInterface *>(const_cast<void *>(cppIn)), Sbk_QDesignerFormWindowManagerInterface_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDesignerFormWindowManagerInterface_SignatureStrings[] = {
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.action(self,action:PySide6.QtDesigner.QDesignerFormWindowManagerInterface.Action)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionAdjustSize(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionBreakLayout(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionCopy(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionCut(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionDelete(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionFormLayout(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionGridLayout(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionGroup(self,actionGroup:PySide6.QtDesigner.QDesignerFormWindowManagerInterface.ActionGroup)->PySide6.QtGui.QActionGroup",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionHorizontalLayout(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionLower(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionPaste(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionRaise(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionRedo(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionSelectAll(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionSimplifyLayout(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionSplitHorizontal(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionSplitVertical(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionUndo(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.actionVerticalLayout(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.activeFormWindow(self)->PySide6.QtDesigner.QDesignerFormWindowInterface",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.addFormWindow(self,formWindow:PySide6.QtDesigner.QDesignerFormWindowInterface)",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.closeAllPreviews(self)",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.core(self)->PySide6.QtDesigner.QDesignerFormEditorInterface",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.createFormWindow(self,parentWidget:PySide6.QtWidgets.QWidget=nullptr,flags:PySide6.QtCore.Qt.WindowType=Qt.WindowFlags())->PySide6.QtDesigner.QDesignerFormWindowInterface",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.createPreviewPixmap(self)->PySide6.QtGui.QPixmap",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.dragItems(self,item_list:QList[PySide6.QtDesigner.QDesignerDnDItemInterface])",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.formWindow(self,index:int)->PySide6.QtDesigner.QDesignerFormWindowInterface",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.formWindowCount(self)->int",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.removeFormWindow(self,formWindow:PySide6.QtDesigner.QDesignerFormWindowInterface)",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.setActiveFormWindow(self,formWindow:PySide6.QtDesigner.QDesignerFormWindowInterface)",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.showPluginDialog(self)",
    "PySide6.QtDesigner.QDesignerFormWindowManagerInterface.showPreview(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QDesignerFormWindowManagerInterface_SignatureByteSize = 480;
static constexpr uint8_t QDesignerFormWindowManagerInterface_SignatureBytes[480] = {
    0x78, 0xda, 0xc5, 0x56, 0x4d, 0x4f, 0xdb, 0x40, 0x10, 0xbd, 0xf7, 0x97, 0x10, 0x29, 0xf5, 0xb1,
    0x07, 0x4b, 0x54, 0x0a, 0x71, 0xa1, 0x48, 0xa9, 0x6a, 0x93, 0xb6, 0x1c, 0x2a, 0x84, 0xb6, 0xde,
    0xb1, 0x3b, 0x74, 0xbd, 0x6b, 0xed, 0x8e, 0x09, 0xe6, 0xd7, 0x77, 0xe3, 0x4d, 0x1c, 0x94, 0x00,
    0x6a, 0x6d, 0x4d, 0xb8, 0x58, 0xe3, 0xfd, 0x78, 0xef, 0xed, 0x7c, 0x69, 0xd2, 0x76, 0x89, 0x12,
    0x3e, 0x44, 0x19, 0x25, 0xe0, 0xb0, 0xd4, 0x60, 0xa3, 0x6c, 0x6b, 0x9d, 0x1b, 0x5b, 0x5d, 0xa3,
    0x96, 0x66, 0xf5, 0x45, 0x68, 0x51, 0x82, 0xbd, 0xd4, 0x04, 0xb6, 0x10, 0x39, 0x9c, 0x38, 0x50,
    0xc5, 0xb4, 0x16, 0x16, 0x34, 0xc5, 0x69, 0x0f, 0x31, 0x37, 0x16, 0xa2, 0xec, 0xeb, 0xaf, 0x3b,
    0xc8, 0xe9, 0x54, 0x37, 0x4a, 0xd5, 0x64, 0x27, 0xef, 0xd2, 0x41, 0x14, 0x91, 0xc8, 0x09, 0x8d,
    0x0e, 0x4c, 0xc1, 0x8e, 0x07, 0x22, 0xcd, 0xba, 0xdb, 0x93, 0xf7, 0x1f, 0x77, 0xf7, 0x2f, 0x1a,
    0x8c, 0xb2, 0xb0, 0x3e, 0x4e, 0xdf, 0x4c, 0xde, 0x35, 0x8e, 0x96, 0xf8, 0x18, 0x7c, 0xc2, 0x43,
    0x72, 0x66, 0x41, 0xfc, 0x59, 0x88, 0xd6, 0x34, 0xc4, 0xc8, 0x32, 0x37, 0x75, 0xcb, 0x09, 0xcf,
    0x2a, 0x3e, 0x01, 0x05, 0xc4, 0x19, 0x83, 0xf5, 0x01, 0xf6, 0x10, 0x5c, 0x58, 0x94, 0x47, 0x20,
    0x31, 0x4d, 0xfd, 0xb4, 0xae, 0xba, 0x85, 0x71, 0xc5, 0xd5, 0x41, 0xbc, 0x24, 0xb7, 0xdb, 0x1c,
    0xa7, 0xf9, 0xb3, 0xb1, 0xf8, 0x68, 0x34, 0x09, 0xc5, 0xee, 0x9e, 0x85, 0x59, 0x81, 0x65, 0xc4,
    0x4f, 0x85, 0x63, 0x4d, 0xd4, 0x2b, 0x81, 0x8e, 0x15, 0x1f, 0xa4, 0x61, 0x84, 0x5f, 0xfa, 0x42,
    0xce, 0x69, 0xa6, 0x14, 0x27, 0x07, 0x56, 0xb5, 0xc2, 0xa2, 0x65, 0xcf, 0xa5, 0xa5, 0xa7, 0xa1,
    0x5d, 0xee, 0x72, 0x33, 0xfd, 0x00, 0x4b, 0x98, 0xb3, 0xf2, 0x7c, 0xd7, 0xac, 0xd1, 0xdf, 0xbe,
    0x80, 0x39, 0x32, 0xf7, 0xb0, 0x3b, 0x70, 0x48, 0xf2, 0x1a, 0x5c, 0x8f, 0x33, 0x98, 0x5e, 0xca,
    0x3d, 0xee, 0x69, 0xd1, 0xff, 0xc7, 0xff, 0x29, 0x62, 0xf0, 0x70, 0x95, 0x2b, 0xe3, 0xc0, 0x17,
    0x59, 0x6a, 0xe1, 0x1e, 0x61, 0xe5, 0x82, 0x13, 0x06, 0xa3, 0xf9, 0xb9, 0xef, 0x5f, 0xdd, 0xf8,
    0x49, 0x22, 0x19, 0x3b, 0xda, 0x8d, 0xb9, 0x1f, 0x89, 0x68, 0x3f, 0x8a, 0x9b, 0x89, 0xf4, 0x1a,
    0x65, 0x09, 0x4f, 0xe7, 0xd2, 0xb0, 0xe0, 0xa2, 0x2c, 0x18, 0xdb, 0xd1, 0x74, 0x5a, 0x28, 0x51,
    0xba, 0x83, 0xf9, 0x95, 0xa2, 0x00, 0xf9, 0xad, 0xad, 0xe1, 0xb4, 0xff, 0x3b, 0x5f, 0x9f, 0x3d,
    0x99, 0x1c, 0x2f, 0x51, 0xc2, 0x0b, 0x37, 0x01, 0x4a, 0xf1, 0xa1, 0x12, 0xf5, 0x0b, 0xf5, 0x10,
    0x36, 0x87, 0xf2, 0x48, 0x2b, 0xca, 0x4b, 0x82, 0x2a, 0xe4, 0xc0, 0x14, 0xbd, 0x79, 0xab, 0xd0,
    0x51, 0x9c, 0x2d, 0xfc, 0xf7, 0xe7, 0x6b, 0xa8, 0x89, 0x4e, 0xd6, 0x37, 0x7b, 0xac, 0x9b, 0xc1,
    0x19, 0x54, 0xec, 0x05, 0xd2, 0x9b, 0xf0, 0x10, 0xa3, 0xa6, 0xe3, 0xf9, 0x7b, 0x27, 0x61, 0x6e,
    0x1a, 0xdd, 0xf7, 0x1e, 0xaf, 0x61, 0x28, 0xa2, 0x85, 0xca, 0x1c, 0x74, 0x9a, 0xb7, 0xa8, 0x76,
    0x07, 0x34, 0x7b, 0xae, 0xeb, 0xbd, 0x89, 0x96, 0xdf, 0x66, 0x95, 0xaa, 0xa6, 0x44, 0x9d, 0xa0,
    0x50, 0xa6, 0x1c, 0xd7, 0x79, 0x3a, 0xb4, 0x50, 0x22, 0x1b, 0xa0, 0xbf, 0xfc, 0xf0, 0x84, 0x0a
};
#endif

PyTypeObject *init_QDesignerFormWindowManagerInterface(PyObject *module)
{
    if (SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX].type != nullptr)
        return SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_QDesignerFormWindowManagerInterface_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QDesignerFormWindowManagerInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDesignerFormWindowManagerInterface",
        "QDesignerFormWindowManagerInterface*",
        &Sbk_QDesignerFormWindowManagerInterface_spec,
        &Shiboken::callCppDestructor< QDesignerFormWindowManagerInterface >,
        Sbk_QDesignerFormWindowManagerInterface_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDesignerFormWindowManagerInterface_TypeF(); // references _Sbk_QDesignerFormWindowManagerInterface_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDesignerFormWindowManagerInterface_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDesignerFormWindowManagerInterface_SignatureBytes, QDesignerFormWindowManagerInterface_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDesignerFormWindowManagerInterface_PropertyStrings);
    SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDesignerFormWindowManagerInterface_PythonToCpp_QDesignerFormWindowManagerInterface_PTR,
        is_QDesignerFormWindowManagerInterface_PythonToCpp_QDesignerFormWindowManagerInterface_PTR_Convertible,
        QDesignerFormWindowManagerInterface_PTR_CppToPython_QDesignerFormWindowManagerInterface);

    Shiboken::Conversions::registerConverterName(converter, "QDesignerFormWindowManagerInterface");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerFormWindowManagerInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerFormWindowManagerInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDesignerFormWindowManagerInterface).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QDesignerFormWindowManagerInterfaceWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QDesignerFormWindowManagerInterface_TypeF(), &Sbk_QDesignerFormWindowManagerInterface_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDesignerFormWindowManagerInterface_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Action'.
    const char *Action_Initializer[] = {
        "CutAction",
        "CopyAction",
        "PasteAction",
        "DeleteAction",
        "SelectAllAction",
        "LowerAction",
        "RaiseAction",
        "UndoAction",
        "RedoAction",
        "HorizontalLayoutAction",
        "VerticalLayoutAction",
        "SplitHorizontalAction",
        "SplitVerticalAction",
        "GridLayoutAction",
        "FormLayoutAction",
        "BreakLayoutAction",
        "AdjustSizeAction",
        "SimplifyLayoutAction",
        "DefaultPreviewAction",
        "FormWindowSettingsDialogAction",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Action_InitializerValues[] = {
        uint16_t(QDesignerFormWindowManagerInterface::Action::CutAction),                     //  0x0064  100
        uint16_t(QDesignerFormWindowManagerInterface::Action::CopyAction),                    //  0x0065  101
        uint16_t(QDesignerFormWindowManagerInterface::Action::PasteAction),                   //  0x0066  102
        uint16_t(QDesignerFormWindowManagerInterface::Action::DeleteAction),                  //  0x0067  103
        uint16_t(QDesignerFormWindowManagerInterface::Action::SelectAllAction),               //  0x0068  104
        uint16_t(QDesignerFormWindowManagerInterface::Action::LowerAction),                   //  0x00c8  200
        uint16_t(QDesignerFormWindowManagerInterface::Action::RaiseAction),                   //  0x00c9  201
        uint16_t(QDesignerFormWindowManagerInterface::Action::UndoAction),                    //  0x012c  300
        uint16_t(QDesignerFormWindowManagerInterface::Action::RedoAction),                    //  0x012d  301
        uint16_t(QDesignerFormWindowManagerInterface::Action::HorizontalLayoutAction),        //  0x0190  400
        uint16_t(QDesignerFormWindowManagerInterface::Action::VerticalLayoutAction),          //  0x0191  401
        uint16_t(QDesignerFormWindowManagerInterface::Action::SplitHorizontalAction),         //  0x0192  402
        uint16_t(QDesignerFormWindowManagerInterface::Action::SplitVerticalAction),           //  0x0193  403
        uint16_t(QDesignerFormWindowManagerInterface::Action::GridLayoutAction),              //  0x0194  404
        uint16_t(QDesignerFormWindowManagerInterface::Action::FormLayoutAction),              //  0x0195  405
        uint16_t(QDesignerFormWindowManagerInterface::Action::BreakLayoutAction),             //  0x0196  406
        uint16_t(QDesignerFormWindowManagerInterface::Action::AdjustSizeAction),              //  0x0197  407
        uint16_t(QDesignerFormWindowManagerInterface::Action::SimplifyLayoutAction),          //  0x0198  408
        uint16_t(QDesignerFormWindowManagerInterface::Action::DefaultPreviewAction),          //  0x01f4  500
        uint16_t(QDesignerFormWindowManagerInterface::Action::FormWindowSettingsDialogAction) //  0x0258  600
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDesignerFormWindowManagerInterface_TypeF(),
        "2:PySide6.QtDesigner.QDesignerFormWindowManagerInterface.Action",
        Action_Initializer, Action_InitializerValues);
    SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_Action_IDX].type = EType;
    // Register converter for enum 'QDesignerFormWindowManagerInterface::Action'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDesignerFormWindowManagerInterface_Action_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDesignerFormWindowManagerInterface_Action,
            is_Enum_PythonToCpp_QDesignerFormWindowManagerInterface_Action_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDesignerFormWindowManagerInterface::Action");
        Shiboken::Conversions::registerConverterAlias(converter, "Action");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Action' enum.

    // Initialization of enum 'ActionGroup'.
    const char *ActionGroup_Initializer[] = {
        "StyledPreviewActionGroup",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ActionGroup_InitializerValues[] = {
        uint8_t(QDesignerFormWindowManagerInterface::ActionGroup::StyledPreviewActionGroup) //  0x64  100
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDesignerFormWindowManagerInterface_TypeF(),
        "2:PySide6.QtDesigner.QDesignerFormWindowManagerInterface.ActionGroup",
        ActionGroup_Initializer, ActionGroup_InitializerValues);
    SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowManagerInterface_ActionGroup_IDX].type = EType;
    // Register converter for enum 'QDesignerFormWindowManagerInterface::ActionGroup'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDesignerFormWindowManagerInterface_ActionGroup_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDesignerFormWindowManagerInterface_ActionGroup,
            is_Enum_PythonToCpp_QDesignerFormWindowManagerInterface_ActionGroup_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDesignerFormWindowManagerInterface::ActionGroup");
        Shiboken::Conversions::registerConverterAlias(converter, "ActionGroup");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ActionGroup' enum.

    PySide::Signal::registerSignals(pyType, &::QDesignerFormWindowManagerInterface::staticMetaObject);
    qRegisterMetaType< ::QDesignerFormWindowManagerInterface::Action >("QDesignerFormWindowManagerInterface::Action");
    qRegisterMetaType< ::QDesignerFormWindowManagerInterface::ActionGroup >("QDesignerFormWindowManagerInterface::ActionGroup");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QDesignerFormWindowManagerInterface::staticMetaObject, sizeof(QDesignerFormWindowManagerInterfaceWrapper));

    return pyType;
}
