// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdesigner_python.h"

// main header
#include "qdesignertaskmenuextension_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qaction.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDesignerTaskMenuExtensionWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QDesignerTaskMenuExtensionWrapper::QDesignerTaskMenuExtensionWrapper() noexcept
{
}

::QAction * QDesignerTaskMenuExtensionWrapper::preferredEditAction() const
{
    if (m_PyMethodCache[0])
        return this->::QDesignerTaskMenuExtension::preferredEditAction();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "preferredEditAction";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QDesignerTaskMenuExtension::preferredEditAction();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerTaskMenuExtension", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerTaskMenuExtension", funcName, Shiboken::SbkType< QAction >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QAction *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QList<QAction*> QDesignerTaskMenuExtensionWrapper::taskActions() const
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerTaskMenuExtension.taskActions");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "taskActions";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerTaskMenuExtension.taskActions");
        return {};
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDesignerTaskMenuExtension", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDesignerTypeConverters[SBK_QtDesigner_QList_QActionPTR_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerTaskMenuExtension", funcName, "list", Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QList<QAction*> cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QDesignerTaskMenuExtensionWrapper::~QDesignerTaskMenuExtensionWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDesignerTaskMenuExtension_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerTaskMenuExtension_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QDesignerTaskMenuExtension");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDesignerTaskMenuExtension >()))
        return -1;

    QDesignerTaskMenuExtensionWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerTaskMenuExtension_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QDesignerTaskMenuExtension()
        cptr = new QDesignerTaskMenuExtensionWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QDesignerTaskMenuExtension >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDesignerTaskMenuExtensionFunc_preferredEditAction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerTaskMenuExtension *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerTaskMenuExtension_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // preferredEditAction()const
        QAction * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QDesignerTaskMenuExtension *>(cppSelf)->::QDesignerTaskMenuExtension::preferredEditAction()
            : const_cast<const ::QDesignerTaskMenuExtension *>(cppSelf)->preferredEditAction();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerTaskMenuExtensionFunc_taskActions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerTaskMenuExtension *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerTaskMenuExtension_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // taskActions()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerTaskMenuExtension.taskActions");
            return {};
        }
        QList<QAction*> cppResult = const_cast<const ::QDesignerTaskMenuExtension *>(cppSelf)->taskActions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtDesignerTypeConverters[SBK_QtDesigner_QList_QActionPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDesignerTaskMenuExtension_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDesignerTaskMenuExtension_methods[] = {
    {"preferredEditAction", reinterpret_cast<PyCFunction>(Sbk_QDesignerTaskMenuExtensionFunc_preferredEditAction), METH_NOARGS, nullptr},
    {"taskActions", reinterpret_cast<PyCFunction>(Sbk_QDesignerTaskMenuExtensionFunc_taskActions), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDesignerTaskMenuExtension_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDesignerTaskMenuExtension *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerTaskMenuExtension_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDesignerTaskMenuExtensionWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDesignerTaskMenuExtension_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDesignerTaskMenuExtension_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDesignerTaskMenuExtension_Type = nullptr;
static PyTypeObject *Sbk_QDesignerTaskMenuExtension_TypeF(void)
{
    return _Sbk_QDesignerTaskMenuExtension_Type;
}

static PyType_Slot Sbk_QDesignerTaskMenuExtension_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDesignerTaskMenuExtension_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDesignerTaskMenuExtension_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDesignerTaskMenuExtension_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDesignerTaskMenuExtension_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDesignerTaskMenuExtension_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDesignerTaskMenuExtension_spec = {
    "2:PySide6.QtDesigner.QDesignerTaskMenuExtension",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDesignerTaskMenuExtension_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDesignerTaskMenuExtension_PythonToCpp_QDesignerTaskMenuExtension_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDesignerTaskMenuExtension_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDesignerTaskMenuExtension_PythonToCpp_QDesignerTaskMenuExtension_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDesignerTaskMenuExtension_TypeF()))
        return QDesignerTaskMenuExtension_PythonToCpp_QDesignerTaskMenuExtension_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDesignerTaskMenuExtension_PTR_CppToPython_QDesignerTaskMenuExtension(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QDesignerTaskMenuExtension *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QDesignerTaskMenuExtension_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDesignerTaskMenuExtension_SignatureStrings[] = {
    "PySide6.QtDesigner.QDesignerTaskMenuExtension(self)",
    "PySide6.QtDesigner.QDesignerTaskMenuExtension.preferredEditAction(self)->PySide6.QtGui.QAction",
    "PySide6.QtDesigner.QDesignerTaskMenuExtension.taskActions(self)->QList[PySide6.QtGui.QAction]",
    nullptr}; // Sentinel
#else
static constexpr size_t QDesignerTaskMenuExtension_SignatureByteSize = 108;
static constexpr uint8_t QDesignerTaskMenuExtension_SignatureBytes[108] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x49, 0x2d, 0xce,
    0x4c, 0xcf, 0x4b, 0x2d, 0xd2, 0x0b, 0x84, 0xb1, 0x42, 0x12, 0x8b, 0xb3, 0x7d, 0x53, 0xf3, 0x4a,
    0x5d, 0x2b, 0x4a, 0x52, 0xf3, 0x8a, 0x33, 0xf3, 0xf3, 0x34, 0x8a, 0x53, 0x73, 0xd2, 0x34, 0xb9,
    0x02, 0x48, 0xd1, 0xa3, 0x57, 0x50, 0x94, 0x9a, 0x96, 0x5a, 0x54, 0x94, 0x9a, 0xe2, 0x9a, 0x92,
    0x59, 0xe2, 0x98, 0x5c, 0x02, 0x37, 0x47, 0xd7, 0x0e, 0x61, 0x90, 0x7b, 0x69, 0xa6, 0x5e, 0x20,
    0x44, 0x92, 0x44, 0xe3, 0x4b, 0x80, 0x22, 0x10, 0x8d, 0xc5, 0x30, 0x63, 0x03, 0x7d, 0x32, 0x8b,
    0x4b, 0xa2, 0xb1, 0x1a, 0x1e, 0xcb, 0x05, 0x00, 0x44, 0x45, 0x58, 0xb7
};
#endif

PyTypeObject *init_QDesignerTaskMenuExtension(PyObject *module)
{
    if (SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerTaskMenuExtension_IDX].type != nullptr)
        return SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerTaskMenuExtension_IDX].type;

    Shiboken::AutoDecRef Sbk_QDesignerTaskMenuExtension_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDesignerTaskMenuExtension_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDesignerTaskMenuExtension",
        "QDesignerTaskMenuExtension*",
        &Sbk_QDesignerTaskMenuExtension_spec,
        &Shiboken::callCppDestructor< QDesignerTaskMenuExtension >,
        Sbk_QDesignerTaskMenuExtension_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDesignerTaskMenuExtension_TypeF(); // references _Sbk_QDesignerTaskMenuExtension_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDesignerTaskMenuExtension_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDesignerTaskMenuExtension_SignatureBytes, QDesignerTaskMenuExtension_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDesignerTaskMenuExtension_PropertyStrings);
    SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerTaskMenuExtension_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDesignerTaskMenuExtension_PythonToCpp_QDesignerTaskMenuExtension_PTR,
        is_QDesignerTaskMenuExtension_PythonToCpp_QDesignerTaskMenuExtension_PTR_Convertible,
        QDesignerTaskMenuExtension_PTR_CppToPython_QDesignerTaskMenuExtension);

    Shiboken::Conversions::registerConverterName(converter, "QDesignerTaskMenuExtension");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerTaskMenuExtension*");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerTaskMenuExtension&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDesignerTaskMenuExtension).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QDesignerTaskMenuExtensionWrapper).name());

    qRegisterMetaType< ::QDesignerTaskMenuExtension *>();

    return pyType;
}
