// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qbardataproxy_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtGraphs/qabstractdataproxy.h>
#include <QtGraphs/qbar3dseries.h>
#include <QtGraphs/qbardataitem.h>
#include <QtGraphs/qbardataproxy.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QBarDataProxyWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QBarDataProxyWrapper::QBarDataProxyWrapper(::QObject * parent) : QBarDataProxy(parent)
{
}

void QBarDataProxyWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarDataProxy", funcName);
        return;
    }
}

void QBarDataProxyWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarDataProxy", funcName);
        return;
    }
}

void QBarDataProxyWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarDataProxy", funcName);
        return;
    }
}

void QBarDataProxyWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarDataProxy", funcName);
        return;
    }
}

bool QBarDataProxyWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarDataProxy", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QBarDataProxy", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QBarDataProxyWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarDataProxy", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QBarDataProxy", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QBarDataProxyWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarDataProxy", funcName);
        return;
    }
}

const QMetaObject *QBarDataProxyWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QBarDataProxy::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QBarDataProxyWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QBarDataProxy::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QBarDataProxyWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QBarDataProxyWrapper *>(this));
    return QBarDataProxy::qt_metacast(_clname);
}

QBarDataProxyWrapper::~QBarDataProxyWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBarDataProxy_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBarDataProxy >()))
        return -1;

    QBarDataProxyWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QBarDataProxy", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBarDataProxy::QBarDataProxy(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QBarDataProxy(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QBarDataProxy(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QBarDataProxy(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QBarDataProxyWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QBarDataProxyWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QBarDataProxy >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QBarDataProxyFunc_addRow(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addRow", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBarDataProxy::addRow(QList<QBarDataItem>)->qsizetype
    // 1: QBarDataProxy::addRow(QList<QBarDataItem>,QString)->qsizetype
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QBarDataItem_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addRow(QList<QBarDataItem>)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 1; // addRow(QList<QBarDataItem>,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addRow", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addRow(QList<QBarDataItem> row)
        {
            ::QList<QBarDataItem> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addRow(QList<QBarDataItem>)
                qsizetype cppResult = cppSelf->addRow(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            }
            break;
        }
        case 1: // addRow(QList<QBarDataItem> row, QString label)
        {
            ::QList<QBarDataItem> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addRow(QList<QBarDataItem>,QString)
                qsizetype cppResult = cppSelf->addRow(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarDataProxyFunc_addRows(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addRows", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBarDataProxy::addRows(QList<QList<QBarDataItem>>)->qsizetype
    // 1: QBarDataProxy::addRows(QList<QList<QBarDataItem>>,QStringList)->qsizetype
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QList_QBarDataItem_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addRows(QList<QList<QBarDataItem>>)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1])))) {
            overloadId = 1; // addRows(QList<QList<QBarDataItem>>,QStringList)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addRows", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addRows(QList<QList<QBarDataItem>> rows)
        {
            ::QList<QList<QBarDataItem>> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addRows(QList<QList<QBarDataItem>>)
                qsizetype cppResult = cppSelf->addRows(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            }
            break;
        }
        case 1: // addRows(QList<QList<QBarDataItem>> rows, QStringList labels)
        {
            ::QList<QList<QBarDataItem>> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QStringList cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addRows(QList<QList<QBarDataItem>>,QStringList)
                qsizetype cppResult = cppSelf->addRows(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarDataProxyFunc_colCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // colCount()const
        qsizetype cppResult = const_cast<const ::QBarDataProxy *>(cppSelf)->colCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarDataProxyFunc_insertRow(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertRow", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBarDataProxy::insertRow(qsizetype,QList<QBarDataItem>)
    // 1: QBarDataProxy::insertRow(qsizetype,QList<QBarDataItem>,QString)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QBarDataItem_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // insertRow(qsizetype,QList<QBarDataItem>)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 1; // insertRow(qsizetype,QList<QBarDataItem>,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertRow", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // insertRow(qsizetype rowIndex, QList<QBarDataItem> row)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QList<QBarDataItem> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insertRow(qsizetype,QList<QBarDataItem>)
                cppSelf->insertRow(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // insertRow(qsizetype rowIndex, QList<QBarDataItem> row, QString label)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QList<QBarDataItem> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insertRow(qsizetype,QList<QBarDataItem>,QString)
                cppSelf->insertRow(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarDataProxyFunc_insertRows(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertRows", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBarDataProxy::insertRows(qsizetype,QList<QList<QBarDataItem>>)
    // 1: QBarDataProxy::insertRows(qsizetype,QList<QList<QBarDataItem>>,QStringList)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QList_QBarDataItem_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // insertRows(qsizetype,QList<QList<QBarDataItem>>)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[2])))) {
            overloadId = 1; // insertRows(qsizetype,QList<QList<QBarDataItem>>,QStringList)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertRows", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // insertRows(qsizetype rowIndex, QList<QList<QBarDataItem>> rows)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QList<QList<QBarDataItem>> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insertRows(qsizetype,QList<QList<QBarDataItem>>)
                cppSelf->insertRows(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // insertRows(qsizetype rowIndex, QList<QList<QBarDataItem>> rows, QStringList labels)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QList<QList<QBarDataItem>> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QStringList cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insertRows(qsizetype,QList<QList<QBarDataItem>>,QStringList)
                cppSelf->insertRows(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarDataProxyFunc_itemAt(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "itemAt", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBarDataProxy::itemAt(QPoint)const->const QBarDataItem&
    // 1: QBarDataProxy::itemAt(qsizetype,qsizetype)const->const QBarDataItem&
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 1; // itemAt(qsizetype,qsizetype)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))) {
        overloadId = 0; // itemAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "itemAt", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // itemAt(QPoint position) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // itemAt(QPoint)const
                const QBarDataItem & cppResult = const_cast<const ::QBarDataProxy *>(cppSelf)->itemAt(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataItem_IDX]), &cppResult);
            }
            break;
        }
        case 1: // itemAt(qsizetype rowIndex, qsizetype columnIndex) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // itemAt(qsizetype,qsizetype)const
                const QBarDataItem & cppResult = const_cast<const ::QBarDataProxy *>(cppSelf)->itemAt(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataItem_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarDataProxyFunc_removeRows(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "removeRows", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:removeRows", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBarDataProxy::removeRows(qsizetype,qsizetype,QBarDataProxy::RemoveLabels=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // removeRows(qsizetype,qsizetype,QBarDataProxy::RemoveLabels)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_RemoveLabels_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 0; // removeRows(qsizetype,qsizetype,QBarDataProxy::RemoveLabels)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "removeRows", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_removeLabels = Shiboken::String::createStaticString("removeLabels");
            if (PyDict_Contains(kwds, key_removeLabels) != 0) {
                value = PyDict_GetItem(kwds, key_removeLabels);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_removeLabels);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "removeRows", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_RemoveLabels_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "removeRows", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_removeLabels);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "removeRows", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);
            }
        }
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QBarDataProxy::RemoveLabels cppArg2(QBarDataProxy::RemoveLabels::No);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeRows(qsizetype,qsizetype,QBarDataProxy::RemoveLabels)
            cppSelf->removeRows(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarDataProxyFunc_resetArray(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments(args, "resetArray", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);

    if (PyArg_UnpackTuple(args, "resetArray", 0, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBarDataProxy::resetArray()
    // 1: QBarDataProxy::resetArray(QList<QList<QBarDataItem>>)
    // 2: QBarDataProxy::resetArray(QList<QList<QBarDataItem>>,QStringList,QStringList)
    if (numArgs == 0) {
        overloadId = 0; // resetArray()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QList_QBarDataItem_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // resetArray(QList<QList<QBarDataItem>>)
        } else if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[2])))) {
            overloadId = 2; // resetArray(QList<QList<QBarDataItem>>,QStringList,QStringList)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "resetArray", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // resetArray()
        {

            // resetArray()
            cppSelf->resetArray();
            break;
        }
        case 1: // resetArray(QList<QList<QBarDataItem>> newArray)
        {
            ::QList<QList<QBarDataItem>> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // resetArray(QList<QList<QBarDataItem>>)
                cppSelf->resetArray(cppArg0);
            }
            break;
        }
        case 2: // resetArray(QList<QList<QBarDataItem>> newArray, QStringList rowLabels, QStringList columnLabels)
        {
            ::QList<QList<QBarDataItem>> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QStringList cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QStringList cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // resetArray(QList<QList<QBarDataItem>>,QStringList,QStringList)
                cppSelf->resetArray(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarDataProxyFunc_rowAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarDataProxy::rowAt(qsizetype)const->const QList<QBarDataItem>&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // rowAt(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rowAt", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rowAt(qsizetype)const
            const QList<QBarDataItem> & cppResult = const_cast<const ::QBarDataProxy *>(cppSelf)->rowAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QBarDataItem_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarDataProxyFunc_rowCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rowCount()const
        qsizetype cppResult = const_cast<const ::QBarDataProxy *>(cppSelf)->rowCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarDataProxyFunc_series(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // series()const
        QBar3DSeries * cppResult = const_cast<const ::QBarDataProxy *>(cppSelf)->series();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarDataProxyFunc_setItem(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setItem", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBarDataProxy::setItem(QPoint,QBarDataItem)
    // 1: QBarDataProxy::setItem(qsizetype,qsizetype,QBarDataItem)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataItem_IDX]), (pyArgs[2])))) {
        overloadId = 1; // setItem(qsizetype,qsizetype,QBarDataItem)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataItem_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setItem(QPoint,QBarDataItem)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setItem", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setItem(QPoint position, QBarDataItem item)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QBarDataItem cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setItem(QPoint,QBarDataItem)
                cppSelf->setItem(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setItem(qsizetype rowIndex, qsizetype columnIndex, QBarDataItem item)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QBarDataItem cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setItem(qsizetype,qsizetype,QBarDataItem)
                cppSelf->setItem(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarDataProxyFunc_setRow(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setRow", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBarDataProxy::setRow(qsizetype,QList<QBarDataItem>)
    // 1: QBarDataProxy::setRow(qsizetype,QList<QBarDataItem>,QString)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QBarDataItem_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setRow(qsizetype,QList<QBarDataItem>)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 1; // setRow(qsizetype,QList<QBarDataItem>,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRow", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setRow(qsizetype rowIndex, QList<QBarDataItem> row)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QList<QBarDataItem> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setRow(qsizetype,QList<QBarDataItem>)
                cppSelf->setRow(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setRow(qsizetype rowIndex, QList<QBarDataItem> row, QString label)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QList<QBarDataItem> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setRow(qsizetype,QList<QBarDataItem>,QString)
                cppSelf->setRow(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarDataProxyFunc_setRows(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setRows", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBarDataProxy::setRows(qsizetype,QList<QList<QBarDataItem>>)
    // 1: QBarDataProxy::setRows(qsizetype,QList<QList<QBarDataItem>>,QStringList)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QList_QBarDataItem_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setRows(qsizetype,QList<QList<QBarDataItem>>)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[2])))) {
            overloadId = 1; // setRows(qsizetype,QList<QList<QBarDataItem>>,QStringList)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRows", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setRows(qsizetype rowIndex, QList<QList<QBarDataItem>> rows)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QList<QList<QBarDataItem>> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setRows(qsizetype,QList<QList<QBarDataItem>>)
                cppSelf->setRows(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setRows(qsizetype rowIndex, QList<QList<QBarDataItem>> rows, QStringList labels)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QList<QList<QBarDataItem>> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QStringList cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setRows(qsizetype,QList<QList<QBarDataItem>>,QStringList)
                cppSelf->setRows(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QBarDataProxy_PropertyStrings[] = {
    "colCount:",
    "rowCount:",
    "series:",
    nullptr // Sentinel
};

static const char *Sbk_QBarDataProxy_EnumFlagInfo[] = {
    "RemoveLabels:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBarDataProxy_methods[] = {
    {"addRow", reinterpret_cast<PyCFunction>(Sbk_QBarDataProxyFunc_addRow), METH_VARARGS, nullptr},
    {"addRows", reinterpret_cast<PyCFunction>(Sbk_QBarDataProxyFunc_addRows), METH_VARARGS, nullptr},
    {"colCount", reinterpret_cast<PyCFunction>(Sbk_QBarDataProxyFunc_colCount), METH_NOARGS, nullptr},
    {"insertRow", reinterpret_cast<PyCFunction>(Sbk_QBarDataProxyFunc_insertRow), METH_VARARGS, nullptr},
    {"insertRows", reinterpret_cast<PyCFunction>(Sbk_QBarDataProxyFunc_insertRows), METH_VARARGS, nullptr},
    {"itemAt", reinterpret_cast<PyCFunction>(Sbk_QBarDataProxyFunc_itemAt), METH_VARARGS, nullptr},
    {"removeRows", reinterpret_cast<PyCFunction>(Sbk_QBarDataProxyFunc_removeRows), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"resetArray", reinterpret_cast<PyCFunction>(Sbk_QBarDataProxyFunc_resetArray), METH_VARARGS, nullptr},
    {"rowAt", reinterpret_cast<PyCFunction>(Sbk_QBarDataProxyFunc_rowAt), METH_O, nullptr},
    {"rowCount", reinterpret_cast<PyCFunction>(Sbk_QBarDataProxyFunc_rowCount), METH_NOARGS, nullptr},
    {"series", reinterpret_cast<PyCFunction>(Sbk_QBarDataProxyFunc_series), METH_NOARGS, nullptr},
    {"setItem", reinterpret_cast<PyCFunction>(Sbk_QBarDataProxyFunc_setItem), METH_VARARGS, nullptr},
    {"setRow", reinterpret_cast<PyCFunction>(Sbk_QBarDataProxyFunc_setRow), METH_VARARGS, nullptr},
    {"setRows", reinterpret_cast<PyCFunction>(Sbk_QBarDataProxyFunc_setRows), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QBarDataProxy_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QBarDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QBarDataProxyWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QBarDataProxy_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBarDataProxy_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBarDataProxy_Type = nullptr;
static PyTypeObject *Sbk_QBarDataProxy_TypeF(void)
{
    return _Sbk_QBarDataProxy_Type;
}

static PyType_Slot Sbk_QBarDataProxy_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QBarDataProxy_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBarDataProxy_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBarDataProxy_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBarDataProxy_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBarDataProxy_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBarDataProxy_spec = {
    "2:PySide6.QtGraphs.QBarDataProxy",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBarDataProxy_slots
};

} //extern "C"

static void *Sbk_QBarDataProxy_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QBarDataProxy *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QBarDataProxy_RemoveLabels(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBarDataProxy::RemoveLabels>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBarDataProxy::RemoveLabels *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBarDataProxy_RemoveLabels_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_RemoveLabels_IDX])))
        return Enum_PythonToCpp_QBarDataProxy_RemoveLabels;
    return {};
}

static PyObject *QBarDataProxy_RemoveLabels_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBarDataProxy::RemoveLabels>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBarDataProxy::RemoveLabels *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_RemoveLabels_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBarDataProxy_PythonToCpp_QBarDataProxy_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBarDataProxy_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBarDataProxy_PythonToCpp_QBarDataProxy_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBarDataProxy_TypeF()))
        return QBarDataProxy_PythonToCpp_QBarDataProxy_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBarDataProxy_PTR_CppToPython_QBarDataProxy(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QBarDataProxy *>(const_cast<void *>(cppIn)), Sbk_QBarDataProxy_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBarDataProxy_SignatureStrings[] = {
    "PySide6.QtGraphs.QBarDataProxy(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,rowCount:qsizetype=None,colCount:qsizetype=None,series:QBar3DSeries=None)",
    "1:PySide6.QtGraphs.QBarDataProxy.addRow(self,row:QList[PySide6.QtGraphs.QBarDataItem])->qsizetype",
    "0:PySide6.QtGraphs.QBarDataProxy.addRow(self,row:QList[PySide6.QtGraphs.QBarDataItem],label:QString)->qsizetype",
    "1:PySide6.QtGraphs.QBarDataProxy.addRows(self,rows:QList[QList[PySide6.QtGraphs.QBarDataItem]])->qsizetype",
    "0:PySide6.QtGraphs.QBarDataProxy.addRows(self,rows:QList[QList[PySide6.QtGraphs.QBarDataItem]],labels:QStringList)->qsizetype",
    "PySide6.QtGraphs.QBarDataProxy.colCount(self)->qsizetype",
    "1:PySide6.QtGraphs.QBarDataProxy.insertRow(self,rowIndex:qsizetype,row:QList[PySide6.QtGraphs.QBarDataItem])",
    "0:PySide6.QtGraphs.QBarDataProxy.insertRow(self,rowIndex:qsizetype,row:QList[PySide6.QtGraphs.QBarDataItem],label:QString)",
    "1:PySide6.QtGraphs.QBarDataProxy.insertRows(self,rowIndex:qsizetype,rows:QList[QList[PySide6.QtGraphs.QBarDataItem]])",
    "0:PySide6.QtGraphs.QBarDataProxy.insertRows(self,rowIndex:qsizetype,rows:QList[QList[PySide6.QtGraphs.QBarDataItem]],labels:QStringList)",
    "1:PySide6.QtGraphs.QBarDataProxy.itemAt(self,position:PySide6.QtCore.QPoint)->PySide6.QtGraphs.QBarDataItem",
    "0:PySide6.QtGraphs.QBarDataProxy.itemAt(self,rowIndex:qsizetype,columnIndex:qsizetype)->PySide6.QtGraphs.QBarDataItem",
    "PySide6.QtGraphs.QBarDataProxy.removeRows(self,rowIndex:qsizetype,removeCount:qsizetype,removeLabels:PySide6.QtGraphs.QBarDataProxy.RemoveLabels=QBarDataProxy.RemoveLabels.No)",
    "2:PySide6.QtGraphs.QBarDataProxy.resetArray(self)",
    "1:PySide6.QtGraphs.QBarDataProxy.resetArray(self,newArray:QList[QList[PySide6.QtGraphs.QBarDataItem]])",
    "0:PySide6.QtGraphs.QBarDataProxy.resetArray(self,newArray:QList[QList[PySide6.QtGraphs.QBarDataItem]],rowLabels:QStringList,columnLabels:QStringList)",
    "PySide6.QtGraphs.QBarDataProxy.rowAt(self,rowIndex:qsizetype)->QList[PySide6.QtGraphs.QBarDataItem]",
    "PySide6.QtGraphs.QBarDataProxy.rowCount(self)->qsizetype",
    "PySide6.QtGraphs.QBarDataProxy.series(self)->PySide6.QtGraphs.QBar3DSeries",
    "1:PySide6.QtGraphs.QBarDataProxy.setItem(self,position:PySide6.QtCore.QPoint,item:PySide6.QtGraphs.QBarDataItem)",
    "0:PySide6.QtGraphs.QBarDataProxy.setItem(self,rowIndex:qsizetype,columnIndex:qsizetype,item:PySide6.QtGraphs.QBarDataItem)",
    "1:PySide6.QtGraphs.QBarDataProxy.setRow(self,rowIndex:qsizetype,row:QList[PySide6.QtGraphs.QBarDataItem])",
    "0:PySide6.QtGraphs.QBarDataProxy.setRow(self,rowIndex:qsizetype,row:QList[PySide6.QtGraphs.QBarDataItem],label:QString)",
    "1:PySide6.QtGraphs.QBarDataProxy.setRows(self,rowIndex:qsizetype,rows:QList[QList[PySide6.QtGraphs.QBarDataItem]])",
    "0:PySide6.QtGraphs.QBarDataProxy.setRows(self,rowIndex:qsizetype,rows:QList[QList[PySide6.QtGraphs.QBarDataItem]],labels:QStringList)",
    nullptr}; // Sentinel
#else
static constexpr size_t QBarDataProxy_SignatureByteSize = 434;
static constexpr uint8_t QBarDataProxy_SignatureBytes[434] = {
    0x78, 0xda, 0xbd, 0x95, 0x5d, 0x4f, 0xc2, 0x30, 0x14, 0x86, 0xef, 0xf9, 0x25, 0x62, 0xe6, 0xe2,
    0x47, 0xe2, 0x45, 0x13, 0x4c, 0x10, 0x12, 0x43, 0x5c, 0x60, 0x83, 0x4b, 0xe3, 0x45, 0x61, 0x47,
    0xad, 0x19, 0xed, 0x6c, 0x8b, 0x63, 0xfe, 0x7a, 0xf7, 0xed, 0x18, 0xdb, 0xda, 0x91, 0xc9, 0x65,
    0x3f, 0x4e, 0x9e, 0xf3, 0x9e, 0xf3, 0xb6, 0xc7, 0x0e, 0x57, 0xc4, 0x85, 0x7b, 0xd3, 0x91, 0x4f,
    0x1c, 0xfb, 0x1f, 0xc2, 0x74, 0x1e, 0x31, 0x9f, 0x62, 0x89, 0x6d, 0xce, 0xf6, 0xe1, 0x85, 0x00,
    0xef, 0xcd, 0xf0, 0x31, 0x07, 0x2a, 0x91, 0x5d, 0x5c, 0x9d, 0x30, 0x0e, 0xa6, 0xb3, 0x58, 0x7f,
    0xc2, 0x46, 0x8e, 0xe8, 0xce, 0xf3, 0x7c, 0xc9, 0x8d, 0x4b, 0xf4, 0x0c, 0x61, 0xc0, 0xb8, 0xbb,
    0xa0, 0x5e, 0x38, 0x9a, 0x33, 0x0a, 0x06, 0x67, 0xc1, 0x84, 0xed, 0xa2, 0xd0, 0x2f, 0x41, 0x7e,
    0x40, 0x86, 0x3e, 0xa4, 0xfb, 0x1b, 0xe6, 0xd5, 0xee, 0x0b, 0xe0, 0x04, 0x04, 0x8a, 0x53, 0xb8,
    0x9b, 0xae, 0x92, 0x45, 0x72, 0x30, 0x1c, 0xdc, 0x94, 0xe8, 0x75, 0x89, 0x9a, 0xd8, 0x75, 0x97,
    0x2c, 0x48, 0xf3, 0x8d, 0xb0, 0xc8, 0xb1, 0x88, 0x90, 0x2f, 0x8d, 0x41, 0x33, 0x09, 0xdb, 0xd7,
    0xe1, 0xd5, 0x43, 0x91, 0xc0, 0xe0, 0xfa, 0x3f, 0x08, 0x86, 0x87, 0xd7, 0xe0, 0x21, 0x67, 0x25,
    0x39, 0xa1, 0xef, 0x07, 0x3c, 0x4d, 0x45, 0xa2, 0x00, 0x8a, 0x8c, 0xa8, 0xc3, 0x3d, 0x49, 0xda,
    0x89, 0xa8, 0x54, 0xa3, 0xc8, 0x45, 0xc6, 0x21, 0x07, 0x74, 0x05, 0x3b, 0xf7, 0x42, 0x02, 0xef,
    0x56, 0x21, 0x42, 0x23, 0xc3, 0xc8, 0x72, 0x53, 0x66, 0xd4, 0x85, 0xfd, 0x9f, 0xab, 0xf4, 0x9d,
    0xa0, 0xae, 0x51, 0x7f, 0xb0, 0x8a, 0x29, 0x3a, 0xe8, 0x14, 0x6d, 0xec, 0x6e, 0xfe, 0xe8, 0x20,
    0xb8, 0x3f, 0x6a, 0x9d, 0x55, 0x34, 0xe4, 0x47, 0xb1, 0x63, 0x99, 0x7d, 0x45, 0x4c, 0x10, 0x49,
    0x18, 0x3d, 0xfa, 0x8c, 0x6c, 0x46, 0x68, 0xec, 0xbb, 0xd6, 0x0c, 0x34, 0x44, 0x97, 0x58, 0x35,
    0x82, 0x23, 0xb3, 0xee, 0xb6, 0xb4, 0xb2, 0xab, 0xa4, 0x2a, 0x98, 0x1c, 0xb6, 0xec, 0x1b, 0xda,
    0x0b, 0x9d, 0x5c, 0xa9, 0xfc, 0x99, 0xd9, 0xae, 0x95, 0xd6, 0x54, 0x01, 0x59, 0x96, 0xee, 0x8e,
    0x9a, 0x8f, 0xcc, 0x39, 0x1b, 0x0e, 0x6e, 0x91, 0x32, 0x63, 0x01, 0x72, 0xcc, 0x39, 0x4e, 0x07,
    0x84, 0x46, 0x0f, 0x2b, 0x11, 0x06, 0x85, 0x20, 0x59, 0xf5, 0xec, 0xd9, 0x3e, 0x30, 0x71, 0xfd,
    0xad, 0x23, 0x9f, 0x66, 0xad, 0xb7, 0x6a, 0x0c, 0xac, 0xca, 0x89, 0x05, 0xcd, 0x8e, 0x8a, 0xbc,
    0xa3, 0x93, 0x94, 0x06, 0xa3, 0xe1, 0x13, 0x55, 0x04, 0xa6, 0x13, 0x37, 0x0f, 0xab, 0xbd, 0x9c,
    0x4f, 0x62, 0x75, 0x93, 0xa3, 0xda, 0xc7, 0xd9, 0xea, 0xbc, 0x54, 0x23, 0x7e, 0x68, 0xa8, 0x55,
    0xb4, 0x46, 0xbb, 0x0f, 0x80, 0xba, 0xcf, 0x55, 0x0b, 0xad, 0xa3, 0xf5, 0x4c, 0x83, 0xa7, 0x27,
    0x52, 0xe7, 0xa9, 0x93, 0x72, 0xcf, 0x3a, 0x72, 0xfa, 0x46, 0xd6, 0xce, 0x9b, 0x5f, 0xc8, 0xe6,
    0x01, 0xb5
};
#endif

PyTypeObject *init_QBarDataProxy(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX].type;

    Shiboken::AutoDecRef Sbk_QBarDataProxy_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractDataProxy_IDX]))));

    _Sbk_QBarDataProxy_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBarDataProxy",
        "QBarDataProxy*",
        &Sbk_QBarDataProxy_spec,
        &Shiboken::callCppDestructor< QBarDataProxy >,
        Sbk_QBarDataProxy_Type_bases.object(),
        0);
    auto *pyType = Sbk_QBarDataProxy_TypeF(); // references _Sbk_QBarDataProxy_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBarDataProxy_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBarDataProxy_SignatureBytes, QBarDataProxy_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBarDataProxy_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBarDataProxy_PythonToCpp_QBarDataProxy_PTR,
        is_QBarDataProxy_PythonToCpp_QBarDataProxy_PTR_Convertible,
        QBarDataProxy_PTR_CppToPython_QBarDataProxy);

    Shiboken::Conversions::registerConverterName(converter, "QBarDataProxy");
    Shiboken::Conversions::registerConverterName(converter, "QBarDataProxy*");
    Shiboken::Conversions::registerConverterName(converter, "QBarDataProxy&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBarDataProxy).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QBarDataProxyWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QBarDataProxy_TypeF(), &Sbk_QBarDataProxy_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QBarDataProxy_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'RemoveLabels'.
    const char *RemoveLabels_Initializer[] = {
        "No",
        "Yes",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t RemoveLabels_InitializerValues[] = {
        int8_t(QBarDataProxy::RemoveLabels::No), //  0x00  0
        int8_t(QBarDataProxy::RemoveLabels::Yes) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBarDataProxy_TypeF(),
        "2:PySide6.QtGraphs.QBarDataProxy.RemoveLabels",
        RemoveLabels_Initializer, RemoveLabels_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_RemoveLabels_IDX].type = EType;
    // Register converter for enum 'QBarDataProxy::RemoveLabels'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBarDataProxy_RemoveLabels_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBarDataProxy_RemoveLabels,
            is_Enum_PythonToCpp_QBarDataProxy_RemoveLabels_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBarDataProxy::RemoveLabels");
        Shiboken::Conversions::registerConverterAlias(converter, "RemoveLabels");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'RemoveLabels' enum.

    PySide::Signal::registerSignals(pyType, &::QBarDataProxy::staticMetaObject);
    qRegisterMetaType< ::QBarDataProxy::RemoveLabels >("QBarDataProxy::RemoveLabels");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QBarDataProxy::staticMetaObject, sizeof(QBarDataProxyWrapper));

    return pyType;
}
