// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qbarseries_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGraphs/qabstractseries.h>
#include <QtGraphs/qbarseries.h>
#include <QtGraphs/qbarset.h>
#include <QtGui/qcolor.h>
#include <QtQml/qqmlcomponent.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QBarSeriesWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QBarSeriesWrapper::QBarSeriesWrapper(::QObject * parent) : QBarSeries(parent)
{
}

void QBarSeriesWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarSeries", funcName);
        return;
    }
}

void QBarSeriesWrapper::classBegin()
{
    if (m_PyMethodCache[1]) {
        return this->::QAbstractSeries::classBegin();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "classBegin";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QAbstractSeries::classBegin();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarSeries", funcName);
        return;
    }
}

void QBarSeriesWrapper::componentComplete()
{
    if (m_PyMethodCache[2]) {
        return this->::QBarSeries::componentComplete();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "componentComplete";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QBarSeries::componentComplete();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarSeries", funcName);
        return;
    }
}

void QBarSeriesWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarSeries", funcName);
        return;
    }
}

void QBarSeriesWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarSeries", funcName);
        return;
    }
}

void QBarSeriesWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[5]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarSeries", funcName);
        return;
    }
}

bool QBarSeriesWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[6])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarSeries", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QBarSeries", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QBarSeriesWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[7])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarSeries", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QBarSeries", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QBarSeriesWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[8]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarSeries", funcName);
        return;
    }
}

::QAbstractSeries::SeriesType QBarSeriesWrapper::type() const
{
    if (m_PyMethodCache[9])
        return this->::QBarSeries::type();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QAbstractSeries::SeriesType::Line;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "type";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QBarSeries::type();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QBarSeries", funcName);
        return QAbstractSeries::SeriesType::Line;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractSeries_SeriesType_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QBarSeries", funcName, Shiboken::SbkType< QAbstractSeries::SeriesType >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QAbstractSeries::SeriesType::Line;
    }
    ::QAbstractSeries::SeriesType cppResult{QAbstractSeries::SeriesType::Line};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

const QMetaObject *QBarSeriesWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QBarSeries::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QBarSeriesWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QBarSeries::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QBarSeriesWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QBarSeriesWrapper *>(this));
    return QBarSeries::qt_metacast(_clname);
}

QBarSeriesWrapper::~QBarSeriesWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBarSeries_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBarSeries >()))
        return -1;

    QBarSeriesWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QBarSeries", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBarSeries::QBarSeries(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QBarSeries(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QBarSeries(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QBarSeries(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QBarSeriesWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QBarSeriesWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QBarSeries >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QBarSeriesFunc_append(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarSeries::append(QBarSet*)->bool
    // 1: QBarSeries::append(QList<QBarSet*>)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSet_IDX]), (pyArg)))) {
        overloadId = 0; // append(QBarSet*)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QBarSetPTR_IDX], (pyArg)))) {
        overloadId = 1; // append(QList<QBarSet*>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "append", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // append(QBarSet *set)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QBarSet *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QBarSet*)
                bool cppResult = cppSelf->append(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyArg);
            }
            break;
        }
        case 1: // append(const QList<QBarSet*> &sets)
        {
            ::QList<QBarSet*> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QList<QBarSet*>)
                bool cppResult = cppSelf->append(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyArg);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_at(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarSeries::at(qsizetype)->QBarSet*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // at(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "at", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // at(qsizetype)
            QBarSet * cppResult = cppSelf->at(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSet_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_barDelegate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // barDelegate()const
        QQmlComponent * cppResult = const_cast<const ::QBarSeries *>(cppSelf)->barDelegate();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlComponent_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_barSets(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // barSets()const
        QList<QBarSet*> cppResult = const_cast<const ::QBarSeries *>(cppSelf)->barSets();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QBarSetPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_barWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // barWidth()const
        qreal cppResult = const_cast<const ::QBarSeries *>(cppSelf)->barWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_barsType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // barsType()const
        QBarSeries::BarsType cppResult = const_cast<const ::QBarSeries *>(cppSelf)->barsType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_BarsType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_borderColors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // borderColors()const
        QList<QColor> cppResult = const_cast<const ::QBarSeries *>(cppSelf)->borderColors();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QColor_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_componentComplete(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // componentComplete()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QBarSeries::componentComplete()
            : cppSelf->componentComplete();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        qsizetype cppResult = const_cast<const ::QBarSeries *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_deselectAll(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // deselectAll()
        cppSelf->deselectAll();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_find(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarSeries::find(QBarSet*)const->qsizetype
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSet_IDX]), (pyArg)))) {
        overloadId = 0; // find(QBarSet*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "find", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBarSet *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // find(QBarSet*)const
            qsizetype cppResult = const_cast<const ::QBarSeries *>(cppSelf)->find(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_insert(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insert", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBarSeries::insert(qsizetype,QBarSet*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSet_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insert(qsizetype,QBarSet*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insert", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QBarSet *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insert(qsizetype,QBarSet*)
            bool cppResult = cppSelf->insert(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[1]);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_labelsAngle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelsAngle()const
        qreal cppResult = const_cast<const ::QBarSeries *>(cppSelf)->labelsAngle();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_labelsFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelsFormat()const
        QString cppResult = const_cast<const ::QBarSeries *>(cppSelf)->labelsFormat();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_labelsMargin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelsMargin()const
        qreal cppResult = const_cast<const ::QBarSeries *>(cppSelf)->labelsMargin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_labelsPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelsPosition()const
        QBarSeries::LabelsPosition cppResult = const_cast<const ::QBarSeries *>(cppSelf)->labelsPosition();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_LabelsPosition_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_labelsPrecision(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelsPrecision()const
        int cppResult = const_cast<const ::QBarSeries *>(cppSelf)->labelsPrecision();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_labelsVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelsVisible()const
        bool cppResult = const_cast<const ::QBarSeries *>(cppSelf)->labelsVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_remove(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarSeries::remove(QBarSet*)->bool
    // 1: QBarSeries::remove(qsizetype)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 1; // remove(qsizetype)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSet_IDX]), (pyArg)))) {
        overloadId = 0; // remove(QBarSet*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "remove", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // remove(QBarSet *set)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QBarSet *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // remove(QBarSet*)
                bool cppResult = cppSelf->remove(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // remove(qsizetype index)
        {
            qsizetype cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // remove(qsizetype)
                bool cppResult = cppSelf->remove(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_removeMultiple(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "removeMultiple", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBarSeries::removeMultiple(qsizetype,qsizetype)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // removeMultiple(qsizetype,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "removeMultiple", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeMultiple(qsizetype,qsizetype)
            cppSelf->removeMultiple(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_replace(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "replace", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBarSeries::replace(QBarSet*,QBarSet*)->bool
    // 1: QBarSeries::replace(QList<QBarSet*>)->bool
    // 2: QBarSeries::replace(qsizetype,QBarSet*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSet_IDX]), (pyArgs[1])))) {
        overloadId = 2; // replace(qsizetype,QBarSet*)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSet_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSet_IDX]), (pyArgs[1])))) {
        overloadId = 0; // replace(QBarSet*,QBarSet*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QBarSetPTR_IDX], (pyArgs[0])))) {
        overloadId = 1; // replace(QList<QBarSet*>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "replace", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // replace(QBarSet *oldValue, QBarSet *newValue)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QBarSet *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QBarSet *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // replace(QBarSet*,QBarSet*)
                bool cppResult = cppSelf->replace(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // replace(const QList<QBarSet*> &sets)
        {
            ::QList<QBarSet*> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // replace(QList<QBarSet*>)
                bool cppResult = cppSelf->replace(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // replace(qsizetype index, QBarSet *set)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QBarSet *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // replace(qsizetype,QBarSet*)
                cppSelf->replace(cppArg0, cppArg1);
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_selectAll(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectAll()
        cppSelf->selectAll();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_seriesColors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // seriesColors()const
        QList<QColor> cppResult = const_cast<const ::QBarSeries *>(cppSelf)->seriesColors();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QColor_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_setBarDelegate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarSeries::setBarDelegate(QQmlComponent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlComponent_IDX]), (pyArg)))) {
        overloadId = 0; // setBarDelegate(QQmlComponent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBarDelegate", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQmlComponent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBarDelegate(QQmlComponent*)
            cppSelf->setBarDelegate(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_setBarWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarSeries::setBarWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setBarWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBarWidth", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBarWidth(qreal)
            cppSelf->setBarWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_setBarsType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarSeries::setBarsType(QBarSeries::BarsType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_BarsType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setBarsType(QBarSeries::BarsType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBarsType", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        ::QBarSeries::BarsType cppArg0{QBarSeries::BarsType::Groups};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBarsType(QBarSeries::BarsType)
            cppSelf->setBarsType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_setBorderColors(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarSeries::setBorderColors(QList<QColor>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QColor_IDX], (pyArg)))) {
        overloadId = 0; // setBorderColors(QList<QColor>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBorderColors", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        ::QList<QColor> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBorderColors(QList<QColor>)
            cppSelf->setBorderColors(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_setLabelsAngle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarSeries::setLabelsAngle(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setLabelsAngle(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelsAngle", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelsAngle(qreal)
            cppSelf->setLabelsAngle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_setLabelsFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarSeries::setLabelsFormat(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setLabelsFormat(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelsFormat", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelsFormat(QString)
            cppSelf->setLabelsFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_setLabelsMargin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarSeries::setLabelsMargin(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setLabelsMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelsMargin", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelsMargin(qreal)
            cppSelf->setLabelsMargin(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_setLabelsPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarSeries::setLabelsPosition(QBarSeries::LabelsPosition)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_LabelsPosition_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setLabelsPosition(QBarSeries::LabelsPosition)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelsPosition", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        ::QBarSeries::LabelsPosition cppArg0{QBarSeries::LabelsPosition::Center};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelsPosition(QBarSeries::LabelsPosition)
            cppSelf->setLabelsPosition(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_setLabelsPrecision(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarSeries::setLabelsPrecision(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLabelsPrecision(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelsPrecision", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelsPrecision(int)
            cppSelf->setLabelsPrecision(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_setLabelsVisible(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setLabelsVisible", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    if (PyArg_ParseTuple(args, "|O:setLabelsVisible", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBarSeries::setLabelsVisible(bool=)
    if (numArgs == 0) {
        overloadId = 0; // setLabelsVisible(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // setLabelsVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setLabelsVisible", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_visible = Shiboken::String::createStaticString("visible");
            if (PyDict_Contains(kwds, key_visible) != 0) {
                value = PyDict_GetItem(kwds, key_visible);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_visible);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setLabelsVisible", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "setLabelsVisible", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_visible);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setLabelsVisible", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelsVisible(bool)
            cppSelf->setLabelsVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_setSeriesColors(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarSeries::setSeriesColors(QList<QColor>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QColor_IDX], (pyArg)))) {
        overloadId = 0; // setSeriesColors(QList<QColor>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSeriesColors", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        ::QList<QColor> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSeriesColors(QList<QColor>)
            cppSelf->setSeriesColors(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarSeriesFunc_take(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarSeries::take(QBarSet*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSet_IDX]), (pyArg)))) {
        overloadId = 0; // take(QBarSet*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "take", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBarSet *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // take(QBarSet*)
            bool cppResult = cppSelf->take(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarSeriesFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QAbstractSeries::SeriesType cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QBarSeries *>(cppSelf)->::QBarSeries::type()
            : const_cast<const ::QBarSeries *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractSeries_SeriesType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QBarSeries_PropertyStrings[] = {
    "barDelegate::",
    "barSets:",
    "barWidth::",
    "barsType::",
    "borderColors::",
    "count:",
    "labelsAngle::",
    "labelsFormat::",
    "labelsMargin::",
    "labelsPosition::",
    "labelsPrecision::",
    "labelsVisible::",
    "seriesColors::",
    nullptr // Sentinel
};

static const char *Sbk_QBarSeries_EnumFlagInfo[] = {
    "BarsType:Enum",
    "LabelsPosition:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBarSeries_methods[] = {
    {"append", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_append), METH_O, nullptr},
    {"at", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_at), METH_O, nullptr},
    {"barDelegate", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_barDelegate), METH_NOARGS, nullptr},
    {"barSets", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_barSets), METH_NOARGS, nullptr},
    {"barWidth", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_barWidth), METH_NOARGS, nullptr},
    {"barsType", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_barsType), METH_NOARGS, nullptr},
    {"borderColors", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_borderColors), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_clear), METH_NOARGS, nullptr},
    {"componentComplete", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_componentComplete), METH_NOARGS, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_count), METH_NOARGS, nullptr},
    {"deselectAll", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_deselectAll), METH_NOARGS, nullptr},
    {"find", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_find), METH_O, nullptr},
    {"insert", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_insert), METH_VARARGS, nullptr},
    {"labelsAngle", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_labelsAngle), METH_NOARGS, nullptr},
    {"labelsFormat", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_labelsFormat), METH_NOARGS, nullptr},
    {"labelsMargin", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_labelsMargin), METH_NOARGS, nullptr},
    {"labelsPosition", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_labelsPosition), METH_NOARGS, nullptr},
    {"labelsPrecision", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_labelsPrecision), METH_NOARGS, nullptr},
    {"labelsVisible", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_labelsVisible), METH_NOARGS, nullptr},
    {"remove", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_remove), METH_O, nullptr},
    {"removeMultiple", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_removeMultiple), METH_VARARGS, nullptr},
    {"replace", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_replace), METH_VARARGS, nullptr},
    {"selectAll", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_selectAll), METH_NOARGS, nullptr},
    {"seriesColors", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_seriesColors), METH_NOARGS, nullptr},
    {"setBarDelegate", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_setBarDelegate), METH_O, nullptr},
    {"setBarWidth", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_setBarWidth), METH_O, nullptr},
    {"setBarsType", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_setBarsType), METH_O, nullptr},
    {"setBorderColors", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_setBorderColors), METH_O, nullptr},
    {"setLabelsAngle", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_setLabelsAngle), METH_O, nullptr},
    {"setLabelsFormat", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_setLabelsFormat), METH_O, nullptr},
    {"setLabelsMargin", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_setLabelsMargin), METH_O, nullptr},
    {"setLabelsPosition", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_setLabelsPosition), METH_O, nullptr},
    {"setLabelsPrecision", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_setLabelsPrecision), METH_O, nullptr},
    {"setLabelsVisible", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_setLabelsVisible), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setSeriesColors", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_setSeriesColors), METH_O, nullptr},
    {"take", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_take), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QBarSeriesFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QBarSeries_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QBarSeriesWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QBarSeries_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBarSeries_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QBarSeriesSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QBarSeries *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractSeries_IDX]))
        return static_cast< ::QAbstractSeries *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX]))
        return static_cast< ::QQmlParserStatus *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBarSeries_Type = nullptr;
static PyTypeObject *Sbk_QBarSeries_TypeF(void)
{
    return _Sbk_QBarSeries_Type;
}

static PyType_Slot Sbk_QBarSeries_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QBarSeries_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBarSeries_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBarSeries_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBarSeries_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBarSeries_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBarSeries_spec = {
    "2:PySide6.QtGraphs.QBarSeries",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBarSeries_slots
};

} //extern "C"

static void *Sbk_QBarSeries_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QBarSeries *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QQmlParserStatus >())
        return dynamic_cast< ::QBarSeries *>(reinterpret_cast< ::QQmlParserStatus *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QBarSeries_LabelsPosition(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBarSeries::LabelsPosition>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBarSeries::LabelsPosition *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBarSeries_LabelsPosition_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_LabelsPosition_IDX])))
        return Enum_PythonToCpp_QBarSeries_LabelsPosition;
    return {};
}

static PyObject *QBarSeries_LabelsPosition_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBarSeries::LabelsPosition>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBarSeries::LabelsPosition *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_LabelsPosition_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QBarSeries_BarsType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBarSeries::BarsType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBarSeries::BarsType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBarSeries_BarsType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_BarsType_IDX])))
        return Enum_PythonToCpp_QBarSeries_BarsType;
    return {};
}

static PyObject *QBarSeries_BarsType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBarSeries::BarsType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBarSeries::BarsType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_BarsType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBarSeries_PythonToCpp_QBarSeries_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBarSeries_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBarSeries_PythonToCpp_QBarSeries_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBarSeries_TypeF()))
        return QBarSeries_PythonToCpp_QBarSeries_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBarSeries_PTR_CppToPython_QBarSeries(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QBarSeries *>(const_cast<void *>(cppIn)), Sbk_QBarSeries_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBarSeries_SignatureStrings[] = {
    "PySide6.QtGraphs.QBarSeries(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,seriesColors:QList[PySide6.QtGui.QColor]=None,borderColors:QList[PySide6.QtGui.QColor]=None,barsType:QBarSeries.BarsType=None,barWidth:qreal=None,count:qsizetype=None,labelsVisible:bool=None,labelsFormat:QString=None,labelsPosition:QBarSeries.LabelsPosition=None,labelsMargin:qreal=None,labelsAngle:qreal=None,labelsPrecision:int=None,barDelegate:QQmlComponent=None,barSets:QList[PySide6.QtGraphs.QBarSet]=None)",
    "1:PySide6.QtGraphs.QBarSeries.append(self,set:PySide6.QtGraphs.QBarSet)->bool",
    "0:PySide6.QtGraphs.QBarSeries.append(self,sets:QList[PySide6.QtGraphs.QBarSet])->bool",
    "PySide6.QtGraphs.QBarSeries.at(self,index:qsizetype)->PySide6.QtGraphs.QBarSet",
    "PySide6.QtGraphs.QBarSeries.barDelegate(self)->PySide6.QtQml.QQmlComponent",
    "PySide6.QtGraphs.QBarSeries.barSets(self)->QList[PySide6.QtGraphs.QBarSet]",
    "PySide6.QtGraphs.QBarSeries.barWidth(self)->qreal",
    "PySide6.QtGraphs.QBarSeries.barsType(self)->PySide6.QtGraphs.QBarSeries.BarsType",
    "PySide6.QtGraphs.QBarSeries.borderColors(self)->QList[PySide6.QtGui.QColor]",
    "PySide6.QtGraphs.QBarSeries.clear(self)",
    "PySide6.QtGraphs.QBarSeries.componentComplete(self)",
    "PySide6.QtGraphs.QBarSeries.count(self)->qsizetype",
    "PySide6.QtGraphs.QBarSeries.deselectAll(self)",
    "PySide6.QtGraphs.QBarSeries.find(self,set:PySide6.QtGraphs.QBarSet)->qsizetype",
    "PySide6.QtGraphs.QBarSeries.insert(self,index:qsizetype,set:PySide6.QtGraphs.QBarSet)->bool",
    "PySide6.QtGraphs.QBarSeries.labelsAngle(self)->qreal",
    "PySide6.QtGraphs.QBarSeries.labelsFormat(self)->QString",
    "PySide6.QtGraphs.QBarSeries.labelsMargin(self)->qreal",
    "PySide6.QtGraphs.QBarSeries.labelsPosition(self)->PySide6.QtGraphs.QBarSeries.LabelsPosition",
    "PySide6.QtGraphs.QBarSeries.labelsPrecision(self)->int",
    "PySide6.QtGraphs.QBarSeries.labelsVisible(self)->bool",
    "1:PySide6.QtGraphs.QBarSeries.remove(self,set:PySide6.QtGraphs.QBarSet)->bool",
    "0:PySide6.QtGraphs.QBarSeries.remove(self,index:qsizetype)->bool",
    "PySide6.QtGraphs.QBarSeries.removeMultiple(self,index:qsizetype,count:qsizetype)",
    "2:PySide6.QtGraphs.QBarSeries.replace(self,oldValue:PySide6.QtGraphs.QBarSet,newValue:PySide6.QtGraphs.QBarSet)->bool",
    "1:PySide6.QtGraphs.QBarSeries.replace(self,sets:QList[PySide6.QtGraphs.QBarSet])->bool",
    "0:PySide6.QtGraphs.QBarSeries.replace(self,index:qsizetype,set:PySide6.QtGraphs.QBarSet)",
    "PySide6.QtGraphs.QBarSeries.selectAll(self)",
    "PySide6.QtGraphs.QBarSeries.seriesColors(self)->QList[PySide6.QtGui.QColor]",
    "PySide6.QtGraphs.QBarSeries.setBarDelegate(self,newBarDelegate:PySide6.QtQml.QQmlComponent)",
    "PySide6.QtGraphs.QBarSeries.setBarWidth(self,width:qreal)",
    "PySide6.QtGraphs.QBarSeries.setBarsType(self,type:PySide6.QtGraphs.QBarSeries.BarsType)",
    "PySide6.QtGraphs.QBarSeries.setBorderColors(self,newBorderColors:QList[PySide6.QtGui.QColor])",
    "PySide6.QtGraphs.QBarSeries.setLabelsAngle(self,angle:qreal)",
    "PySide6.QtGraphs.QBarSeries.setLabelsFormat(self,format:QString)",
    "PySide6.QtGraphs.QBarSeries.setLabelsMargin(self,margin:qreal)",
    "PySide6.QtGraphs.QBarSeries.setLabelsPosition(self,position:PySide6.QtGraphs.QBarSeries.LabelsPosition)",
    "PySide6.QtGraphs.QBarSeries.setLabelsPrecision(self,precision:int)",
    "PySide6.QtGraphs.QBarSeries.setLabelsVisible(self,visible:bool=true)",
    "PySide6.QtGraphs.QBarSeries.setSeriesColors(self,newSeriesColors:QList[PySide6.QtGui.QColor])",
    "PySide6.QtGraphs.QBarSeries.take(self,set:PySide6.QtGraphs.QBarSet)->bool",
    "PySide6.QtGraphs.QBarSeries.type(self)->PySide6.QtGraphs.QAbstractSeries.SeriesType",
    nullptr}; // Sentinel
#else
static constexpr size_t QBarSeries_SignatureByteSize = 663;
static constexpr uint8_t QBarSeries_SignatureBytes[663] = {
    0x78, 0xda, 0xad, 0x97, 0xc1, 0x8e, 0xd3, 0x30, 0x10, 0x86, 0xef, 0x7d, 0x12, 0x8a, 0x4c, 0xb4,
    0x70, 0xe0, 0x10, 0x69, 0x91, 0xda, 0x22, 0xf6, 0x40, 0x97, 0x6d, 0x14, 0xb4, 0x1c, 0x10, 0x07,
    0x27, 0x99, 0x76, 0x0d, 0xae, 0x9d, 0xb5, 0x9d, 0x2d, 0xe5, 0xe9, 0x71, 0x92, 0x3a, 0x71, 0xd2,
    0xd6, 0x76, 0x04, 0xa7, 0x4a, 0xce, 0xcc, 0x67, 0xcf, 0x8c, 0xe7, 0xf7, 0x74, 0x73, 0x4c, 0x49,
    0x01, 0xef, 0xa3, 0x44, 0xdd, 0x09, 0x5c, 0x3e, 0xc9, 0x28, 0x59, 0x62, 0x91, 0x82, 0x20, 0x20,
    0x5f, 0x49, 0xa0, 0x5b, 0x54, 0x62, 0x01, 0x4c, 0xc5, 0x9b, 0xce, 0x6e, 0xc5, 0x05, 0x44, 0xc9,
    0x43, 0xf6, 0x13, 0x72, 0x75, 0xcb, 0x2a, 0x4a, 0x4b, 0x25, 0xd0, 0xeb, 0xf8, 0x33, 0x1c, 0x0f,
    0x5c, 0x14, 0x0f, 0x8c, 0x1e, 0x6f, 0xbf, 0x70, 0x06, 0x48, 0x36, 0x90, 0x15, 0xa7, 0x5c, 0xc8,
    0x38, 0x59, 0x13, 0xa9, 0xbe, 0xf7, 0x90, 0xbb, 0x8a, 0x44, 0x49, 0xf3, 0xed, 0x47, 0x6b, 0x9d,
    0x69, 0x5f, 0x10, 0xc1, 0xd6, 0x58, 0xc8, 0xaf, 0xc7, 0x12, 0xe2, 0xfe, 0xb4, 0xd1, 0xf2, 0xb4,
    0xd6, 0x59, 0x7c, 0x23, 0x85, 0x7a, 0x8a, 0x9f, 0x05, 0x60, 0xda, 0xae, 0xe5, 0xbc, 0xd2, 0x91,
    0x3c, 0x4b, 0xf2, 0x07, 0x54, 0x67, 0x48, 0x71, 0x06, 0x54, 0x3e, 0x12, 0x49, 0x32, 0x0a, 0x71,
    0xc6, 0x39, 0xb5, 0xd7, 0x3f, 0x71, 0xb1, 0xc7, 0x2a, 0x4e, 0x52, 0x25, 0x08, 0xdb, 0xd9, 0x5f,
    0x36, 0x5c, 0x12, 0x45, 0x38, 0xb3, 0x8f, 0xb0, 0x1e, 0x7c, 0xb1, 0xad, 0xef, 0xb1, 0xd8, 0x11,
    0x66, 0x1f, 0xa6, 0x5d, 0x5f, 0xb0, 0x9d, 0xde, 0xf5, 0x6c, 0x79, 0x23, 0x20, 0xd7, 0x27, 0xd2,
    0x74, 0xc2, 0x54, 0x17, 0xd0, 0x47, 0xa0, 0xb0, 0xc3, 0x4a, 0x47, 0x9d, 0xec, 0xe9, 0x8a, 0xef,
    0x4b, 0xbd, 0x6e, 0x7d, 0x4e, 0x41, 0x5d, 0x48, 0x9d, 0x5d, 0x55, 0xd5, 0xa6, 0x6f, 0x3e, 0x7b,
    0x1b, 0x6f, 0xae, 0xd7, 0x3d, 0xc2, 0x65, 0x09, 0xac, 0x68, 0xcb, 0x2f, 0x41, 0x5d, 0xb3, 0x55,
    0xf3, 0x37, 0x1f, 0xea, 0x7c, 0xcd, 0x6e, 0xa6, 0xd0, 0xbc, 0x47, 0x34, 0x54, 0x27, 0x53, 0xb5,
    0x3c, 0xc2, 0x0a, 0xf8, 0xdd, 0x57, 0x54, 0xbb, 0x5e, 0xc3, 0x3a, 0x71, 0x56, 0x6e, 0x1b, 0xee,
    0x80, 0xa3, 0x73, 0x1d, 0x0d, 0x12, 0xee, 0x43, 0xd5, 0x75, 0x30, 0x18, 0x4f, 0xac, 0x3e, 0x54,
    0x73, 0x85, 0x0d, 0xab, 0xb9, 0x25, 0x3e, 0x8f, 0xa6, 0x05, 0xce, 0x83, 0x38, 0xb7, 0x35, 0xed,
    0xe2, 0x06, 0x5a, 0x5d, 0x79, 0x35, 0xa4, 0xbe, 0x39, 0x9d, 0xac, 0x9c, 0x02, 0x16, 0x2d, 0xc4,
    0x6d, 0x67, 0xf2, 0x5c, 0x27, 0x9c, 0x82, 0x29, 0x89, 0xc7, 0x47, 0x77, 0x76, 0x97, 0x27, 0x73,
    0x1d, 0x9c, 0x2e, 0x05, 0x68, 0x73, 0x2d, 0x61, 0x0b, 0x4a, 0x03, 0x36, 0xd8, 0x92, 0xc0, 0x86,
    0x08, 0xdb, 0x9c, 0x30, 0xad, 0x8e, 0x97, 0xef, 0x70, 0x50, 0xc7, 0xb9, 0xd8, 0x96, 0xb0, 0x84,
    0xdf, 0x1c, 0x5b, 0xed, 0xba, 0x42, 0xb7, 0xa2, 0x17, 0xe0, 0xd7, 0xaa, 0xdb, 0xd4, 0xdd, 0x8c,
    0x4e, 0x86, 0xdc, 0xd6, 0xa1, 0xb2, 0x86, 0xc0, 0x8d, 0x82, 0x1a, 0x3a, 0xf1, 0x34, 0xee, 0xe0,
    0x1d, 0x30, 0x4e, 0x4d, 0xb2, 0xdd, 0x62, 0x29, 0x60, 0xcf, 0x5f, 0xe0, 0x7f, 0x89, 0xa5, 0x4d,
    0x3b, 0x17, 0x37, 0x6f, 0xed, 0x5b, 0xf7, 0xfb, 0x8a, 0x2a, 0x52, 0xd2, 0xcb, 0x98, 0xf1, 0x2b,
    0x38, 0x9f, 0xbd, 0xf3, 0x9c, 0xa8, 0xa4, 0x38, 0x3f, 0xb1, 0x38, 0x2d, 0x1e, 0x31, 0xad, 0xe0,
    0x6a, 0x94, 0x88, 0xc1, 0xc1, 0x6d, 0x11, 0x9a, 0x55, 0x6b, 0xd7, 0x29, 0xaf, 0xc6, 0x4d, 0x38,
    0x76, 0x52, 0xe3, 0x39, 0xd3, 0x3e, 0x45, 0x49, 0xec, 0xb1, 0xe8, 0x5f, 0x25, 0x55, 0x9f, 0x78,
    0x39, 0x7a, 0xba, 0xea, 0x02, 0x58, 0x6b, 0xb1, 0xe3, 0x1d, 0x9b, 0x07, 0xb0, 0xfb, 0x07, 0x08,
    0x1d, 0xfa, 0x71, 0x2a, 0xc4, 0xb3, 0x7f, 0x88, 0x50, 0x9d, 0xdd, 0x38, 0xe4, 0x2d, 0xf2, 0x73,
    0xc7, 0xef, 0x51, 0x13, 0x6e, 0xe0, 0xe8, 0xe8, 0xa5, 0xaf, 0x47, 0xca, 0x89, 0x70, 0x3f, 0x9d,
    0x05, 0x3a, 0x5b, 0x0a, 0x8a, 0xb6, 0x83, 0xd9, 0x31, 0x10, 0x60, 0x49, 0x29, 0xda, 0x5b, 0x43,
    0x63, 0xa0, 0xfb, 0x40, 0x53, 0x51, 0x69, 0x66, 0xd4, 0x70, 0x69, 0x0d, 0xdd, 0x67, 0x20, 0xaf,
    0xa8, 0xb4, 0xe7, 0xd5, 0x40, 0x84, 0x2d, 0xb5, 0xe8, 0xc5, 0x9e, 0xbf, 0x95, 0xa8, 0xfc, 0x57,
    0x21, 0x1d, 0xf7, 0x51, 0x7d, 0x15, 0xd2, 0xc0, 0xff, 0x1c, 0x6e, 0xba, 0xc2, 0xbf, 0x26, 0x08,
    0xba, 0x93, 0xe4, 0x1c, 0xc6, 0x16, 0x99, 0x54, 0x02, 0xe7, 0xa7, 0x50, 0xa2, 0xf6, 0xa7, 0x99,
    0xc9, 0xfe, 0x02, 0x83, 0x38, 0xed, 0x20
};
#endif

PyTypeObject *init_QBarSeries(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX].type;

    Shiboken::AutoDecRef Sbk_QBarSeries_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractSeries_IDX]))));

    _Sbk_QBarSeries_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBarSeries",
        "QBarSeries*",
        &Sbk_QBarSeries_spec,
        &Shiboken::callCppDestructor< QBarSeries >,
        Sbk_QBarSeries_Type_bases.object(),
        0);
    auto *pyType = Sbk_QBarSeries_TypeF(); // references _Sbk_QBarSeries_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBarSeries_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBarSeries_SignatureBytes, QBarSeries_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBarSeries_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBarSeries_PythonToCpp_QBarSeries_PTR,
        is_QBarSeries_PythonToCpp_QBarSeries_PTR_Convertible,
        QBarSeries_PTR_CppToPython_QBarSeries);

    Shiboken::Conversions::registerConverterName(converter, "QBarSeries");
    Shiboken::Conversions::registerConverterName(converter, "QBarSeries*");
    Shiboken::Conversions::registerConverterName(converter, "QBarSeries&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBarSeries).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QBarSeriesWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstractSeries_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QBarSeries_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QBarSeries_TypeF(), &Sbk_QBarSeriesSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QBarSeries_TypeF(), &Sbk_QBarSeries_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QBarSeries_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'LabelsPosition'.
    const char *LabelsPosition_Initializer[] = {
        "Center",
        "InsideEnd",
        "InsideBase",
        "OutsideEnd",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t LabelsPosition_InitializerValues[] = {
        int8_t(QBarSeries::LabelsPosition::Center),     //  0x00  0
        int8_t(QBarSeries::LabelsPosition::InsideEnd),  //  0x01  1
        int8_t(QBarSeries::LabelsPosition::InsideBase), //  0x02  2
        int8_t(QBarSeries::LabelsPosition::OutsideEnd)  //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBarSeries_TypeF(),
        "2:PySide6.QtGraphs.QBarSeries.LabelsPosition",
        LabelsPosition_Initializer, LabelsPosition_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_LabelsPosition_IDX].type = EType;
    // Register converter for enum 'QBarSeries::LabelsPosition'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBarSeries_LabelsPosition_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBarSeries_LabelsPosition,
            is_Enum_PythonToCpp_QBarSeries_LabelsPosition_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBarSeries::LabelsPosition");
        Shiboken::Conversions::registerConverterAlias(converter, "LabelsPosition");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'LabelsPosition' enum.

    // Initialization of enum 'BarsType'.
    const char *BarsType_Initializer[] = {
        "Groups",
        "Stacked",
        "StackedPercent",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t BarsType_InitializerValues[] = {
        int8_t(QBarSeries::BarsType::Groups),        //  0x00  0
        int8_t(QBarSeries::BarsType::Stacked),       //  0x01  1
        int8_t(QBarSeries::BarsType::StackedPercent) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBarSeries_TypeF(),
        "2:PySide6.QtGraphs.QBarSeries.BarsType",
        BarsType_Initializer, BarsType_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QBarSeries_BarsType_IDX].type = EType;
    // Register converter for enum 'QBarSeries::BarsType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBarSeries_BarsType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBarSeries_BarsType,
            is_Enum_PythonToCpp_QBarSeries_BarsType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBarSeries::BarsType");
        Shiboken::Conversions::registerConverterAlias(converter, "BarsType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'BarsType' enum.

    PySide::Signal::registerSignals(pyType, &::QBarSeries::staticMetaObject);
    qRegisterMetaType< ::QBarSeries::LabelsPosition >("QBarSeries::LabelsPosition");
    qRegisterMetaType< ::QBarSeries::BarsType >("QBarSeries::BarsType");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QBarSeries::staticMetaObject, sizeof(QBarSeriesWrapper));

    return pyType;
}
