// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qgraphsline_wrapper.h"

// Argument includes
#include <QtGraphs/qgraphstheme.h>
#include <QtGui/qcolor.h>
#include <QtQml/qjsvalue.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphsLine_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGraphsLine >()))
        return -1;

    ::QGraphsLine *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QGraphsLine", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGraphsLine::QGraphsLine()
    // 1: QGraphsLine::QGraphsLine(QGraphsLine)
    if (numArgs == 0) {
        overloadId = 0; // QGraphsLine()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QGraphsLine(QGraphsLine)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGraphsLine()
        {

            // QGraphsLine()
            cptr = new ::QGraphsLine();
            break;
        }
        case 1: // QGraphsLine(const QGraphsLine &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGraphsLine cppArg0_local;
            ::QGraphsLine *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGraphsLine(QGraphsLine)
                cptr = new ::QGraphsLine(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGraphsLine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGraphsLineFunc_labelTextColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelTextColor()const
        QColor cppResult = const_cast<const ::QGraphsLine *>(cppSelf)->labelTextColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsLineFunc_mainColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mainColor()const
        QColor cppResult = const_cast<const ::QGraphsLine *>(cppSelf)->mainColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsLineFunc_mainWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mainWidth()const
        qreal cppResult = const_cast<const ::QGraphsLine *>(cppSelf)->mainWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsLineFunc_setLabelTextColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsLine::setLabelTextColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setLabelTextColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelTextColor", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelTextColor(QColor)
            cppSelf->setLabelTextColor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsLineFunc_setMainColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsLine::setMainColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setMainColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMainColor", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMainColor(QColor)
            cppSelf->setMainColor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsLineFunc_setMainWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsLine::setMainWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setMainWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMainWidth", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMainWidth(qreal)
            cppSelf->setMainWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsLineFunc_setSubColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsLine::setSubColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setSubColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSubColor", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSubColor(QColor)
            cppSelf->setSubColor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsLineFunc_setSubWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsLine::setSubWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setSubWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSubWidth", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSubWidth(qreal)
            cppSelf->setSubWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsLineFunc_subColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // subColor()const
        QColor cppResult = const_cast<const ::QGraphsLine *>(cppSelf)->subColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsLineFunc_subWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // subWidth()const
        qreal cppResult = const_cast<const ::QGraphsLine *>(cppSelf)->subWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsLine__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGraphsLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGraphsLine_PropertyStrings[] = {
    "labelTextColor::",
    "mainColor::",
    "mainWidth::",
    "subColor::",
    "subWidth::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGraphsLine_methods[] = {
    {"labelTextColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsLineFunc_labelTextColor), METH_NOARGS, nullptr},
    {"mainColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsLineFunc_mainColor), METH_NOARGS, nullptr},
    {"mainWidth", reinterpret_cast<PyCFunction>(Sbk_QGraphsLineFunc_mainWidth), METH_NOARGS, nullptr},
    {"setLabelTextColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsLineFunc_setLabelTextColor), METH_O, nullptr},
    {"setMainColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsLineFunc_setMainColor), METH_O, nullptr},
    {"setMainWidth", reinterpret_cast<PyCFunction>(Sbk_QGraphsLineFunc_setMainWidth), METH_O, nullptr},
    {"setSubColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsLineFunc_setSubColor), METH_O, nullptr},
    {"setSubWidth", reinterpret_cast<PyCFunction>(Sbk_QGraphsLineFunc_setSubWidth), METH_O, nullptr},
    {"subColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsLineFunc_subColor), METH_NOARGS, nullptr},
    {"subWidth", reinterpret_cast<PyCFunction>(Sbk_QGraphsLineFunc_subWidth), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGraphsLine__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QGraphsLine_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGraphsLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), (pyArg)))) {
                // operator!=(const QGraphsLine &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGraphsLine cppArg0_local;
                ::QGraphsLine *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), (pyArg)))) {
                // operator==(const QGraphsLine &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGraphsLine cppArg0_local;
                ::QGraphsLine *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QGraphsLine_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGraphsLine_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGraphsLine_Type = nullptr;
static PyTypeObject *Sbk_QGraphsLine_TypeF(void)
{
    return _Sbk_QGraphsLine_Type;
}

static PyType_Slot Sbk_QGraphsLine_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGraphsLine_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGraphsLine_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QGraphsLine_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGraphsLine_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGraphsLine_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGraphsLine_spec = {
    "2:PySide6.QtGraphs.QGraphsLine",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGraphsLine_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGraphsLine_PythonToCpp_QGraphsLine_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGraphsLine_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGraphsLine_PythonToCpp_QGraphsLine_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGraphsLine_TypeF()))
        return QGraphsLine_PythonToCpp_QGraphsLine_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGraphsLine_PTR_CppToPython_QGraphsLine(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QGraphsLine_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QGraphsLine_COPY_CppToPython_QGraphsLine(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGraphsLine *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGraphsLine_TypeF(), new ::QGraphsLine(*source), true, true);
}

// Python to C++ copy conversion.
static void QGraphsLine_PythonToCpp_QGraphsLine_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGraphsLine *>(cppOut) = *reinterpret_cast< ::QGraphsLine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGraphsLine_PythonToCpp_QGraphsLine_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGraphsLine_TypeF()))
        return QGraphsLine_PythonToCpp_QGraphsLine_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGraphsLine_SignatureStrings[] = {
    "1:PySide6.QtGraphs.QGraphsLine(self,*:KeywordOnly=None,mainColor:QColor=None,subColor:QColor=None,mainWidth:qreal=None,subWidth:qreal=None,labelTextColor:QColor=None)",
    "0:PySide6.QtGraphs.QGraphsLine(self,other:PySide6.QtGraphs.QGraphsLine,*:KeywordOnly=None,mainColor:QColor=None,subColor:QColor=None,mainWidth:qreal=None,subWidth:qreal=None,labelTextColor:QColor=None)",
    "PySide6.QtGraphs.QGraphsLine.labelTextColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtGraphs.QGraphsLine.mainColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtGraphs.QGraphsLine.mainWidth(self)->qreal",
    "PySide6.QtGraphs.QGraphsLine.setLabelTextColor(self,newColor:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGraphs.QGraphsLine.setMainColor(self,newColor:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGraphs.QGraphsLine.setMainWidth(self,newWidth:qreal)",
    "PySide6.QtGraphs.QGraphsLine.setSubColor(self,newColor:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGraphs.QGraphsLine.setSubWidth(self,newWidth:qreal)",
    "PySide6.QtGraphs.QGraphsLine.subColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtGraphs.QGraphsLine.subWidth(self)->qreal",
    "PySide6.QtGraphs.QGraphsLine.__copy__(self)->typing.Self",
    "PySide6.QtGraphs.QGraphsLine.__ne__(self,rhs:PySide6.QtGraphs.QGraphsLine)->bool",
    "PySide6.QtGraphs.QGraphsLine.__eq__(self,rhs:PySide6.QtGraphs.QGraphsLine)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QGraphsLine_SignatureByteSize = 315;
static constexpr uint8_t QGraphsLine_SignatureBytes[315] = {
    0x78, 0xda, 0xd5, 0x94, 0x4b, 0x4f, 0x83, 0x40, 0x14, 0x85, 0xf7, 0xfe, 0x0a, 0x96, 0x62, 0xc6,
    0x89, 0x4d, 0x4c, 0x17, 0x24, 0xba, 0xe9, 0xa2, 0x0b, 0xf1, 0x81, 0xf8, 0x58, 0x18, 0x43, 0x66,
    0xe4, 0x0a, 0x93, 0x8c, 0x77, 0xe8, 0xcc, 0x90, 0xca, 0xbf, 0x97, 0xf2, 0x68, 0xa9, 0x18, 0xa8,
    0x75, 0x63, 0x57, 0x13, 0x6e, 0xce, 0x39, 0xdc, 0xef, 0x0e, 0x97, 0x89, 0x77, 0x57, 0x84, 0x22,
    0x86, 0x29, 0x0d, 0xec, 0x5c, 0xb3, 0x2c, 0x35, 0x34, 0xa8, 0x4f, 0x5f, 0x20, 0x1c, 0x1b, 0x90,
    0xef, 0xe4, 0xc4, 0xbb, 0x82, 0x62, 0xa9, 0x74, 0x7c, 0x8b, 0xb2, 0xb8, 0xb8, 0x51, 0x08, 0xe4,
    0x83, 0x09, 0x9c, 0x29, 0xa9, 0xb4, 0x17, 0x54, 0x47, 0x5d, 0x35, 0x39, 0xef, 0x17, 0x57, 0xd2,
    0x67, 0x11, 0xdb, 0xd4, 0x5b, 0x68, 0x60, 0x72, 0xad, 0xec, 0xd5, 0x24, 0xe3, 0x20, 0x1f, 0xe0,
    0xd3, 0xf6, 0x32, 0xdc, 0xa3, 0xb3, 0x1d, 0xda, 0x54, 0x36, 0x05, 0x3d, 0xa8, 0xfb, 0x0f, 0x24,
    0x43, 0xfd, 0xd1, 0x6d, 0x63, 0x85, 0xe5, 0x9e, 0x5e, 0x76, 0x2c, 0xb9, 0xa0, 0x75, 0xda, 0x70,
    0xce, 0x1a, 0xea, 0x6f, 0x11, 0x15, 0x58, 0x1b, 0x51, 0xf1, 0x0d, 0x7b, 0x0c, 0x58, 0xbf, 0x4f,
    0x40, 0x10, 0x96, 0xf5, 0x20, 0x6c, 0x91, 0x09, 0x4c, 0xe8, 0x23, 0x0a, 0x85, 0x2f, 0x3f, 0xb5,
    0x44, 0x9c, 0xc0, 0x67, 0x56, 0xe0, 0x24, 0xb4, 0xba, 0x54, 0x12, 0xe7, 0x9b, 0xe8, 0x3e, 0xe1,
    0x6c, 0x7a, 0x5e, 0xaa, 0x9e, 0x98, 0x16, 0x0c, 0x6d, 0x57, 0x30, 0x53, 0x1a, 0xca, 0x83, 0xce,
    0xa5, 0xe2, 0x4c, 0xb6, 0x71, 0x6d, 0x50, 0x8e, 0x46, 0x24, 0x08, 0xb1, 0x23, 0xd0, 0xbe, 0xba,
    0xa3, 0x18, 0xd7, 0x5b, 0x03, 0x3c, 0x54, 0x82, 0xcd, 0xfd, 0xad, 0x08, 0x3a, 0x9f, 0xe9, 0xb8,
    0x3d, 0x6c, 0x16, 0xe0, 0x60, 0xf9, 0xc3, 0x66, 0x2f, 0xf7, 0xc1, 0xef, 0xb2, 0xef, 0xb5, 0x3c,
    0xa6, 0xfb, 0xf2, 0xdd, 0x76, 0x27, 0x8a, 0xde, 0x54, 0x56, 0x44, 0x51, 0x6b, 0x69, 0x26, 0x1d,
    0x96, 0x4f, 0x63, 0x46, 0x84, 0xc6, 0x46, 0x74, 0x6a, 0x06, 0x7f, 0x80, 0x65, 0x2e, 0x57, 0x6a,
    0xb4, 0x13, 0x58, 0xfc, 0x36, 0xf0, 0x0b, 0x54, 0x31, 0x3f, 0xe2
};
#endif

PyTypeObject *init_QGraphsLine(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX].type;

    Shiboken::AutoDecRef Sbk_QGraphsLine_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGraphsLine_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGraphsLine",
        "QGraphsLine",
        &Sbk_QGraphsLine_spec,
        &Shiboken::callCppDestructor< ::QGraphsLine >,
        Sbk_QGraphsLine_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGraphsLine_TypeF(); // references _Sbk_QGraphsLine_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGraphsLine_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGraphsLine_SignatureBytes, QGraphsLine_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGraphsLine_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGraphsLine_PythonToCpp_QGraphsLine_PTR,
        is_QGraphsLine_PythonToCpp_QGraphsLine_PTR_Convertible,
        QGraphsLine_PTR_CppToPython_QGraphsLine,
        QGraphsLine_COPY_CppToPython_QGraphsLine);

    Shiboken::Conversions::registerConverterName(converter, "QGraphsLine");
    Shiboken::Conversions::registerConverterName(converter, "QGraphsLine*");
    Shiboken::Conversions::registerConverterName(converter, "QGraphsLine&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGraphsLine).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGraphsLine_PythonToCpp_QGraphsLine_COPY,
        is_QGraphsLine_PythonToCpp_QGraphsLine_COPY_Convertible);

    qRegisterMetaType< ::QGraphsLine >("QGraphsLine");

    return pyType;
}
