// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qgraphstheme_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGraphs/qgraphstheme.h>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qfont.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGraphsThemeWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGraphsThemeWrapper::QGraphsThemeWrapper(::QObject * parent) : QGraphsTheme(parent)
{
}

void QGraphsThemeWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphsTheme", funcName);
        return;
    }
}

void QGraphsThemeWrapper::classBegin()
{
    if (m_PyMethodCache[1]) {
        return this->::QGraphsTheme::classBegin();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "classBegin";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QGraphsTheme::classBegin();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphsTheme", funcName);
        return;
    }
}

void QGraphsThemeWrapper::componentComplete()
{
    if (m_PyMethodCache[2]) {
        return this->::QGraphsTheme::componentComplete();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "componentComplete";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QGraphsTheme::componentComplete();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphsTheme", funcName);
        return;
    }
}

void QGraphsThemeWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphsTheme", funcName);
        return;
    }
}

void QGraphsThemeWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphsTheme", funcName);
        return;
    }
}

void QGraphsThemeWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[5]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphsTheme", funcName);
        return;
    }
}

bool QGraphsThemeWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[6])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphsTheme", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGraphsTheme", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QGraphsThemeWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[7])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphsTheme", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGraphsTheme", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGraphsThemeWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[8]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphsTheme", funcName);
        return;
    }
}

const QMetaObject *QGraphsThemeWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QGraphsTheme::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QGraphsThemeWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QGraphsTheme::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QGraphsThemeWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QGraphsThemeWrapper *>(this));
    return QGraphsTheme::qt_metacast(_clname);
}

QGraphsThemeWrapper::~QGraphsThemeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphsTheme_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);
    if (type != myType)
        Shiboken::ObjectType::copyMultipleInheritance(type, myType);

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGraphsTheme >()))
        return -1;

    QGraphsThemeWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QGraphsTheme", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGraphsTheme::QGraphsTheme(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QGraphsTheme(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QGraphsTheme(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QGraphsTheme(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QGraphsThemeWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QGraphsThemeWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QGraphsTheme >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QGraphsThemeFunc_axisX(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axisX()const
        QGraphsLine cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->axisX();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_axisXLabelFont(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axisXLabelFont()const
        QFont cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->axisXLabelFont();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_axisY(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axisY()const
        QGraphsLine cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->axisY();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_axisYLabelFont(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axisYLabelFont()const
        QFont cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->axisYLabelFont();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_axisZ(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axisZ()const
        QGraphsLine cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->axisZ();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_axisZLabelFont(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axisZLabelFont()const
        QFont cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->axisZLabelFont();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_backgroundColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // backgroundColor()const
        QColor cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->backgroundColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_borderColors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // borderColors()const
        QList<QColor> cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->borderColors();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QColor_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_borderWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // borderWidth()const
        qreal cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->borderWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_classBegin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // classBegin()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QGraphsTheme::classBegin()
            : cppSelf->classBegin();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_colorScheme(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // colorScheme()const
        QGraphsTheme::ColorScheme cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->colorScheme();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_ColorScheme_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_colorStyle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // colorStyle()const
        QGraphsTheme::ColorStyle cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->colorStyle();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_ColorStyle_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_componentComplete(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // componentComplete()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QGraphsTheme::componentComplete()
            : cppSelf->componentComplete();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_dirtyBits(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dirtyBits()
        QGraphsThemeDirtyBitField * cppResult = cppSelf->dirtyBits();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsThemeDirtyBitField_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_grid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // grid()const
        QGraphsLine cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->grid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_handleBaseColorUpdate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // handleBaseColorUpdate()
        cppSelf->handleBaseColorUpdate();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_handleBaseGradientUpdate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // handleBaseGradientUpdate()
        cppSelf->handleBaseGradientUpdate();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_isBackgroundVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isBackgroundVisible()const
        bool cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->isBackgroundVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_isGridVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isGridVisible()const
        bool cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->isGridVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_isLabelBackgroundVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLabelBackgroundVisible()const
        bool cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->isLabelBackgroundVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_isLabelBorderVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLabelBorderVisible()const
        bool cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->isLabelBorderVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_isPlotAreaBackgroundVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isPlotAreaBackgroundVisible()const
        bool cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->isPlotAreaBackgroundVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_labelBackgroundColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelBackgroundColor()const
        QColor cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->labelBackgroundColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_labelFont(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelFont()const
        QFont cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->labelFont();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_labelTextColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelTextColor()const
        QColor cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->labelTextColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_labelsVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelsVisible()const
        bool cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->labelsVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_multiHighlightColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // multiHighlightColor()const
        QColor cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->multiHighlightColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_multiHighlightGradient(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // multiHighlightGradient()const
        QLinearGradient cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->multiHighlightGradient();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_plotAreaBackgroundColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // plotAreaBackgroundColor()const
        QColor cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->plotAreaBackgroundColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_resetColorTheme(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resetColorTheme()
        cppSelf->resetColorTheme();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_resetDirtyBits(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resetDirtyBits()
        cppSelf->resetDirtyBits();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_resetThemeDirty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resetThemeDirty()
        cppSelf->resetThemeDirty();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_seriesColors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // seriesColors()const
        QList<QColor> cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->seriesColors();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QColor_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_seriesGradients(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // seriesGradients()const
        QList<QLinearGradient> cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->seriesGradients();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QLinearGradient_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_setAxisX(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setAxisX(QGraphsLine)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), (pyArg)))) {
        overloadId = 0; // setAxisX(QGraphsLine)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAxisX", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphsLine cppArg0_local;
        ::QGraphsLine *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setAxisX(QGraphsLine)
            cppSelf->setAxisX(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setAxisXLabelFont(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setAxisXLabelFont(QFont)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
        overloadId = 0; // setAxisXLabelFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAxisXLabelFont", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setAxisXLabelFont(QFont)
            cppSelf->setAxisXLabelFont(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setAxisY(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setAxisY(QGraphsLine)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), (pyArg)))) {
        overloadId = 0; // setAxisY(QGraphsLine)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAxisY", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphsLine cppArg0_local;
        ::QGraphsLine *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setAxisY(QGraphsLine)
            cppSelf->setAxisY(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setAxisYLabelFont(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setAxisYLabelFont(QFont)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
        overloadId = 0; // setAxisYLabelFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAxisYLabelFont", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setAxisYLabelFont(QFont)
            cppSelf->setAxisYLabelFont(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setAxisZ(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setAxisZ(QGraphsLine)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), (pyArg)))) {
        overloadId = 0; // setAxisZ(QGraphsLine)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAxisZ", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphsLine cppArg0_local;
        ::QGraphsLine *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setAxisZ(QGraphsLine)
            cppSelf->setAxisZ(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setAxisZLabelFont(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setAxisZLabelFont(QFont)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
        overloadId = 0; // setAxisZLabelFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAxisZLabelFont", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setAxisZLabelFont(QFont)
            cppSelf->setAxisZLabelFont(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setBackgroundColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setBackgroundColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setBackgroundColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBackgroundColor", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackgroundColor(QColor)
            cppSelf->setBackgroundColor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setBackgroundVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setBackgroundVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setBackgroundVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBackgroundVisible", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackgroundVisible(bool)
            cppSelf->setBackgroundVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setBorderColors(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setBorderColors(QList<QColor>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QColor_IDX], (pyArg)))) {
        overloadId = 0; // setBorderColors(QList<QColor>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBorderColors", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        ::QList<QColor> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBorderColors(QList<QColor>)
            cppSelf->setBorderColors(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setBorderWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setBorderWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setBorderWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBorderWidth", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBorderWidth(qreal)
            cppSelf->setBorderWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setColorScheme(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setColorScheme(QGraphsTheme::ColorScheme)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_ColorScheme_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setColorScheme(QGraphsTheme::ColorScheme)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColorScheme", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        ::QGraphsTheme::ColorScheme cppArg0{QGraphsTheme::ColorScheme::Automatic};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColorScheme(QGraphsTheme::ColorScheme)
            cppSelf->setColorScheme(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setColorStyle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setColorStyle(QGraphsTheme::ColorStyle)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_ColorStyle_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setColorStyle(QGraphsTheme::ColorStyle)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColorStyle", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        ::QGraphsTheme::ColorStyle cppArg0{QGraphsTheme::ColorStyle::Uniform};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColorStyle(QGraphsTheme::ColorStyle)
            cppSelf->setColorStyle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setGrid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setGrid(QGraphsLine)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsLine_IDX]), (pyArg)))) {
        overloadId = 0; // setGrid(QGraphsLine)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGrid", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphsLine cppArg0_local;
        ::QGraphsLine *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setGrid(QGraphsLine)
            cppSelf->setGrid(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setGridVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setGridVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setGridVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGridVisible", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGridVisible(bool)
            cppSelf->setGridVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setLabelBackgroundColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setLabelBackgroundColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setLabelBackgroundColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelBackgroundColor", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelBackgroundColor(QColor)
            cppSelf->setLabelBackgroundColor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setLabelBackgroundVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setLabelBackgroundVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setLabelBackgroundVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelBackgroundVisible", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelBackgroundVisible(bool)
            cppSelf->setLabelBackgroundVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setLabelBorderVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setLabelBorderVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setLabelBorderVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelBorderVisible", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelBorderVisible(bool)
            cppSelf->setLabelBorderVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setLabelFont(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setLabelFont(QFont)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
        overloadId = 0; // setLabelFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelFont", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelFont(QFont)
            cppSelf->setLabelFont(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setLabelTextColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setLabelTextColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setLabelTextColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelTextColor", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelTextColor(QColor)
            cppSelf->setLabelTextColor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setLabelsVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setLabelsVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setLabelsVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelsVisible", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelsVisible(bool)
            cppSelf->setLabelsVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setMultiHighlightColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setMultiHighlightColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setMultiHighlightColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMultiHighlightColor", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMultiHighlightColor(QColor)
            cppSelf->setMultiHighlightColor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setMultiHighlightGradient(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setMultiHighlightGradient(QLinearGradient)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), (pyArg)))) {
        overloadId = 0; // setMultiHighlightGradient(QLinearGradient)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMultiHighlightGradient", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLinearGradient cppArg0_local;
        ::QLinearGradient *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setMultiHighlightGradient(QLinearGradient)
            cppSelf->setMultiHighlightGradient(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setPlotAreaBackgroundColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setPlotAreaBackgroundColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setPlotAreaBackgroundColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPlotAreaBackgroundColor", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPlotAreaBackgroundColor(QColor)
            cppSelf->setPlotAreaBackgroundColor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setPlotAreaBackgroundVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setPlotAreaBackgroundVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setPlotAreaBackgroundVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPlotAreaBackgroundVisible", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPlotAreaBackgroundVisible(bool)
            cppSelf->setPlotAreaBackgroundVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setSeriesColors(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setSeriesColors(QList<QColor>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QColor_IDX], (pyArg)))) {
        overloadId = 0; // setSeriesColors(QList<QColor>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSeriesColors", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        ::QList<QColor> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSeriesColors(QList<QColor>)
            cppSelf->setSeriesColors(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setSeriesGradients(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setSeriesGradients(QList<QLinearGradient>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QLinearGradient_IDX], (pyArg)))) {
        overloadId = 0; // setSeriesGradients(QList<QLinearGradient>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSeriesGradients", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        ::QList<QLinearGradient> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSeriesGradients(QList<QLinearGradient>)
            cppSelf->setSeriesGradients(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setSingleHighlightColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setSingleHighlightColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setSingleHighlightColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSingleHighlightColor", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSingleHighlightColor(QColor)
            cppSelf->setSingleHighlightColor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setSingleHighlightGradient(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphsTheme::setSingleHighlightGradient(QLinearGradient)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), (pyArg)))) {
        overloadId = 0; // setSingleHighlightGradient(QLinearGradient)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSingleHighlightGradient", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLinearGradient cppArg0_local;
        ::QLinearGradient *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSingleHighlightGradient(QLinearGradient)
            cppSelf->setSingleHighlightGradient(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_setTheme(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setTheme", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setTheme", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphsTheme::setTheme(QGraphsTheme::Theme,QGraphsTheme::ForceTheme=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_Theme_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setTheme(QGraphsTheme::Theme,QGraphsTheme::ForceTheme)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_ForceTheme_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setTheme(QGraphsTheme::Theme,QGraphsTheme::ForceTheme)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setTheme", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_force = Shiboken::String::createStaticString("force");
            if (PyDict_Contains(kwds, key_force) != 0) {
                value = PyDict_GetItem(kwds, key_force);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_force);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setTheme", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_ForceTheme_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setTheme", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_force);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setTheme", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]);
            }
        }
        ::QGraphsTheme::Theme cppArg0{QGraphsTheme::Theme::QtGreen};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QGraphsTheme::ForceTheme cppArg1(QGraphsTheme::ForceTheme::No);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTheme(QGraphsTheme::Theme,QGraphsTheme::ForceTheme)
            cppSelf->setTheme(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphsThemeFunc_singleHighlightColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // singleHighlightColor()const
        QColor cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->singleHighlightColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_singleHighlightGradient(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // singleHighlightGradient()const
        QLinearGradient cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->singleHighlightGradient();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_theme(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // theme()const
        QGraphsTheme::Theme cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->theme();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_Theme_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphsThemeFunc_themeDirty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // themeDirty()const
        bool cppResult = const_cast<const ::QGraphsTheme *>(cppSelf)->themeDirty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGraphsTheme_PropertyStrings[] = {
    "axisX::",
    "axisXLabelFont::",
    "axisY::",
    "axisYLabelFont::",
    "axisZ::",
    "axisZLabelFont::",
    "backgroundColor::",
    "backgroundVisible:isBackgroundVisible:",
    "borderColors::",
    "borderWidth::",
    "colorScheme::",
    "colorStyle::",
    "grid::",
    "gridVisible:isGridVisible:",
    "labelBackgroundColor::",
    "labelBackgroundVisible:isLabelBackgroundVisible:",
    "labelBorderVisible:isLabelBorderVisible:",
    "labelFont::",
    "labelTextColor::",
    "labelsVisible::",
    "multiHighlightColor::",
    "plotAreaBackgroundColor::",
    "plotAreaBackgroundVisible:isPlotAreaBackgroundVisible:",
    "seriesColors::",
    "singleHighlightColor::",
    "theme::",
    nullptr // Sentinel
};

static const char *Sbk_QGraphsTheme_EnumFlagInfo[] = {
    "ColorScheme:Enum",
    "ColorStyle:Enum",
    "ForceTheme:Enum",
    "GradientQMLStyle:IntEnum",
    "Theme:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGraphsTheme_methods[] = {
    {"axisX", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_axisX), METH_NOARGS, nullptr},
    {"axisXLabelFont", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_axisXLabelFont), METH_NOARGS, nullptr},
    {"axisY", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_axisY), METH_NOARGS, nullptr},
    {"axisYLabelFont", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_axisYLabelFont), METH_NOARGS, nullptr},
    {"axisZ", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_axisZ), METH_NOARGS, nullptr},
    {"axisZLabelFont", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_axisZLabelFont), METH_NOARGS, nullptr},
    {"backgroundColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_backgroundColor), METH_NOARGS, nullptr},
    {"borderColors", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_borderColors), METH_NOARGS, nullptr},
    {"borderWidth", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_borderWidth), METH_NOARGS, nullptr},
    {"classBegin", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_classBegin), METH_NOARGS, nullptr},
    {"colorScheme", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_colorScheme), METH_NOARGS, nullptr},
    {"colorStyle", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_colorStyle), METH_NOARGS, nullptr},
    {"componentComplete", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_componentComplete), METH_NOARGS, nullptr},
    {"dirtyBits", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_dirtyBits), METH_NOARGS, nullptr},
    {"grid", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_grid), METH_NOARGS, nullptr},
    {"handleBaseColorUpdate", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_handleBaseColorUpdate), METH_NOARGS, nullptr},
    {"handleBaseGradientUpdate", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_handleBaseGradientUpdate), METH_NOARGS, nullptr},
    {"isBackgroundVisible", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_isBackgroundVisible), METH_NOARGS, nullptr},
    {"isGridVisible", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_isGridVisible), METH_NOARGS, nullptr},
    {"isLabelBackgroundVisible", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_isLabelBackgroundVisible), METH_NOARGS, nullptr},
    {"isLabelBorderVisible", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_isLabelBorderVisible), METH_NOARGS, nullptr},
    {"isPlotAreaBackgroundVisible", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_isPlotAreaBackgroundVisible), METH_NOARGS, nullptr},
    {"labelBackgroundColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_labelBackgroundColor), METH_NOARGS, nullptr},
    {"labelFont", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_labelFont), METH_NOARGS, nullptr},
    {"labelTextColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_labelTextColor), METH_NOARGS, nullptr},
    {"labelsVisible", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_labelsVisible), METH_NOARGS, nullptr},
    {"multiHighlightColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_multiHighlightColor), METH_NOARGS, nullptr},
    {"multiHighlightGradient", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_multiHighlightGradient), METH_NOARGS, nullptr},
    {"plotAreaBackgroundColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_plotAreaBackgroundColor), METH_NOARGS, nullptr},
    {"resetColorTheme", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_resetColorTheme), METH_NOARGS, nullptr},
    {"resetDirtyBits", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_resetDirtyBits), METH_NOARGS, nullptr},
    {"resetThemeDirty", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_resetThemeDirty), METH_NOARGS, nullptr},
    {"seriesColors", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_seriesColors), METH_NOARGS, nullptr},
    {"seriesGradients", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_seriesGradients), METH_NOARGS, nullptr},
    {"setAxisX", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setAxisX), METH_O, nullptr},
    {"setAxisXLabelFont", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setAxisXLabelFont), METH_O, nullptr},
    {"setAxisY", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setAxisY), METH_O, nullptr},
    {"setAxisYLabelFont", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setAxisYLabelFont), METH_O, nullptr},
    {"setAxisZ", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setAxisZ), METH_O, nullptr},
    {"setAxisZLabelFont", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setAxisZLabelFont), METH_O, nullptr},
    {"setBackgroundColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setBackgroundColor), METH_O, nullptr},
    {"setBackgroundVisible", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setBackgroundVisible), METH_O, nullptr},
    {"setBorderColors", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setBorderColors), METH_O, nullptr},
    {"setBorderWidth", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setBorderWidth), METH_O, nullptr},
    {"setColorScheme", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setColorScheme), METH_O, nullptr},
    {"setColorStyle", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setColorStyle), METH_O, nullptr},
    {"setGrid", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setGrid), METH_O, nullptr},
    {"setGridVisible", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setGridVisible), METH_O, nullptr},
    {"setLabelBackgroundColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setLabelBackgroundColor), METH_O, nullptr},
    {"setLabelBackgroundVisible", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setLabelBackgroundVisible), METH_O, nullptr},
    {"setLabelBorderVisible", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setLabelBorderVisible), METH_O, nullptr},
    {"setLabelFont", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setLabelFont), METH_O, nullptr},
    {"setLabelTextColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setLabelTextColor), METH_O, nullptr},
    {"setLabelsVisible", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setLabelsVisible), METH_O, nullptr},
    {"setMultiHighlightColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setMultiHighlightColor), METH_O, nullptr},
    {"setMultiHighlightGradient", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setMultiHighlightGradient), METH_O, nullptr},
    {"setPlotAreaBackgroundColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setPlotAreaBackgroundColor), METH_O, nullptr},
    {"setPlotAreaBackgroundVisible", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setPlotAreaBackgroundVisible), METH_O, nullptr},
    {"setSeriesColors", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setSeriesColors), METH_O, nullptr},
    {"setSeriesGradients", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setSeriesGradients), METH_O, nullptr},
    {"setSingleHighlightColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setSingleHighlightColor), METH_O, nullptr},
    {"setSingleHighlightGradient", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setSingleHighlightGradient), METH_O, nullptr},
    {"setTheme", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_setTheme), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"singleHighlightColor", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_singleHighlightColor), METH_NOARGS, nullptr},
    {"singleHighlightGradient", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_singleHighlightGradient), METH_NOARGS, nullptr},
    {"theme", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_theme), METH_NOARGS, nullptr},
    {"themeDirty", reinterpret_cast<PyCFunction>(Sbk_QGraphsThemeFunc_themeDirty), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGraphsTheme_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGraphsTheme *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGraphsThemeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGraphsTheme_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGraphsTheme_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
int *
Sbk_QGraphsTheme_mi_init(const void *cptr)
{
    static int mi_offsets[] = {-2, 0, 0, 0, 0};
    if (mi_offsets[0] == -2) {
        const auto *class_ptr = reinterpret_cast<const QGraphsTheme *>(cptr);
        const auto base = reinterpret_cast<uintptr_t>(class_ptr);
        int *p = mi_offsets;
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(static_cast<const QGraphsTheme *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QQmlParserStatus *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QQmlParserStatus *>(static_cast<const QGraphsTheme *>(static_cast<const void *>(class_ptr)))) - base);
        std::sort(mi_offsets, p);
        auto *end = std::unique(mi_offsets, p);
        *end++ = -1;
        if (mi_offsets[0] == 0)
            std::memmove(&mi_offsets[0], &mi_offsets[1], (end - mi_offsets  - 1) * sizeof(int));
    }
    return mi_offsets;
}
static void * Sbk_QGraphsThemeSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QGraphsTheme *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX]))
        return static_cast< ::QQmlParserStatus *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGraphsTheme_Type = nullptr;
static PyTypeObject *Sbk_QGraphsTheme_TypeF(void)
{
    return _Sbk_QGraphsTheme_Type;
}

static PyType_Slot Sbk_QGraphsTheme_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGraphsTheme_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGraphsTheme_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGraphsTheme_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGraphsTheme_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGraphsTheme_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGraphsTheme_spec = {
    "2:PySide6.QtGraphs.QGraphsTheme",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGraphsTheme_slots
};

} //extern "C"

static void *Sbk_QGraphsTheme_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QGraphsTheme *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QQmlParserStatus >())
        return dynamic_cast< ::QGraphsTheme *>(reinterpret_cast< ::QQmlParserStatus *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QGraphsTheme_Theme(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGraphsTheme::Theme>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGraphsTheme::Theme *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGraphsTheme_Theme_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_Theme_IDX])))
        return Enum_PythonToCpp_QGraphsTheme_Theme;
    return {};
}

static PyObject *QGraphsTheme_Theme_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGraphsTheme::Theme>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGraphsTheme::Theme *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_Theme_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QGraphsTheme_ColorStyle(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGraphsTheme::ColorStyle>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGraphsTheme::ColorStyle *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGraphsTheme_ColorStyle_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_ColorStyle_IDX])))
        return Enum_PythonToCpp_QGraphsTheme_ColorStyle;
    return {};
}

static PyObject *QGraphsTheme_ColorStyle_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGraphsTheme::ColorStyle>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGraphsTheme::ColorStyle *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_ColorStyle_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QGraphsTheme_ForceTheme(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGraphsTheme::ForceTheme>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGraphsTheme::ForceTheme *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGraphsTheme_ForceTheme_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_ForceTheme_IDX])))
        return Enum_PythonToCpp_QGraphsTheme_ForceTheme;
    return {};
}

static PyObject *QGraphsTheme_ForceTheme_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGraphsTheme::ForceTheme>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGraphsTheme::ForceTheme *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_ForceTheme_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QGraphsTheme_ColorScheme(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGraphsTheme::ColorScheme>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGraphsTheme::ColorScheme *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGraphsTheme_ColorScheme_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_ColorScheme_IDX])))
        return Enum_PythonToCpp_QGraphsTheme_ColorScheme;
    return {};
}

static PyObject *QGraphsTheme_ColorScheme_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGraphsTheme::ColorScheme>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGraphsTheme::ColorScheme *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_ColorScheme_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGraphsTheme_PythonToCpp_QGraphsTheme_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGraphsTheme_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGraphsTheme_PythonToCpp_QGraphsTheme_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGraphsTheme_TypeF()))
        return QGraphsTheme_PythonToCpp_QGraphsTheme_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGraphsTheme_PTR_CppToPython_QGraphsTheme(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QGraphsTheme *>(const_cast<void *>(cppIn)), Sbk_QGraphsTheme_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGraphsTheme_SignatureStrings[] = {
    "PySide6.QtGraphs.QGraphsTheme(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,colorScheme:QGraphsTheme.ColorScheme=None,theme:QGraphsTheme.Theme=None,colorStyle:QGraphsTheme.ColorStyle=None,backgroundColor:QColor=None,backgroundVisible:bool=None,plotAreaBackgroundColor:QColor=None,plotAreaBackgroundVisible:bool=None,gridVisible:bool=None,axisXLabelFont:QFont=None,axisYLabelFont:QFont=None,axisZLabelFont:QFont=None,grid:QGraphsLine=None,axisX:QGraphsLine=None,axisY:QGraphsLine=None,axisZ:QGraphsLine=None,labelFont:QFont=None,labelsVisible:bool=None,labelBackgroundColor:QColor=None,labelTextColor:QColor=None,labelBackgroundVisible:bool=None,labelBorderVisible:bool=None,seriesColors:QList[PySide6.QtGui.QColor]=None,borderColors:QList[PySide6.QtGui.QColor]=None,borderWidth:qreal=None,singleHighlightColor:QColor=None,multiHighlightColor:QColor=None)",
    "PySide6.QtGraphs.QGraphsTheme.axisX(self)->PySide6.QtGraphs.QGraphsLine",
    "PySide6.QtGraphs.QGraphsTheme.axisXLabelFont(self)->PySide6.QtGui.QFont",
    "PySide6.QtGraphs.QGraphsTheme.axisY(self)->PySide6.QtGraphs.QGraphsLine",
    "PySide6.QtGraphs.QGraphsTheme.axisYLabelFont(self)->PySide6.QtGui.QFont",
    "PySide6.QtGraphs.QGraphsTheme.axisZ(self)->PySide6.QtGraphs.QGraphsLine",
    "PySide6.QtGraphs.QGraphsTheme.axisZLabelFont(self)->PySide6.QtGui.QFont",
    "PySide6.QtGraphs.QGraphsTheme.backgroundColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtGraphs.QGraphsTheme.borderColors(self)->QList[PySide6.QtGui.QColor]",
    "PySide6.QtGraphs.QGraphsTheme.borderWidth(self)->qreal",
    "PySide6.QtGraphs.QGraphsTheme.classBegin(self)",
    "PySide6.QtGraphs.QGraphsTheme.colorScheme(self)->PySide6.QtGraphs.QGraphsTheme.ColorScheme",
    "PySide6.QtGraphs.QGraphsTheme.colorStyle(self)->PySide6.QtGraphs.QGraphsTheme.ColorStyle",
    "PySide6.QtGraphs.QGraphsTheme.componentComplete(self)",
    "PySide6.QtGraphs.QGraphsTheme.dirtyBits(self)->PySide6.QtGraphs.QGraphsThemeDirtyBitField",
    "PySide6.QtGraphs.QGraphsTheme.grid(self)->PySide6.QtGraphs.QGraphsLine",
    "PySide6.QtGraphs.QGraphsTheme.handleBaseColorUpdate(self)",
    "PySide6.QtGraphs.QGraphsTheme.handleBaseGradientUpdate(self)",
    "PySide6.QtGraphs.QGraphsTheme.isBackgroundVisible(self)->bool",
    "PySide6.QtGraphs.QGraphsTheme.isGridVisible(self)->bool",
    "PySide6.QtGraphs.QGraphsTheme.isLabelBackgroundVisible(self)->bool",
    "PySide6.QtGraphs.QGraphsTheme.isLabelBorderVisible(self)->bool",
    "PySide6.QtGraphs.QGraphsTheme.isPlotAreaBackgroundVisible(self)->bool",
    "PySide6.QtGraphs.QGraphsTheme.labelBackgroundColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtGraphs.QGraphsTheme.labelFont(self)->PySide6.QtGui.QFont",
    "PySide6.QtGraphs.QGraphsTheme.labelTextColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtGraphs.QGraphsTheme.labelsVisible(self)->bool",
    "PySide6.QtGraphs.QGraphsTheme.multiHighlightColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtGraphs.QGraphsTheme.multiHighlightGradient(self)->PySide6.QtGui.QLinearGradient",
    "PySide6.QtGraphs.QGraphsTheme.plotAreaBackgroundColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtGraphs.QGraphsTheme.resetColorTheme(self)",
    "PySide6.QtGraphs.QGraphsTheme.resetDirtyBits(self)",
    "PySide6.QtGraphs.QGraphsTheme.resetThemeDirty(self)",
    "PySide6.QtGraphs.QGraphsTheme.seriesColors(self)->QList[PySide6.QtGui.QColor]",
    "PySide6.QtGraphs.QGraphsTheme.seriesGradients(self)->QList[PySide6.QtGui.QLinearGradient]",
    "PySide6.QtGraphs.QGraphsTheme.setAxisX(self,newAxisX:PySide6.QtGraphs.QGraphsLine)",
    "PySide6.QtGraphs.QGraphsTheme.setAxisXLabelFont(self,newAxisXLabelFont:typing.Union[PySide6.QtGui.QFont, QString, QStringList])",
    "PySide6.QtGraphs.QGraphsTheme.setAxisY(self,newAxisY:PySide6.QtGraphs.QGraphsLine)",
    "PySide6.QtGraphs.QGraphsTheme.setAxisYLabelFont(self,newAxisYLabelFont:typing.Union[PySide6.QtGui.QFont, QString, QStringList])",
    "PySide6.QtGraphs.QGraphsTheme.setAxisZ(self,newAxisZ:PySide6.QtGraphs.QGraphsLine)",
    "PySide6.QtGraphs.QGraphsTheme.setAxisZLabelFont(self,newAxisZLabelFont:typing.Union[PySide6.QtGui.QFont, QString, QStringList])",
    "PySide6.QtGraphs.QGraphsTheme.setBackgroundColor(self,newBackgroundColor:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGraphs.QGraphsTheme.setBackgroundVisible(self,newBackgroundVisible:bool)",
    "PySide6.QtGraphs.QGraphsTheme.setBorderColors(self,newBorderColors:QList[PySide6.QtGui.QColor])",
    "PySide6.QtGraphs.QGraphsTheme.setBorderWidth(self,newBorderWidth:qreal)",
    "PySide6.QtGraphs.QGraphsTheme.setColorScheme(self,newColorScheme:PySide6.QtGraphs.QGraphsTheme.ColorScheme)",
    "PySide6.QtGraphs.QGraphsTheme.setColorStyle(self,newColorStyle:PySide6.QtGraphs.QGraphsTheme.ColorStyle)",
    "PySide6.QtGraphs.QGraphsTheme.setGrid(self,newGrid:PySide6.QtGraphs.QGraphsLine)",
    "PySide6.QtGraphs.QGraphsTheme.setGridVisible(self,newGridVisibility:bool)",
    "PySide6.QtGraphs.QGraphsTheme.setLabelBackgroundColor(self,newLabelBackgroundColor:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGraphs.QGraphsTheme.setLabelBackgroundVisible(self,newLabelBackgroundVisibility:bool)",
    "PySide6.QtGraphs.QGraphsTheme.setLabelBorderVisible(self,newLabelBorderVisibility:bool)",
    "PySide6.QtGraphs.QGraphsTheme.setLabelFont(self,newFont:typing.Union[PySide6.QtGui.QFont, QString, QStringList])",
    "PySide6.QtGraphs.QGraphsTheme.setLabelTextColor(self,newLabelTextColor:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGraphs.QGraphsTheme.setLabelsVisible(self,newLabelsVisibility:bool)",
    "PySide6.QtGraphs.QGraphsTheme.setMultiHighlightColor(self,newMultiHighlightColor:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGraphs.QGraphsTheme.setMultiHighlightGradient(self,gradient:PySide6.QtGui.QLinearGradient)",
    "PySide6.QtGraphs.QGraphsTheme.setPlotAreaBackgroundColor(self,newBackgroundColor:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGraphs.QGraphsTheme.setPlotAreaBackgroundVisible(self,newBackgroundVisibility:bool)",
    "PySide6.QtGraphs.QGraphsTheme.setSeriesColors(self,newSeriesColors:QList[PySide6.QtGui.QColor])",
    "PySide6.QtGraphs.QGraphsTheme.setSeriesGradients(self,newSeriesGradients:QList[PySide6.QtGui.QLinearGradient])",
    "PySide6.QtGraphs.QGraphsTheme.setSingleHighlightColor(self,newSingleHighlightColor:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGraphs.QGraphsTheme.setSingleHighlightGradient(self,gradient:PySide6.QtGui.QLinearGradient)",
    "PySide6.QtGraphs.QGraphsTheme.setTheme(self,newTheme:PySide6.QtGraphs.QGraphsTheme.Theme,force:PySide6.QtGraphs.QGraphsTheme.ForceTheme=QGraphsTheme.ForceTheme.No)",
    "PySide6.QtGraphs.QGraphsTheme.singleHighlightColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtGraphs.QGraphsTheme.singleHighlightGradient(self)->PySide6.QtGui.QLinearGradient",
    "PySide6.QtGraphs.QGraphsTheme.theme(self)->PySide6.QtGraphs.QGraphsTheme.Theme",
    "PySide6.QtGraphs.QGraphsTheme.themeDirty(self)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QGraphsTheme_SignatureByteSize = 957;
static constexpr uint8_t QGraphsTheme_SignatureBytes[957] = {
    0x78, 0xda, 0xd5, 0x59, 0xdf, 0x4f, 0xdb, 0x30, 0x10, 0x7e, 0xdf, 0x5f, 0xc1, 0xe3, 0x3a, 0x65,
    0x91, 0x26, 0x4d, 0x3c, 0x44, 0x62, 0x12, 0x05, 0xd1, 0x49, 0x0b, 0xd0, 0xae, 0x85, 0x2d, 0x41,
    0x3c, 0xb8, 0x8d, 0x49, 0xbd, 0xb9, 0x4e, 0x66, 0xbb, 0x82, 0xfe, 0xf7, 0x8b, 0x9d, 0x26, 0xce,
    0x0f, 0x27, 0x71, 0x48, 0x41, 0xea, 0x03, 0x85, 0xde, 0x9d, 0xbf, 0xbb, 0xb3, 0xcf, 0xe7, 0xcf,
    0x66, 0xba, 0x9b, 0xa3, 0x00, 0x9e, 0xda, 0x33, 0x3e, 0xa1, 0x20, 0x5e, 0x33, 0x7b, 0x96, 0xfe,
    0x5e, 0xac, 0xe1, 0x06, 0x7e, 0x64, 0x10, 0x3f, 0x59, 0x31, 0xa0, 0x90, 0x70, 0x67, 0x9a, 0x5b,
    0x5e, 0x44, 0x14, 0xda, 0xb3, 0xdb, 0xe5, 0x1f, 0xb8, 0xe2, 0x67, 0x64, 0x8b, 0x71, 0xcc, 0xa9,
    0xf5, 0xc9, 0xf9, 0x01, 0x77, 0xcf, 0x11, 0x0d, 0x6e, 0x09, 0xde, 0x9d, 0xdd, 0x44, 0x04, 0x5a,
    0xab, 0x08, 0x47, 0x74, 0xbe, 0x12, 0x48, 0x4e, 0x11, 0xd6, 0xbe, 0x50, 0x8a, 0xd4, 0x92, 0xd7,
    0x6d, 0x16, 0x4a, 0x9b, 0xe2, 0xf0, 0x1d, 0xd6, 0xc2, 0x08, 0x79, 0x6a, 0xb7, 0x04, 0xab, 0xbf,
    0x21, 0x8d, 0xb6, 0x24, 0x90, 0x1a, 0x67, 0x26, 0x7f, 0x55, 0x75, 0xf7, 0x88, 0xa1, 0x65, 0x02,
    0xb5, 0x8c, 0x22, 0x9c, 0xea, 0x62, 0x1c, 0xf1, 0x73, 0x0a, 0xc1, 0xb8, 0x65, 0x7c, 0xdd, 0xa6,
    0x8e, 0x13, 0x52, 0xa4, 0x91, 0x82, 0x17, 0xc4, 0x7e, 0xbb, 0x60, 0x09, 0xf1, 0x55, 0x94, 0x4c,
    0xe3, 0x4c, 0x7c, 0x2a, 0x8d, 0xd7, 0xa8, 0xf1, 0xb5, 0x1a, 0xe1, 0x23, 0x9b, 0x05, 0x17, 0x11,
    0x58, 0xf0, 0xa1, 0x17, 0x7b, 0x7a, 0xb1, 0x5f, 0x17, 0x63, 0x9d, 0x3f, 0x29, 0x64, 0xf5, 0xac,
    0xa4, 0xbc, 0x6d, 0xc2, 0xa4, 0xc1, 0x02, 0xbe, 0xf0, 0x06, 0x55, 0xdb, 0x44, 0xa6, 0x06, 0x49,
    0x2d, 0x41, 0x5a, 0x57, 0x32, 0x48, 0x11, 0x64, 0x12, 0x8e, 0x39, 0x33, 0x17, 0x31, 0xfe, 0xa0,
    0x4a, 0x73, 0xb2, 0x45, 0x76, 0xea, 0xea, 0x71, 0xbf, 0xee, 0x12, 0xa5, 0x9f, 0xf5, 0x2f, 0x14,
    0xf0, 0xb5, 0xf3, 0x2f, 0x59, 0xed, 0xcc, 0x25, 0x22, 0x21, 0x86, 0xdf, 0x51, 0xb8, 0xc6, 0xc9,
    0x8f, 0x26, 0xa3, 0xcd, 0x16, 0x73, 0xd4, 0xac, 0x1f, 0x7d, 0x98, 0xb6, 0x6d, 0x33, 0x5b, 0x2e,
    0x9f, 0xdc, 0x6c, 0xa3, 0xcf, 0xdf, 0x9a, 0x4c, 0xc5, 0x42, 0x99, 0xe0, 0xe4, 0x65, 0xa3, 0x01,
    0x14, 0xf9, 0x0a, 0x95, 0x01, 0x8e, 0x77, 0xa0, 0x78, 0xbc, 0x03, 0xc5, 0xe3, 0x1f, 0x28, 0x1e,
    0xff, 0x00, 0xf1, 0x54, 0x1a, 0x4d, 0x03, 0x90, 0xd4, 0x75, 0x21, 0x15, 0xca, 0x33, 0x83, 0x69,
    0xa9, 0x52, 0x23, 0x34, 0x59, 0xbe, 0x19, 0x98, 0xac, 0xe2, 0x8e, 0x61, 0x2b, 0x0c, 0x18, 0x1b,
    0xc3, 0x10, 0x91, 0x74, 0x54, 0x97, 0xb9, 0xea, 0xde, 0x5d, 0x6b, 0x52, 0x6b, 0xf7, 0x46, 0xd0,
    0xa2, 0xa3, 0xf7, 0x41, 0x16, 0xf6, 0x9d, 0xc0, 0x9b, 0x38, 0xd9, 0x88, 0x24, 0xd9, 0x9b, 0x9b,
    0x18, 0x43, 0x0e, 0x8d, 0x32, 0x0d, 0x10, 0xe5, 0xbb, 0x31, 0xe2, 0xcc, 0x28, 0x9a, 0xcb, 0xbd,
    0xf5, 0x15, 0x82, 0x38, 0xe8, 0x40, 0x16, 0x6d, 0xfc, 0x00, 0x05, 0xbd, 0x06, 0x24, 0xc0, 0x70,
    0x0c, 0x18, 0x94, 0x33, 0x71, 0x17, 0x07, 0xc0, 0x30, 0x35, 0x35, 0x32, 0x91, 0x06, 0x28, 0x99,
    0x99, 0x1e, 0x83, 0x11, 0xab, 0x75, 0xef, 0x2c, 0x19, 0xd1, 0xa7, 0x3b, 0x47, 0x4f, 0xd4, 0x41,
    0xd9, 0x6b, 0x9c, 0xab, 0x3d, 0x38, 0x5e, 0x01, 0x51, 0x3c, 0x5a, 0x7a, 0x0d, 0x9f, 0x36, 0xd1,
    0x80, 0x1e, 0x28, 0xba, 0xa3, 0x73, 0x40, 0x0b, 0xc1, 0xc3, 0xfb, 0x59, 0xf9, 0xac, 0x1e, 0x1a,
    0x0b, 0xeb, 0x3f, 0x25, 0x9a, 0xf3, 0x73, 0x40, 0x14, 0x65, 0xb4, 0xac, 0xbe, 0x1b, 0x00, 0xc5,
    0x2e, 0x03, 0x34, 0x33, 0xea, 0x40, 0x6e, 0x60, 0x8a, 0x03, 0x62, 0xa5, 0x90, 0xc1, 0x34, 0x61,
    0xc5, 0xb8, 0x47, 0x26, 0x63, 0x2e, 0xcb, 0xbd, 0xc9, 0x64, 0x88, 0xea, 0x52, 0x46, 0x63, 0x8a,
    0x44, 0x6b, 0xf8, 0xd9, 0x94, 0xa2, 0x65, 0xf3, 0xdc, 0x0e, 0x58, 0x5e, 0x93, 0x6e, 0x64, 0x7e,
    0x9e, 0x13, 0x28, 0x8b, 0xc0, 0x67, 0xf9, 0xcd, 0x69, 0x6b, 0xab, 0x23, 0x43, 0xc8, 0x32, 0x57,
    0xc8, 0xb1, 0x15, 0x33, 0xe7, 0xbb, 0x38, 0xe1, 0x86, 0xf6, 0x1d, 0x41, 0x11, 0x79, 0xd0, 0x6c,
    0x3c, 0xeb, 0x64, 0x36, 0xe7, 0x34, 0x31, 0xc9, 0xff, 0x10, 0xf9, 0x3e, 0x1a, 0xfa, 0xf7, 0x4a,
    0x6e, 0xbd, 0x43, 0xa4, 0xe4, 0xe9, 0x53, 0xf2, 0xde, 0x2b, 0x25, 0xbf, 0xe4, 0xd6, 0x3f, 0x44,
    0x4a, 0xbe, 0x3e, 0x25, 0xff, 0x3d, 0x52, 0xd2, 0x35, 0x02, 0x11, 0x40, 0xf5, 0x66, 0xd4, 0x16,
    0x81, 0xb4, 0x48, 0x3c, 0xbb, 0x80, 0x23, 0xf2, 0x25, 0x0b, 0xa4, 0x62, 0xf4, 0x33, 0x5c, 0x82,
    0xd3, 0xaf, 0x89, 0xd5, 0x3d, 0xa0, 0x08, 0x88, 0x90, 0xab, 0xf7, 0x71, 0x6e, 0x4f, 0x70, 0xb4,
    0x04, 0x38, 0x83, 0xcb, 0x80, 0xb6, 0x84, 0xa1, 0x90, 0xc0, 0xe0, 0x04, 0x91, 0x9e, 0x29, 0x15,
    0xfb, 0x78, 0x39, 0xa9, 0xe2, 0xad, 0xcc, 0x04, 0xb2, 0xca, 0x72, 0x25, 0x9a, 0xe1, 0xcd, 0xcc,
    0x18, 0x5f, 0xf1, 0x5e, 0x05, 0x5f, 0xb8, 0xca, 0x19, 0xe0, 0x5c, 0x54, 0x98, 0xad, 0xc0, 0x29,
    0xc8, 0x1c, 0x63, 0x9a, 0x6b, 0xec, 0x2b, 0xa7, 0xba, 0xca, 0x95, 0x7c, 0xe7, 0x30, 0xa5, 0xbd,
    0x06, 0x8e, 0x26, 0x19, 0xd5, 0x14, 0x2e, 0xc4, 0x97, 0xa1, 0x7b, 0xae, 0xca, 0xde, 0x32, 0x5c,
    0x29, 0x43, 0x18, 0xf1, 0x9d, 0x69, 0x5d, 0xb8, 0x4d, 0x4c, 0x48, 0x40, 0xea, 0x94, 0xc7, 0xb4,
    0x8f, 0x5a, 0xc8, 0xaa, 0x26, 0xbd, 0xd7, 0x4e, 0x5e, 0x8d, 0xc9, 0x2a, 0x6c, 0xa5, 0xea, 0x8f,
    0x5b, 0xea, 0xa6, 0x6f, 0xdc, 0x43, 0xdd, 0x3a, 0xfb, 0xcc, 0x93, 0x50, 0x0f, 0x48, 0xc7, 0xb6,
    0xf2, 0x4c, 0xbb, 0x28, 0xac, 0xff, 0x7a, 0x5c, 0x37, 0x70, 0x63, 0x81, 0xa9, 0xd1, 0x1d, 0xd3,
    0x44, 0x5d, 0x37, 0x13, 0x75, 0x2b, 0xdc, 0x7f, 0x73, 0x5a, 0xb9, 0xa1, 0x81, 0x93, 0x69, 0x0b,
    0x67, 0x3f, 0xf2, 0xa3, 0xba, 0xfd, 0x36, 0xaa, 0x39, 0xb2, 0x7b, 0x15, 0xde, 0xbc, 0xca, 0xff,
    0x05, 0xe0, 0xdc, 0xf0, 0xf5, 0xd5, 0x18, 0xbf, 0x7c, 0x23, 0x50, 0x2e, 0x72, 0xb9, 0x63, 0x72,
    0x45, 0x30, 0x71, 0xa7, 0x79, 0xc4, 0x55, 0x3e, 0x75, 0x2f, 0xbc, 0x47, 0x54, 0x09, 0x95, 0xf8,
    0xdf, 0x68, 0x2b, 0x2d, 0x4a, 0xcc, 0x68, 0x61, 0xc0, 0x89, 0xe4, 0xa7, 0xf5, 0x14, 0xd1, 0x55,
    0x97, 0xe5, 0x95, 0xb0, 0x49, 0xff, 0xe9, 0xd3, 0x20, 0xb7, 0x6f, 0xa2, 0xce, 0x18, 0x9b, 0xd6,
    0xf8, 0x75, 0x97, 0x73, 0xd6, 0x32, 0xab, 0x03, 0x5f, 0x12, 0xb8, 0xf9, 0xf3, 0xe9, 0xc2, 0xe0,
    0xe1, 0x94, 0x57, 0xae, 0xf6, 0xfb, 0x57, 0x97, 0xff, 0x49, 0x75, 0x28, 0xe1
};
#endif

PyTypeObject *init_QGraphsTheme(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX].type;

    Shiboken::AutoDecRef Sbk_QGraphsTheme_Type_bases(PyTuple_Pack(2,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX])),
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX]))));

    _Sbk_QGraphsTheme_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGraphsTheme",
        "QGraphsTheme*",
        &Sbk_QGraphsTheme_spec,
        &Shiboken::callCppDestructor< QGraphsTheme >,
        Sbk_QGraphsTheme_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGraphsTheme_TypeF(); // references _Sbk_QGraphsTheme_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGraphsTheme_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGraphsTheme_SignatureBytes, QGraphsTheme_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGraphsTheme_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGraphsTheme_PythonToCpp_QGraphsTheme_PTR,
        is_QGraphsTheme_PythonToCpp_QGraphsTheme_PTR_Convertible,
        QGraphsTheme_PTR_CppToPython_QGraphsTheme);

    Shiboken::Conversions::registerConverterName(converter, "QGraphsTheme");
    Shiboken::Conversions::registerConverterName(converter, "QGraphsTheme*");
    Shiboken::Conversions::registerConverterName(converter, "QGraphsTheme&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGraphsTheme).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGraphsThemeWrapper).name());

    MultipleInheritanceInitFunction func = Sbk_QGraphsTheme_mi_init;
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QGraphsTheme_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QGraphsTheme_TypeF(), &Sbk_QGraphsThemeSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QGraphsTheme_TypeF(), &Sbk_QGraphsTheme_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QGraphsTheme_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Theme'.
    const char *Theme_Initializer[] = {
        "QtGreen",
        "QtGreenNeon",
        "MixSeries",
        "OrangeSeries",
        "YellowSeries",
        "BlueSeries",
        "PurpleSeries",
        "GreySeries",
        "UserDefined",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Theme_InitializerValues[] = {
        int8_t(QGraphsTheme::Theme::QtGreen),      //  0x00  0
        int8_t(QGraphsTheme::Theme::QtGreenNeon),  //  0x01  1
        int8_t(QGraphsTheme::Theme::MixSeries),    //  0x02  2
        int8_t(QGraphsTheme::Theme::OrangeSeries), //  0x03  3
        int8_t(QGraphsTheme::Theme::YellowSeries), //  0x04  4
        int8_t(QGraphsTheme::Theme::BlueSeries),   //  0x05  5
        int8_t(QGraphsTheme::Theme::PurpleSeries), //  0x06  6
        int8_t(QGraphsTheme::Theme::GreySeries),   //  0x07  7
        int8_t(QGraphsTheme::Theme::UserDefined)   //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGraphsTheme_TypeF(),
        "2:PySide6.QtGraphs.QGraphsTheme.Theme",
        Theme_Initializer, Theme_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_Theme_IDX].type = EType;
    // Register converter for enum 'QGraphsTheme::Theme'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGraphsTheme_Theme_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGraphsTheme_Theme,
            is_Enum_PythonToCpp_QGraphsTheme_Theme_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGraphsTheme::Theme");
        Shiboken::Conversions::registerConverterAlias(converter, "Theme");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Theme' enum.

    // Initialization of enum 'ColorStyle'.
    const char *ColorStyle_Initializer[] = {
        "Uniform",
        "ObjectGradient",
        "RangeGradient",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t ColorStyle_InitializerValues[] = {
        int8_t(QGraphsTheme::ColorStyle::Uniform),        //  0x00  0
        int8_t(QGraphsTheme::ColorStyle::ObjectGradient), //  0x01  1
        int8_t(QGraphsTheme::ColorStyle::RangeGradient)   //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGraphsTheme_TypeF(),
        "2:PySide6.QtGraphs.QGraphsTheme.ColorStyle",
        ColorStyle_Initializer, ColorStyle_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_ColorStyle_IDX].type = EType;
    // Register converter for enum 'QGraphsTheme::ColorStyle'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGraphsTheme_ColorStyle_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGraphsTheme_ColorStyle,
            is_Enum_PythonToCpp_QGraphsTheme_ColorStyle_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGraphsTheme::ColorStyle");
        Shiboken::Conversions::registerConverterAlias(converter, "ColorStyle");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ColorStyle' enum.

    // Initialization of enum 'ForceTheme'.
    const char *ForceTheme_Initializer[] = {
        "No",
        "Yes",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t ForceTheme_InitializerValues[] = {
        int8_t(QGraphsTheme::ForceTheme::No), //  0x00  0
        int8_t(QGraphsTheme::ForceTheme::Yes) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGraphsTheme_TypeF(),
        "2:PySide6.QtGraphs.QGraphsTheme.ForceTheme",
        ForceTheme_Initializer, ForceTheme_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_ForceTheme_IDX].type = EType;
    // Register converter for enum 'QGraphsTheme::ForceTheme'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGraphsTheme_ForceTheme_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGraphsTheme_ForceTheme,
            is_Enum_PythonToCpp_QGraphsTheme_ForceTheme_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGraphsTheme::ForceTheme");
        Shiboken::Conversions::registerConverterAlias(converter, "ForceTheme");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ForceTheme' enum.

    // Initialization of enum 'ColorScheme'.
    const char *ColorScheme_Initializer[] = {
        "Automatic",
        "Light",
        "Dark",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t ColorScheme_InitializerValues[] = {
        int8_t(QGraphsTheme::ColorScheme::Automatic), //  0x00  0
        int8_t(QGraphsTheme::ColorScheme::Light),     //  0x01  1
        int8_t(QGraphsTheme::ColorScheme::Dark)       //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGraphsTheme_TypeF(),
        "2:PySide6.QtGraphs.QGraphsTheme.ColorScheme",
        ColorScheme_Initializer, ColorScheme_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_ColorScheme_IDX].type = EType;
    // Register converter for enum 'QGraphsTheme::ColorScheme'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGraphsTheme_ColorScheme_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGraphsTheme_ColorScheme,
            is_Enum_PythonToCpp_QGraphsTheme_ColorScheme_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGraphsTheme::ColorScheme");
        Shiboken::Conversions::registerConverterAlias(converter, "ColorScheme");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ColorScheme' enum.

    PySide::Signal::registerSignals(pyType, &::QGraphsTheme::staticMetaObject);
    qRegisterMetaType< ::QGraphsTheme::Theme >("QGraphsTheme::Theme");
    qRegisterMetaType< ::QGraphsTheme::ColorStyle >("QGraphsTheme::ColorStyle");
    qRegisterMetaType< ::QGraphsTheme::ForceTheme >("QGraphsTheme::ForceTheme");
    qRegisterMetaType< ::QGraphsTheme::ColorScheme >("QGraphsTheme::ColorScheme");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QGraphsTheme::staticMetaObject, sizeof(QGraphsThemeWrapper));

    return pyType;
}
