// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qitemmodelsurfacedataproxy_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtGraphs/qitemmodelsurfacedataproxy.h>
#include <QtGraphs/qsurface3dseries.h>
#include <QtGraphs/qsurfacedataitem.h>
#include <qabstractitemmodel.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qregularexpression.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QItemModelSurfaceDataProxyWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QItemModelSurfaceDataProxyWrapper::QItemModelSurfaceDataProxyWrapper(::QAbstractItemModel * itemModel, ::QObject * parent) : QItemModelSurfaceDataProxy(itemModel, parent)
{
}

QItemModelSurfaceDataProxyWrapper::QItemModelSurfaceDataProxyWrapper(::QAbstractItemModel * itemModel, const ::QString & rowRole, const ::QString & columnRole, const ::QString & xPosRole, const ::QString & yPosRole, const ::QString & zPosRole, ::QObject * parent) : QItemModelSurfaceDataProxy(itemModel, rowRole, columnRole, xPosRole, yPosRole, zPosRole, parent)
{
}

QItemModelSurfaceDataProxyWrapper::QItemModelSurfaceDataProxyWrapper(::QAbstractItemModel * itemModel, const ::QString & rowRole, const ::QString & columnRole, const ::QString & xPosRole, const ::QString & yPosRole, const ::QString & zPosRole, const ::QStringList & rowCategories, const ::QStringList & columnCategories, ::QObject * parent) : QItemModelSurfaceDataProxy(itemModel, rowRole, columnRole, xPosRole, yPosRole, zPosRole, rowCategories, columnCategories, parent)
{
}

QItemModelSurfaceDataProxyWrapper::QItemModelSurfaceDataProxyWrapper(::QAbstractItemModel * itemModel, const ::QString & rowRole, const ::QString & columnRole, const ::QString & yPosRole, ::QObject * parent) : QItemModelSurfaceDataProxy(itemModel, rowRole, columnRole, yPosRole, parent)
{
}

QItemModelSurfaceDataProxyWrapper::QItemModelSurfaceDataProxyWrapper(::QAbstractItemModel * itemModel, const ::QString & rowRole, const ::QString & columnRole, const ::QString & yPosRole, const ::QStringList & rowCategories, const ::QStringList & columnCategories, ::QObject * parent) : QItemModelSurfaceDataProxy(itemModel, rowRole, columnRole, yPosRole, rowCategories, columnCategories, parent)
{
}

QItemModelSurfaceDataProxyWrapper::QItemModelSurfaceDataProxyWrapper(::QAbstractItemModel * itemModel, const ::QString & yPosRole, ::QObject * parent) : QItemModelSurfaceDataProxy(itemModel, yPosRole, parent)
{
}

QItemModelSurfaceDataProxyWrapper::QItemModelSurfaceDataProxyWrapper(::QObject * parent) : QItemModelSurfaceDataProxy(parent)
{
}

void QItemModelSurfaceDataProxyWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QItemModelSurfaceDataProxy", funcName);
        return;
    }
}

void QItemModelSurfaceDataProxyWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QItemModelSurfaceDataProxy", funcName);
        return;
    }
}

void QItemModelSurfaceDataProxyWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QItemModelSurfaceDataProxy", funcName);
        return;
    }
}

void QItemModelSurfaceDataProxyWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QItemModelSurfaceDataProxy", funcName);
        return;
    }
}

bool QItemModelSurfaceDataProxyWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QItemModelSurfaceDataProxy", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QItemModelSurfaceDataProxy", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QItemModelSurfaceDataProxyWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QItemModelSurfaceDataProxy", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QItemModelSurfaceDataProxy", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QItemModelSurfaceDataProxyWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QItemModelSurfaceDataProxy", funcName);
        return;
    }
}

const QMetaObject *QItemModelSurfaceDataProxyWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QItemModelSurfaceDataProxy::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QItemModelSurfaceDataProxyWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QItemModelSurfaceDataProxy::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QItemModelSurfaceDataProxyWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QItemModelSurfaceDataProxyWrapper *>(this));
    return QItemModelSurfaceDataProxy::qt_metacast(_clname);
}

QItemModelSurfaceDataProxyWrapper::~QItemModelSurfaceDataProxyWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QItemModelSurfaceDataProxy_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QItemModelSurfaceDataProxy >()))
        return -1;

    QItemModelSurfaceDataProxyWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[9];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOOOOOOOO:QItemModelSurfaceDataProxy", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::QItemModelSurfaceDataProxy(QAbstractItemModel*,QObject*=)
    // 1: QItemModelSurfaceDataProxy::QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QString,QObject*=)
    // 2: QItemModelSurfaceDataProxy::QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QString,QStringList,QStringList,QObject*=)
    // 3: QItemModelSurfaceDataProxy::QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QObject*=)
    // 4: QItemModelSurfaceDataProxy::QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QStringList,QStringList,QObject*=)
    // 5: QItemModelSurfaceDataProxy::QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QObject*=)
    // 6: QItemModelSurfaceDataProxy::QItemModelSurfaceDataProxy(QObject*=)
    if (numArgs == 0) {
        overloadId = 6; // QItemModelSurfaceDataProxy(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QItemModelSurfaceDataProxy(QAbstractItemModel*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QItemModelSurfaceDataProxy(QAbstractItemModel*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 5; // QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QObject*)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))) {
                overloadId = 5; // QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QObject*)
            } else if (numArgs >= 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 3; // QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QObject*)
                } else if (numArgs >= 6
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[4])))
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[5])))) {
                    if (numArgs == 6) {
                        overloadId = 4; // QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QStringList,QStringList,QObject*)
                    } else if (numArgs >= 7
                        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[6])))) {
                        overloadId = 4; // QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QStringList,QStringList,QObject*)
                    }
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4])))) {
                    overloadId = 3; // QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QObject*)
                } else if (numArgs >= 6
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[5])))) {
                    if (numArgs == 6) {
                        overloadId = 1; // QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QString,QObject*)
                    } else if (numArgs >= 8
                        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[6])))
                        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[7])))) {
                        if (numArgs == 8) {
                            overloadId = 2; // QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QString,QStringList,QStringList,QObject*)
                        } else if (numArgs >= 9
                            && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[8])))) {
                            overloadId = 2; // QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QString,QStringList,QStringList,QObject*)
                        }
                    } else if (numArgs >= 7
                        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[6])))) {
                        overloadId = 1; // QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QString,QObject*)
                    }
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 6; // QItemModelSurfaceDataProxy(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QItemModelSurfaceDataProxy(QAbstractItemModel *itemModel, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAbstractItemModel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemModelSurfaceDataProxy(QAbstractItemModel*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QItemModelSurfaceDataProxyWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QItemModelSurfaceDataProxyWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 1: // QItemModelSurfaceDataProxy(QAbstractItemModel *itemModel, const QString &rowRole, const QString &columnRole, const QString &xPosRole, const QString &yPosRole, const QString &zPosRole, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAbstractItemModel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QString cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QString cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return -1;
            ::QObject *cppArg6 = nullptr;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QString,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QItemModelSurfaceDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QItemModelSurfaceDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[6], self);
            }
            break;
        }
        case 2: // QItemModelSurfaceDataProxy(QAbstractItemModel *itemModel, const QString &rowRole, const QString &columnRole, const QString &xPosRole, const QString &yPosRole, const QString &zPosRole, const QStringList &rowCategories, const QStringList &columnCategories, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAbstractItemModel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QString cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QString cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            ::QStringList cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            ::QStringList cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return -1;
            ::QObject *cppArg8 = nullptr;
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QString,QString,QStringList,QStringList,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QItemModelSurfaceDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QItemModelSurfaceDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[8], self);
            }
            break;
        }
        case 3: // QItemModelSurfaceDataProxy(QAbstractItemModel *itemModel, const QString &rowRole, const QString &columnRole, const QString &yPosRole, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAbstractItemModel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return -1;
            ::QObject *cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QItemModelSurfaceDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QItemModelSurfaceDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[4], self);
            }
            break;
        }
        case 4: // QItemModelSurfaceDataProxy(QAbstractItemModel *itemModel, const QString &rowRole, const QString &columnRole, const QString &yPosRole, const QStringList &rowCategories, const QStringList &columnCategories, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAbstractItemModel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QStringList cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QStringList cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return -1;
            ::QObject *cppArg6 = nullptr;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QString,QString,QStringList,QStringList,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QItemModelSurfaceDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QItemModelSurfaceDataProxyWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[6], self);
            }
            break;
        }
        case 5: // QItemModelSurfaceDataProxy(QAbstractItemModel *itemModel, const QString &yPosRole, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAbstractItemModel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QObject *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemModelSurfaceDataProxy(QAbstractItemModel*,QString,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QItemModelSurfaceDataProxyWrapper(cppArg0, cppArg1, cppArg2);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QItemModelSurfaceDataProxyWrapper(cppArg0, cppArg1, cppArg2);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[2], self);
            }
            break;
        }
        case 6: // QItemModelSurfaceDataProxy(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QItemModelSurfaceDataProxy(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QItemModelSurfaceDataProxyWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QItemModelSurfaceDataProxyWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QItemModelSurfaceDataProxy >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_autoColumnCategories(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoColumnCategories()const
        bool cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->autoColumnCategories();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_autoRowCategories(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoRowCategories()const
        bool cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->autoRowCategories();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_columnCategories(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // columnCategories()const
        QStringList cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->columnCategories();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_columnCategoryIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::columnCategoryIndex(QString)->qsizetype
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // columnCategoryIndex(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "columnCategoryIndex", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // columnCategoryIndex(QString)
            qsizetype cppResult = cppSelf->columnCategoryIndex(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_columnRole(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // columnRole()const
        QString cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->columnRole();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_columnRolePattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // columnRolePattern()const
        QRegularExpression cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->columnRolePattern();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_columnRoleReplace(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // columnRoleReplace()const
        QString cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->columnRoleReplace();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_itemModel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // itemModel()const
        QAbstractItemModel * cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->itemModel();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_multiMatchBehavior(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // multiMatchBehavior()const
        QItemModelSurfaceDataProxy::MultiMatchBehavior cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->multiMatchBehavior();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_MultiMatchBehavior_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_remap(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "remap", 7, 7, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::remap(QString,QString,QString,QString,QString,QStringList,QStringList)
    if (numArgs == 7
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[6])))) {
        overloadId = 0; // remap(QString,QString,QString,QString,QString,QStringList,QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "remap", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QString cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QString cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QStringList cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        ::QStringList cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);

        if (Shiboken::Errors::occurred() == nullptr) {
            // remap(QString,QString,QString,QString,QString,QStringList,QStringList)
            cppSelf->remap(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_rowCategories(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rowCategories()const
        QStringList cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->rowCategories();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_rowCategoryIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::rowCategoryIndex(QString)->qsizetype
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // rowCategoryIndex(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rowCategoryIndex", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rowCategoryIndex(QString)
            qsizetype cppResult = cppSelf->rowCategoryIndex(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_rowRole(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rowRole()const
        QString cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->rowRole();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_rowRolePattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rowRolePattern()const
        QRegularExpression cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->rowRolePattern();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_rowRoleReplace(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rowRoleReplace()const
        QString cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->rowRoleReplace();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setAutoColumnCategories(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setAutoColumnCategories(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoColumnCategories(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoColumnCategories", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoColumnCategories(bool)
            cppSelf->setAutoColumnCategories(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setAutoRowCategories(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setAutoRowCategories(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoRowCategories(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoRowCategories", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoRowCategories(bool)
            cppSelf->setAutoRowCategories(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setColumnCategories(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setColumnCategories(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setColumnCategories(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColumnCategories", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColumnCategories(QStringList)
            cppSelf->setColumnCategories(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setColumnRole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setColumnRole(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setColumnRole(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColumnRole", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColumnRole(QString)
            cppSelf->setColumnRole(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setColumnRolePattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setColumnRolePattern(QRegularExpression)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
        overloadId = 0; // setColumnRolePattern(QRegularExpression)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColumnRolePattern", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRegularExpression cppArg0_local;
        ::QRegularExpression *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setColumnRolePattern(QRegularExpression)
            cppSelf->setColumnRolePattern(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setColumnRoleReplace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setColumnRoleReplace(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setColumnRoleReplace(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColumnRoleReplace", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColumnRoleReplace(QString)
            cppSelf->setColumnRoleReplace(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setItemModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setItemModel(QAbstractItemModel*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), (pyArg)))) {
        overloadId = 0; // setItemModel(QAbstractItemModel*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setItemModel", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractItemModel *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItemModel(QAbstractItemModel*)
            cppSelf->setItemModel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setMultiMatchBehavior(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setMultiMatchBehavior(QItemModelSurfaceDataProxy::MultiMatchBehavior)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_MultiMatchBehavior_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMultiMatchBehavior(QItemModelSurfaceDataProxy::MultiMatchBehavior)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMultiMatchBehavior", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QItemModelSurfaceDataProxy::MultiMatchBehavior cppArg0{QItemModelSurfaceDataProxy::MultiMatchBehavior::First};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMultiMatchBehavior(QItemModelSurfaceDataProxy::MultiMatchBehavior)
            cppSelf->setMultiMatchBehavior(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setRowCategories(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setRowCategories(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setRowCategories(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRowCategories", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRowCategories(QStringList)
            cppSelf->setRowCategories(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setRowRole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setRowRole(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setRowRole(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRowRole", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRowRole(QString)
            cppSelf->setRowRole(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setRowRolePattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setRowRolePattern(QRegularExpression)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
        overloadId = 0; // setRowRolePattern(QRegularExpression)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRowRolePattern", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRegularExpression cppArg0_local;
        ::QRegularExpression *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRowRolePattern(QRegularExpression)
            cppSelf->setRowRolePattern(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setRowRoleReplace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setRowRoleReplace(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setRowRoleReplace(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRowRoleReplace", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRowRoleReplace(QString)
            cppSelf->setRowRoleReplace(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setUseModelCategories(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setUseModelCategories(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setUseModelCategories(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUseModelCategories", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUseModelCategories(bool)
            cppSelf->setUseModelCategories(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setXPosRole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setXPosRole(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setXPosRole(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setXPosRole", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setXPosRole(QString)
            cppSelf->setXPosRole(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setXPosRolePattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setXPosRolePattern(QRegularExpression)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
        overloadId = 0; // setXPosRolePattern(QRegularExpression)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setXPosRolePattern", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRegularExpression cppArg0_local;
        ::QRegularExpression *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setXPosRolePattern(QRegularExpression)
            cppSelf->setXPosRolePattern(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setXPosRoleReplace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setXPosRoleReplace(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setXPosRoleReplace(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setXPosRoleReplace", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setXPosRoleReplace(QString)
            cppSelf->setXPosRoleReplace(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setYPosRole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setYPosRole(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setYPosRole(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setYPosRole", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setYPosRole(QString)
            cppSelf->setYPosRole(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setYPosRolePattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setYPosRolePattern(QRegularExpression)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
        overloadId = 0; // setYPosRolePattern(QRegularExpression)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setYPosRolePattern", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRegularExpression cppArg0_local;
        ::QRegularExpression *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setYPosRolePattern(QRegularExpression)
            cppSelf->setYPosRolePattern(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setYPosRoleReplace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setYPosRoleReplace(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setYPosRoleReplace(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setYPosRoleReplace", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setYPosRoleReplace(QString)
            cppSelf->setYPosRoleReplace(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setZPosRole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setZPosRole(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setZPosRole(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setZPosRole", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setZPosRole(QString)
            cppSelf->setZPosRole(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setZPosRolePattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setZPosRolePattern(QRegularExpression)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
        overloadId = 0; // setZPosRolePattern(QRegularExpression)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setZPosRolePattern", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRegularExpression cppArg0_local;
        ::QRegularExpression *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setZPosRolePattern(QRegularExpression)
            cppSelf->setZPosRolePattern(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_setZPosRoleReplace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemModelSurfaceDataProxy::setZPosRoleReplace(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setZPosRoleReplace(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setZPosRoleReplace", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setZPosRoleReplace(QString)
            cppSelf->setZPosRoleReplace(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_useModelCategories(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // useModelCategories()const
        bool cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->useModelCategories();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_xPosRole(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // xPosRole()const
        QString cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->xPosRole();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_xPosRolePattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // xPosRolePattern()const
        QRegularExpression cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->xPosRolePattern();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_xPosRoleReplace(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // xPosRoleReplace()const
        QString cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->xPosRoleReplace();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_yPosRole(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // yPosRole()const
        QString cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->yPosRole();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_yPosRolePattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // yPosRolePattern()const
        QRegularExpression cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->yPosRolePattern();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_yPosRoleReplace(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // yPosRoleReplace()const
        QString cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->yPosRoleReplace();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_zPosRole(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // zPosRole()const
        QString cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->zPosRole();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_zPosRolePattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // zPosRolePattern()const
        QRegularExpression cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->zPosRolePattern();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemModelSurfaceDataProxyFunc_zPosRoleReplace(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // zPosRoleReplace()const
        QString cppResult = const_cast<const ::QItemModelSurfaceDataProxy *>(cppSelf)->zPosRoleReplace();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QItemModelSurfaceDataProxy_PropertyStrings[] = {
    "autoColumnCategories::",
    "autoRowCategories::",
    "columnCategories::",
    "columnRole::",
    "columnRolePattern::",
    "columnRoleReplace::",
    "itemModel::",
    "multiMatchBehavior::",
    "rowCategories::",
    "rowRole::",
    "rowRolePattern::",
    "rowRoleReplace::",
    "useModelCategories::",
    "xPosRole::",
    "xPosRolePattern::",
    "xPosRoleReplace::",
    "yPosRole::",
    "yPosRolePattern::",
    "yPosRoleReplace::",
    "zPosRole::",
    "zPosRolePattern::",
    "zPosRoleReplace::",
    nullptr // Sentinel
};

static const char *Sbk_QItemModelSurfaceDataProxy_EnumFlagInfo[] = {
    "MultiMatchBehavior:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QItemModelSurfaceDataProxy_methods[] = {
    {"autoColumnCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_autoColumnCategories), METH_NOARGS, nullptr},
    {"autoRowCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_autoRowCategories), METH_NOARGS, nullptr},
    {"columnCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_columnCategories), METH_NOARGS, nullptr},
    {"columnCategoryIndex", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_columnCategoryIndex), METH_O, nullptr},
    {"columnRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_columnRole), METH_NOARGS, nullptr},
    {"columnRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_columnRolePattern), METH_NOARGS, nullptr},
    {"columnRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_columnRoleReplace), METH_NOARGS, nullptr},
    {"itemModel", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_itemModel), METH_NOARGS, nullptr},
    {"multiMatchBehavior", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_multiMatchBehavior), METH_NOARGS, nullptr},
    {"remap", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_remap), METH_VARARGS, nullptr},
    {"rowCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_rowCategories), METH_NOARGS, nullptr},
    {"rowCategoryIndex", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_rowCategoryIndex), METH_O, nullptr},
    {"rowRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_rowRole), METH_NOARGS, nullptr},
    {"rowRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_rowRolePattern), METH_NOARGS, nullptr},
    {"rowRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_rowRoleReplace), METH_NOARGS, nullptr},
    {"setAutoColumnCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setAutoColumnCategories), METH_O, nullptr},
    {"setAutoRowCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setAutoRowCategories), METH_O, nullptr},
    {"setColumnCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setColumnCategories), METH_O, nullptr},
    {"setColumnRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setColumnRole), METH_O, nullptr},
    {"setColumnRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setColumnRolePattern), METH_O, nullptr},
    {"setColumnRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setColumnRoleReplace), METH_O, nullptr},
    {"setItemModel", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setItemModel), METH_O, nullptr},
    {"setMultiMatchBehavior", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setMultiMatchBehavior), METH_O, nullptr},
    {"setRowCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setRowCategories), METH_O, nullptr},
    {"setRowRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setRowRole), METH_O, nullptr},
    {"setRowRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setRowRolePattern), METH_O, nullptr},
    {"setRowRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setRowRoleReplace), METH_O, nullptr},
    {"setUseModelCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setUseModelCategories), METH_O, nullptr},
    {"setXPosRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setXPosRole), METH_O, nullptr},
    {"setXPosRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setXPosRolePattern), METH_O, nullptr},
    {"setXPosRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setXPosRoleReplace), METH_O, nullptr},
    {"setYPosRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setYPosRole), METH_O, nullptr},
    {"setYPosRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setYPosRolePattern), METH_O, nullptr},
    {"setYPosRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setYPosRoleReplace), METH_O, nullptr},
    {"setZPosRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setZPosRole), METH_O, nullptr},
    {"setZPosRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setZPosRolePattern), METH_O, nullptr},
    {"setZPosRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_setZPosRoleReplace), METH_O, nullptr},
    {"useModelCategories", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_useModelCategories), METH_NOARGS, nullptr},
    {"xPosRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_xPosRole), METH_NOARGS, nullptr},
    {"xPosRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_xPosRolePattern), METH_NOARGS, nullptr},
    {"xPosRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_xPosRoleReplace), METH_NOARGS, nullptr},
    {"yPosRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_yPosRole), METH_NOARGS, nullptr},
    {"yPosRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_yPosRolePattern), METH_NOARGS, nullptr},
    {"yPosRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_yPosRoleReplace), METH_NOARGS, nullptr},
    {"zPosRole", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_zPosRole), METH_NOARGS, nullptr},
    {"zPosRolePattern", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_zPosRolePattern), METH_NOARGS, nullptr},
    {"zPosRoleReplace", reinterpret_cast<PyCFunction>(Sbk_QItemModelSurfaceDataProxyFunc_zPosRoleReplace), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QItemModelSurfaceDataProxy_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QItemModelSurfaceDataProxyWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QItemModelSurfaceDataProxy_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QItemModelSurfaceDataProxy_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QItemModelSurfaceDataProxy_Type = nullptr;
static PyTypeObject *Sbk_QItemModelSurfaceDataProxy_TypeF(void)
{
    return _Sbk_QItemModelSurfaceDataProxy_Type;
}

static PyType_Slot Sbk_QItemModelSurfaceDataProxy_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QItemModelSurfaceDataProxy_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QItemModelSurfaceDataProxy_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QItemModelSurfaceDataProxy_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QItemModelSurfaceDataProxy_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QItemModelSurfaceDataProxy_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QItemModelSurfaceDataProxy_spec = {
    "2:PySide6.QtGraphs.QItemModelSurfaceDataProxy",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QItemModelSurfaceDataProxy_slots
};

} //extern "C"

static void *Sbk_QItemModelSurfaceDataProxy_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QItemModelSurfaceDataProxy *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QItemModelSurfaceDataProxy_MultiMatchBehavior(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QItemModelSurfaceDataProxy::MultiMatchBehavior>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QItemModelSurfaceDataProxy::MultiMatchBehavior *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QItemModelSurfaceDataProxy_MultiMatchBehavior_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_MultiMatchBehavior_IDX])))
        return Enum_PythonToCpp_QItemModelSurfaceDataProxy_MultiMatchBehavior;
    return {};
}

static PyObject *QItemModelSurfaceDataProxy_MultiMatchBehavior_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QItemModelSurfaceDataProxy::MultiMatchBehavior>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QItemModelSurfaceDataProxy::MultiMatchBehavior *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_MultiMatchBehavior_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QItemModelSurfaceDataProxy_PythonToCpp_QItemModelSurfaceDataProxy_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QItemModelSurfaceDataProxy_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QItemModelSurfaceDataProxy_PythonToCpp_QItemModelSurfaceDataProxy_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QItemModelSurfaceDataProxy_TypeF()))
        return QItemModelSurfaceDataProxy_PythonToCpp_QItemModelSurfaceDataProxy_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QItemModelSurfaceDataProxy_PTR_CppToPython_QItemModelSurfaceDataProxy(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QItemModelSurfaceDataProxy *>(const_cast<void *>(cppIn)), Sbk_QItemModelSurfaceDataProxy_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QItemModelSurfaceDataProxy_SignatureStrings[] = {
    "6:PySide6.QtGraphs.QItemModelSurfaceDataProxy(self,itemModel:PySide6.QtCore.QAbstractItemModel,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,itemModel:QAbstractItemModel=None,rowRole:QString=None,columnRole:QString=None,xPosRole:QString=None,yPosRole:QString=None,zPosRole:QString=None,rowCategories:QStringList=None,columnCategories:QStringList=None,useModelCategories:bool=None,autoRowCategories:bool=None,autoColumnCategories:bool=None,rowRolePattern:QRegularExpression=None,columnRolePattern:QRegularExpression=None,xPosRolePattern:QRegularExpression=None,yPosRolePattern:QRegularExpression=None,zPosRolePattern:QRegularExpression=None,rowRoleReplace:QString=None,columnRoleReplace:QString=None,xPosRoleReplace:QString=None,yPosRoleReplace:QString=None,zPosRoleReplace:QString=None,multiMatchBehavior:QItemModelSurfaceDataProxy.MultiMatchBehavior=None)",
    "5:PySide6.QtGraphs.QItemModelSurfaceDataProxy(self,itemModel:PySide6.QtCore.QAbstractItemModel,rowRole:QString,columnRole:QString,xPosRole:QString,yPosRole:QString,zPosRole:QString,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,itemModel:QAbstractItemModel=None,rowRole:QString=None,columnRole:QString=None,xPosRole:QString=None,yPosRole:QString=None,zPosRole:QString=None,rowCategories:QStringList=None,columnCategories:QStringList=None,useModelCategories:bool=None,autoRowCategories:bool=None,autoColumnCategories:bool=None,rowRolePattern:QRegularExpression=None,columnRolePattern:QRegularExpression=None,xPosRolePattern:QRegularExpression=None,yPosRolePattern:QRegularExpression=None,zPosRolePattern:QRegularExpression=None,rowRoleReplace:QString=None,columnRoleReplace:QString=None,xPosRoleReplace:QString=None,yPosRoleReplace:QString=None,zPosRoleReplace:QString=None,multiMatchBehavior:QItemModelSurfaceDataProxy.MultiMatchBehavior=None)",
    "4:PySide6.QtGraphs.QItemModelSurfaceDataProxy(self,itemModel:PySide6.QtCore.QAbstractItemModel,rowRole:QString,columnRole:QString,xPosRole:QString,yPosRole:QString,zPosRole:QString,rowCategories:QStringList,columnCategories:QStringList,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,itemModel:QAbstractItemModel=None,rowRole:QString=None,columnRole:QString=None,xPosRole:QString=None,yPosRole:QString=None,zPosRole:QString=None,rowCategories:QStringList=None,columnCategories:QStringList=None,useModelCategories:bool=None,autoRowCategories:bool=None,autoColumnCategories:bool=None,rowRolePattern:QRegularExpression=None,columnRolePattern:QRegularExpression=None,xPosRolePattern:QRegularExpression=None,yPosRolePattern:QRegularExpression=None,zPosRolePattern:QRegularExpression=None,rowRoleReplace:QString=None,columnRoleReplace:QString=None,xPosRoleReplace:QString=None,yPosRoleReplace:QString=None,zPosRoleReplace:QString=None,multiMatchBehavior:QItemModelSurfaceDataProxy.MultiMatchBehavior=None)",
    "3:PySide6.QtGraphs.QItemModelSurfaceDataProxy(self,itemModel:PySide6.QtCore.QAbstractItemModel,rowRole:QString,columnRole:QString,yPosRole:QString,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,itemModel:QAbstractItemModel=None,rowRole:QString=None,columnRole:QString=None,xPosRole:QString=None,yPosRole:QString=None,zPosRole:QString=None,rowCategories:QStringList=None,columnCategories:QStringList=None,useModelCategories:bool=None,autoRowCategories:bool=None,autoColumnCategories:bool=None,rowRolePattern:QRegularExpression=None,columnRolePattern:QRegularExpression=None,xPosRolePattern:QRegularExpression=None,yPosRolePattern:QRegularExpression=None,zPosRolePattern:QRegularExpression=None,rowRoleReplace:QString=None,columnRoleReplace:QString=None,xPosRoleReplace:QString=None,yPosRoleReplace:QString=None,zPosRoleReplace:QString=None,multiMatchBehavior:QItemModelSurfaceDataProxy.MultiMatchBehavior=None)",
    "2:PySide6.QtGraphs.QItemModelSurfaceDataProxy(self,itemModel:PySide6.QtCore.QAbstractItemModel,rowRole:QString,columnRole:QString,yPosRole:QString,rowCategories:QStringList,columnCategories:QStringList,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,itemModel:QAbstractItemModel=None,rowRole:QString=None,columnRole:QString=None,xPosRole:QString=None,yPosRole:QString=None,zPosRole:QString=None,rowCategories:QStringList=None,columnCategories:QStringList=None,useModelCategories:bool=None,autoRowCategories:bool=None,autoColumnCategories:bool=None,rowRolePattern:QRegularExpression=None,columnRolePattern:QRegularExpression=None,xPosRolePattern:QRegularExpression=None,yPosRolePattern:QRegularExpression=None,zPosRolePattern:QRegularExpression=None,rowRoleReplace:QString=None,columnRoleReplace:QString=None,xPosRoleReplace:QString=None,yPosRoleReplace:QString=None,zPosRoleReplace:QString=None,multiMatchBehavior:QItemModelSurfaceDataProxy.MultiMatchBehavior=None)",
    "1:PySide6.QtGraphs.QItemModelSurfaceDataProxy(self,itemModel:PySide6.QtCore.QAbstractItemModel,yPosRole:QString,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,itemModel:QAbstractItemModel=None,rowRole:QString=None,columnRole:QString=None,xPosRole:QString=None,yPosRole:QString=None,zPosRole:QString=None,rowCategories:QStringList=None,columnCategories:QStringList=None,useModelCategories:bool=None,autoRowCategories:bool=None,autoColumnCategories:bool=None,rowRolePattern:QRegularExpression=None,columnRolePattern:QRegularExpression=None,xPosRolePattern:QRegularExpression=None,yPosRolePattern:QRegularExpression=None,zPosRolePattern:QRegularExpression=None,rowRoleReplace:QString=None,columnRoleReplace:QString=None,xPosRoleReplace:QString=None,yPosRoleReplace:QString=None,zPosRoleReplace:QString=None,multiMatchBehavior:QItemModelSurfaceDataProxy.MultiMatchBehavior=None)",
    "0:PySide6.QtGraphs.QItemModelSurfaceDataProxy(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,itemModel:QAbstractItemModel=None,rowRole:QString=None,columnRole:QString=None,xPosRole:QString=None,yPosRole:QString=None,zPosRole:QString=None,rowCategories:QStringList=None,columnCategories:QStringList=None,useModelCategories:bool=None,autoRowCategories:bool=None,autoColumnCategories:bool=None,rowRolePattern:QRegularExpression=None,columnRolePattern:QRegularExpression=None,xPosRolePattern:QRegularExpression=None,yPosRolePattern:QRegularExpression=None,zPosRolePattern:QRegularExpression=None,rowRoleReplace:QString=None,columnRoleReplace:QString=None,xPosRoleReplace:QString=None,yPosRoleReplace:QString=None,zPosRoleReplace:QString=None,multiMatchBehavior:QItemModelSurfaceDataProxy.MultiMatchBehavior=None)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.autoColumnCategories(self)->bool",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.autoRowCategories(self)->bool",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.columnCategories(self)->QStringList",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.columnCategoryIndex(self,category:QString)->qsizetype",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.columnRole(self)->QString",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.columnRolePattern(self)->PySide6.QtCore.QRegularExpression",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.columnRoleReplace(self)->QString",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.itemModel(self)->PySide6.QtCore.QAbstractItemModel",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.multiMatchBehavior(self)->PySide6.QtGraphs.QItemModelSurfaceDataProxy.MultiMatchBehavior",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.remap(self,rowRole:QString,columnRole:QString,xPosRole:QString,yPosRole:QString,zPosRole:QString,rowCategories:QStringList,columnCategories:QStringList)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.rowCategories(self)->QStringList",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.rowCategoryIndex(self,category:QString)->qsizetype",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.rowRole(self)->QString",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.rowRolePattern(self)->PySide6.QtCore.QRegularExpression",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.rowRoleReplace(self)->QString",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setAutoColumnCategories(self,enable:bool)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setAutoRowCategories(self,enable:bool)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setColumnCategories(self,categories:QStringList)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setColumnRole(self,role:QString)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setColumnRolePattern(self,pattern:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setColumnRoleReplace(self,replace:QString)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setItemModel(self,itemModel:PySide6.QtCore.QAbstractItemModel)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setMultiMatchBehavior(self,behavior:PySide6.QtGraphs.QItemModelSurfaceDataProxy.MultiMatchBehavior)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setRowCategories(self,categories:QStringList)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setRowRole(self,role:QString)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setRowRolePattern(self,pattern:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setRowRoleReplace(self,replace:QString)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setUseModelCategories(self,enable:bool)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setXPosRole(self,role:QString)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setXPosRolePattern(self,pattern:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setXPosRoleReplace(self,replace:QString)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setYPosRole(self,role:QString)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setYPosRolePattern(self,pattern:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setYPosRoleReplace(self,replace:QString)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setZPosRole(self,role:QString)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setZPosRolePattern(self,pattern:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.setZPosRoleReplace(self,replace:QString)",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.useModelCategories(self)->bool",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.xPosRole(self)->QString",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.xPosRolePattern(self)->PySide6.QtCore.QRegularExpression",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.xPosRoleReplace(self)->QString",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.yPosRole(self)->QString",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.yPosRolePattern(self)->PySide6.QtCore.QRegularExpression",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.yPosRoleReplace(self)->QString",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.zPosRole(self)->QString",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.zPosRolePattern(self)->PySide6.QtCore.QRegularExpression",
    "PySide6.QtGraphs.QItemModelSurfaceDataProxy.zPosRoleReplace(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QItemModelSurfaceDataProxy_SignatureByteSize = 727;
static constexpr uint8_t QItemModelSurfaceDataProxy_SignatureBytes[727] = {
    0x78, 0xda, 0xed, 0x98, 0x5d, 0x6f, 0xda, 0x30, 0x14, 0x86, 0xef, 0xf7, 0x2b, 0x76, 0x39, 0xa6,
    0x2c, 0xea, 0xbe, 0x7a, 0x81, 0xd4, 0x49, 0x1d, 0x9b, 0x26, 0xb4, 0xb1, 0x42, 0x50, 0x25, 0x60,
    0xea, 0x85, 0x09, 0xa7, 0x90, 0x29, 0xd8, 0x99, 0xe3, 0xac, 0x71, 0x7e, 0x7d, 0x03, 0x24, 0x90,
    0xc4, 0x0e, 0x34, 0x4e, 0xa0, 0x4c, 0xf3, 0xad, 0x7d, 0x78, 0x7d, 0x7c, 0xfc, 0x3e, 0xc7, 0x0e,
    0x97, 0xed, 0x3e, 0x1f, 0x3a, 0x33, 0xb8, 0x34, 0x07, 0xec, 0x1b, 0x45, 0xde, 0xc2, 0x37, 0x07,
    0x5d, 0x06, 0xcb, 0x1e, 0x99, 0x81, 0x3b, 0x0c, 0xe8, 0x3d, 0xb2, 0xe1, 0x0b, 0x62, 0xa8, 0x4f,
    0x49, 0xc8, 0x5f, 0xf9, 0xe0, 0xde, 0x1b, 0x4e, 0x3a, 0x9d, 0xf9, 0x69, 0x87, 0x50, 0x30, 0x07,
    0xd7, 0x53, 0x9f, 0x51, 0x64, 0xb3, 0xad, 0x80, 0xe1, 0x21, 0x0a, 0x98, 0x09, 0x81, 0x37, 0xd3,
    0xdf, 0x60, 0xb3, 0x2b, 0x1c, 0xb8, 0xae, 0xc7, 0xa8, 0xf1, 0xba, 0xfd, 0x1d, 0xf8, 0x03, 0xa1,
    0xb3, 0x1b, 0xec, 0xf2, 0xab, 0x9f, 0x04, 0x43, 0x66, 0x11, 0x51, 0x75, 0x13, 0x41, 0xc9, 0x83,
    0x45, 0x5c, 0x68, 0x0f, 0x86, 0x8c, 0x3a, 0x78, 0xbe, 0x19, 0xb4, 0x89, 0x1b, 0x2c, 0xb1, 0x38,
    0x1e, 0xf6, 0x89, 0x2f, 0x8e, 0x72, 0xe9, 0x68, 0x24, 0x1d, 0x8d, 0x97, 0xeb, 0x20, 0x06, 0x73,
    0x42, 0x1d, 0xf0, 0xd3, 0xa9, 0x1f, 0x8e, 0xcf, 0xb2, 0x0b, 0xef, 0x8b, 0x08, 0x7c, 0x58, 0x67,
    0x9f, 0x89, 0x99, 0x12, 0x92, 0x6c, 0x06, 0x05, 0x8c, 0x58, 0xb9, 0x15, 0xf2, 0x73, 0x9d, 0xa2,
    0xfc, 0x6e, 0x3a, 0xa9, 0x43, 0x1f, 0x31, 0x06, 0x14, 0xb7, 0x07, 0x16, 0xcc, 0x03, 0x17, 0xd1,
    0xaf, 0xa1, 0x47, 0xc1, 0xf7, 0x1d, 0x82, 0x8b, 0x95, 0x39, 0x14, 0x99, 0xd6, 0xea, 0x50, 0x1c,
    0x7f, 0x62, 0x5c, 0xf4, 0xc4, 0xb8, 0x64, 0x23, 0x16, 0x78, 0x6e, 0x6c, 0xba, 0xb2, 0x73, 0x95,
    0x4e, 0xa7, 0x29, 0x4b, 0x27, 0xf9, 0xbe, 0xc9, 0x68, 0xdf, 0xe4, 0x32, 0x70, 0x99, 0xd3, 0x43,
    0xcc, 0x5e, 0x7c, 0x86, 0x05, 0xfa, 0xeb, 0x10, 0xda, 0x2e, 0x87, 0xc3, 0xec, 0x09, 0xd1, 0x6b,
    0x95, 0xd6, 0x8b, 0x8f, 0xc7, 0x65, 0xac, 0x00, 0x82, 0x84, 0x01, 0xc1, 0xfe, 0x82, 0xf3, 0x05,
    0xd3, 0x6b, 0x72, 0x35, 0xb9, 0x9a, 0xdc, 0x0f, 0xff, 0x22, 0xb9, 0xa5, 0x7e, 0xdf, 0x6b, 0x75,
    0x0d, 0xbc, 0x06, 0x5e, 0x03, 0xff, 0xfe, 0xd9, 0x81, 0xe7, 0xfa, 0x22, 0xd6, 0x5c, 0x6a, 0x2e,
    0x0b, 0x5c, 0xbe, 0x3b, 0x3f, 0x2e, 0xf5, 0x35, 0xab, 0x71, 0xd6, 0x38, 0xab, 0xe1, 0xfc, 0xf6,
    0xb8, 0x38, 0xeb, 0x3b, 0x54, 0x43, 0xa7, 0xa1, 0x2b, 0x42, 0x77, 0x51, 0x1d, 0x3a, 0xcd, 0x8d,
    0xe6, 0xe6, 0xbf, 0xe7, 0xa6, 0x02, 0x35, 0xa6, 0xec, 0xb0, 0xd7, 0x28, 0xb5, 0xde, 0x7c, 0x5a,
    0x9d, 0x79, 0x65, 0xb1, 0x9c, 0xab, 0x94, 0x95, 0xec, 0x92, 0x94, 0x32, 0x2e, 0x57, 0xd7, 0xe3,
    0x5d, 0x3c, 0x83, 0x70, 0xd3, 0x30, 0xec, 0x64, 0x28, 0x3d, 0x88, 0x78, 0x8d, 0x3f, 0xbe, 0x13,
    0x01, 0xe3, 0x1e, 0x28, 0xac, 0xb0, 0x3a, 0xda, 0x42, 0xae, 0x8a, 0x2a, 0x89, 0x7b, 0x53, 0xb1,
    0x62, 0x47, 0x13, 0x3c, 0xad, 0xb8, 0x4c, 0xe2, 0xc3, 0x3a, 0x39, 0x6f, 0x5b, 0x67, 0x59, 0xae,
    0x42, 0x43, 0xad, 0x24, 0x2f, 0x42, 0x21, 0xae, 0x73, 0x58, 0x45, 0x84, 0xa5, 0x52, 0x12, 0x14,
    0x96, 0xc8, 0xdb, 0x38, 0xe6, 0x9c, 0xfe, 0x03, 0xad, 0xc6, 0x3a, 0x95, 0xa1, 0xa9, 0x4a, 0xd4,
    0x4e, 0xec, 0x28, 0x38, 0x25, 0x55, 0xae, 0xe3, 0xcb, 0xfc, 0x45, 0x75, 0x1c, 0x90, 0xf2, 0x77,
    0x48, 0x9d, 0x6c, 0x7d, 0x60, 0xd7, 0x65, 0xbd, 0xd8, 0x00, 0x8c, 0xa6, 0xb1, 0x59, 0x56, 0x6d,
    0xb4, 0xa5, 0xa2, 0x2a, 0x36, 0xe5, 0x5a, 0x92, 0xf2, 0x24, 0xed, 0x06, 0x2c, 0xba, 0x15, 0xdf,
    0x1e, 0x7e, 0x4c, 0xc6, 0x0e, 0x93, 0x1a, 0x62, 0x59, 0x1b, 0xc4, 0xcf, 0xc4, 0xcd, 0xd3, 0x20,
    0xb6, 0x65, 0xac, 0x6a, 0xde, 0xe2, 0xf8, 0xdc, 0x7f, 0x1d, 0x74, 0x86, 0xf1, 0x32, 0x49, 0xe3,
    0xae, 0x46, 0x1e, 0x59, 0xab, 0x18, 0x34, 0xff, 0x0a, 0xa8, 0x2c, 0xdb, 0xcd, 0xb5, 0xde, 0x2a,
    0x9f, 0x9c, 0x95, 0x97, 0xea, 0xc9, 0xdb, 0xb0, 0x31, 0x4d, 0x5f, 0x2a, 0xf5, 0xba, 0x71, 0xe5,
    0x7c, 0x24, 0x96, 0x6e, 0xc8, 0x80, 0x56, 0xa6, 0xf5, 0xd4, 0x73, 0x9f, 0x25, 0x76, 0xa0, 0xd3,
    0x5b, 0xcf, 0x12, 0x5b, 0x54, 0x6d, 0xdf, 0xdd, 0x0a, 0xdf, 0x16, 0xf5, 0x9b, 0xca, 0x28, 0xb9,
    0x12, 0x1b, 0xa8, 0xfb, 0x28, 0xff, 0x05, 0xf0, 0x4c, 0x85, 0x1f, 0xe5, 0x9f, 0xfa, 0xcd, 0x54,
    0x7e, 0xdc, 0x5c, 0x95, 0xc6, 0x67, 0x51, 0xa5, 0xf1, 0x31, 0xaa, 0x34, 0x69, 0xae, 0x4a, 0x93,
    0xb3, 0xa8, 0xd2, 0xa4, 0xf1, 0x2a, 0x05, 0x72, 0x84, 0x55, 0x3e, 0xd6, 0xc2, 0x6c, 0xb5, 0x15,
    0x9f, 0x3f, 0xa1, 0xa4, 0xcc, 0x8d, 0xbf, 0xd6, 0x42, 0x49, 0x15, 0x15, 0xf3, 0xe5, 0x0d, 0xec,
    0x99, 0x9f, 0x62, 0xcf, 0xbc, 0xb9, 0x3d, 0x47, 0x0d, 0xec, 0x39, 0x3a, 0xc5, 0x9e, 0xa3, 0xfd,
    0x7b, 0x7e, 0x04, 0xbc, 0x37, 0xf6, 0x96
};
#endif

PyTypeObject *init_QItemModelSurfaceDataProxy(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX].type;

    Shiboken::AutoDecRef Sbk_QItemModelSurfaceDataProxy_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataProxy_IDX]))));

    _Sbk_QItemModelSurfaceDataProxy_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QItemModelSurfaceDataProxy",
        "QItemModelSurfaceDataProxy*",
        &Sbk_QItemModelSurfaceDataProxy_spec,
        &Shiboken::callCppDestructor< QItemModelSurfaceDataProxy >,
        Sbk_QItemModelSurfaceDataProxy_Type_bases.object(),
        0);
    auto *pyType = Sbk_QItemModelSurfaceDataProxy_TypeF(); // references _Sbk_QItemModelSurfaceDataProxy_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QItemModelSurfaceDataProxy_SignatureStrings);
#else
    InitSignatureBytes(pyType, QItemModelSurfaceDataProxy_SignatureBytes, QItemModelSurfaceDataProxy_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QItemModelSurfaceDataProxy_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QItemModelSurfaceDataProxy_PythonToCpp_QItemModelSurfaceDataProxy_PTR,
        is_QItemModelSurfaceDataProxy_PythonToCpp_QItemModelSurfaceDataProxy_PTR_Convertible,
        QItemModelSurfaceDataProxy_PTR_CppToPython_QItemModelSurfaceDataProxy);

    Shiboken::Conversions::registerConverterName(converter, "QItemModelSurfaceDataProxy");
    Shiboken::Conversions::registerConverterName(converter, "QItemModelSurfaceDataProxy*");
    Shiboken::Conversions::registerConverterName(converter, "QItemModelSurfaceDataProxy&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QItemModelSurfaceDataProxy).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QItemModelSurfaceDataProxyWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QItemModelSurfaceDataProxy_TypeF(), &Sbk_QItemModelSurfaceDataProxy_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QItemModelSurfaceDataProxy_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'MultiMatchBehavior'.
    const char *MultiMatchBehavior_Initializer[] = {
        "First",
        "Last",
        "Average",
        "CumulativeY",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t MultiMatchBehavior_InitializerValues[] = {
        int8_t(QItemModelSurfaceDataProxy::MultiMatchBehavior::First),      //  0x00  0
        int8_t(QItemModelSurfaceDataProxy::MultiMatchBehavior::Last),       //  0x01  1
        int8_t(QItemModelSurfaceDataProxy::MultiMatchBehavior::Average),    //  0x02  2
        int8_t(QItemModelSurfaceDataProxy::MultiMatchBehavior::CumulativeY) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QItemModelSurfaceDataProxy_TypeF(),
        "2:PySide6.QtGraphs.QItemModelSurfaceDataProxy.MultiMatchBehavior",
        MultiMatchBehavior_Initializer, MultiMatchBehavior_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QItemModelSurfaceDataProxy_MultiMatchBehavior_IDX].type = EType;
    // Register converter for enum 'QItemModelSurfaceDataProxy::MultiMatchBehavior'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QItemModelSurfaceDataProxy_MultiMatchBehavior_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QItemModelSurfaceDataProxy_MultiMatchBehavior,
            is_Enum_PythonToCpp_QItemModelSurfaceDataProxy_MultiMatchBehavior_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QItemModelSurfaceDataProxy::MultiMatchBehavior");
        Shiboken::Conversions::registerConverterAlias(converter, "MultiMatchBehavior");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'MultiMatchBehavior' enum.

    PySide::Signal::registerSignals(pyType, &::QItemModelSurfaceDataProxy::staticMetaObject);
    qRegisterMetaType< ::QItemModelSurfaceDataProxy::MultiMatchBehavior >("QItemModelSurfaceDataProxy::MultiMatchBehavior");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QItemModelSurfaceDataProxy::staticMetaObject, sizeof(QItemModelSurfaceDataProxyWrapper));

    return pyType;
}
