// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qscatterdataitem_wrapper.h"

// Argument includes
#include <QtGui/qquaternion.h>
#include <QtGui/qvectornd.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScatterDataItem_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QScatterDataItem >()))
        return -1;

    ::QScatterDataItem *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QScatterDataItem", 0, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QScatterDataItem::QScatterDataItem()
    // 1: QScatterDataItem::QScatterDataItem(QVector3D)
    // 2: QScatterDataItem::QScatterDataItem(QVector3D,QQuaternion)
    // 3: QScatterDataItem::QScatterDataItem(QScatterDataItem)
    // 4: QScatterDataItem::QScatterDataItem(float,float,float)
    if (numArgs == 0) {
        overloadId = 0; // QScatterDataItem()
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 4; // QScatterDataItem(float,float,float)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QScatterDataItem(QScatterDataItem)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QScatterDataItem(QVector3D)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QScatterDataItem(QVector3D,QQuaternion)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QScatterDataItem()
        {

            // QScatterDataItem()
            cptr = new ::QScatterDataItem();
            break;
        }
        case 1: // QScatterDataItem(QVector3D position)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QVector3D cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QScatterDataItem(QVector3D)
                cptr = new ::QScatterDataItem(cppArg0);
            }
            break;
        }
        case 2: // QScatterDataItem(QVector3D position, const QQuaternion &rotation)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QVector3D cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QQuaternion cppArg1_local;
            ::QQuaternion *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QScatterDataItem(QVector3D,QQuaternion)
                cptr = new ::QScatterDataItem(cppArg0, *cppArg1);
            }
            break;
        }
        case 3: // QScatterDataItem(const QScatterDataItem &QScatterDataItem)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QScatterDataItem cppArg0_local;
            ::QScatterDataItem *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QScatterDataItem(QScatterDataItem)
                cptr = new ::QScatterDataItem(*cppArg0);
            }
            break;
        }
        case 4: // QScatterDataItem(float x, float y, float z)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QScatterDataItem(float,float,float)
                cptr = new ::QScatterDataItem(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QScatterDataItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QScatterDataItemFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // position()const
        QVector3D cppResult = const_cast<const ::QScatterDataItem *>(cppSelf)->position();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScatterDataItemFunc_rotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rotation()const
        QQuaternion cppResult = const_cast<const ::QScatterDataItem *>(cppSelf)->rotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScatterDataItemFunc_setPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScatterDataItem::setPosition(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setPosition(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPosition", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPosition(QVector3D)
            cppSelf->setPosition(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScatterDataItemFunc_setRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScatterDataItem::setRotation(QQuaternion)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArg)))) {
        overloadId = 0; // setRotation(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRotation", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuaternion cppArg0_local;
        ::QQuaternion *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotation(QQuaternion)
            cppSelf->setRotation(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScatterDataItemFunc_setX(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScatterDataItem::setX(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setX(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setX", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setX(float)
            cppSelf->setX(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScatterDataItemFunc_setY(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScatterDataItem::setY(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setY(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setY", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setY(float)
            cppSelf->setY(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScatterDataItemFunc_setZ(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScatterDataItem::setZ(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setZ(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setZ", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setZ(float)
            cppSelf->setZ(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScatterDataItemFunc_x(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // x()const
        float cppResult = const_cast<const ::QScatterDataItem *>(cppSelf)->x();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScatterDataItemFunc_y(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // y()const
        float cppResult = const_cast<const ::QScatterDataItem *>(cppSelf)->y();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScatterDataItemFunc_z(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScatterDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // z()const
        float cppResult = const_cast<const ::QScatterDataItem *>(cppSelf)->z();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScatterDataItem__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QScatterDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QScatterDataItem_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QScatterDataItem_methods[] = {
    {"position", reinterpret_cast<PyCFunction>(Sbk_QScatterDataItemFunc_position), METH_NOARGS, nullptr},
    {"rotation", reinterpret_cast<PyCFunction>(Sbk_QScatterDataItemFunc_rotation), METH_NOARGS, nullptr},
    {"setPosition", reinterpret_cast<PyCFunction>(Sbk_QScatterDataItemFunc_setPosition), METH_O, nullptr},
    {"setRotation", reinterpret_cast<PyCFunction>(Sbk_QScatterDataItemFunc_setRotation), METH_O, nullptr},
    {"setX", reinterpret_cast<PyCFunction>(Sbk_QScatterDataItemFunc_setX), METH_O, nullptr},
    {"setY", reinterpret_cast<PyCFunction>(Sbk_QScatterDataItemFunc_setY), METH_O, nullptr},
    {"setZ", reinterpret_cast<PyCFunction>(Sbk_QScatterDataItemFunc_setZ), METH_O, nullptr},
    {"x", reinterpret_cast<PyCFunction>(Sbk_QScatterDataItemFunc_x), METH_NOARGS, nullptr},
    {"y", reinterpret_cast<PyCFunction>(Sbk_QScatterDataItemFunc_y), METH_NOARGS, nullptr},
    {"z", reinterpret_cast<PyCFunction>(Sbk_QScatterDataItemFunc_z), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QScatterDataItem__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QScatterDataItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QScatterDataItem_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QScatterDataItem_Type = nullptr;
static PyTypeObject *Sbk_QScatterDataItem_TypeF(void)
{
    return _Sbk_QScatterDataItem_Type;
}

static PyType_Slot Sbk_QScatterDataItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QScatterDataItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QScatterDataItem_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QScatterDataItem_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QScatterDataItem_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QScatterDataItem_spec = {
    "2:PySide6.QtGraphs.QScatterDataItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QScatterDataItem_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QScatterDataItem_PythonToCpp_QScatterDataItem_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QScatterDataItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QScatterDataItem_PythonToCpp_QScatterDataItem_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QScatterDataItem_TypeF()))
        return QScatterDataItem_PythonToCpp_QScatterDataItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QScatterDataItem_PTR_CppToPython_QScatterDataItem(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QScatterDataItem_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QScatterDataItem_COPY_CppToPython_QScatterDataItem(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QScatterDataItem *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QScatterDataItem_TypeF(), new ::QScatterDataItem(*source), true, true);
}

// Python to C++ copy conversion.
static void QScatterDataItem_PythonToCpp_QScatterDataItem_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QScatterDataItem *>(cppOut) = *reinterpret_cast< ::QScatterDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QScatterDataItem_PythonToCpp_QScatterDataItem_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QScatterDataItem_TypeF()))
        return QScatterDataItem_PythonToCpp_QScatterDataItem_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QScatterDataItem_SignatureStrings[] = {
    "4:PySide6.QtGraphs.QScatterDataItem(self)",
    "3:PySide6.QtGraphs.QScatterDataItem(self,position:PySide6.QtGui.QVector3D)",
    "2:PySide6.QtGraphs.QScatterDataItem(self,position:PySide6.QtGui.QVector3D,rotation:PySide6.QtGui.QQuaternion)",
    "1:PySide6.QtGraphs.QScatterDataItem(self,QScatterDataItem:PySide6.QtGraphs.QScatterDataItem)",
    "0:PySide6.QtGraphs.QScatterDataItem(self,x:float,y:float,z:float)",
    "PySide6.QtGraphs.QScatterDataItem.position(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtGraphs.QScatterDataItem.rotation(self)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGraphs.QScatterDataItem.setPosition(self,pos:PySide6.QtGui.QVector3D)",
    "PySide6.QtGraphs.QScatterDataItem.setRotation(self,rot:PySide6.QtGui.QQuaternion)",
    "PySide6.QtGraphs.QScatterDataItem.setX(self,value:float)",
    "PySide6.QtGraphs.QScatterDataItem.setY(self,value:float)",
    "PySide6.QtGraphs.QScatterDataItem.setZ(self,value:float)",
    "PySide6.QtGraphs.QScatterDataItem.x(self)->float",
    "PySide6.QtGraphs.QScatterDataItem.y(self)->float",
    "PySide6.QtGraphs.QScatterDataItem.z(self)->float",
    "PySide6.QtGraphs.QScatterDataItem.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QScatterDataItem_SignatureByteSize = 224;
static constexpr uint8_t QScatterDataItem_SignatureBytes[224] = {
    0x78, 0xda, 0xad, 0x91, 0x41, 0x0b, 0x82, 0x30, 0x18, 0x86, 0xef, 0xfb, 0x25, 0x0d, 0x6c, 0x54,
    0x46, 0x87, 0x0e, 0x9d, 0x84, 0xe8, 0xe6, 0x12, 0xa2, 0xba, 0xc8, 0xb0, 0x55, 0x03, 0x73, 0xe2,
    0x3e, 0xc3, 0xf5, 0xeb, 0xb3, 0x4c, 0x92, 0xc8, 0xfa, 0x92, 0x4e, 0x63, 0xdb, 0xf7, 0x3c, 0x1b,
    0xef, 0x3b, 0x9e, 0xfa, 0x36, 0x50, 0x3b, 0x39, 0x61, 0x1c, 0xe6, 0x99, 0x48, 0x8f, 0x86, 0xf1,
    0x20, 0x12, 0x00, 0x32, 0xf3, 0x04, 0x88, 0x05, 0xc8, 0x53, 0xcf, 0xc8, 0x78, 0x4f, 0x89, 0x8b,
    0x9c, 0x74, 0x52, 0x6d, 0x14, 0x28, 0x9d, 0x34, 0xe7, 0x73, 0xc5, 0xf8, 0x4a, 0x46, 0xa0, 0x33,
    0xd7, 0xa3, 0x64, 0xf4, 0x2f, 0x95, 0x93, 0x69, 0x10, 0xef, 0x06, 0x78, 0x2e, 0x4a, 0x59, 0x52,
    0xde, 0x50, 0x32, 0xc4, 0xbe, 0xf6, 0x7a, 0xfa, 0x9d, 0xa3, 0x64, 0x80, 0x95, 0x17, 0xd3, 0x7d,
    0xac, 0x05, 0x38, 0xf6, 0xb1, 0x5e, 0xaa, 0x95, 0x92, 0xaf, 0x3c, 0xab, 0x53, 0xa8, 0x8a, 0xe8,
    0xcf, 0x5a, 0xc2, 0x40, 0x98, 0xea, 0xb8, 0x5a, 0x4c, 0xcf, 0xd4, 0x10, 0x2e, 0x23, 0xc1, 0x6f,
    0x7e, 0xec, 0x56, 0x56, 0x7b, 0xe5, 0x28, 0xdf, 0xb2, 0xf9, 0xbd, 0x5b, 0xb7, 0x9f, 0x6a, 0x45,
    0x19, 0xd7, 0x95, 0xea, 0x2c, 0xe2, 0x5c, 0xe2, 0x03, 0x2f, 0xc1, 0x4d, 0x57, 0x70, 0xdb, 0x09,
    0x2c, 0xea, 0x46, 0xee, 0x04, 0x02, 0xb0, 0xbf, 0x02, 0x97, 0x5f, 0x81, 0x30, 0x8c, 0x74, 0x6a,
    0xc3, 0xb0, 0xe6, 0xc0, 0xa6, 0x2a, 0x39, 0xb0, 0xa0, 0xdc, 0x91, 0x2b, 0xf4, 0xb8, 0x83, 0x30
};
#endif

PyTypeObject *init_QScatterDataItem(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX].type;

    Shiboken::AutoDecRef Sbk_QScatterDataItem_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QScatterDataItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QScatterDataItem",
        "QScatterDataItem",
        &Sbk_QScatterDataItem_spec,
        &Shiboken::callCppDestructor< ::QScatterDataItem >,
        Sbk_QScatterDataItem_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QScatterDataItem_TypeF(); // references _Sbk_QScatterDataItem_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QScatterDataItem_SignatureStrings);
#else
    InitSignatureBytes(pyType, QScatterDataItem_SignatureBytes, QScatterDataItem_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QScatterDataItem_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataItem_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QScatterDataItem_PythonToCpp_QScatterDataItem_PTR,
        is_QScatterDataItem_PythonToCpp_QScatterDataItem_PTR_Convertible,
        QScatterDataItem_PTR_CppToPython_QScatterDataItem,
        QScatterDataItem_COPY_CppToPython_QScatterDataItem);

    Shiboken::Conversions::registerConverterName(converter, "QScatterDataItem");
    Shiboken::Conversions::registerConverterName(converter, "QScatterDataItem*");
    Shiboken::Conversions::registerConverterName(converter, "QScatterDataItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QScatterDataItem).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QScatterDataItem_PythonToCpp_QScatterDataItem_COPY,
        is_QScatterDataItem_PythonToCpp_QScatterDataItem_COPY_Convertible);

    qRegisterMetaType< ::QScatterDataItem >("QScatterDataItem");

    return pyType;
}
