// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qsurfacedataitem_wrapper.h"

// Argument includes
#include <QtGui/qvectornd.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSurfaceDataItem_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSurfaceDataItem >()))
        return -1;

    ::QSurfaceDataItem *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]);

    if (PyArg_UnpackTuple(args, "QSurfaceDataItem", 0, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSurfaceDataItem::QSurfaceDataItem()
    // 1: QSurfaceDataItem::QSurfaceDataItem(QVector3D)
    // 2: QSurfaceDataItem::QSurfaceDataItem(QSurfaceDataItem)
    // 3: QSurfaceDataItem::QSurfaceDataItem(float,float,float)
    if (numArgs == 0) {
        overloadId = 0; // QSurfaceDataItem()
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 3; // QSurfaceDataItem(float,float,float)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QSurfaceDataItem(QSurfaceDataItem)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QSurfaceDataItem(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSurfaceDataItem()
        {

            // QSurfaceDataItem()
            cptr = new ::QSurfaceDataItem();
            break;
        }
        case 1: // QSurfaceDataItem(QVector3D position)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QVector3D cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSurfaceDataItem(QVector3D)
                cptr = new ::QSurfaceDataItem(cppArg0);
            }
            break;
        }
        case 2: // QSurfaceDataItem(const QSurfaceDataItem &QSurfaceDataItem)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSurfaceDataItem cppArg0_local;
            ::QSurfaceDataItem *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSurfaceDataItem(QSurfaceDataItem)
                cptr = new ::QSurfaceDataItem(*cppArg0);
            }
            break;
        }
        case 3: // QSurfaceDataItem(float x, float y, float z)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSurfaceDataItem(float,float,float)
                cptr = new ::QSurfaceDataItem(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSurfaceDataItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSurfaceDataItemFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // position()const
        QVector3D cppResult = const_cast<const ::QSurfaceDataItem *>(cppSelf)->position();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceDataItemFunc_setPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceDataItem::setPosition(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setPosition(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPosition", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPosition(QVector3D)
            cppSelf->setPosition(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceDataItemFunc_setX(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceDataItem::setX(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setX(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setX", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setX(float)
            cppSelf->setX(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceDataItemFunc_setY(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceDataItem::setY(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setY(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setY", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setY(float)
            cppSelf->setY(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceDataItemFunc_setZ(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceDataItem::setZ(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setZ(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setZ", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setZ(float)
            cppSelf->setZ(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceDataItemFunc_x(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // x()const
        float cppResult = const_cast<const ::QSurfaceDataItem *>(cppSelf)->x();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceDataItemFunc_y(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // y()const
        float cppResult = const_cast<const ::QSurfaceDataItem *>(cppSelf)->y();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceDataItemFunc_z(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // z()const
        float cppResult = const_cast<const ::QSurfaceDataItem *>(cppSelf)->z();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceDataItem__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSurfaceDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSurfaceDataItem_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSurfaceDataItem_methods[] = {
    {"position", reinterpret_cast<PyCFunction>(Sbk_QSurfaceDataItemFunc_position), METH_NOARGS, nullptr},
    {"setPosition", reinterpret_cast<PyCFunction>(Sbk_QSurfaceDataItemFunc_setPosition), METH_O, nullptr},
    {"setX", reinterpret_cast<PyCFunction>(Sbk_QSurfaceDataItemFunc_setX), METH_O, nullptr},
    {"setY", reinterpret_cast<PyCFunction>(Sbk_QSurfaceDataItemFunc_setY), METH_O, nullptr},
    {"setZ", reinterpret_cast<PyCFunction>(Sbk_QSurfaceDataItemFunc_setZ), METH_O, nullptr},
    {"x", reinterpret_cast<PyCFunction>(Sbk_QSurfaceDataItemFunc_x), METH_NOARGS, nullptr},
    {"y", reinterpret_cast<PyCFunction>(Sbk_QSurfaceDataItemFunc_y), METH_NOARGS, nullptr},
    {"z", reinterpret_cast<PyCFunction>(Sbk_QSurfaceDataItemFunc_z), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSurfaceDataItem__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSurfaceDataItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSurfaceDataItem_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSurfaceDataItem_Type = nullptr;
static PyTypeObject *Sbk_QSurfaceDataItem_TypeF(void)
{
    return _Sbk_QSurfaceDataItem_Type;
}

static PyType_Slot Sbk_QSurfaceDataItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSurfaceDataItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSurfaceDataItem_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSurfaceDataItem_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSurfaceDataItem_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSurfaceDataItem_spec = {
    "2:PySide6.QtGraphs.QSurfaceDataItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSurfaceDataItem_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSurfaceDataItem_PythonToCpp_QSurfaceDataItem_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSurfaceDataItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSurfaceDataItem_PythonToCpp_QSurfaceDataItem_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSurfaceDataItem_TypeF()))
        return QSurfaceDataItem_PythonToCpp_QSurfaceDataItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSurfaceDataItem_PTR_CppToPython_QSurfaceDataItem(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QSurfaceDataItem_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QSurfaceDataItem_COPY_CppToPython_QSurfaceDataItem(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSurfaceDataItem *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSurfaceDataItem_TypeF(), new ::QSurfaceDataItem(*source), true, true);
}

// Python to C++ copy conversion.
static void QSurfaceDataItem_PythonToCpp_QSurfaceDataItem_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSurfaceDataItem *>(cppOut) = *reinterpret_cast< ::QSurfaceDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QSurfaceDataItem_PythonToCpp_QSurfaceDataItem_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSurfaceDataItem_TypeF()))
        return QSurfaceDataItem_PythonToCpp_QSurfaceDataItem_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSurfaceDataItem_SignatureStrings[] = {
    "3:PySide6.QtGraphs.QSurfaceDataItem(self)",
    "2:PySide6.QtGraphs.QSurfaceDataItem(self,position:PySide6.QtGui.QVector3D)",
    "1:PySide6.QtGraphs.QSurfaceDataItem(self,QSurfaceDataItem:PySide6.QtGraphs.QSurfaceDataItem)",
    "0:PySide6.QtGraphs.QSurfaceDataItem(self,x:float,y:float,z:float)",
    "PySide6.QtGraphs.QSurfaceDataItem.position(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtGraphs.QSurfaceDataItem.setPosition(self,pos:PySide6.QtGui.QVector3D)",
    "PySide6.QtGraphs.QSurfaceDataItem.setX(self,value:float)",
    "PySide6.QtGraphs.QSurfaceDataItem.setY(self,value:float)",
    "PySide6.QtGraphs.QSurfaceDataItem.setZ(self,value:float)",
    "PySide6.QtGraphs.QSurfaceDataItem.x(self)->float",
    "PySide6.QtGraphs.QSurfaceDataItem.y(self)->float",
    "PySide6.QtGraphs.QSurfaceDataItem.z(self)->float",
    "PySide6.QtGraphs.QSurfaceDataItem.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QSurfaceDataItem_SignatureByteSize = 188;
static constexpr uint8_t QSurfaceDataItem_SignatureBytes[188] = {
    0x78, 0xda, 0x9d, 0x90, 0xc1, 0x0a, 0x82, 0x40, 0x10, 0x86, 0xef, 0xfb, 0x24, 0x2d, 0xd8, 0x52,
    0x09, 0x1d, 0x3c, 0x74, 0x0a, 0xa2, 0x9b, 0x22, 0x44, 0x75, 0x59, 0x16, 0x1b, 0x6b, 0xc1, 0xdc,
    0xc5, 0x1d, 0xc3, 0xf5, 0xe9, 0xb3, 0x4c, 0x90, 0x40, 0x5c, 0x3d, 0x0d, 0x33, 0xcc, 0xf7, 0xc1,
    0xff, 0xfb, 0x41, 0x68, 0x63, 0x79, 0x83, 0x2d, 0x8b, 0xf0, 0x50, 0x08, 0xfd, 0x30, 0x2c, 0x8a,
    0xcb, 0x22, 0x15, 0x09, 0xec, 0x05, 0x8a, 0x23, 0xc2, 0x73, 0x61, 0x20, 0x4b, 0x29, 0xd9, 0x38,
    0x7e, 0x7a, 0x5a, 0x19, 0x89, 0x52, 0xe5, 0xfd, 0xff, 0x52, 0xb2, 0xe8, 0x04, 0x09, 0xaa, 0xc2,
    0xdf, 0x53, 0xb2, 0x76, 0x55, 0xfd, 0x5f, 0xc7, 0x39, 0x4a, 0x56, 0xae, 0xf2, 0x2a, 0x48, 0x33,
    0x25, 0xd0, 0xb3, 0xbf, 0x59, 0xb7, 0x93, 0x92, 0x51, 0x9e, 0x75, 0x11, 0xdb, 0x6a, 0x96, 0xbb,
    0x81, 0xa4, 0x0e, 0x26, 0x03, 0x18, 0xf6, 0x65, 0x9f, 0xf6, 0x86, 0x8b, 0x73, 0xf2, 0x9d, 0x5b,
    0xd1, 0x4b, 0x64, 0x25, 0xb8, 0x47, 0x6a, 0xc0, 0xcb, 0x5c, 0xf0, 0x3a, 0x0b, 0xac, 0xba, 0xf6,
    0xbe, 0x84, 0x03, 0x60, 0xa7, 0x02, 0xf5, 0x54, 0x80, 0xf3, 0x44, 0x69, 0xcb, 0x79, 0xc7, 0xa1,
    0xd5, 0x32, 0xbf, 0xb3, 0xb8, 0xd9, 0xc8, 0x1b, 0x82, 0x7f, 0x21, 0x3b
};
#endif

PyTypeObject *init_QSurfaceDataItem(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX].type;

    Shiboken::AutoDecRef Sbk_QSurfaceDataItem_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSurfaceDataItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSurfaceDataItem",
        "QSurfaceDataItem",
        &Sbk_QSurfaceDataItem_spec,
        &Shiboken::callCppDestructor< ::QSurfaceDataItem >,
        Sbk_QSurfaceDataItem_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSurfaceDataItem_TypeF(); // references _Sbk_QSurfaceDataItem_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSurfaceDataItem_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSurfaceDataItem_SignatureBytes, QSurfaceDataItem_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSurfaceDataItem_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QSurfaceDataItem_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSurfaceDataItem_PythonToCpp_QSurfaceDataItem_PTR,
        is_QSurfaceDataItem_PythonToCpp_QSurfaceDataItem_PTR_Convertible,
        QSurfaceDataItem_PTR_CppToPython_QSurfaceDataItem,
        QSurfaceDataItem_COPY_CppToPython_QSurfaceDataItem);

    Shiboken::Conversions::registerConverterName(converter, "QSurfaceDataItem");
    Shiboken::Conversions::registerConverterName(converter, "QSurfaceDataItem*");
    Shiboken::Conversions::registerConverterName(converter, "QSurfaceDataItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSurfaceDataItem).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QSurfaceDataItem_PythonToCpp_QSurfaceDataItem_COPY,
        is_QSurfaceDataItem_PythonToCpp_QSurfaceDataItem_COPY_Convertible);

    qRegisterMetaType< ::QSurfaceDataItem >("QSurfaceDataItem");

    return pyType;
}
