// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qtgraphs3d_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {

static const char *Sbk_QtGraphs3D_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QtGraphs3D_EnumFlagInfo[] = {
    "CameraPreset:Enum",
    "ElementType:Enum",
    "GridLineType:Enum",
    "OptimizationHint:Flag:OptimizationHints",
    "RenderingMode:Enum",
    "SelectionFlag:Flag:SelectionFlags",
    "ShadowQuality:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QtGraphs3D_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QtGraphs3D_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QtGraphs3D_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QtGraphs3D_Type = nullptr;
static PyTypeObject *Sbk_QtGraphs3D_TypeF(void)
{
    return _Sbk_QtGraphs3D_Type;
}

static PyType_Slot Sbk_QtGraphs3D_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(Sbk_object_dealloc /* PYSIDE-832: Prevent replacement of "0" with subtype_dealloc. */)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QtGraphs3D_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QtGraphs3D_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QtGraphs3D_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QtGraphs3D_spec = {
    "2:PySide6.QtGraphs.QtGraphs3D",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QtGraphs3D_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QtGraphs3D_SelectionFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QtGraphs3D::SelectionFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QtGraphs3D::SelectionFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QtGraphs3D_SelectionFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_SelectionFlag_IDX])))
        return Enum_PythonToCpp_QtGraphs3D_SelectionFlag;
    return {};
}

static PyObject *QtGraphs3D_SelectionFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QtGraphs3D::SelectionFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QtGraphs3D::SelectionFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_SelectionFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QtGraphs3D_SelectionFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QtGraphs3D::SelectionFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QtGraphs3D::SelectionFlag> *>(cppOut) = value;

}

static PyObject *QtGraphs3D_SelectionFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QtGraphs3D::SelectionFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_SelectionFlag_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QtGraphs3D_ShadowQuality(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QtGraphs3D::ShadowQuality>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QtGraphs3D::ShadowQuality *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QtGraphs3D_ShadowQuality_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_ShadowQuality_IDX])))
        return Enum_PythonToCpp_QtGraphs3D_ShadowQuality;
    return {};
}

static PyObject *QtGraphs3D_ShadowQuality_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QtGraphs3D::ShadowQuality>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QtGraphs3D::ShadowQuality *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_ShadowQuality_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QtGraphs3D_ElementType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QtGraphs3D::ElementType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QtGraphs3D::ElementType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QtGraphs3D_ElementType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_ElementType_IDX])))
        return Enum_PythonToCpp_QtGraphs3D_ElementType;
    return {};
}

static PyObject *QtGraphs3D_ElementType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QtGraphs3D::ElementType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QtGraphs3D::ElementType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_ElementType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QtGraphs3D_OptimizationHint(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QtGraphs3D::OptimizationHint>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QtGraphs3D::OptimizationHint *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QtGraphs3D_OptimizationHint_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_OptimizationHint_IDX])))
        return Enum_PythonToCpp_QtGraphs3D_OptimizationHint;
    return {};
}

static PyObject *QtGraphs3D_OptimizationHint_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QtGraphs3D::OptimizationHint>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QtGraphs3D::OptimizationHint *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_OptimizationHint_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QtGraphs3D_OptimizationHint(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QtGraphs3D::OptimizationHint>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QtGraphs3D::OptimizationHint> *>(cppOut) = value;

}

static PyObject *QtGraphs3D_OptimizationHint_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QtGraphs3D::OptimizationHint> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_OptimizationHint_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QtGraphs3D_RenderingMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QtGraphs3D::RenderingMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QtGraphs3D::RenderingMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QtGraphs3D_RenderingMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_RenderingMode_IDX])))
        return Enum_PythonToCpp_QtGraphs3D_RenderingMode;
    return {};
}

static PyObject *QtGraphs3D_RenderingMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QtGraphs3D::RenderingMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QtGraphs3D::RenderingMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_RenderingMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QtGraphs3D_CameraPreset(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QtGraphs3D::CameraPreset>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QtGraphs3D::CameraPreset *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QtGraphs3D_CameraPreset_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_CameraPreset_IDX])))
        return Enum_PythonToCpp_QtGraphs3D_CameraPreset;
    return {};
}

static PyObject *QtGraphs3D_CameraPreset_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QtGraphs3D::CameraPreset>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QtGraphs3D::CameraPreset *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_CameraPreset_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QtGraphs3D_GridLineType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QtGraphs3D::GridLineType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QtGraphs3D::GridLineType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QtGraphs3D_GridLineType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_GridLineType_IDX])))
        return Enum_PythonToCpp_QtGraphs3D_GridLineType;
    return {};
}

static PyObject *QtGraphs3D_GridLineType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QtGraphs3D::GridLineType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QtGraphs3D::GridLineType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_GridLineType_IDX]), castCppIn);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QtGraphsQtGraphs3D_SignatureStrings[] = {
    nullptr}; // Sentinel
#else
static constexpr size_t QtGraphsQtGraphs3D_SignatureByteSize = 0;
static constexpr uint8_t QtGraphsQtGraphs3D_SignatureBytes[1] = {
    0x00
};
#endif

PyTypeObject *init_QtGraphsQtGraphs3D(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphsQtGraphs3D_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphsQtGraphs3D_IDX].type;

    Shiboken::AutoDecRef Sbk_QtGraphs3D_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QtGraphs3D_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QtGraphs3D",
        "QtGraphs3D",
        &Sbk_QtGraphs3D_spec,
        nullptr,
        Sbk_QtGraphs3D_Type_bases.object(),
        0);
    auto *pyType = Sbk_QtGraphs3D_TypeF(); // references _Sbk_QtGraphs3D_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QtGraphsQtGraphs3D_SignatureStrings);
#else
    InitSignatureBytes(pyType, QtGraphsQtGraphs3D_SignatureBytes, QtGraphsQtGraphs3D_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QtGraphs3D_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphsQtGraphs3D_IDX].type = pyType;


    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QtGraphs3D_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SelectionFlag'.
    const char *SelectionFlag_Initializer[] = {
        "None_",
        "Item",
        "Row",
        "ItemAndRow",
        "Column",
        "ItemAndColumn",
        "RowAndColumn",
        "ItemRowAndColumn",
        "Slice",
        "MultiSeries",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t SelectionFlag_InitializerValues[] = {
        int8_t(QtGraphs3D::SelectionFlag::None),             //  0x00  0
        int8_t(QtGraphs3D::SelectionFlag::Item),             //  0x01  1
        int8_t(QtGraphs3D::SelectionFlag::Row),              //  0x02  2
        int8_t(QtGraphs3D::SelectionFlag::ItemAndRow),       //  0x03  3
        int8_t(QtGraphs3D::SelectionFlag::Column),           //  0x04  4
        int8_t(QtGraphs3D::SelectionFlag::ItemAndColumn),    //  0x05  5
        int8_t(QtGraphs3D::SelectionFlag::RowAndColumn),     //  0x06  6
        int8_t(QtGraphs3D::SelectionFlag::ItemRowAndColumn), //  0x07  7
        int8_t(QtGraphs3D::SelectionFlag::Slice),            //  0x08  8
        int8_t(QtGraphs3D::SelectionFlag::MultiSeries)       //  0x10  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QtGraphs3D_TypeF(),
        "2:PySide6.QtGraphs.QtGraphs3D.SelectionFlag",
        SelectionFlag_Initializer, SelectionFlag_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_SelectionFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGraphsTypeStructs[SBK_QFlags_QtGraphs3D_SelectionFlag_IDX].type =
        EType;
    // Register converter for enum 'QtGraphs3D::SelectionFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QtGraphs3D_SelectionFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QtGraphs3D_SelectionFlag,
            is_Enum_PythonToCpp_QtGraphs3D_SelectionFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QtGraphs3D::SelectionFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "SelectionFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QtGraphs3D_SelectionFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QtGraphs3D_SelectionFlag,
            is_Enum_PythonToCpp_QtGraphs3D_SelectionFlag_Convertible);
        // Register converter for flag 'QFlags<QtGraphs3D::SelectionFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QtGraphs3D::SelectionFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QtGraphs3D::SelectionFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'SelectionFlag' enum/flags.

    // Initialization of enum 'ShadowQuality'.
    const char *ShadowQuality_Initializer[] = {
        "None_",
        "Low",
        "Medium",
        "High",
        "SoftLow",
        "SoftMedium",
        "SoftHigh",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t ShadowQuality_InitializerValues[] = {
        int8_t(QtGraphs3D::ShadowQuality::None),       //  0x00  0
        int8_t(QtGraphs3D::ShadowQuality::Low),        //  0x01  1
        int8_t(QtGraphs3D::ShadowQuality::Medium),     //  0x02  2
        int8_t(QtGraphs3D::ShadowQuality::High),       //  0x03  3
        int8_t(QtGraphs3D::ShadowQuality::SoftLow),    //  0x04  4
        int8_t(QtGraphs3D::ShadowQuality::SoftMedium), //  0x05  5
        int8_t(QtGraphs3D::ShadowQuality::SoftHigh)    //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QtGraphs3D_TypeF(),
        "2:PySide6.QtGraphs.QtGraphs3D.ShadowQuality",
        ShadowQuality_Initializer, ShadowQuality_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_ShadowQuality_IDX].type = EType;
    // Register converter for enum 'QtGraphs3D::ShadowQuality'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QtGraphs3D_ShadowQuality_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QtGraphs3D_ShadowQuality,
            is_Enum_PythonToCpp_QtGraphs3D_ShadowQuality_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QtGraphs3D::ShadowQuality");
        Shiboken::Conversions::registerConverterAlias(converter, "ShadowQuality");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ShadowQuality' enum.

    // Initialization of enum 'ElementType'.
    const char *ElementType_Initializer[] = {
        "None_",
        "Series",
        "AxisXLabel",
        "AxisYLabel",
        "AxisZLabel",
        "CustomItem",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t ElementType_InitializerValues[] = {
        int8_t(QtGraphs3D::ElementType::None),       //  0x00  0
        int8_t(QtGraphs3D::ElementType::Series),     //  0x01  1
        int8_t(QtGraphs3D::ElementType::AxisXLabel), //  0x02  2
        int8_t(QtGraphs3D::ElementType::AxisYLabel), //  0x03  3
        int8_t(QtGraphs3D::ElementType::AxisZLabel), //  0x04  4
        int8_t(QtGraphs3D::ElementType::CustomItem)  //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QtGraphs3D_TypeF(),
        "2:PySide6.QtGraphs.QtGraphs3D.ElementType",
        ElementType_Initializer, ElementType_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_ElementType_IDX].type = EType;
    // Register converter for enum 'QtGraphs3D::ElementType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QtGraphs3D_ElementType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QtGraphs3D_ElementType,
            is_Enum_PythonToCpp_QtGraphs3D_ElementType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QtGraphs3D::ElementType");
        Shiboken::Conversions::registerConverterAlias(converter, "ElementType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ElementType' enum.

    // Initialization of enum 'OptimizationHint'.
    const char *OptimizationHint_Initializer[] = {
        "Default",
        "Legacy",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t OptimizationHint_InitializerValues[] = {
        int8_t(QtGraphs3D::OptimizationHint::Default), //  0x00  0
        int8_t(QtGraphs3D::OptimizationHint::Legacy)   //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QtGraphs3D_TypeF(),
        "2:PySide6.QtGraphs.QtGraphs3D.OptimizationHint",
        OptimizationHint_Initializer, OptimizationHint_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_OptimizationHint_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGraphsTypeStructs[SBK_QFlags_QtGraphs3D_OptimizationHint_IDX].type =
        EType;
    // Register converter for enum 'QtGraphs3D::OptimizationHint'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QtGraphs3D_OptimizationHint_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QtGraphs3D_OptimizationHint,
            is_Enum_PythonToCpp_QtGraphs3D_OptimizationHint_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QtGraphs3D::OptimizationHint");
        Shiboken::Conversions::registerConverterAlias(converter, "OptimizationHint");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QtGraphs3D_OptimizationHint_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QtGraphs3D_OptimizationHint,
            is_Enum_PythonToCpp_QtGraphs3D_OptimizationHint_Convertible);
        // Register converter for flag 'QFlags<QtGraphs3D::OptimizationHint>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QtGraphs3D::OptimizationHint>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QtGraphs3D::OptimizationHints");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'OptimizationHint' enum/flags.

    // Initialization of enum 'RenderingMode'.
    const char *RenderingMode_Initializer[] = {
        "DirectToBackground",
        "Indirect",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t RenderingMode_InitializerValues[] = {
        int8_t(QtGraphs3D::RenderingMode::DirectToBackground), //  0x00  0
        int8_t(QtGraphs3D::RenderingMode::Indirect)            //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QtGraphs3D_TypeF(),
        "2:PySide6.QtGraphs.QtGraphs3D.RenderingMode",
        RenderingMode_Initializer, RenderingMode_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_RenderingMode_IDX].type = EType;
    // Register converter for enum 'QtGraphs3D::RenderingMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QtGraphs3D_RenderingMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QtGraphs3D_RenderingMode,
            is_Enum_PythonToCpp_QtGraphs3D_RenderingMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QtGraphs3D::RenderingMode");
        Shiboken::Conversions::registerConverterAlias(converter, "RenderingMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'RenderingMode' enum.

    // Initialization of enum 'CameraPreset'.
    const char *CameraPreset_Initializer[] = {
        "NoPreset",
        "FrontLow",
        "Front",
        "FrontHigh",
        "LeftLow",
        "Left",
        "LeftHigh",
        "RightLow",
        "Right",
        "RightHigh",
        "BehindLow",
        "Behind",
        "BehindHigh",
        "IsometricLeft",
        "IsometricLeftHigh",
        "IsometricRight",
        "IsometricRightHigh",
        "DirectlyAbove",
        "DirectlyAboveCW45",
        "DirectlyAboveCCW45",
        "FrontBelow",
        "LeftBelow",
        "RightBelow",
        "BehindBelow",
        "DirectlyBelow",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t CameraPreset_InitializerValues[] = {
        int8_t(QtGraphs3D::CameraPreset::NoPreset),           //  0x00  0
        int8_t(QtGraphs3D::CameraPreset::FrontLow),           //  0x01  1
        int8_t(QtGraphs3D::CameraPreset::Front),              //  0x02  2
        int8_t(QtGraphs3D::CameraPreset::FrontHigh),          //  0x03  3
        int8_t(QtGraphs3D::CameraPreset::LeftLow),            //  0x04  4
        int8_t(QtGraphs3D::CameraPreset::Left),               //  0x05  5
        int8_t(QtGraphs3D::CameraPreset::LeftHigh),           //  0x06  6
        int8_t(QtGraphs3D::CameraPreset::RightLow),           //  0x07  7
        int8_t(QtGraphs3D::CameraPreset::Right),              //  0x08  8
        int8_t(QtGraphs3D::CameraPreset::RightHigh),          //  0x09  9
        int8_t(QtGraphs3D::CameraPreset::BehindLow),          //  0x0a  10
        int8_t(QtGraphs3D::CameraPreset::Behind),             //  0x0b  11
        int8_t(QtGraphs3D::CameraPreset::BehindHigh),         //  0x0c  12
        int8_t(QtGraphs3D::CameraPreset::IsometricLeft),      //  0x0d  13
        int8_t(QtGraphs3D::CameraPreset::IsometricLeftHigh),  //  0x0e  14
        int8_t(QtGraphs3D::CameraPreset::IsometricRight),     //  0x0f  15
        int8_t(QtGraphs3D::CameraPreset::IsometricRightHigh), //  0x10  16
        int8_t(QtGraphs3D::CameraPreset::DirectlyAbove),      //  0x11  17
        int8_t(QtGraphs3D::CameraPreset::DirectlyAboveCW45),  //  0x12  18
        int8_t(QtGraphs3D::CameraPreset::DirectlyAboveCCW45), //  0x13  19
        int8_t(QtGraphs3D::CameraPreset::FrontBelow),         //  0x14  20
        int8_t(QtGraphs3D::CameraPreset::LeftBelow),          //  0x15  21
        int8_t(QtGraphs3D::CameraPreset::RightBelow),         //  0x16  22
        int8_t(QtGraphs3D::CameraPreset::BehindBelow),        //  0x17  23
        int8_t(QtGraphs3D::CameraPreset::DirectlyBelow)       //  0x18  24
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QtGraphs3D_TypeF(),
        "2:PySide6.QtGraphs.QtGraphs3D.CameraPreset",
        CameraPreset_Initializer, CameraPreset_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_CameraPreset_IDX].type = EType;
    // Register converter for enum 'QtGraphs3D::CameraPreset'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QtGraphs3D_CameraPreset_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QtGraphs3D_CameraPreset,
            is_Enum_PythonToCpp_QtGraphs3D_CameraPreset_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QtGraphs3D::CameraPreset");
        Shiboken::Conversions::registerConverterAlias(converter, "CameraPreset");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CameraPreset' enum.

    // Initialization of enum 'GridLineType'.
    const char *GridLineType_Initializer[] = {
        "Shader",
        "Geometry",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t GridLineType_InitializerValues[] = {
        int8_t(QtGraphs3D::GridLineType::Shader),  //  0x00  0
        int8_t(QtGraphs3D::GridLineType::Geometry) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QtGraphs3D_TypeF(),
        "2:PySide6.QtGraphs.QtGraphs3D.GridLineType",
        GridLineType_Initializer, GridLineType_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_GridLineType_IDX].type = EType;
    // Register converter for enum 'QtGraphs3D::GridLineType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QtGraphs3D_GridLineType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QtGraphs3D_GridLineType,
            is_Enum_PythonToCpp_QtGraphs3D_GridLineType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QtGraphs3D::GridLineType");
        Shiboken::Conversions::registerConverterAlias(converter, "GridLineType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'GridLineType' enum.

    qRegisterMetaType< ::QtGraphs3D::SelectionFlag >("QtGraphs3D::SelectionFlag");
    qRegisterMetaType< ::QtGraphs3D::ShadowQuality >("QtGraphs3D::ShadowQuality");
    qRegisterMetaType< ::QtGraphs3D::ElementType >("QtGraphs3D::ElementType");
    qRegisterMetaType< ::QtGraphs3D::OptimizationHint >("QtGraphs3D::OptimizationHint");
    qRegisterMetaType< ::QtGraphs3D::RenderingMode >("QtGraphs3D::RenderingMode");
    qRegisterMetaType< ::QtGraphs3D::CameraPreset >("QtGraphs3D::CameraPreset");
    qRegisterMetaType< ::QtGraphs3D::GridLineType >("QtGraphs3D::GridLineType");

    return pyType;
}
