// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qvalue3daxisformatter_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <QtGraphs/qvalue3daxis.h>
#include <QtGraphs/qvalue3daxisformatter.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qlocale.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QValue3DAxisFormatterWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QValue3DAxisFormatterWrapper::QValue3DAxisFormatterWrapper(::QObject * parent) : QValue3DAxisFormatter(parent)
{
}

void QValue3DAxisFormatterWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QValue3DAxisFormatter", funcName);
        return;
    }
}

void QValue3DAxisFormatterWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QValue3DAxisFormatter", funcName);
        return;
    }
}

::QValue3DAxisFormatter * QValue3DAxisFormatterWrapper::createNewInstance() const
{
    if (m_PyMethodCache[2])
        return this->::QValue3DAxisFormatter::createNewInstance();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createNewInstance";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QValue3DAxisFormatter::createNewInstance();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QValue3DAxisFormatter", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QValue3DAxisFormatter", funcName, Shiboken::SbkType< QValue3DAxisFormatter >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QValue3DAxisFormatter *cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (Shiboken::Object::checkType(pyResult))
        Shiboken::Object::releaseOwnership(pyResult);
    return cppResult;
}

void QValue3DAxisFormatterWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QValue3DAxisFormatter", funcName);
        return;
    }
}

void QValue3DAxisFormatterWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QValue3DAxisFormatter", funcName);
        return;
    }
}

bool QValue3DAxisFormatterWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QValue3DAxisFormatter", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QValue3DAxisFormatter", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QValue3DAxisFormatterWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[6])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QValue3DAxisFormatter", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QValue3DAxisFormatter", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QValue3DAxisFormatterWrapper::populateCopy(::QValue3DAxisFormatter & copy)
{
    if (m_PyMethodCache[7]) {
        return this->::QValue3DAxisFormatter::populateCopy(copy);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "populateCopy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QValue3DAxisFormatter::populateCopy(copy);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), &copy)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), &copy)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QValue3DAxisFormatter", funcName);
        return;
    }
}

float QValue3DAxisFormatterWrapper::positionAt(float value) const
{
    if (m_PyMethodCache[8])
        return this->::QValue3DAxisFormatter::positionAt(value);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "positionAt";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QValue3DAxisFormatter::positionAt(value);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &value)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(f)",
        value
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QValue3DAxisFormatter", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QValue3DAxisFormatter", funcName, "float", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    float cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QValue3DAxisFormatterWrapper::recalculate()
{
    if (m_PyMethodCache[9]) {
        return this->::QValue3DAxisFormatter::recalculate();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "recalculate";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QValue3DAxisFormatter::recalculate();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QValue3DAxisFormatter", funcName);
        return;
    }
}

::QString QValue3DAxisFormatterWrapper::stringForValue(qreal value, const ::QString & format)
{
    if (m_PyMethodCache[10])
        return this->::QValue3DAxisFormatter::stringForValue(value, format);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QString();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "stringForValue";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QValue3DAxisFormatter::stringForValue(value, format);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &value),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &format)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(dN)",
        value,
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &format)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QValue3DAxisFormatter", funcName);
        return ::QString();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QValue3DAxisFormatter", funcName, "QString", Py_TYPE(pyResult)->tp_name);
        return ::QString();
    }
    ::QString cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QValue3DAxisFormatterWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[11]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QValue3DAxisFormatter", funcName);
        return;
    }
}

float QValue3DAxisFormatterWrapper::valueAt(float position) const
{
    if (m_PyMethodCache[12])
        return this->::QValue3DAxisFormatter::valueAt(position);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "valueAt";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        gil.release();
        return this->::QValue3DAxisFormatter::valueAt(position);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &position)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(f)",
        position
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QValue3DAxisFormatter", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QValue3DAxisFormatter", funcName, "float", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    float cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

const QMetaObject *QValue3DAxisFormatterWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QValue3DAxisFormatter::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QValue3DAxisFormatterWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QValue3DAxisFormatter::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QValue3DAxisFormatterWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QValue3DAxisFormatterWrapper *>(this));
    return QValue3DAxisFormatter::qt_metacast(_clname);
}

QValue3DAxisFormatterWrapper::~QValue3DAxisFormatterWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QValue3DAxisFormatter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QValue3DAxisFormatter >()))
        return -1;

    QValue3DAxisFormatterWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QValue3DAxisFormatter", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::QValue3DAxisFormatter(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QValue3DAxisFormatter(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QValue3DAxisFormatter(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QValue3DAxisFormatter(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QValue3DAxisFormatterWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QValue3DAxisFormatterWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QValue3DAxisFormatter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_allowNegatives(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // allowNegatives()const
        bool cppResult = const_cast<const ::QValue3DAxisFormatter *>(cppSelf)->allowNegatives();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_allowZero(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // allowZero()const
        bool cppResult = const_cast<const ::QValue3DAxisFormatter *>(cppSelf)->allowZero();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_axis(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axis()const
        QValue3DAxis * cppResult = const_cast<const ::QValue3DAxisFormatter *>(cppSelf)->axis();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxis_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_createNewInstance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createNewInstance()const
        QValue3DAxisFormatter * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QValue3DAxisFormatter *>(cppSelf)->::QValue3DAxisFormatter::createNewInstance()
            : const_cast<const ::QValue3DAxisFormatter *>(cppSelf)->createNewInstance();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), cppResult);

        // Ownership transferences.
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_gridPositions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // gridPositions()
        QList<float> cppResult = cppSelf->gridPositions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_float_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_labelPositions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelPositions()
        QList<float> cppResult = cppSelf->labelPositions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_float_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_labelStrings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelStrings()
        QStringList cppResult = cppSelf->labelStrings();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_locale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // locale()const
        QLocale cppResult = const_cast<const ::QValue3DAxisFormatter *>(cppSelf)->locale();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_markDirty(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "markDirty", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);

    if (PyArg_ParseTuple(args, "|O:markDirty", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::markDirty(bool=)
    if (numArgs == 0) {
        overloadId = 0; // markDirty(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // markDirty(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "markDirty", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_labelsChange = Shiboken::String::createStaticString("labelsChange");
            if (PyDict_Contains(kwds, key_labelsChange) != 0) {
                value = PyDict_GetItem(kwds, key_labelsChange);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_labelsChange);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "markDirty", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "markDirty", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_labelsChange);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "markDirty", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);
            }
        }
        bool cppArg0 = false;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // markDirty(bool)
            cppSelf->markDirty(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_populateCopy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::populateCopy(QValue3DAxisFormatter&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), (pyArg)))) {
        overloadId = 0; // populateCopy(QValue3DAxisFormatter&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "populateCopy", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QValue3DAxisFormatter *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // populateCopy(QValue3DAxisFormatter&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QValue3DAxisFormatter::populateCopy(*cppArg0)
                : cppSelf->populateCopy(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_positionAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::positionAt(float)const->float
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // positionAt(float)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "positionAt", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // positionAt(float)const
            float cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QValue3DAxisFormatter *>(cppSelf)->::QValue3DAxisFormatter::positionAt(cppArg0)
                : const_cast<const ::QValue3DAxisFormatter *>(cppSelf)->positionAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_recalculate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // recalculate()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QValue3DAxisFormatter::recalculate()
            : cppSelf->recalculate();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_setAllowNegatives(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::setAllowNegatives(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAllowNegatives(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAllowNegatives", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAllowNegatives(bool)
            cppSelf->setAllowNegatives(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_setAllowZero(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::setAllowZero(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAllowZero(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAllowZero", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAllowZero(bool)
            cppSelf->setAllowZero(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_setAxis(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::setAxis(QValue3DAxis*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxis_IDX]), (pyArg)))) {
        overloadId = 0; // setAxis(QValue3DAxis*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAxis", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QValue3DAxis *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAxis(QValue3DAxis*)
            cppSelf->setAxis(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_setGridPoitions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::setGridPoitions(QList<float>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_float_IDX], (pyArg)))) {
        overloadId = 0; // setGridPoitions(QList<float>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGridPoitions", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        ::QList<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGridPoitions(QList<float>)
            cppSelf->setGridPoitions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_setLabelStrings(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::setLabelStrings(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setLabelStrings(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelStrings", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelStrings(QStringList)
            cppSelf->setLabelStrings(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_setLocale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::setLocale(QLocale)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
        overloadId = 0; // setLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLocale", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocale(QLocale)
            cppSelf->setLocale(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_setSubGridPositions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::setSubGridPositions(QList<float>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_float_IDX], (pyArg)))) {
        overloadId = 0; // setSubGridPositions(QList<float>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSubGridPositions", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        ::QList<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSubGridPositions(QList<float>)
            cppSelf->setSubGridPositions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_setlabelPositions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::setlabelPositions(QList<float>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_float_IDX], (pyArg)))) {
        overloadId = 0; // setlabelPositions(QList<float>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setlabelPositions", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        ::QList<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setlabelPositions(QList<float>)
            cppSelf->setlabelPositions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_stringForValue(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "stringForValue", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::stringForValue(qreal,QString)->QString
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // stringForValue(qreal,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "stringForValue", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // stringForValue(qreal,QString)
            QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QValue3DAxisFormatter::stringForValue(cppArg0, cppArg1)
                : cppSelf->stringForValue(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_subGridPositions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // subGridPositions()
        QList<float> cppResult = cppSelf->subGridPositions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_float_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QValue3DAxisFormatterFunc_valueAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::valueAt(float)const->float
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // valueAt(float)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "valueAt", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // valueAt(float)const
            float cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QValue3DAxisFormatter *>(cppSelf)->::QValue3DAxisFormatter::valueAt(cppArg0)
                : const_cast<const ::QValue3DAxisFormatter *>(cppSelf)->valueAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QValue3DAxisFormatter_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QValue3DAxisFormatter_methods[] = {
    {"allowNegatives", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_allowNegatives), METH_NOARGS, nullptr},
    {"allowZero", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_allowZero), METH_NOARGS, nullptr},
    {"axis", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_axis), METH_NOARGS, nullptr},
    {"createNewInstance", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_createNewInstance), METH_NOARGS, nullptr},
    {"gridPositions", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_gridPositions), METH_NOARGS, nullptr},
    {"labelPositions", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_labelPositions), METH_NOARGS, nullptr},
    {"labelStrings", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_labelStrings), METH_NOARGS, nullptr},
    {"locale", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_locale), METH_NOARGS, nullptr},
    {"markDirty", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_markDirty), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"populateCopy", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_populateCopy), METH_O, nullptr},
    {"positionAt", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_positionAt), METH_O, nullptr},
    {"recalculate", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_recalculate), METH_NOARGS, nullptr},
    {"setAllowNegatives", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_setAllowNegatives), METH_O, nullptr},
    {"setAllowZero", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_setAllowZero), METH_O, nullptr},
    {"setAxis", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_setAxis), METH_O, nullptr},
    {"setGridPoitions", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_setGridPoitions), METH_O, nullptr},
    {"setLabelStrings", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_setLabelStrings), METH_O, nullptr},
    {"setLocale", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_setLocale), METH_O, nullptr},
    {"setSubGridPositions", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_setSubGridPositions), METH_O, nullptr},
    {"setlabelPositions", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_setlabelPositions), METH_O, nullptr},
    {"stringForValue", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_stringForValue), METH_VARARGS, nullptr},
    {"subGridPositions", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_subGridPositions), METH_NOARGS, nullptr},
    {"valueAt", reinterpret_cast<PyCFunction>(Sbk_QValue3DAxisFormatterFunc_valueAt), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QValue3DAxisFormatter_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QValue3DAxisFormatterWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QValue3DAxisFormatter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QValue3DAxisFormatter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QValue3DAxisFormatter_Type = nullptr;
static PyTypeObject *Sbk_QValue3DAxisFormatter_TypeF(void)
{
    return _Sbk_QValue3DAxisFormatter_Type;
}

static PyType_Slot Sbk_QValue3DAxisFormatter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QValue3DAxisFormatter_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QValue3DAxisFormatter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QValue3DAxisFormatter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QValue3DAxisFormatter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QValue3DAxisFormatter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QValue3DAxisFormatter_spec = {
    "2:PySide6.QtGraphs.QValue3DAxisFormatter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QValue3DAxisFormatter_slots
};

} //extern "C"

static void *Sbk_QValue3DAxisFormatter_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QValue3DAxisFormatter *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QValue3DAxisFormatter_PythonToCpp_QValue3DAxisFormatter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QValue3DAxisFormatter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QValue3DAxisFormatter_PythonToCpp_QValue3DAxisFormatter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QValue3DAxisFormatter_TypeF()))
        return QValue3DAxisFormatter_PythonToCpp_QValue3DAxisFormatter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QValue3DAxisFormatter_PTR_CppToPython_QValue3DAxisFormatter(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QValue3DAxisFormatter *>(const_cast<void *>(cppIn)), Sbk_QValue3DAxisFormatter_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QValue3DAxisFormatter_SignatureStrings[] = {
    "PySide6.QtGraphs.QValue3DAxisFormatter(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtGraphs.QValue3DAxisFormatter.allowNegatives(self)->bool",
    "PySide6.QtGraphs.QValue3DAxisFormatter.allowZero(self)->bool",
    "PySide6.QtGraphs.QValue3DAxisFormatter.axis(self)->PySide6.QtGraphs.QValue3DAxis",
    "PySide6.QtGraphs.QValue3DAxisFormatter.createNewInstance(self)->PySide6.QtGraphs.QValue3DAxisFormatter",
    "PySide6.QtGraphs.QValue3DAxisFormatter.gridPositions(self)->QList[float]",
    "PySide6.QtGraphs.QValue3DAxisFormatter.labelPositions(self)->QList[float]",
    "PySide6.QtGraphs.QValue3DAxisFormatter.labelStrings(self)->QStringList",
    "PySide6.QtGraphs.QValue3DAxisFormatter.locale(self)->PySide6.QtCore.QLocale",
    "PySide6.QtGraphs.QValue3DAxisFormatter.markDirty(self,labelsChange:bool=false)",
    "PySide6.QtGraphs.QValue3DAxisFormatter.populateCopy(self,copy:PySide6.QtGraphs.QValue3DAxisFormatter)",
    "PySide6.QtGraphs.QValue3DAxisFormatter.positionAt(self,value:float)->float",
    "PySide6.QtGraphs.QValue3DAxisFormatter.recalculate(self)",
    "PySide6.QtGraphs.QValue3DAxisFormatter.setAllowNegatives(self,allow:bool)",
    "PySide6.QtGraphs.QValue3DAxisFormatter.setAllowZero(self,allow:bool)",
    "PySide6.QtGraphs.QValue3DAxisFormatter.setAxis(self,axis:PySide6.QtGraphs.QValue3DAxis)",
    "PySide6.QtGraphs.QValue3DAxisFormatter.setGridPoitions(self,gridPositions:QList[float])",
    "PySide6.QtGraphs.QValue3DAxisFormatter.setLabelStrings(self,labelStrings:QStringList)",
    "PySide6.QtGraphs.QValue3DAxisFormatter.setLocale(self,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])",
    "PySide6.QtGraphs.QValue3DAxisFormatter.setSubGridPositions(self,subGridPositions:QList[float])",
    "PySide6.QtGraphs.QValue3DAxisFormatter.setlabelPositions(self,labelPositions:QList[float])",
    "PySide6.QtGraphs.QValue3DAxisFormatter.stringForValue(self,value:qreal,format:QString)->QString",
    "PySide6.QtGraphs.QValue3DAxisFormatter.subGridPositions(self)->QList[float]",
    "PySide6.QtGraphs.QValue3DAxisFormatter.valueAt(self,position:float)->float",
    nullptr}; // Sentinel
#else
static constexpr size_t QValue3DAxisFormatter_SignatureByteSize = 418;
static constexpr uint8_t QValue3DAxisFormatter_SignatureBytes[418] = {
    0x78, 0xda, 0xad, 0x94, 0xcf, 0x4f, 0x83, 0x30, 0x14, 0xc7, 0xef, 0xfe, 0x15, 0x1e, 0x5d, 0x52,
    0xb9, 0x98, 0x78, 0x20, 0x99, 0xc9, 0x32, 0xe3, 0x62, 0x42, 0x26, 0x64, 0xd1, 0x83, 0x8b, 0x87,
    0xc2, 0x1e, 0xac, 0xda, 0xb5, 0xd8, 0x3e, 0x36, 0xf7, 0xdf, 0x5b, 0x8a, 0x30, 0xb6, 0x91, 0xa5,
    0x10, 0x4f, 0xd0, 0x1f, 0xef, 0xf3, 0xda, 0x6f, 0xdf, 0xf7, 0x85, 0xfb, 0x05, 0x5b, 0xc1, 0xbd,
    0x17, 0xe1, 0x4c, 0xd1, 0x7c, 0xad, 0xbd, 0xe8, 0x8d, 0xf2, 0x02, 0xee, 0x1e, 0x27, 0x3f, 0x4c,
    0x3f, 0x49, 0xb5, 0xa1, 0x88, 0xa0, 0x6e, 0x34, 0xf0, 0x94, 0xe4, 0x54, 0x81, 0x40, 0x3f, 0x6c,
    0x42, 0xa6, 0x52, 0x81, 0x17, 0xbd, 0xc4, 0x9f, 0x90, 0xe0, 0x58, 0x14, 0x9c, 0xe7, 0xa8, 0x46,
    0x57, 0xa1, 0x13, 0xd2, 0xa3, 0x9c, 0xcb, 0xdd, 0x1c, 0x32, 0x8a, 0x6c, 0x0b, 0xda, 0x66, 0x18,
    0xdd, 0x3e, 0xc4, 0x52, 0xf2, 0x5e, 0x84, 0x77, 0x50, 0x72, 0x50, 0xb0, 0x19, 0xd5, 0x71, 0x17,
    0x43, 0x5c, 0x81, 0x89, 0x02, 0x8a, 0x30, 0x87, 0xdd, 0xb3, 0xd0, 0x48, 0x45, 0x02, 0x4e, 0xf4,
    0x26, 0xde, 0x35, 0x4d, 0xa6, 0xd8, 0x2a, 0x94, 0x9a, 0x21, 0x93, 0xa2, 0xb9, 0x40, 0x14, 0x30,
    0x8d, 0xcb, 0x94, 0x4b, 0x8a, 0x1f, 0xae, 0x20, 0x4e, 0x63, 0xe0, 0xff, 0x47, 0x5a, 0xa0, 0x62,
    0x22, 0x3b, 0x70, 0xaa, 0x71, 0x49, 0x73, 0xc6, 0xc8, 0x84, 0xf2, 0x0e, 0xd5, 0xaa, 0x2a, 0x0b,
    0xec, 0xaa, 0x2b, 0x6b, 0x43, 0xd5, 0xd7, 0x23, 0x53, 0xb8, 0xaf, 0x2a, 0xd7, 0x9e, 0x50, 0x4f,
    0xd7, 0x54, 0x64, 0xe0, 0x97, 0x55, 0x32, 0x4e, 0x29, 0xd7, 0xe0, 0x5c, 0xab, 0xb9, 0xcc, 0x0b,
    0x6e, 0x5e, 0x77, 0x2a, 0xf3, 0x3f, 0x62, 0x62, 0xfe, 0x7c, 0xb7, 0xe8, 0x1e, 0x59, 0xaa, 0xc7,
    0x98, 0x60, 0x95, 0x63, 0x5b, 0x6e, 0xf2, 0xed, 0x5b, 0x18, 0x41, 0xec, 0xd7, 0x15, 0xa5, 0xc0,
    0xa8, 0x95, 0xd8, 0x33, 0x57, 0x82, 0xba, 0x06, 0x6a, 0xc0, 0xc9, 0xb9, 0x31, 0x89, 0xb5, 0x9a,
    0x55, 0xae, 0x37, 0xa9, 0x31, 0xe8, 0x50, 0x48, 0x6d, 0x54, 0x52, 0x5a, 0xf6, 0xb2, 0xe6, 0x7d,
    0xb8, 0x33, 0x6b, 0xa4, 0x56, 0xf5, 0x93, 0x23, 0x6b, 0xf9, 0x6d, 0x27, 0xf4, 0xe1, 0x06, 0xa7,
    0x6e, 0x20, 0x6d, 0x7f, 0xf8, 0x2d, 0x63, 0xf4, 0xa2, 0x1e, 0xcc, 0x41, 0x2a, 0xa3, 0xf8, 0xb8,
    0xcf, 0x0d, 0xc8, 0x7b, 0x15, 0xe6, 0xb8, 0xcb, 0x6e, 0xbb, 0x90, 0xeb, 0xee, 0x79, 0x2f, 0x30,
    0x4e, 0x28, 0x68, 0x06, 0xbd, 0x6e, 0xb6, 0x28, 0xe2, 0xd9, 0x59, 0xf7, 0x21, 0xfa, 0x64, 0x76,
    0xb0, 0x70, 0x1d, 0x0d, 0x89, 0x1c, 0xcf, 0x0d, 0x44, 0x5b, 0xc1, 0xcd, 0xd8, 0xae, 0xb6, 0xad,
    0xf5, 0x6d, 0x5a, 0x36, 0x27, 0xa9, 0xdd, 0x59, 0x3f, 0xcc, 0xa1, 0x77, 0x39, 0xf3, 0xbb, 0x64,
    0x19, 0xd8, 0x4a, 0xed, 0xb9, 0x6a, 0xff, 0xd7, 0xfd, 0xe0, 0xa4, 0x05, 0xfc, 0x02, 0x6e, 0xf2,
    0xd3, 0x5e
};
#endif

PyTypeObject *init_QValue3DAxisFormatter(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX].type;

    Shiboken::AutoDecRef Sbk_QValue3DAxisFormatter_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QValue3DAxisFormatter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QValue3DAxisFormatter",
        "QValue3DAxisFormatter*",
        &Sbk_QValue3DAxisFormatter_spec,
        &Shiboken::callCppDestructor< QValue3DAxisFormatter >,
        Sbk_QValue3DAxisFormatter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QValue3DAxisFormatter_TypeF(); // references _Sbk_QValue3DAxisFormatter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QValue3DAxisFormatter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QValue3DAxisFormatter_SignatureBytes, QValue3DAxisFormatter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QValue3DAxisFormatter_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxisFormatter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QValue3DAxisFormatter_PythonToCpp_QValue3DAxisFormatter_PTR,
        is_QValue3DAxisFormatter_PythonToCpp_QValue3DAxisFormatter_PTR_Convertible,
        QValue3DAxisFormatter_PTR_CppToPython_QValue3DAxisFormatter);

    Shiboken::Conversions::registerConverterName(converter, "QValue3DAxisFormatter");
    Shiboken::Conversions::registerConverterName(converter, "QValue3DAxisFormatter*");
    Shiboken::Conversions::registerConverterName(converter, "QValue3DAxisFormatter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QValue3DAxisFormatter).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QValue3DAxisFormatterWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QValue3DAxisFormatter_TypeF(), &Sbk_QValue3DAxisFormatter_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QValue3DAxisFormatter::staticMetaObject, sizeof(QValue3DAxisFormatterWrapper));

    return pyType;
}
