// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphswidgets_python.h"

// main header
#include "q3dbarswidgetitem_wrapper.h"

// Argument includes
#include <QList>
#include <QtGraphs/q3dscene.h>
#include <QtGraphs/qabstract3daxis.h>
#include <QtGraphs/qabstract3dseries.h>
#include <QtGraphs/qbar3dseries.h>
#include <QtGraphs/qcategory3daxis.h>
#include <QtGraphs/qcustom3ditem.h>
#include <QtGraphs/qgraphs3dnamespace.h>
#include <QtGraphs/qgraphstheme.h>
#include <QtGraphs/qvalue3daxis.h>
#include <QtGui/qcolor.h>
#include <QtGui/qvectornd.h>
#include <QtQuick/qquickitemgrabresult.h>
#include <QtQuickWidgets/qquickwidget.h>
#include <qcoreevent.h>
#include <qlocale.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsharedpointer.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void Q3DBarsWidgetItemWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

Q3DBarsWidgetItemWrapper::Q3DBarsWidgetItemWrapper(::QObject * parent) : Q3DBarsWidgetItem(parent)
{
}

void Q3DBarsWidgetItemWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DBarsWidgetItem", funcName);
        return;
    }
}

void Q3DBarsWidgetItemWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DBarsWidgetItem", funcName);
        return;
    }
}

void Q3DBarsWidgetItemWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DBarsWidgetItem", funcName);
        return;
    }
}

void Q3DBarsWidgetItemWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DBarsWidgetItem", funcName);
        return;
    }
}

bool Q3DBarsWidgetItemWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::Q3DBarsWidgetItem::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::Q3DBarsWidgetItem::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DBarsWidgetItem", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("Q3DBarsWidgetItem", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool Q3DBarsWidgetItemWrapper::eventFilter(::QObject * obj, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::Q3DGraphsWidgetItem::eventFilter(obj, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::Q3DGraphsWidgetItem::eventFilter(obj, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), obj),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), obj),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DBarsWidgetItem", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("Q3DBarsWidgetItem", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void Q3DBarsWidgetItemWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DBarsWidgetItem", funcName);
        return;
    }
}

const QMetaObject *Q3DBarsWidgetItemWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Q3DBarsWidgetItem::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int Q3DBarsWidgetItemWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Q3DBarsWidgetItem::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *Q3DBarsWidgetItemWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< Q3DBarsWidgetItemWrapper *>(this));
    return Q3DBarsWidgetItem::qt_metacast(_clname);
}

Q3DBarsWidgetItemWrapper::~Q3DBarsWidgetItemWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Q3DBarsWidgetItem_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Q3DBarsWidgetItem >()))
        return -1;

    Q3DBarsWidgetItemWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:Q3DBarsWidgetItem", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::Q3DBarsWidgetItem(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // Q3DBarsWidgetItem(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // Q3DBarsWidgetItem(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Q3DBarsWidgetItem(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) Q3DBarsWidgetItemWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new Q3DBarsWidgetItemWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Q3DBarsWidgetItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_addAxis(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::addAxis(QAbstract3DAxis*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), (pyArg)))) {
        overloadId = 0; // addAxis(QAbstract3DAxis*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addAxis", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstract3DAxis *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addAxis(QAbstract3DAxis*)
            cppSelf->addAxis(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_addSeries(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::addSeries(QBar3DSeries*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), (pyArg)))) {
        overloadId = 0; // addSeries(QBar3DSeries*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addSeries", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBar3DSeries *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addSeries(QBar3DSeries*)
            cppSelf->addSeries(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_axes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axes()const
        QList<QAbstract3DAxis*> cppResult = const_cast<const ::Q3DBarsWidgetItem *>(cppSelf)->axes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsWidgetsTypeConverters[SBK_QtGraphsWidgets_QList_QAbstract3DAxisPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_barSeriesMargin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // barSeriesMargin()const
        QSizeF cppResult = const_cast<const ::Q3DBarsWidgetItem *>(cppSelf)->barSeriesMargin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_barSpacing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // barSpacing()const
        QSizeF cppResult = const_cast<const ::Q3DBarsWidgetItem *>(cppSelf)->barSpacing();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_barThickness(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // barThickness()const
        float cppResult = const_cast<const ::Q3DBarsWidgetItem *>(cppSelf)->barThickness();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_columnAxis(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // columnAxis()const
        QCategory3DAxis * cppResult = const_cast<const ::Q3DBarsWidgetItem *>(cppSelf)->columnAxis();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QCategory3DAxis_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Q3DBarsWidgetItem::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_floorLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // floorLevel()const
        float cppResult = const_cast<const ::Q3DBarsWidgetItem *>(cppSelf)->floorLevel();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_insertSeries(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertSeries", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::insertSeries(int,QBar3DSeries*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insertSeries(int,QBar3DSeries*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertSeries", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QBar3DSeries *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertSeries(int,QBar3DSeries*)
            cppSelf->insertSeries(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_isBarSpacingRelative(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isBarSpacingRelative()const
        bool cppResult = const_cast<const ::Q3DBarsWidgetItem *>(cppSelf)->isBarSpacingRelative();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_isMultiSeriesUniform(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isMultiSeriesUniform()const
        bool cppResult = const_cast<const ::Q3DBarsWidgetItem *>(cppSelf)->isMultiSeriesUniform();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_primarySeries(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // primarySeries()const
        QBar3DSeries * cppResult = const_cast<const ::Q3DBarsWidgetItem *>(cppSelf)->primarySeries();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_releaseAxis(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::releaseAxis(QAbstract3DAxis*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), (pyArg)))) {
        overloadId = 0; // releaseAxis(QAbstract3DAxis*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "releaseAxis", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstract3DAxis *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // releaseAxis(QAbstract3DAxis*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtdatavisualization.cpp (releaseownership)]
            Shiboken::Object::releaseOwnership(pyArg);
            // END of custom code block [file: ../glue/qtdatavisualization.cpp (releaseownership)]
            // ========================================================================
            // End of code injection

            cppSelf->releaseAxis(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "releaseAxis(QAbstract3DAxis*)1", pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_removeSeries(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::removeSeries(QBar3DSeries*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), (pyArg)))) {
        overloadId = 0; // removeSeries(QBar3DSeries*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeSeries", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBar3DSeries *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeSeries(QBar3DSeries*)
            cppSelf->removeSeries(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_rowAxis(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rowAxis()const
        QCategory3DAxis * cppResult = const_cast<const ::Q3DBarsWidgetItem *>(cppSelf)->rowAxis();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QCategory3DAxis_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_selectedSeries(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedSeries()const
        QBar3DSeries * cppResult = const_cast<const ::Q3DBarsWidgetItem *>(cppSelf)->selectedSeries();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_seriesList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // seriesList()const
        QList<QBar3DSeries*> cppResult = const_cast<const ::Q3DBarsWidgetItem *>(cppSelf)->seriesList();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsWidgetsTypeConverters[SBK_QtGraphsWidgets_QList_QBar3DSeriesPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_setBarSeriesMargin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::setBarSeriesMargin(QSizeF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
        overloadId = 0; // setBarSeriesMargin(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBarSeriesMargin", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSizeF cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBarSeriesMargin(QSizeF)
            cppSelf->setBarSeriesMargin(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_setBarSpacing(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::setBarSpacing(QSizeF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
        overloadId = 0; // setBarSpacing(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBarSpacing", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSizeF cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBarSpacing(QSizeF)
            cppSelf->setBarSpacing(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_setBarSpacingRelative(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::setBarSpacingRelative(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setBarSpacingRelative(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBarSpacingRelative", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBarSpacingRelative(bool)
            cppSelf->setBarSpacingRelative(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_setBarThickness(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::setBarThickness(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setBarThickness(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBarThickness", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBarThickness(float)
            cppSelf->setBarThickness(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_setColumnAxis(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::setColumnAxis(QCategory3DAxis*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QCategory3DAxis_IDX]), (pyArg)))) {
        overloadId = 0; // setColumnAxis(QCategory3DAxis*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColumnAxis", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCategory3DAxis *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColumnAxis(QCategory3DAxis*)
            cppSelf->setColumnAxis(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_setFloorLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::setFloorLevel(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setFloorLevel(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFloorLevel", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFloorLevel(float)
            cppSelf->setFloorLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_setMultiSeriesUniform(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::setMultiSeriesUniform(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setMultiSeriesUniform(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMultiSeriesUniform", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMultiSeriesUniform(bool)
            cppSelf->setMultiSeriesUniform(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_setPrimarySeries(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::setPrimarySeries(QBar3DSeries*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), (pyArg)))) {
        overloadId = 0; // setPrimarySeries(QBar3DSeries*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPrimarySeries", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBar3DSeries *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPrimarySeries(QBar3DSeries*)
            cppSelf->setPrimarySeries(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_setRowAxis(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::setRowAxis(QCategory3DAxis*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QCategory3DAxis_IDX]), (pyArg)))) {
        overloadId = 0; // setRowAxis(QCategory3DAxis*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRowAxis", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCategory3DAxis *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRowAxis(QCategory3DAxis*)
            cppSelf->setRowAxis(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_setValueAxis(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DBarsWidgetItem::setValueAxis(QValue3DAxis*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxis_IDX]), (pyArg)))) {
        overloadId = 0; // setValueAxis(QValue3DAxis*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setValueAxis", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QValue3DAxis *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValueAxis(QValue3DAxis*)
            cppSelf->setValueAxis(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DBarsWidgetItemFunc_valueAxis(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // valueAxis()const
        QValue3DAxis * cppResult = const_cast<const ::Q3DBarsWidgetItem *>(cppSelf)->valueAxis();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QValue3DAxis_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Q3DBarsWidgetItem_PropertyStrings[] = {
    "barSeriesMargin::",
    "barSpacing::",
    "barSpacingRelative:isBarSpacingRelative:",
    "barThickness::",
    "columnAxis::",
    "floorLevel::",
    "multiSeriesUniform:isMultiSeriesUniform:",
    "primarySeries::",
    "rowAxis::",
    "selectedSeries:",
    "valueAxis::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Q3DBarsWidgetItem_methods[] = {
    {"addAxis", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_addAxis), METH_O, nullptr},
    {"addSeries", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_addSeries), METH_O, nullptr},
    {"axes", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_axes), METH_NOARGS, nullptr},
    {"barSeriesMargin", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_barSeriesMargin), METH_NOARGS, nullptr},
    {"barSpacing", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_barSpacing), METH_NOARGS, nullptr},
    {"barThickness", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_barThickness), METH_NOARGS, nullptr},
    {"columnAxis", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_columnAxis), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_event), METH_O, nullptr},
    {"floorLevel", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_floorLevel), METH_NOARGS, nullptr},
    {"insertSeries", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_insertSeries), METH_VARARGS, nullptr},
    {"isBarSpacingRelative", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_isBarSpacingRelative), METH_NOARGS, nullptr},
    {"isMultiSeriesUniform", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_isMultiSeriesUniform), METH_NOARGS, nullptr},
    {"primarySeries", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_primarySeries), METH_NOARGS, nullptr},
    {"releaseAxis", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_releaseAxis), METH_O, nullptr},
    {"removeSeries", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_removeSeries), METH_O, nullptr},
    {"rowAxis", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_rowAxis), METH_NOARGS, nullptr},
    {"selectedSeries", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_selectedSeries), METH_NOARGS, nullptr},
    {"seriesList", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_seriesList), METH_NOARGS, nullptr},
    {"setBarSeriesMargin", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_setBarSeriesMargin), METH_O, nullptr},
    {"setBarSpacing", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_setBarSpacing), METH_O, nullptr},
    {"setBarSpacingRelative", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_setBarSpacingRelative), METH_O, nullptr},
    {"setBarThickness", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_setBarThickness), METH_O, nullptr},
    {"setColumnAxis", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_setColumnAxis), METH_O, nullptr},
    {"setFloorLevel", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_setFloorLevel), METH_O, nullptr},
    {"setMultiSeriesUniform", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_setMultiSeriesUniform), METH_O, nullptr},
    {"setPrimarySeries", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_setPrimarySeries), METH_O, nullptr},
    {"setRowAxis", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_setRowAxis), METH_O, nullptr},
    {"setValueAxis", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_setValueAxis), METH_O, nullptr},
    {"valueAxis", reinterpret_cast<PyCFunction>(Sbk_Q3DBarsWidgetItemFunc_valueAxis), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Q3DBarsWidgetItem_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Q3DBarsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<Q3DBarsWidgetItemWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Q3DBarsWidgetItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Q3DBarsWidgetItem_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Q3DBarsWidgetItem_Type = nullptr;
static PyTypeObject *Sbk_Q3DBarsWidgetItem_TypeF(void)
{
    return _Sbk_Q3DBarsWidgetItem_Type;
}

static PyType_Slot Sbk_Q3DBarsWidgetItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Q3DBarsWidgetItem_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Q3DBarsWidgetItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Q3DBarsWidgetItem_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Q3DBarsWidgetItem_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Q3DBarsWidgetItem_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Q3DBarsWidgetItem_spec = {
    "2:PySide6.QtGraphsWidgets.Q3DBarsWidgetItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Q3DBarsWidgetItem_slots
};

} //extern "C"

static void *Sbk_Q3DBarsWidgetItem_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Q3DBarsWidgetItem *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Q3DBarsWidgetItem_PythonToCpp_Q3DBarsWidgetItem_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Q3DBarsWidgetItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Q3DBarsWidgetItem_PythonToCpp_Q3DBarsWidgetItem_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Q3DBarsWidgetItem_TypeF()))
        return Q3DBarsWidgetItem_PythonToCpp_Q3DBarsWidgetItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Q3DBarsWidgetItem_PTR_CppToPython_Q3DBarsWidgetItem(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Q3DBarsWidgetItem *>(const_cast<void *>(cppIn)), Sbk_Q3DBarsWidgetItem_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Q3DBarsWidgetItem_SignatureStrings[] = {
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,multiSeriesUniform:bool=None,barThickness:float=None,barSpacing:QSizeF=None,barSpacingRelative:bool=None,barSeriesMargin:QSizeF=None,rowAxis:QCategory3DAxis=None,columnAxis:QCategory3DAxis=None,valueAxis:QValue3DAxis=None,primarySeries:QBar3DSeries=None,selectedSeries:QBar3DSeries=None,floorLevel:float=None)",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.addAxis(self,axis:PySide6.QtGraphs.QAbstract3DAxis)",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.addSeries(self,series:PySide6.QtGraphs.QBar3DSeries)",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.axes(self)->QList[PySide6.QtGraphs.QAbstract3DAxis]",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.barSeriesMargin(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.barSpacing(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.barThickness(self)->float",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.columnAxis(self)->PySide6.QtGraphs.QCategory3DAxis",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.floorLevel(self)->float",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.insertSeries(self,index:int,series:PySide6.QtGraphs.QBar3DSeries)",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.isBarSpacingRelative(self)->bool",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.isMultiSeriesUniform(self)->bool",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.primarySeries(self)->PySide6.QtGraphs.QBar3DSeries",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.releaseAxis(self,axis:PySide6.QtGraphs.QAbstract3DAxis)",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.removeSeries(self,series:PySide6.QtGraphs.QBar3DSeries)",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.rowAxis(self)->PySide6.QtGraphs.QCategory3DAxis",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.selectedSeries(self)->PySide6.QtGraphs.QBar3DSeries",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.seriesList(self)->QList[PySide6.QtGraphs.QBar3DSeries]",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.setBarSeriesMargin(self,margin:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.setBarSpacing(self,spacing:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.setBarSpacingRelative(self,relative:bool)",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.setBarThickness(self,thicknessRatio:float)",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.setColumnAxis(self,axis:PySide6.QtGraphs.QCategory3DAxis)",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.setFloorLevel(self,level:float)",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.setMultiSeriesUniform(self,uniform:bool)",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.setPrimarySeries(self,series:PySide6.QtGraphs.QBar3DSeries)",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.setRowAxis(self,axis:PySide6.QtGraphs.QCategory3DAxis)",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.setValueAxis(self,axis:PySide6.QtGraphs.QValue3DAxis)",
    "PySide6.QtGraphsWidgets.Q3DBarsWidgetItem.valueAxis(self)->PySide6.QtGraphs.QValue3DAxis",
    nullptr}; // Sentinel
#else
static constexpr size_t Q3DBarsWidgetItem_SignatureByteSize = 563;
static constexpr uint8_t Q3DBarsWidgetItem_SignatureBytes[563] = {
    0x78, 0xda, 0xbd, 0x96, 0x4f, 0x6f, 0xda, 0x30, 0x18, 0xc6, 0xef, 0xfd, 0x14, 0x3b, 0x8e, 0xc9,
    0xcb, 0x05, 0x69, 0x87, 0x48, 0x9d, 0x54, 0x60, 0x9d, 0xa6, 0xb5, 0x2b, 0x81, 0xb5, 0x3b, 0x54,
    0x1c, 0x4c, 0xf2, 0x42, 0xbd, 0x39, 0x76, 0x64, 0xbf, 0xa1, 0x64, 0x9f, 0x7e, 0x0e, 0x26, 0x60,
    0x13, 0xb2, 0xce, 0x15, 0xec, 0x16, 0xdb, 0xc9, 0xef, 0xfd, 0x93, 0xc7, 0x8f, 0x3d, 0xae, 0xa6,
    0x2c, 0x83, 0x0f, 0x51, 0x82, 0x9f, 0x15, 0x2d, 0x9e, 0xf4, 0x0f, 0x96, 0x2d, 0x01, 0x75, 0x94,
    0xf4, 0x47, 0x03, 0xaa, 0xb6, 0xc3, 0x2f, 0x08, 0xf9, 0x5b, 0x0d, 0x7c, 0x41, 0x0a, 0xaa, 0x40,
    0x60, 0x3c, 0xde, 0x7d, 0x35, 0x94, 0x0a, 0xa2, 0xe4, 0x6e, 0xfe, 0x13, 0x52, 0xbc, 0x14, 0x25,
    0xe7, 0x05, 0x2a, 0xf2, 0x2e, 0xfe, 0x0a, 0xd5, 0xb3, 0x54, 0xd9, 0x9d, 0xe0, 0xd5, 0xe5, 0x37,
    0x29, 0x80, 0xe4, 0x25, 0x47, 0x36, 0x05, 0xc5, 0x40, 0xdf, 0x0b, 0xb6, 0x90, 0x2a, 0x8f, 0xe7,
    0x52, 0x72, 0xbb, 0x38, 0xa7, 0xea, 0xfb, 0x13, 0x4b, 0x7f, 0x09, 0xd0, 0x3a, 0x5e, 0x70, 0x49,
    0x71, 0x37, 0x3f, 0x2d, 0x68, 0xca, 0xc4, 0x32, 0x4e, 0xa6, 0xec, 0x37, 0x5c, 0x1f, 0x4e, 0x4f,
    0x80, 0x53, 0x64, 0x2b, 0xf0, 0x59, 0x36, 0xcc, 0x2d, 0x55, 0x4b, 0x26, 0xbc, 0x0f, 0x95, 0x7c,
    0xbe, 0x5a, 0x33, 0x1d, 0x27, 0x43, 0x8a, 0xb0, 0x94, 0xaa, 0xea, 0x8f, 0xea, 0xb1, 0x5d, 0x4c,
    0x25, 0x2f, 0x73, 0xd1, 0xbd, 0xbe, 0xa2, 0xbc, 0x04, 0xbb, 0xfc, 0x50, 0x3f, 0xba, 0x6b, 0x85,
    0x62, 0x39, 0x55, 0x95, 0x0d, 0x1c, 0x27, 0xa6, 0x73, 0xfd, 0x91, 0x1d, 0xd8, 0x75, 0xd3, 0x3b,
    0xd3, 0x1f, 0xc8, 0x3a, 0x5f, 0x30, 0x45, 0x4b, 0x75, 0x03, 0x2b, 0xe0, 0x4e, 0xfd, 0xbd, 0x8b,
    0xf1, 0xbf, 0xfe, 0x9d, 0x88, 0x66, 0x59, 0x9d, 0x8e, 0xfd, 0x4b, 0xb4, 0xce, 0xf2, 0xf0, 0xdb,
    0x28, 0xb9, 0x9a, 0x6b, 0x54, 0x34, 0x45, 0x9b, 0x79, 0x20, 0xdd, 0x66, 0x6b, 0xf9, 0xda, 0x96,
    0xd1, 0x8e, 0xe0, 0xd4, 0x15, 0x84, 0x5f, 0x6f, 0xc9, 0xbd, 0xf7, 0x1f, 0x93, 0x1b, 0xa6, 0xf1,
    0xf1, 0xa5, 0xe4, 0x67, 0x01, 0xf4, 0x03, 0x45, 0x34, 0x81, 0x0e, 0x35, 0xbc, 0xd1, 0x49, 0x20,
    0xd6, 0xaa, 0xf0, 0x84, 0xc4, 0xdd, 0x36, 0x68, 0x98, 0x1b, 0x35, 0x04, 0x30, 0xf6, 0x2a, 0x6e,
    0x67, 0xd5, 0xb4, 0xd2, 0x57, 0x77, 0x00, 0xdc, 0xe8, 0x53, 0xa0, 0x95, 0xc0, 0xe6, 0xb1, 0xe5,
    0x03, 0x9f, 0xea, 0x59, 0x13, 0xb3, 0xde, 0x8e, 0x01, 0xdc, 0xbd, 0xfa, 0x5f, 0x5b, 0x36, 0x13,
    0x46, 0x93, 0xe8, 0x6a, 0x94, 0x89, 0x0c, 0xd6, 0x31, 0x13, 0x78, 0x72, 0xb5, 0x32, 0x3d, 0x68,
    0x19, 0x50, 0x93, 0x77, 0x60, 0xe1, 0x4c, 0xdf, 0xb6, 0x7c, 0xf1, 0x95, 0x28, 0xcf, 0x82, 0xba,
    0xff, 0xbd, 0x53, 0x73, 0x00, 0x5c, 0x19, 0xff, 0xa2, 0x1a, 0xce, 0xe8, 0x30, 0x0a, 0x72, 0xb9,
    0x82, 0x73, 0x9a, 0xcc, 0xd6, 0xfc, 0xcf, 0xb0, 0x2d, 0x7c, 0x77, 0x3f, 0x75, 0xef, 0x6d, 0x1f,
    0x6a, 0x57, 0x7c, 0xc9, 0x22, 0x1d, 0xfe, 0x2c, 0x28, 0x00, 0x0e, 0x8e, 0x58, 0x24, 0xc9, 0xed,
    0x01, 0x8a, 0x55, 0x61, 0x84, 0x1e, 0x19, 0x75, 0x4a, 0xf1, 0x78, 0xd4, 0xe2, 0xc8, 0x9b, 0x63,
    0xd3, 0xb3, 0x5e, 0x78, 0x0e, 0x8e, 0x9f, 0x12, 0xbd, 0x3d, 0xf9, 0xff, 0x7f, 0x7c, 0x6f, 0x53,
    0x13, 0xe5, 0xde, 0x31, 0xc2, 0x99, 0xbe, 0xa3, 0x13, 0x6c, 0x86, 0x13, 0x03, 0x95, 0xf6, 0xb0,
    0x0f, 0x84, 0x0e, 0x7d, 0x8b, 0xef, 0xda, 0x8b, 0xbe, 0x9c, 0x03, 0x63, 0x5c, 0xfb, 0x8e, 0x4c,
    0xf8, 0xfe, 0x6a, 0x12, 0x48, 0xea, 0x30, 0x38, 0x52, 0x3a, 0xb7, 0xc0, 0x40, 0xe4, 0xb8, 0x65,
    0x75, 0x27, 0x37, 0x0b, 0x13, 0x65, 0xe2, 0xf8, 0xc5, 0x59, 0x7a, 0xfc, 0xd0, 0x5c, 0x28, 0xff,
    0x1a, 0xc2, 0xb9, 0x6b, 0x86, 0xf0, 0x57, 0x1e, 0xfc, 0xa8, 0x1d, 0x39, 0xe4, 0x8b, 0x3f, 0x57,
    0x00, 0x5f, 0xfb
};
#endif

PyTypeObject *init_Q3DBarsWidgetItem(PyObject *module)
{
    if (SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX].type != nullptr)
        return SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX].type;

    Shiboken::AutoDecRef Sbk_Q3DBarsWidgetItem_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]))));

    _Sbk_Q3DBarsWidgetItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "Q3DBarsWidgetItem",
        "Q3DBarsWidgetItem*",
        &Sbk_Q3DBarsWidgetItem_spec,
        &Shiboken::callCppDestructor< Q3DBarsWidgetItem >,
        Sbk_Q3DBarsWidgetItem_Type_bases.object(),
        0);
    auto *pyType = Sbk_Q3DBarsWidgetItem_TypeF(); // references _Sbk_Q3DBarsWidgetItem_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Q3DBarsWidgetItem_SignatureStrings);
#else
    InitSignatureBytes(pyType, Q3DBarsWidgetItem_SignatureBytes, Q3DBarsWidgetItem_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Q3DBarsWidgetItem_PropertyStrings);
    SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DBarsWidgetItem_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Q3DBarsWidgetItem_PythonToCpp_Q3DBarsWidgetItem_PTR,
        is_Q3DBarsWidgetItem_PythonToCpp_Q3DBarsWidgetItem_PTR_Convertible,
        Q3DBarsWidgetItem_PTR_CppToPython_Q3DBarsWidgetItem);

    Shiboken::Conversions::registerConverterName(converter, "Q3DBarsWidgetItem");
    Shiboken::Conversions::registerConverterName(converter, "Q3DBarsWidgetItem*");
    Shiboken::Conversions::registerConverterName(converter, "Q3DBarsWidgetItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Q3DBarsWidgetItem).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(Q3DBarsWidgetItemWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Q3DBarsWidgetItem_TypeF(), &Sbk_Q3DBarsWidgetItem_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Q3DBarsWidgetItem::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Q3DBarsWidgetItem::staticMetaObject, sizeof(Q3DBarsWidgetItemWrapper));

    return pyType;
}
