// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qabstracttextdocumentlayout_selection_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractTextDocumentLayout_Selection_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAbstractTextDocumentLayout::Selection >()))
        return -1;

    ::QAbstractTextDocumentLayout::Selection *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Selection", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Selection::Selection()
    // 1: Selection::Selection(QAbstractTextDocumentLayout::Selection)
    if (numArgs == 0) {
        overloadId = 0; // Selection()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Selection(QAbstractTextDocumentLayout::Selection)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Selection()
        {

            // Selection()
            cptr = new ::QAbstractTextDocumentLayout::Selection();
            break;
        }
        case 1: // Selection(const QAbstractTextDocumentLayout::Selection &Selection)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAbstractTextDocumentLayout::Selection cppArg0_local;
            ::QAbstractTextDocumentLayout::Selection *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Selection(QAbstractTextDocumentLayout::Selection)
                cptr = new ::QAbstractTextDocumentLayout::Selection(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QAbstractTextDocumentLayout::Selection >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAbstractTextDocumentLayout_Selection__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QAbstractTextDocumentLayout::Selection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAbstractTextDocumentLayout_Selection_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractTextDocumentLayout_Selection_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QAbstractTextDocumentLayout_Selection__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QAbstractTextDocumentLayout_Selection_get_cursor(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractTextDocumentLayout::Selection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->cursor)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->cursor))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->cursor)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), &(cppSelf->cursor), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QAbstractTextDocumentLayout_Selection_set_cursor(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAbstractTextDocumentLayout::Selection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("cursor");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("cursor", "QTextCursor");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->cursor;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QAbstractTextDocumentLayout_Selection_get_format(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractTextDocumentLayout::Selection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->format)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->format))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->format)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &(cppSelf->format), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QAbstractTextDocumentLayout_Selection_set_format(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAbstractTextDocumentLayout::Selection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("format");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("format", "QTextCharFormat");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->format;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

// Getters and Setters for Selection
static PyGetSetDef Sbk_QAbstractTextDocumentLayout_Selection_getsetlist[] = {
    {const_cast<char *>("cursor"), Sbk_QAbstractTextDocumentLayout_Selection_get_cursor, Sbk_QAbstractTextDocumentLayout_Selection_set_cursor, nullptr, nullptr},
    {const_cast<char *>("format"), Sbk_QAbstractTextDocumentLayout_Selection_get_format, Sbk_QAbstractTextDocumentLayout_Selection_set_format, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QAbstractTextDocumentLayout_Selection_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractTextDocumentLayout_Selection_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractTextDocumentLayout_Selection_Type = nullptr;
static PyTypeObject *Sbk_QAbstractTextDocumentLayout_Selection_TypeF(void)
{
    return _Sbk_QAbstractTextDocumentLayout_Selection_Type;
}

static PyType_Slot Sbk_QAbstractTextDocumentLayout_Selection_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractTextDocumentLayout_Selection_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractTextDocumentLayout_Selection_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractTextDocumentLayout_Selection_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QAbstractTextDocumentLayout_Selection_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractTextDocumentLayout_Selection_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractTextDocumentLayout_Selection_spec = {
    "2:PySide6.QtGui.QAbstractTextDocumentLayout.Selection",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractTextDocumentLayout_Selection_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Selection_PythonToCpp_Selection_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractTextDocumentLayout_Selection_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Selection_PythonToCpp_Selection_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractTextDocumentLayout_Selection_TypeF()))
        return Selection_PythonToCpp_Selection_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Selection_PTR_CppToPython_Selection(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QAbstractTextDocumentLayout_Selection_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *Selection_COPY_CppToPython_Selection(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QAbstractTextDocumentLayout::Selection *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QAbstractTextDocumentLayout_Selection_TypeF(), new ::QAbstractTextDocumentLayout::Selection(*source), true, true);
}

// Python to C++ copy conversion.
static void Selection_PythonToCpp_Selection_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QAbstractTextDocumentLayout::Selection *>(cppOut) = *reinterpret_cast< ::QAbstractTextDocumentLayout::Selection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Selection_PythonToCpp_Selection_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractTextDocumentLayout_Selection_TypeF()))
        return Selection_PythonToCpp_Selection_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstractTextDocumentLayout_Selection_SignatureStrings[] = {
    "1:PySide6.QtGui.QAbstractTextDocumentLayout.Selection(self)",
    "0:PySide6.QtGui.QAbstractTextDocumentLayout.Selection(self,Selection:PySide6.QtGui.QAbstractTextDocumentLayout.Selection)",
    "PySide6.QtGui.QAbstractTextDocumentLayout.Selection.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstractTextDocumentLayout_Selection_SignatureByteSize = 104;
static constexpr uint8_t QAbstractTextDocumentLayout_Selection_SignatureBytes[104] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x74, 0x4c, 0x2a, 0x2e, 0x29, 0x4a, 0x4c, 0x2e, 0x09, 0x49, 0xad, 0x28, 0x71,
    0xc9, 0x4f, 0x2e, 0xcd, 0x4d, 0xcd, 0x2b, 0xf1, 0x49, 0xac, 0xcc, 0x2f, 0x2d, 0xd1, 0x0b, 0x4e,
    0xcd, 0x49, 0x4d, 0x2e, 0xc9, 0xcc, 0xcf, 0xd3, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x20,
    0x5b, 0xaf, 0x0e, 0x9c, 0x4b, 0x8e, 0x11, 0x9a, 0x5c, 0x64, 0x68, 0xd2, 0x8b, 0x8f, 0x4f, 0xce,
    0x2f, 0xa8, 0x8c, 0x8f, 0x87, 0x38, 0x5e, 0xd7, 0xae, 0xa4, 0xb2, 0x20, 0x33, 0x2f, 0x1d, 0xa4,
    0x20, 0x8d, 0x0b, 0x00, 0xbd, 0xcf, 0x61, 0x28
};
#endif

PyTypeObject *init_QAbstractTextDocumentLayout_Selection(PyObject *enclosingClass)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractTextDocumentLayout_Selection_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAbstractTextDocumentLayout_Selection_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Selection",
        "QAbstractTextDocumentLayout::Selection",
        &Sbk_QAbstractTextDocumentLayout_Selection_spec,
        &Shiboken::callCppDestructor< ::QAbstractTextDocumentLayout::Selection >,
        Sbk_QAbstractTextDocumentLayout_Selection_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QAbstractTextDocumentLayout_Selection_TypeF(); // references _Sbk_QAbstractTextDocumentLayout_Selection_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstractTextDocumentLayout_Selection_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstractTextDocumentLayout_Selection_SignatureBytes, QAbstractTextDocumentLayout_Selection_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractTextDocumentLayout_Selection_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Selection_PythonToCpp_Selection_PTR,
        is_Selection_PythonToCpp_Selection_PTR_Convertible,
        Selection_PTR_CppToPython_Selection,
        Selection_COPY_CppToPython_Selection);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractTextDocumentLayout::Selection");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractTextDocumentLayout::Selection*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractTextDocumentLayout::Selection&");
    Shiboken::Conversions::registerConverterAlias(converter, "Selection");
    Shiboken::Conversions::registerConverterAlias(converter, "Selection*");
    Shiboken::Conversions::registerConverterAlias(converter, "Selection&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractTextDocumentLayout::Selection).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Selection_PythonToCpp_Selection_COPY,
        is_Selection_PythonToCpp_Selection_COPY_Convertible);

    qRegisterMetaType< ::QAbstractTextDocumentLayout::Selection >("Selection");
    qRegisterMetaType< ::QAbstractTextDocumentLayout::Selection >("QAbstractTextDocumentLayout::Selection");

    return pyType;
}
