// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qaccessible_state_wrapper.h"

// Argument includes
#include <QtGui/qaccessible_base.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAccessible_State_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAccessible::State >()))
        return -1;

    ::QAccessible::State *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "State", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: State::State()
    // 1: State::State(QAccessible::State)
    if (numArgs == 0) {
        overloadId = 0; // State()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), (pyArgs[0])))) {
        overloadId = 1; // State(QAccessible::State)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // State()
        {

            // State()
            cptr = new ::QAccessible::State();
            break;
        }
        case 1: // State(const QAccessible::State &State)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAccessible::State cppArg0_local;
            ::QAccessible::State *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // State(QAccessible::State)
                cptr = new ::QAccessible::State(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QAccessible::State >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAccessible_State__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAccessible_State_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAccessible_State_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QAccessible_State__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QAccessible_State_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), (pyArg)))) {
                // operator==(const QAccessible::State &second)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QAccessible::State cppArg0_local;
                ::QAccessible::State *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

static PyObject *Sbk_QAccessible_State_get_disabled(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->disabled;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_disabled(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("disabled");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("disabled", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->disabled;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->disabled = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_selected(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->selected;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_selected(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("selected");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("selected", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->selected;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->selected = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_focusable(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->focusable;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_focusable(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("focusable");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("focusable", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->focusable;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->focusable = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_focused(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->focused;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_focused(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("focused");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("focused", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->focused;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->focused = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_pressed(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->pressed;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_pressed(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("pressed");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("pressed", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->pressed;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->pressed = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_checkable(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->checkable;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_checkable(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("checkable");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("checkable", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->checkable;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->checkable = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_checked(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->checked;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_checked(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("checked");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("checked", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->checked;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->checked = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_checkStateMixed(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->checkStateMixed;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_checkStateMixed(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("checkStateMixed");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("checkStateMixed", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->checkStateMixed;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->checkStateMixed = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_readOnly(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->readOnly;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_readOnly(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("readOnly");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("readOnly", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->readOnly;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->readOnly = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_hotTracked(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->hotTracked;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_hotTracked(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("hotTracked");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("hotTracked", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->hotTracked;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->hotTracked = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_defaultButton(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->defaultButton;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_defaultButton(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("defaultButton");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("defaultButton", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->defaultButton;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->defaultButton = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_expanded(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->expanded;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_expanded(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("expanded");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("expanded", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->expanded;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->expanded = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_collapsed(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->collapsed;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_collapsed(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("collapsed");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("collapsed", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->collapsed;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->collapsed = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_busy(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->busy;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_busy(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("busy");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("busy", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->busy;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->busy = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_expandable(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->expandable;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_expandable(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("expandable");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("expandable", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->expandable;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->expandable = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_marqueed(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->marqueed;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_marqueed(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("marqueed");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("marqueed", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->marqueed;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->marqueed = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_animated(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->animated;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_animated(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("animated");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("animated", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->animated;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->animated = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_invisible(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->invisible;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_invisible(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("invisible");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("invisible", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->invisible;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->invisible = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_offscreen(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->offscreen;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_offscreen(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("offscreen");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("offscreen", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->offscreen;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->offscreen = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_sizeable(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->sizeable;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_sizeable(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("sizeable");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("sizeable", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->sizeable;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->sizeable = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_movable(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->movable;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_movable(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("movable");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("movable", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->movable;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->movable = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_selfVoicing(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->selfVoicing;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_selfVoicing(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("selfVoicing");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("selfVoicing", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->selfVoicing;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->selfVoicing = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_selectable(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->selectable;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_selectable(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("selectable");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("selectable", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->selectable;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->selectable = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_linked(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->linked;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_linked(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("linked");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("linked", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->linked;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->linked = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_traversed(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->traversed;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_traversed(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("traversed");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("traversed", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->traversed;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->traversed = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_multiSelectable(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->multiSelectable;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_multiSelectable(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("multiSelectable");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("multiSelectable", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->multiSelectable;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->multiSelectable = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_extSelectable(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->extSelectable;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_extSelectable(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("extSelectable");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("extSelectable", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->extSelectable;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->extSelectable = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_passwordEdit(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->passwordEdit;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_passwordEdit(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("passwordEdit");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("passwordEdit", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->passwordEdit;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->passwordEdit = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_hasPopup(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->hasPopup;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_hasPopup(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("hasPopup");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("hasPopup", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->hasPopup;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->hasPopup = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_modal(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->modal;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_modal(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("modal");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("modal", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->modal;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->modal = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_active(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->active;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_active(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("active");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("active", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->active;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->active = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_invalid(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->invalid;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_invalid(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("invalid");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("invalid", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->invalid;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->invalid = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_editable(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->editable;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_editable(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("editable");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("editable", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->editable;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->editable = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_multiLine(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->multiLine;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_multiLine(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("multiLine");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("multiLine", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->multiLine;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->multiLine = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_selectableText(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->selectableText;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_selectableText(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("selectableText");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("selectableText", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->selectableText;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->selectableText = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_supportsAutoCompletion(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->supportsAutoCompletion;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_supportsAutoCompletion(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("supportsAutoCompletion");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("supportsAutoCompletion", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->supportsAutoCompletion;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->supportsAutoCompletion = cppOut_local;

    return 0;
}

static PyObject *Sbk_QAccessible_State_get_searchEdit(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->searchEdit;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QAccessible_State_set_searchEdit(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("searchEdit");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("searchEdit", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->searchEdit;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->searchEdit = cppOut_local;

    return 0;
}

// Getters and Setters for State
static PyGetSetDef Sbk_QAccessible_State_getsetlist[] = {
    {const_cast<char *>("disabled"), Sbk_QAccessible_State_get_disabled, Sbk_QAccessible_State_set_disabled, nullptr, nullptr},
    {const_cast<char *>("selected"), Sbk_QAccessible_State_get_selected, Sbk_QAccessible_State_set_selected, nullptr, nullptr},
    {const_cast<char *>("focusable"), Sbk_QAccessible_State_get_focusable, Sbk_QAccessible_State_set_focusable, nullptr, nullptr},
    {const_cast<char *>("focused"), Sbk_QAccessible_State_get_focused, Sbk_QAccessible_State_set_focused, nullptr, nullptr},
    {const_cast<char *>("pressed"), Sbk_QAccessible_State_get_pressed, Sbk_QAccessible_State_set_pressed, nullptr, nullptr},
    {const_cast<char *>("checkable"), Sbk_QAccessible_State_get_checkable, Sbk_QAccessible_State_set_checkable, nullptr, nullptr},
    {const_cast<char *>("checked"), Sbk_QAccessible_State_get_checked, Sbk_QAccessible_State_set_checked, nullptr, nullptr},
    {const_cast<char *>("checkStateMixed"), Sbk_QAccessible_State_get_checkStateMixed, Sbk_QAccessible_State_set_checkStateMixed, nullptr, nullptr},
    {const_cast<char *>("readOnly"), Sbk_QAccessible_State_get_readOnly, Sbk_QAccessible_State_set_readOnly, nullptr, nullptr},
    {const_cast<char *>("hotTracked"), Sbk_QAccessible_State_get_hotTracked, Sbk_QAccessible_State_set_hotTracked, nullptr, nullptr},
    {const_cast<char *>("defaultButton"), Sbk_QAccessible_State_get_defaultButton, Sbk_QAccessible_State_set_defaultButton, nullptr, nullptr},
    {const_cast<char *>("expanded"), Sbk_QAccessible_State_get_expanded, Sbk_QAccessible_State_set_expanded, nullptr, nullptr},
    {const_cast<char *>("collapsed"), Sbk_QAccessible_State_get_collapsed, Sbk_QAccessible_State_set_collapsed, nullptr, nullptr},
    {const_cast<char *>("busy"), Sbk_QAccessible_State_get_busy, Sbk_QAccessible_State_set_busy, nullptr, nullptr},
    {const_cast<char *>("expandable"), Sbk_QAccessible_State_get_expandable, Sbk_QAccessible_State_set_expandable, nullptr, nullptr},
    {const_cast<char *>("marqueed"), Sbk_QAccessible_State_get_marqueed, Sbk_QAccessible_State_set_marqueed, nullptr, nullptr},
    {const_cast<char *>("animated"), Sbk_QAccessible_State_get_animated, Sbk_QAccessible_State_set_animated, nullptr, nullptr},
    {const_cast<char *>("invisible"), Sbk_QAccessible_State_get_invisible, Sbk_QAccessible_State_set_invisible, nullptr, nullptr},
    {const_cast<char *>("offscreen"), Sbk_QAccessible_State_get_offscreen, Sbk_QAccessible_State_set_offscreen, nullptr, nullptr},
    {const_cast<char *>("sizeable"), Sbk_QAccessible_State_get_sizeable, Sbk_QAccessible_State_set_sizeable, nullptr, nullptr},
    {const_cast<char *>("movable"), Sbk_QAccessible_State_get_movable, Sbk_QAccessible_State_set_movable, nullptr, nullptr},
    {const_cast<char *>("selfVoicing"), Sbk_QAccessible_State_get_selfVoicing, Sbk_QAccessible_State_set_selfVoicing, nullptr, nullptr},
    {const_cast<char *>("selectable"), Sbk_QAccessible_State_get_selectable, Sbk_QAccessible_State_set_selectable, nullptr, nullptr},
    {const_cast<char *>("linked"), Sbk_QAccessible_State_get_linked, Sbk_QAccessible_State_set_linked, nullptr, nullptr},
    {const_cast<char *>("traversed"), Sbk_QAccessible_State_get_traversed, Sbk_QAccessible_State_set_traversed, nullptr, nullptr},
    {const_cast<char *>("multiSelectable"), Sbk_QAccessible_State_get_multiSelectable, Sbk_QAccessible_State_set_multiSelectable, nullptr, nullptr},
    {const_cast<char *>("extSelectable"), Sbk_QAccessible_State_get_extSelectable, Sbk_QAccessible_State_set_extSelectable, nullptr, nullptr},
    {const_cast<char *>("passwordEdit"), Sbk_QAccessible_State_get_passwordEdit, Sbk_QAccessible_State_set_passwordEdit, nullptr, nullptr},
    {const_cast<char *>("hasPopup"), Sbk_QAccessible_State_get_hasPopup, Sbk_QAccessible_State_set_hasPopup, nullptr, nullptr},
    {const_cast<char *>("modal"), Sbk_QAccessible_State_get_modal, Sbk_QAccessible_State_set_modal, nullptr, nullptr},
    {const_cast<char *>("active"), Sbk_QAccessible_State_get_active, Sbk_QAccessible_State_set_active, nullptr, nullptr},
    {const_cast<char *>("invalid"), Sbk_QAccessible_State_get_invalid, Sbk_QAccessible_State_set_invalid, nullptr, nullptr},
    {const_cast<char *>("editable"), Sbk_QAccessible_State_get_editable, Sbk_QAccessible_State_set_editable, nullptr, nullptr},
    {const_cast<char *>("multiLine"), Sbk_QAccessible_State_get_multiLine, Sbk_QAccessible_State_set_multiLine, nullptr, nullptr},
    {const_cast<char *>("selectableText"), Sbk_QAccessible_State_get_selectableText, Sbk_QAccessible_State_set_selectableText, nullptr, nullptr},
    {const_cast<char *>("supportsAutoCompletion"), Sbk_QAccessible_State_get_supportsAutoCompletion, Sbk_QAccessible_State_set_supportsAutoCompletion, nullptr, nullptr},
    {const_cast<char *>("searchEdit"), Sbk_QAccessible_State_get_searchEdit, Sbk_QAccessible_State_set_searchEdit, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QAccessible_State_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAccessible_State_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAccessible_State_Type = nullptr;
static PyTypeObject *Sbk_QAccessible_State_TypeF(void)
{
    return _Sbk_QAccessible_State_Type;
}

static PyType_Slot Sbk_QAccessible_State_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAccessible_State_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAccessible_State_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QAccessible_State_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAccessible_State_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QAccessible_State_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAccessible_State_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAccessible_State_spec = {
    "2:PySide6.QtGui.QAccessible.State",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAccessible_State_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void State_PythonToCpp_State_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAccessible_State_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_State_PythonToCpp_State_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAccessible_State_TypeF()))
        return State_PythonToCpp_State_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *State_PTR_CppToPython_State(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QAccessible_State_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *State_COPY_CppToPython_State(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QAccessible::State *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QAccessible_State_TypeF(), new ::QAccessible::State(*source), true, true);
}

// Python to C++ copy conversion.
static void State_PythonToCpp_State_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QAccessible::State *>(cppOut) = *reinterpret_cast< ::QAccessible::State *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_State_PythonToCpp_State_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QAccessible_State_TypeF()))
        return State_PythonToCpp_State_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAccessible_State_SignatureStrings[] = {
    "1:PySide6.QtGui.QAccessible.State(self)",
    "0:PySide6.QtGui.QAccessible.State(self,State:PySide6.QtGui.QAccessible.State)",
    "PySide6.QtGui.QAccessible.State.__copy__(self)->typing.Self",
    "PySide6.QtGui.QAccessible.State.__eq__(self,second:PySide6.QtGui.QAccessible.State)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QAccessible_State_SignatureByteSize = 106;
static constexpr uint8_t QAccessible_State_SignatureBytes[106] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x74, 0x4c, 0x4e, 0x4e, 0x2d, 0x2e, 0xce, 0x4c, 0xca, 0x49, 0xd5, 0x0b, 0x2e,
    0x49, 0x2c, 0x49, 0xd5, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x20, 0x4a, 0x9d, 0x0e, 0x98,
    0x49, 0x48, 0xa9, 0x26, 0x17, 0x01, 0x05, 0x7a, 0xf1, 0xf1, 0xc9, 0xf9, 0x05, 0x95, 0xf1, 0xf1,
    0x10, 0xcb, 0x75, 0xed, 0x4a, 0x2a, 0x0b, 0x32, 0xf3, 0xd2, 0xf5, 0x82, 0x81, 0x3c, 0x22, 0xf4,
    0xa6, 0x16, 0x42, 0x75, 0xea, 0x14, 0xa7, 0x26, 0xe7, 0xe7, 0xa5, 0x10, 0x74, 0x8f, 0xae, 0x5d,
    0x52, 0x7e, 0x7e, 0x0e, 0x17, 0x00, 0x42, 0xbc, 0x5e, 0x3d
};
#endif

PyTypeObject *init_QAccessible_State(PyObject *enclosingClass)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX].type;

    Shiboken::AutoDecRef Sbk_QAccessible_State_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAccessible_State_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "State",
        "QAccessible::State",
        &Sbk_QAccessible_State_spec,
        &Shiboken::callCppDestructor< ::QAccessible::State >,
        Sbk_QAccessible_State_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QAccessible_State_TypeF(); // references _Sbk_QAccessible_State_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAccessible_State_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAccessible_State_SignatureBytes, QAccessible_State_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAccessible_State_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_State_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        State_PythonToCpp_State_PTR,
        is_State_PythonToCpp_State_PTR_Convertible,
        State_PTR_CppToPython_State,
        State_COPY_CppToPython_State);

    Shiboken::Conversions::registerConverterName(converter, "QAccessible::State");
    Shiboken::Conversions::registerConverterName(converter, "QAccessible::State*");
    Shiboken::Conversions::registerConverterName(converter, "QAccessible::State&");
    Shiboken::Conversions::registerConverterAlias(converter, "State");
    Shiboken::Conversions::registerConverterAlias(converter, "State*");
    Shiboken::Conversions::registerConverterAlias(converter, "State&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAccessible::State).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        State_PythonToCpp_State_COPY,
        is_State_PythonToCpp_State_COPY_Convertible);

    qRegisterMetaType< ::QAccessible::State >("State");
    qRegisterMetaType< ::QAccessible::State >("QAccessible::State");

    return pyType;
}
