// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qaccessible_wrapper.h"

// inner classes
#include "qaccessible_state_wrapper.h"

// Extra includes
#include <QtGui/QAccessibleInterface>

// Argument includes
#include <QtGui/qaccessible.h>
#include <QtGui/qaccessible_base.h>
#include <QtGui/qtextcursor.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtgui.cpp (qaccessible-pysidefactory)]
// Helper for QAccessible::installFactory() that forwards the calls to
// Python callables.
class PySideAccessibleFactory
{
    PySideAccessibleFactory() = default;
public:
    ~PySideAccessibleFactory();

    static PySideAccessibleFactory *instance() { return m_instance; }
    static PySideAccessibleFactory *ensureInstance();

    static void installFactory(PyObject *f);
    static void cleanup();

    static QAccessibleInterface *factory(const QString &key, QObject *o);

private:
    QAccessibleInterface *callFactories(const QString &key, QObject *o);

    static PySideAccessibleFactory *m_instance;

    QList<PyObject *> m_factoryFunctions;
    QList<PyObject *> m_objects;
};

PySideAccessibleFactory *PySideAccessibleFactory::m_instance = nullptr;

PySideAccessibleFactory::~PySideAccessibleFactory()
{
    QAccessible::removeFactory(PySideAccessibleFactory::factory);
    if (!m_factoryFunctions.isEmpty()) {
        Shiboken::GilState state;
        for (auto *f : m_factoryFunctions)
            Py_DECREF(f);
        for (auto *o : m_objects)
            Py_DECREF(o);
    }
}

PySideAccessibleFactory *PySideAccessibleFactory::ensureInstance()
{
    if (m_instance == nullptr) {
        m_instance = new PySideAccessibleFactory;
        QAccessible::installFactory(PySideAccessibleFactory::factory);
        qAddPostRoutine(PySideAccessibleFactory::cleanup);
    }
    return m_instance;
}

void PySideAccessibleFactory::installFactory(PyObject *f)
{
    if (m_instance != nullptr) {
        Py_INCREF(f);
        m_instance->m_factoryFunctions.append(f);
    }
}

void PySideAccessibleFactory::cleanup()
{
    delete m_instance;
    m_instance = nullptr;
}

QAccessibleInterface *PySideAccessibleFactory::factory(const QString &key, QObject *o)
{
    return m_instance ? m_instance->callFactories(key, o) : nullptr;
}

QAccessibleInterface *PySideAccessibleFactory::callFactories(const QString &key, QObject *o)
{
    Shiboken::GilState state;
    Shiboken::AutoDecRef arglist(PyTuple_New(2));
    PyTuple_SetItem(arglist, 0, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &key));
    PyTuple_SetItem(arglist, 1, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), o));

    for (auto *f : m_factoryFunctions) {
        if (PyObject *pyResult = PyObject_CallObject(f, arglist)) {
            if (pyResult != Py_None) {
                m_objects.append(pyResult);
                ::QAccessibleInterface* result{nullptr};
Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), pyResult, &(result));
                return result;
            }
            Py_DECREF(pyResult);
        }
    }

    return nullptr;
}
// END of custom code block [file: ../glue/qtgui.cpp (qaccessible-pysidefactory)]
// ========================================================================
// End of code injection



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAccessible_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAccessible >()))
        return -1;

    ::QAccessible *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAccessible", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAccessible::QAccessible(QAccessible)
    if (numArgs == 1
        && (pyArgs[0] != Py_None && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]), (pyArgs[0]))))) {
        overloadId = 0; // QAccessible(QAccessible)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QAccessible *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAccessible(QAccessible)
            cptr = new ::QAccessible(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QAccessible >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAccessibleFunc_accessibleInterface(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QAccessible::accessibleInterface(uint)->QAccessibleInterface*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // accessibleInterface(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "accessibleInterface", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // accessibleInterface(uint)
            QAccessibleInterface * cppResult = ::QAccessible::accessibleInterface(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleFunc_cleanup(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cleanup()
        ::QAccessible::cleanup();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAccessibleFunc_deleteAccessibleInterface(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QAccessible::deleteAccessibleInterface(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // deleteAccessibleInterface(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "deleteAccessibleInterface", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // deleteAccessibleInterface(uint)
            ::QAccessible::deleteAccessibleInterface(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAccessibleFunc_installFactory(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QAccessible::installFactory(PyCallable)
    if (PyCallable_Check(pyArg)) {
        overloadId = 0; // installFactory(PyCallable)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "installFactory", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // installFactory(PyCallable)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qaccessible-installfactory)]
            PySideAccessibleFactory::ensureInstance()->installFactory(pyArg);
            // END of custom code block [file: ../glue/qtgui.cpp (qaccessible-installfactory)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAccessibleFunc_isActive(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isActive()
        bool cppResult = ::QAccessible::isActive();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleFunc_qAccessibleTextBoundaryHelper(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qAccessibleTextBoundaryHelper", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QAccessible::qAccessibleTextBoundaryHelper(QTextCursor,QAccessible::TextBoundaryType)->std::pair<int,int>
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_TextBoundaryType_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // qAccessibleTextBoundaryHelper(QTextCursor,QAccessible::TextBoundaryType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "qAccessibleTextBoundaryHelper", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTextCursor cppArg0_local;
        ::QTextCursor *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QAccessible::TextBoundaryType cppArg1{QAccessible::CharBoundary};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qAccessibleTextBoundaryHelper(QTextCursor,QAccessible::TextBoundaryType)
            std::pair<int,int> cppResult = ::QAccessible::qAccessibleTextBoundaryHelper(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_int_int_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleFunc_queryAccessibleInterface(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QAccessible::queryAccessibleInterface(QObject*)->QAccessibleInterface*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // queryAccessibleInterface(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "queryAccessibleInterface", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // queryAccessibleInterface(QObject*)
            QAccessibleInterface * cppResult = ::QAccessible::queryAccessibleInterface(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleFunc_registerAccessibleInterface(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QAccessible::registerAccessibleInterface(QAccessibleInterface*)->unsigned int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), (pyArg)))) {
        overloadId = 0; // registerAccessibleInterface(QAccessibleInterface*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "registerAccessibleInterface", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAccessibleInterface *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // registerAccessibleInterface(QAccessibleInterface*)
            unsigned int cppResult = ::QAccessible::registerAccessibleInterface(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleFunc_setActive(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QAccessible::setActive(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setActive(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setActive", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActive(bool)
            ::QAccessible::setActive(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAccessibleFunc_setRootObject(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QAccessible::setRootObject(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // setRootObject(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRootObject", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRootObject(QObject*)
            ::QAccessible::setRootObject(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAccessibleFunc_uniqueId(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QAccessible::uniqueId(QAccessibleInterface*)->unsigned int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), (pyArg)))) {
        overloadId = 0; // uniqueId(QAccessibleInterface*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "uniqueId", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAccessibleInterface *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // uniqueId(QAccessibleInterface*)
            unsigned int cppResult = ::QAccessible::uniqueId(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleFunc_updateAccessibility(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QAccessible::updateAccessibility(QAccessibleEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]), (pyArg)))) {
        overloadId = 0; // updateAccessibility(QAccessibleEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "updateAccessibility", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAccessibleEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateAccessibility(QAccessibleEvent*)
            ::QAccessible::updateAccessibility(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAccessible__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QAccessible *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAccessible_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QAccessible_EnumFlagInfo[] = {
    "AnnouncementPoliteness:Enum",
    "Attribute:Enum",
    "Event:Enum",
    "InterfaceType:Enum",
    "RelationFlag:Flag:Relation",
    "Role:Enum",
    "Text:Enum",
    "TextBoundaryType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAccessible_methods[] = {
    {"accessibleInterface", reinterpret_cast<PyCFunction>(Sbk_QAccessibleFunc_accessibleInterface), METH_O|METH_STATIC, nullptr},
    {"cleanup", reinterpret_cast<PyCFunction>(Sbk_QAccessibleFunc_cleanup), METH_NOARGS|METH_STATIC, nullptr},
    {"deleteAccessibleInterface", reinterpret_cast<PyCFunction>(Sbk_QAccessibleFunc_deleteAccessibleInterface), METH_O|METH_STATIC, nullptr},
    {"installFactory", reinterpret_cast<PyCFunction>(Sbk_QAccessibleFunc_installFactory), METH_O|METH_STATIC, nullptr},
    {"isActive", reinterpret_cast<PyCFunction>(Sbk_QAccessibleFunc_isActive), METH_NOARGS|METH_STATIC, nullptr},
    {"qAccessibleTextBoundaryHelper", reinterpret_cast<PyCFunction>(Sbk_QAccessibleFunc_qAccessibleTextBoundaryHelper), METH_VARARGS|METH_STATIC, nullptr},
    {"queryAccessibleInterface", reinterpret_cast<PyCFunction>(Sbk_QAccessibleFunc_queryAccessibleInterface), METH_O|METH_STATIC, nullptr},
    {"registerAccessibleInterface", reinterpret_cast<PyCFunction>(Sbk_QAccessibleFunc_registerAccessibleInterface), METH_O|METH_STATIC, nullptr},
    {"setActive", reinterpret_cast<PyCFunction>(Sbk_QAccessibleFunc_setActive), METH_O|METH_STATIC, nullptr},
    {"setRootObject", reinterpret_cast<PyCFunction>(Sbk_QAccessibleFunc_setRootObject), METH_O|METH_STATIC, nullptr},
    {"uniqueId", reinterpret_cast<PyCFunction>(Sbk_QAccessibleFunc_uniqueId), METH_O|METH_STATIC, nullptr},
    {"updateAccessibility", reinterpret_cast<PyCFunction>(Sbk_QAccessibleFunc_updateAccessibility), METH_O|METH_STATIC, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QAccessible__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QAccessible_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAccessible_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAccessible_Type = nullptr;
static PyTypeObject *Sbk_QAccessible_TypeF(void)
{
    return _Sbk_QAccessible_Type;
}

static PyType_Slot Sbk_QAccessible_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAccessible_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAccessible_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAccessible_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAccessible_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAccessible_spec = {
    "2:PySide6.QtGui.QAccessible",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAccessible_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAccessible_Event(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAccessible::Event>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAccessible::Event *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAccessible_Event_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Event_IDX])))
        return Enum_PythonToCpp_QAccessible_Event;
    return {};
}

static PyObject *QAccessible_Event_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAccessible::Event>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAccessible::Event *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Event_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAccessible_Role(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAccessible::Role>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAccessible::Role *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAccessible_Role_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Role_IDX])))
        return Enum_PythonToCpp_QAccessible_Role;
    return {};
}

static PyObject *QAccessible_Role_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAccessible::Role>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAccessible::Role *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Role_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAccessible_Text(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAccessible::Text>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAccessible::Text *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAccessible_Text_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Text_IDX])))
        return Enum_PythonToCpp_QAccessible_Text;
    return {};
}

static PyObject *QAccessible_Text_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAccessible::Text>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAccessible::Text *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Text_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAccessible_RelationFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAccessible::RelationFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAccessible::RelationFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAccessible_RelationFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_RelationFlag_IDX])))
        return Enum_PythonToCpp_QAccessible_RelationFlag;
    return {};
}

static PyObject *QAccessible_RelationFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAccessible::RelationFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAccessible::RelationFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_RelationFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QAccessible_RelationFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QAccessible::RelationFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QAccessible::RelationFlag> *>(cppOut) = value;

}

static PyObject *QAccessible_RelationFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QAccessible::RelationFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_RelationFlag_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QAccessible_InterfaceType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAccessible::InterfaceType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAccessible::InterfaceType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAccessible_InterfaceType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_InterfaceType_IDX])))
        return Enum_PythonToCpp_QAccessible_InterfaceType;
    return {};
}

static PyObject *QAccessible_InterfaceType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAccessible::InterfaceType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAccessible::InterfaceType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_InterfaceType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAccessible_TextBoundaryType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAccessible::TextBoundaryType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAccessible::TextBoundaryType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAccessible_TextBoundaryType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_TextBoundaryType_IDX])))
        return Enum_PythonToCpp_QAccessible_TextBoundaryType;
    return {};
}

static PyObject *QAccessible_TextBoundaryType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAccessible::TextBoundaryType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAccessible::TextBoundaryType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_TextBoundaryType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAccessible_Attribute(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAccessible::Attribute>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAccessible::Attribute *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAccessible_Attribute_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Attribute_IDX])))
        return Enum_PythonToCpp_QAccessible_Attribute;
    return {};
}

static PyObject *QAccessible_Attribute_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAccessible::Attribute>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAccessible::Attribute *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Attribute_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAccessible_AnnouncementPoliteness(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAccessible::AnnouncementPoliteness>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAccessible::AnnouncementPoliteness *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAccessible_AnnouncementPoliteness_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_AnnouncementPoliteness_IDX])))
        return Enum_PythonToCpp_QAccessible_AnnouncementPoliteness;
    return {};
}

static PyObject *QAccessible_AnnouncementPoliteness_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAccessible::AnnouncementPoliteness>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAccessible::AnnouncementPoliteness *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_AnnouncementPoliteness_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAccessible_PythonToCpp_QAccessible_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAccessible_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAccessible_PythonToCpp_QAccessible_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAccessible_TypeF()))
        return QAccessible_PythonToCpp_QAccessible_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAccessible_PTR_CppToPython_QAccessible(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QAccessible_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QAccessible_COPY_CppToPython_QAccessible(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QAccessible *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QAccessible_TypeF(), new ::QAccessible(*source), true, true);
}

// Python to C++ copy conversion.
static void QAccessible_PythonToCpp_QAccessible_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QAccessible *>(cppOut) = *reinterpret_cast< ::QAccessible *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QAccessible_PythonToCpp_QAccessible_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QAccessible_TypeF()))
        return QAccessible_PythonToCpp_QAccessible_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAccessible_SignatureStrings[] = {
    "PySide6.QtGui.QAccessible(self,QAccessible:PySide6.QtGui.QAccessible)",
    "PySide6.QtGui.QAccessible.accessibleInterface(uniqueId:unsigned int)->PySide6.QtGui.QAccessibleInterface",
    "PySide6.QtGui.QAccessible.cleanup()",
    "PySide6.QtGui.QAccessible.deleteAccessibleInterface(uniqueId:unsigned int)",
    "PySide6.QtGui.QAccessible.installFactory(arg__1:PyCallable)",
    "PySide6.QtGui.QAccessible.isActive()->bool",
    "PySide6.QtGui.QAccessible.qAccessibleTextBoundaryHelper(cursor:PySide6.QtGui.QTextCursor,boundaryType:PySide6.QtGui.QAccessible.TextBoundaryType)->std.pair[int, int]",
    "PySide6.QtGui.QAccessible.queryAccessibleInterface(arg__1:PySide6.QtCore.QObject)->PySide6.QtGui.QAccessibleInterface",
    "PySide6.QtGui.QAccessible.registerAccessibleInterface(iface:PySide6.QtGui.QAccessibleInterface)->unsigned int",
    "PySide6.QtGui.QAccessible.setActive(active:bool)",
    "PySide6.QtGui.QAccessible.setRootObject(object:PySide6.QtCore.QObject)",
    "PySide6.QtGui.QAccessible.uniqueId(iface:PySide6.QtGui.QAccessibleInterface)->unsigned int",
    "PySide6.QtGui.QAccessible.updateAccessibility(event:PySide6.QtGui.QAccessibleEvent)",
    "PySide6.QtGui.QAccessible.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QAccessible_SignatureByteSize = 328;
static constexpr uint8_t QAccessible_SignatureBytes[328] = {
    0x78, 0xda, 0xb5, 0x54, 0xcb, 0x4e, 0xc3, 0x30, 0x10, 0xbc, 0xf7, 0x2b, 0x38, 0xba, 0x52, 0x89,
    0xc4, 0x85, 0x43, 0x0e, 0x48, 0xa5, 0xe2, 0xd1, 0x13, 0x2d, 0xed, 0x0d, 0xa1, 0xc8, 0xb1, 0xb7,
    0xd1, 0x22, 0xcb, 0x76, 0xed, 0x75, 0x85, 0xff, 0x1e, 0x27, 0xf4, 0x11, 0xa1, 0xc6, 0x45, 0x42,
    0x5c, 0x62, 0xc7, 0x3b, 0xbb, 0x3b, 0x3b, 0x13, 0x67, 0x11, 0x57, 0x28, 0xe1, 0xb6, 0x58, 0xd2,
    0x53, 0xc0, 0x62, 0x39, 0x15, 0x02, 0xbc, 0xc7, 0x5a, 0x01, 0xf3, 0xa0, 0x36, 0x93, 0xde, 0x41,
    0xb9, 0x18, 0x82, 0x8e, 0x47, 0x83, 0xa1, 0x82, 0x1f, 0xb7, 0x73, 0x4d, 0xe0, 0x36, 0x5c, 0x00,
    0x0b, 0x1a, 0xb7, 0x01, 0xe6, 0xb2, 0x0c, 0xda, 0x63, 0xa3, 0x41, 0x5e, 0xa1, 0xa6, 0xf1, 0xf5,
    0xdd, 0x60, 0x95, 0x63, 0x6a, 0xa6, 0x91, 0x50, 0xc0, 0x75, 0xb0, 0x2c, 0x47, 0x46, 0x82, 0x02,
    0x82, 0xe9, 0xaf, 0x29, 0x65, 0x4a, 0xa1, 0xf6, 0xc4, 0x95, 0x7a, 0xe4, 0x82, 0x8c, 0x8b, 0x8c,
    0xbb, 0xa6, 0xaa, 0x6e, 0x92, 0x44, 0xb3, 0x74, 0xc8, 0x2f, 0x68, 0x82, 0x7e, 0x2a, 0x08, 0x77,
    0xc0, 0xd2, 0xcc, 0xb5, 0x31, 0x2a, 0x03, 0xdd, 0x9e, 0xf6, 0x6b, 0xf8, 0xa4, 0x7b, 0x13, 0xb4,
    0xe4, 0x2e, 0x3e, 0x83, 0xb2, 0xe0, 0x98, 0x08, 0xce, 0x1b, 0xf7, 0xd3, 0x98, 0x16, 0x38, 0xeb,
    0x22, 0x93, 0x7a, 0x8f, 0x5f, 0x47, 0x9b, 0xf1, 0xaf, 0xe8, 0x97, 0x6e, 0xa1, 0x89, 0x97, 0x27,
    0x59, 0x58, 0x8e, 0xee, 0x2d, 0xe9, 0x30, 0x69, 0xc5, 0x78, 0xcf, 0xb1, 0x0c, 0xe0, 0xe2, 0x39,
    0x59, 0x8f, 0xb2, 0x1c, 0x32, 0x67, 0xc6, 0x41, 0xb1, 0x7c, 0xa9, 0x3f, 0x40, 0xfc, 0xd9, 0x71,
    0x07, 0x0d, 0xfa, 0x04, 0x3b, 0xd7, 0x18, 0xdb, 0x67, 0x79, 0xb9, 0x7c, 0xe2, 0xd0, 0x77, 0x3c,
    0xd3, 0xcd, 0x03, 0xed, 0x5d, 0xe3, 0xdd, 0x52, 0xb6, 0xce, 0x8d, 0xf3, 0x09, 0xaf, 0xc6, 0xd0,
    0xf7, 0xac, 0xcc, 0x74, 0xcb, 0x90, 0x12, 0x99, 0x32, 0x87, 0x2f, 0xf3, 0x1f, 0x46, 0x0a, 0x56,
    0xf2, 0xd3, 0x75, 0x40, 0x85, 0x14, 0x19, 0xec, 0x40, 0xd3, 0x70, 0x97, 0x87, 0x36, 0x9c, 0xa3,
    0x5b, 0x55, 0xc2, 0xd8, 0x58, 0x55, 0xdd, 0xef, 0x23, 0x51, 0xa1, 0x68, 0x51, 0x37, 0xc5, 0x2a,
    0xbd, 0x8d, 0xbe, 0x00, 0xc4, 0xda, 0x9a, 0x72
};
#endif

PyTypeObject *init_QAccessible(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX].type;

    Shiboken::AutoDecRef Sbk_QAccessible_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAccessible_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAccessible",
        "QAccessible",
        &Sbk_QAccessible_spec,
        &Shiboken::callCppDestructor< ::QAccessible >,
        Sbk_QAccessible_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QAccessible_TypeF(); // references _Sbk_QAccessible_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAccessible_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAccessible_SignatureBytes, QAccessible_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAccessible_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAccessible_PythonToCpp_QAccessible_PTR,
        is_QAccessible_PythonToCpp_QAccessible_PTR_Convertible,
        QAccessible_PTR_CppToPython_QAccessible,
        QAccessible_COPY_CppToPython_QAccessible);

    Shiboken::Conversions::registerConverterName(converter, "QAccessible");
    Shiboken::Conversions::registerConverterName(converter, "QAccessible*");
    Shiboken::Conversions::registerConverterName(converter, "QAccessible&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAccessible).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QAccessible_PythonToCpp_QAccessible_COPY,
        is_QAccessible_PythonToCpp_QAccessible_COPY_Convertible);


    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAccessible_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Event'.
    const char *Event_Initializer[] = {
        "SoundPlayed",
        "Alert",
        "ForegroundChanged",
        "MenuStart",
        "MenuEnd",
        "PopupMenuStart",
        "PopupMenuEnd",
        "ContextHelpStart",
        "ContextHelpEnd",
        "DragDropStart",
        "DragDropEnd",
        "DialogStart",
        "DialogEnd",
        "ScrollingStart",
        "ScrollingEnd",
        "MenuCommand",
        "ActionChanged",
        "ActiveDescendantChanged",
        "AttributeChanged",
        "DocumentContentChanged",
        "DocumentLoadComplete",
        "DocumentLoadStopped",
        "DocumentReload",
        "HyperlinkEndIndexChanged",
        "HyperlinkNumberOfAnchorsChanged",
        "HyperlinkSelectedLinkChanged",
        "HypertextLinkActivated",
        "HypertextLinkSelected",
        "HyperlinkStartIndexChanged",
        "HypertextChanged",
        "HypertextNLinksChanged",
        "ObjectAttributeChanged",
        "PageChanged",
        "SectionChanged",
        "TableCaptionChanged",
        "TableColumnDescriptionChanged",
        "TableColumnHeaderChanged",
        "TableModelChanged",
        "TableRowDescriptionChanged",
        "TableRowHeaderChanged",
        "TableSummaryChanged",
        "TextAttributeChanged",
        "TextCaretMoved",
        "TextColumnChanged",
        "TextInserted",
        "TextRemoved",
        "TextUpdated",
        "TextSelectionChanged",
        "VisibleDataChanged",
        "ObjectCreated",
        "ObjectDestroyed",
        "ObjectShow",
        "ObjectHide",
        "ObjectReorder",
        "Focus",
        "Selection",
        "SelectionAdd",
        "SelectionRemove",
        "SelectionWithin",
        "StateChanged",
        "LocationChanged",
        "NameChanged",
        "DescriptionChanged",
        "ValueChanged",
        "ParentChanged",
        "HelpChanged",
        "DefaultActionChanged",
        "AcceleratorChanged",
        "Announcement",
        "IdentifierChanged",
        "InvalidEvent",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Event_InitializerValues[] = {
        uint16_t(QAccessible::Event::SoundPlayed),                     //  0x0001  1
        uint16_t(QAccessible::Event::Alert),                           //  0x0002  2
        uint16_t(QAccessible::Event::ForegroundChanged),               //  0x0003  3
        uint16_t(QAccessible::Event::MenuStart),                       //  0x0004  4
        uint16_t(QAccessible::Event::MenuEnd),                         //  0x0005  5
        uint16_t(QAccessible::Event::PopupMenuStart),                  //  0x0006  6
        uint16_t(QAccessible::Event::PopupMenuEnd),                    //  0x0007  7
        uint16_t(QAccessible::Event::ContextHelpStart),                //  0x000c  12
        uint16_t(QAccessible::Event::ContextHelpEnd),                  //  0x000d  13
        uint16_t(QAccessible::Event::DragDropStart),                   //  0x000e  14
        uint16_t(QAccessible::Event::DragDropEnd),                     //  0x000f  15
        uint16_t(QAccessible::Event::DialogStart),                     //  0x0010  16
        uint16_t(QAccessible::Event::DialogEnd),                       //  0x0011  17
        uint16_t(QAccessible::Event::ScrollingStart),                  //  0x0012  18
        uint16_t(QAccessible::Event::ScrollingEnd),                    //  0x0013  19
        uint16_t(QAccessible::Event::MenuCommand),                     //  0x0018  24
        uint16_t(QAccessible::Event::ActionChanged),                   //  0x0101  257
        uint16_t(QAccessible::Event::ActiveDescendantChanged),         //  0x0102  258
        uint16_t(QAccessible::Event::AttributeChanged),                //  0x0103  259
        uint16_t(QAccessible::Event::DocumentContentChanged),          //  0x0104  260
        uint16_t(QAccessible::Event::DocumentLoadComplete),            //  0x0105  261
        uint16_t(QAccessible::Event::DocumentLoadStopped),             //  0x0106  262
        uint16_t(QAccessible::Event::DocumentReload),                  //  0x0107  263
        uint16_t(QAccessible::Event::HyperlinkEndIndexChanged),        //  0x0108  264
        uint16_t(QAccessible::Event::HyperlinkNumberOfAnchorsChanged), //  0x0109  265
        uint16_t(QAccessible::Event::HyperlinkSelectedLinkChanged),    //  0x010a  266
        uint16_t(QAccessible::Event::HypertextLinkActivated),          //  0x010b  267
        uint16_t(QAccessible::Event::HypertextLinkSelected),           //  0x010c  268
        uint16_t(QAccessible::Event::HyperlinkStartIndexChanged),      //  0x010d  269
        uint16_t(QAccessible::Event::HypertextChanged),                //  0x010e  270
        uint16_t(QAccessible::Event::HypertextNLinksChanged),          //  0x010f  271
        uint16_t(QAccessible::Event::ObjectAttributeChanged),          //  0x0110  272
        uint16_t(QAccessible::Event::PageChanged),                     //  0x0111  273
        uint16_t(QAccessible::Event::SectionChanged),                  //  0x0112  274
        uint16_t(QAccessible::Event::TableCaptionChanged),             //  0x0113  275
        uint16_t(QAccessible::Event::TableColumnDescriptionChanged),   //  0x0114  276
        uint16_t(QAccessible::Event::TableColumnHeaderChanged),        //  0x0115  277
        uint16_t(QAccessible::Event::TableModelChanged),               //  0x0116  278
        uint16_t(QAccessible::Event::TableRowDescriptionChanged),      //  0x0117  279
        uint16_t(QAccessible::Event::TableRowHeaderChanged),           //  0x0118  280
        uint16_t(QAccessible::Event::TableSummaryChanged),             //  0x0119  281
        uint16_t(QAccessible::Event::TextAttributeChanged),            //  0x011a  282
        uint16_t(QAccessible::Event::TextCaretMoved),                  //  0x011b  283
        uint16_t(QAccessible::Event::TextColumnChanged),               //  0x011d  285
        uint16_t(QAccessible::Event::TextInserted),                    //  0x011e  286
        uint16_t(QAccessible::Event::TextRemoved),                     //  0x011f  287
        uint16_t(QAccessible::Event::TextUpdated),                     //  0x0120  288
        uint16_t(QAccessible::Event::TextSelectionChanged),            //  0x0121  289
        uint16_t(QAccessible::Event::VisibleDataChanged),              //  0x0122  290
        uint16_t(QAccessible::Event::ObjectCreated),                   //  0x8000  32768
        uint16_t(QAccessible::Event::ObjectDestroyed),                 //  0x8001  32769
        uint16_t(QAccessible::Event::ObjectShow),                      //  0x8002  32770
        uint16_t(QAccessible::Event::ObjectHide),                      //  0x8003  32771
        uint16_t(QAccessible::Event::ObjectReorder),                   //  0x8004  32772
        uint16_t(QAccessible::Event::Focus),                           //  0x8005  32773
        uint16_t(QAccessible::Event::Selection),                       //  0x8006  32774
        uint16_t(QAccessible::Event::SelectionAdd),                    //  0x8007  32775
        uint16_t(QAccessible::Event::SelectionRemove),                 //  0x8008  32776
        uint16_t(QAccessible::Event::SelectionWithin),                 //  0x8009  32777
        uint16_t(QAccessible::Event::StateChanged),                    //  0x800a  32778
        uint16_t(QAccessible::Event::LocationChanged),                 //  0x800b  32779
        uint16_t(QAccessible::Event::NameChanged),                     //  0x800c  32780
        uint16_t(QAccessible::Event::DescriptionChanged),              //  0x800d  32781
        uint16_t(QAccessible::Event::ValueChanged),                    //  0x800e  32782
        uint16_t(QAccessible::Event::ParentChanged),                   //  0x800f  32783
        uint16_t(QAccessible::Event::HelpChanged),                     //  0x80a0  32928
        uint16_t(QAccessible::Event::DefaultActionChanged),            //  0x80b0  32944
        uint16_t(QAccessible::Event::AcceleratorChanged),              //  0x80c0  32960
        uint16_t(QAccessible::Event::Announcement),                    //  0x80d0  32976
        uint16_t(QAccessible::Event::IdentifierChanged),               //  0x80e0  32992
        uint16_t(QAccessible::Event::InvalidEvent)                     //  0x80c1  32961
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAccessible_TypeF(),
        "2:PySide6.QtGui.QAccessible.Event",
        Event_Initializer, Event_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Event_IDX].type = EType;
    // Register converter for enum 'QAccessible::Event'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAccessible_Event_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAccessible_Event,
            is_Enum_PythonToCpp_QAccessible_Event_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAccessible::Event");
        Shiboken::Conversions::registerConverterAlias(converter, "Event");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Event' enum.

    // Initialization of enum 'Role'.
    const char *Role_Initializer[] = {
        "NoRole",
        "TitleBar",
        "MenuBar",
        "ScrollBar",
        "Grip",
        "Sound",
        "Cursor",
        "Caret",
        "AlertMessage",
        "Window",
        "Client",
        "PopupMenu",
        "MenuItem",
        "ToolTip",
        "Application",
        "Document",
        "Pane",
        "Chart",
        "Dialog",
        "Border",
        "Grouping",
        "Separator",
        "ToolBar",
        "StatusBar",
        "Table",
        "ColumnHeader",
        "RowHeader",
        "Column",
        "Row",
        "Cell",
        "Link",
        "HelpBalloon",
        "Assistant",
        "List",
        "ListItem",
        "Tree",
        "TreeItem",
        "PageTab",
        "PropertyPage",
        "Indicator",
        "Graphic",
        "StaticText",
        "EditableText",
        "Button",
        "PushButton",
        "CheckBox",
        "RadioButton",
        "ComboBox",
        "ProgressBar",
        "Dial",
        "HotkeyField",
        "Slider",
        "SpinBox",
        "Canvas",
        "Animation",
        "Equation",
        "ButtonDropDown",
        "ButtonMenu",
        "ButtonDropGrid",
        "Whitespace",
        "PageTabList",
        "Clock",
        "Splitter",
        "LayeredPane",
        "Terminal",
        "Desktop",
        "Paragraph",
        "WebDocument",
        "Section",
        "Notification",
        "ColorChooser",
        "Footer",
        "Form",
        "Heading",
        "Note",
        "ComplementaryContent",
        "UserRole",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Role_InitializerValues[] = {
        uint16_t(QAccessible::Role::NoRole),               //  0x0000  0
        uint16_t(QAccessible::Role::TitleBar),             //  0x0001  1
        uint16_t(QAccessible::Role::MenuBar),              //  0x0002  2
        uint16_t(QAccessible::Role::ScrollBar),            //  0x0003  3
        uint16_t(QAccessible::Role::Grip),                 //  0x0004  4
        uint16_t(QAccessible::Role::Sound),                //  0x0005  5
        uint16_t(QAccessible::Role::Cursor),               //  0x0006  6
        uint16_t(QAccessible::Role::Caret),                //  0x0007  7
        uint16_t(QAccessible::Role::AlertMessage),         //  0x0008  8
        uint16_t(QAccessible::Role::Window),               //  0x0009  9
        uint16_t(QAccessible::Role::Client),               //  0x000a  10
        uint16_t(QAccessible::Role::PopupMenu),            //  0x000b  11
        uint16_t(QAccessible::Role::MenuItem),             //  0x000c  12
        uint16_t(QAccessible::Role::ToolTip),              //  0x000d  13
        uint16_t(QAccessible::Role::Application),          //  0x000e  14
        uint16_t(QAccessible::Role::Document),             //  0x000f  15
        uint16_t(QAccessible::Role::Pane),                 //  0x0010  16
        uint16_t(QAccessible::Role::Chart),                //  0x0011  17
        uint16_t(QAccessible::Role::Dialog),               //  0x0012  18
        uint16_t(QAccessible::Role::Border),               //  0x0013  19
        uint16_t(QAccessible::Role::Grouping),             //  0x0014  20
        uint16_t(QAccessible::Role::Separator),            //  0x0015  21
        uint16_t(QAccessible::Role::ToolBar),              //  0x0016  22
        uint16_t(QAccessible::Role::StatusBar),            //  0x0017  23
        uint16_t(QAccessible::Role::Table),                //  0x0018  24
        uint16_t(QAccessible::Role::ColumnHeader),         //  0x0019  25
        uint16_t(QAccessible::Role::RowHeader),            //  0x001a  26
        uint16_t(QAccessible::Role::Column),               //  0x001b  27
        uint16_t(QAccessible::Role::Row),                  //  0x001c  28
        uint16_t(QAccessible::Role::Cell),                 //  0x001d  29
        uint16_t(QAccessible::Role::Link),                 //  0x001e  30
        uint16_t(QAccessible::Role::HelpBalloon),          //  0x001f  31
        uint16_t(QAccessible::Role::Assistant),            //  0x0020  32
        uint16_t(QAccessible::Role::List),                 //  0x0021  33
        uint16_t(QAccessible::Role::ListItem),             //  0x0022  34
        uint16_t(QAccessible::Role::Tree),                 //  0x0023  35
        uint16_t(QAccessible::Role::TreeItem),             //  0x0024  36
        uint16_t(QAccessible::Role::PageTab),              //  0x0025  37
        uint16_t(QAccessible::Role::PropertyPage),         //  0x0026  38
        uint16_t(QAccessible::Role::Indicator),            //  0x0027  39
        uint16_t(QAccessible::Role::Graphic),              //  0x0028  40
        uint16_t(QAccessible::Role::StaticText),           //  0x0029  41
        uint16_t(QAccessible::Role::EditableText),         //  0x002a  42
        uint16_t(QAccessible::Role::Button),               //  0x002b  43
        uint16_t(QAccessible::Role::PushButton),           //  0x002b  43
        uint16_t(QAccessible::Role::CheckBox),             //  0x002c  44
        uint16_t(QAccessible::Role::RadioButton),          //  0x002d  45
        uint16_t(QAccessible::Role::ComboBox),             //  0x002e  46
        uint16_t(QAccessible::Role::ProgressBar),          //  0x0030  48
        uint16_t(QAccessible::Role::Dial),                 //  0x0031  49
        uint16_t(QAccessible::Role::HotkeyField),          //  0x0032  50
        uint16_t(QAccessible::Role::Slider),               //  0x0033  51
        uint16_t(QAccessible::Role::SpinBox),              //  0x0034  52
        uint16_t(QAccessible::Role::Canvas),               //  0x0035  53
        uint16_t(QAccessible::Role::Animation),            //  0x0036  54
        uint16_t(QAccessible::Role::Equation),             //  0x0037  55
        uint16_t(QAccessible::Role::ButtonDropDown),       //  0x0038  56
        uint16_t(QAccessible::Role::ButtonMenu),           //  0x0039  57
        uint16_t(QAccessible::Role::ButtonDropGrid),       //  0x003a  58
        uint16_t(QAccessible::Role::Whitespace),           //  0x003b  59
        uint16_t(QAccessible::Role::PageTabList),          //  0x003c  60
        uint16_t(QAccessible::Role::Clock),                //  0x003d  61
        uint16_t(QAccessible::Role::Splitter),             //  0x003e  62
        uint16_t(QAccessible::Role::LayeredPane),          //  0x0080  128
        uint16_t(QAccessible::Role::Terminal),             //  0x0081  129
        uint16_t(QAccessible::Role::Desktop),              //  0x0082  130
        uint16_t(QAccessible::Role::Paragraph),            //  0x0083  131
        uint16_t(QAccessible::Role::WebDocument),          //  0x0084  132
        uint16_t(QAccessible::Role::Section),              //  0x0085  133
        uint16_t(QAccessible::Role::Notification),         //  0x0086  134
        uint16_t(QAccessible::Role::ColorChooser),         //  0x0404  1028
        uint16_t(QAccessible::Role::Footer),               //  0x040e  1038
        uint16_t(QAccessible::Role::Form),                 //  0x0410  1040
        uint16_t(QAccessible::Role::Heading),              //  0x0414  1044
        uint16_t(QAccessible::Role::Note),                 //  0x041b  1051
        uint16_t(QAccessible::Role::ComplementaryContent), //  0x042c  1068
        uint16_t(QAccessible::Role::UserRole)              //  0xffff  65535
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAccessible_TypeF(),
        "2:PySide6.QtGui.QAccessible.Role",
        Role_Initializer, Role_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Role_IDX].type = EType;
    // Register converter for enum 'QAccessible::Role'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAccessible_Role_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAccessible_Role,
            is_Enum_PythonToCpp_QAccessible_Role_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAccessible::Role");
        Shiboken::Conversions::registerConverterAlias(converter, "Role");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Role' enum.

    // Initialization of enum 'Text'.
    const char *Text_Initializer[] = {
        "Name",
        "Description",
        "Value",
        "Help",
        "Accelerator",
        "DebugDescription",
        "Identifier",
        "UserText",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Text_InitializerValues[] = {
        uint16_t(QAccessible::Text::Name),             //  0x0000  0
        uint16_t(QAccessible::Text::Description),      //  0x0001  1
        uint16_t(QAccessible::Text::Value),            //  0x0002  2
        uint16_t(QAccessible::Text::Help),             //  0x0003  3
        uint16_t(QAccessible::Text::Accelerator),      //  0x0004  4
        uint16_t(QAccessible::Text::DebugDescription), //  0x0005  5
        uint16_t(QAccessible::Text::Identifier),       //  0x0006  6
        uint16_t(QAccessible::Text::UserText)          //  0xffff  65535
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAccessible_TypeF(),
        "2:PySide6.QtGui.QAccessible.Text",
        Text_Initializer, Text_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Text_IDX].type = EType;
    // Register converter for enum 'QAccessible::Text'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAccessible_Text_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAccessible_Text,
            is_Enum_PythonToCpp_QAccessible_Text_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAccessible::Text");
        Shiboken::Conversions::registerConverterAlias(converter, "Text");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Text' enum.

    // Initialization of enum 'RelationFlag'.
    const char *RelationFlag_Initializer[] = {
        "Label",
        "Labelled",
        "Controller",
        "Controlled",
        "DescriptionFor",
        "Described",
        "FlowsFrom",
        "FlowsTo",
        "AllRelations",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t RelationFlag_InitializerValues[] = {
        uint32_t(QAccessible::RelationFlag::Label),          //  0x00000001  1
        uint32_t(QAccessible::RelationFlag::Labelled),       //  0x00000002  2
        uint32_t(QAccessible::RelationFlag::Controller),     //  0x00000004  4
        uint32_t(QAccessible::RelationFlag::Controlled),     //  0x00000008  8
        uint32_t(QAccessible::RelationFlag::DescriptionFor), //  0x00000010  16
        uint32_t(QAccessible::RelationFlag::Described),      //  0x00000020  32
        uint32_t(QAccessible::RelationFlag::FlowsFrom),      //  0x00000040  64
        uint32_t(QAccessible::RelationFlag::FlowsTo),        //  0x00000080  128
        uint32_t(QAccessible::RelationFlag::AllRelations)    //  0xffffffff  4294967295
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAccessible_TypeF(),
        "2:PySide6.QtGui.QAccessible.RelationFlag",
        RelationFlag_Initializer, RelationFlag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_RelationFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QAccessible_RelationFlag_IDX].type =
        EType;
    // Register converter for enum 'QAccessible::RelationFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAccessible_RelationFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAccessible_RelationFlag,
            is_Enum_PythonToCpp_QAccessible_RelationFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAccessible::RelationFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "RelationFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QAccessible_RelationFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QAccessible_RelationFlag,
            is_Enum_PythonToCpp_QAccessible_RelationFlag_Convertible);
        // Register converter for flag 'QFlags<QAccessible::RelationFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QAccessible::RelationFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QAccessible::Relation");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'RelationFlag' enum/flags.

    // Initialization of enum 'InterfaceType'.
    const char *InterfaceType_Initializer[] = {
        "TextInterface",
        "EditableTextInterface",
        "ValueInterface",
        "ActionInterface",
        "ImageInterface",
        "TableInterface",
        "TableCellInterface",
        "HyperlinkInterface",
        "SelectionInterface",
        "AttributesInterface",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t InterfaceType_InitializerValues[] = {
        uint8_t(QAccessible::InterfaceType::TextInterface),         //  0x00  0
        uint8_t(QAccessible::InterfaceType::EditableTextInterface), //  0x01  1
        uint8_t(QAccessible::InterfaceType::ValueInterface),        //  0x02  2
        uint8_t(QAccessible::InterfaceType::ActionInterface),       //  0x03  3
        uint8_t(QAccessible::InterfaceType::ImageInterface),        //  0x04  4
        uint8_t(QAccessible::InterfaceType::TableInterface),        //  0x05  5
        uint8_t(QAccessible::InterfaceType::TableCellInterface),    //  0x06  6
        uint8_t(QAccessible::InterfaceType::HyperlinkInterface),    //  0x07  7
        uint8_t(QAccessible::InterfaceType::SelectionInterface),    //  0x08  8
        uint8_t(QAccessible::InterfaceType::AttributesInterface)    //  0x09  9
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAccessible_TypeF(),
        "2:PySide6.QtGui.QAccessible.InterfaceType",
        InterfaceType_Initializer, InterfaceType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_InterfaceType_IDX].type = EType;
    // Register converter for enum 'QAccessible::InterfaceType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAccessible_InterfaceType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAccessible_InterfaceType,
            is_Enum_PythonToCpp_QAccessible_InterfaceType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAccessible::InterfaceType");
        Shiboken::Conversions::registerConverterAlias(converter, "InterfaceType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'InterfaceType' enum.

    // Initialization of enum 'TextBoundaryType'.
    const char *TextBoundaryType_Initializer[] = {
        "CharBoundary",
        "WordBoundary",
        "SentenceBoundary",
        "ParagraphBoundary",
        "LineBoundary",
        "NoBoundary",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TextBoundaryType_InitializerValues[] = {
        uint8_t(QAccessible::TextBoundaryType::CharBoundary),      //  0x00  0
        uint8_t(QAccessible::TextBoundaryType::WordBoundary),      //  0x01  1
        uint8_t(QAccessible::TextBoundaryType::SentenceBoundary),  //  0x02  2
        uint8_t(QAccessible::TextBoundaryType::ParagraphBoundary), //  0x03  3
        uint8_t(QAccessible::TextBoundaryType::LineBoundary),      //  0x04  4
        uint8_t(QAccessible::TextBoundaryType::NoBoundary)         //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAccessible_TypeF(),
        "2:PySide6.QtGui.QAccessible.TextBoundaryType",
        TextBoundaryType_Initializer, TextBoundaryType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_TextBoundaryType_IDX].type = EType;
    // Register converter for enum 'QAccessible::TextBoundaryType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAccessible_TextBoundaryType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAccessible_TextBoundaryType,
            is_Enum_PythonToCpp_QAccessible_TextBoundaryType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAccessible::TextBoundaryType");
        Shiboken::Conversions::registerConverterAlias(converter, "TextBoundaryType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'TextBoundaryType' enum.

    // Initialization of enum 'Attribute'.
    const char *Attribute_Initializer[] = {
        "Custom",
        "Level",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Attribute_InitializerValues[] = {
        int8_t(QAccessible::Attribute::Custom), //  0x00  0
        int8_t(QAccessible::Attribute::Level)   //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAccessible_TypeF(),
        "2:PySide6.QtGui.QAccessible.Attribute",
        Attribute_Initializer, Attribute_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Attribute_IDX].type = EType;
    // Register converter for enum 'QAccessible::Attribute'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAccessible_Attribute_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAccessible_Attribute,
            is_Enum_PythonToCpp_QAccessible_Attribute_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAccessible::Attribute");
        Shiboken::Conversions::registerConverterAlias(converter, "Attribute");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Attribute' enum.

    // Initialization of enum 'AnnouncementPoliteness'.
    const char *AnnouncementPoliteness_Initializer[] = {
        "Polite",
        "Assertive",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t AnnouncementPoliteness_InitializerValues[] = {
        int8_t(QAccessible::AnnouncementPoliteness::Polite),   //  0x00  0
        int8_t(QAccessible::AnnouncementPoliteness::Assertive) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAccessible_TypeF(),
        "2:PySide6.QtGui.QAccessible.AnnouncementPoliteness",
        AnnouncementPoliteness_Initializer, AnnouncementPoliteness_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_AnnouncementPoliteness_IDX].type = EType;
    // Register converter for enum 'QAccessible::AnnouncementPoliteness'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAccessible_AnnouncementPoliteness_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAccessible_AnnouncementPoliteness,
            is_Enum_PythonToCpp_QAccessible_AnnouncementPoliteness_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAccessible::AnnouncementPoliteness");
        Shiboken::Conversions::registerConverterAlias(converter, "AnnouncementPoliteness");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AnnouncementPoliteness' enum.


    qRegisterMetaType< ::QAccessible::Event >("QAccessible::Event");
    qRegisterMetaType< ::QAccessible::Role >("QAccessible::Role");
    qRegisterMetaType< ::QAccessible::Text >("QAccessible::Text");
    qRegisterMetaType< ::QAccessible::RelationFlag >("QAccessible::RelationFlag");
    qRegisterMetaType< ::QAccessible::InterfaceType >("QAccessible::InterfaceType");
    qRegisterMetaType< ::QAccessible::TextBoundaryType >("QAccessible::TextBoundaryType");
    qRegisterMetaType< ::QAccessible::Attribute >("QAccessible::Attribute");
    qRegisterMetaType< ::QAccessible::AnnouncementPoliteness >("QAccessible::AnnouncementPoliteness");

    return pyType;
}

