// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qaccessibleannouncementevent_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qaccessible.h>
#include <QtGui/qaccessible_base.h>
#include <qobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAccessibleAnnouncementEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAccessibleAnnouncementEventWrapper::QAccessibleAnnouncementEventWrapper(::QAccessibleInterface * iface, const ::QString & message) : QAccessibleAnnouncementEvent(iface, message)
{
}

QAccessibleAnnouncementEventWrapper::QAccessibleAnnouncementEventWrapper(::QObject * object, const ::QString & message) : QAccessibleAnnouncementEvent(object, message)
{
}

::QAccessibleInterface * QAccessibleAnnouncementEventWrapper::accessibleInterface() const
{
    if (m_PyMethodCache[0])
        return this->::QAccessibleEvent::accessibleInterface();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "accessibleInterface";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QAccessibleEvent::accessibleInterface();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAccessibleAnnouncementEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAccessibleAnnouncementEvent", funcName, Shiboken::SbkType< QAccessibleInterface >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QAccessibleInterface *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QAccessibleAnnouncementEventWrapper::~QAccessibleAnnouncementEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAccessibleAnnouncementEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAccessibleAnnouncementEvent >()))
        return -1;

    QAccessibleAnnouncementEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAccessibleAnnouncementEvent", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAccessibleAnnouncementEvent::QAccessibleAnnouncementEvent(QAccessibleInterface*,QString)
    // 1: QAccessibleAnnouncementEvent::QAccessibleAnnouncementEvent(QObject*,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 1; // QAccessibleAnnouncementEvent(QObject*,QString)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // QAccessibleAnnouncementEvent(QAccessibleInterface*,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAnnouncementEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAnnouncementEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAccessibleAnnouncementEvent(QAccessibleInterface *iface, const QString &message)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAccessibleInterface *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleAnnouncementEvent(QAccessibleInterface*,QString)
                cptr = new QAccessibleAnnouncementEventWrapper(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // QAccessibleAnnouncementEvent(QObject *object, const QString &message)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleAnnouncementEvent(QObject*,QString)
                cptr = new QAccessibleAnnouncementEventWrapper(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAccessibleAnnouncementEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAnnouncementEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAccessibleAnnouncementEventFunc_message(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleAnnouncementEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAnnouncementEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // message()const
        QString cppResult = const_cast<const ::QAccessibleAnnouncementEvent *>(cppSelf)->message();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleAnnouncementEventFunc_politeness(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleAnnouncementEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAnnouncementEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // politeness()const
        QAccessible::AnnouncementPoliteness cppResult = const_cast<const ::QAccessibleAnnouncementEvent *>(cppSelf)->politeness();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_AnnouncementPoliteness_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleAnnouncementEventFunc_setPoliteness(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleAnnouncementEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAnnouncementEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAccessibleAnnouncementEvent::setPoliteness(QAccessible::AnnouncementPoliteness)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_AnnouncementPoliteness_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPoliteness(QAccessible::AnnouncementPoliteness)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPoliteness", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAnnouncementEvent_IDX]);

    // Call function/method
    {
        ::QAccessible::AnnouncementPoliteness cppArg0{QAccessible::AnnouncementPoliteness::Polite};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPoliteness(QAccessible::AnnouncementPoliteness)
            cppSelf->setPoliteness(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QAccessibleAnnouncementEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAccessibleAnnouncementEvent_methods[] = {
    {"message", reinterpret_cast<PyCFunction>(Sbk_QAccessibleAnnouncementEventFunc_message), METH_NOARGS, nullptr},
    {"politeness", reinterpret_cast<PyCFunction>(Sbk_QAccessibleAnnouncementEventFunc_politeness), METH_NOARGS, nullptr},
    {"setPoliteness", reinterpret_cast<PyCFunction>(Sbk_QAccessibleAnnouncementEventFunc_setPoliteness), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAccessibleAnnouncementEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAccessibleAnnouncementEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAnnouncementEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAccessibleAnnouncementEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAccessibleAnnouncementEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAccessibleAnnouncementEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAccessibleAnnouncementEvent_Type = nullptr;
static PyTypeObject *Sbk_QAccessibleAnnouncementEvent_TypeF(void)
{
    return _Sbk_QAccessibleAnnouncementEvent_Type;
}

static PyType_Slot Sbk_QAccessibleAnnouncementEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAccessibleAnnouncementEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAccessibleAnnouncementEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAccessibleAnnouncementEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAccessibleAnnouncementEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAccessibleAnnouncementEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAccessibleAnnouncementEvent_spec = {
    "2:PySide6.QtGui.QAccessibleAnnouncementEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAccessibleAnnouncementEvent_slots
};

} //extern "C"

static void *Sbk_QAccessibleAnnouncementEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QAccessibleEvent *>(cptr)->type() == QAccessible::Announcement)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAccessibleAnnouncementEvent_PythonToCpp_QAccessibleAnnouncementEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAccessibleAnnouncementEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAccessibleAnnouncementEvent_PythonToCpp_QAccessibleAnnouncementEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAccessibleAnnouncementEvent_TypeF()))
        return QAccessibleAnnouncementEvent_PythonToCpp_QAccessibleAnnouncementEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAccessibleAnnouncementEvent_PTR_CppToPython_QAccessibleAnnouncementEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QAccessibleAnnouncementEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QAccessibleAnnouncementEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAccessibleAnnouncementEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QAccessibleAnnouncementEvent(self,iface:PySide6.QtGui.QAccessibleInterface,message:QString)",
    "0:PySide6.QtGui.QAccessibleAnnouncementEvent(self,object:PySide6.QtCore.QObject,message:QString)",
    "PySide6.QtGui.QAccessibleAnnouncementEvent.message(self)->QString",
    "PySide6.QtGui.QAccessibleAnnouncementEvent.politeness(self)->PySide6.QtGui.QAccessible.AnnouncementPoliteness",
    "PySide6.QtGui.QAccessibleAnnouncementEvent.setPoliteness(self,politeness:PySide6.QtGui.QAccessible.AnnouncementPoliteness)",
    nullptr}; // Sentinel
#else
static constexpr size_t QAccessibleAnnouncementEvent_SignatureByteSize = 162;
static constexpr uint8_t QAccessibleAnnouncementEvent_SignatureBytes[162] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x74, 0x4c, 0x4e, 0x4e, 0x2d, 0x2e, 0xce, 0x4c, 0xca, 0x49, 0x75, 0xcc, 0xcb,
    0xcb, 0x2f, 0xcd, 0x4b, 0x4e, 0xcd, 0x4d, 0xcd, 0x2b, 0x71, 0x2d, 0x03, 0x12, 0x1a, 0xc5, 0xa9,
    0x39, 0x69, 0x3a, 0x99, 0x69, 0x89, 0xc9, 0xa9, 0xb8, 0x75, 0x79, 0xe6, 0x95, 0xa4, 0x16, 0x81,
    0x94, 0xe8, 0xe4, 0x02, 0x45, 0x12, 0xd3, 0x53, 0xad, 0x02, 0x83, 0x4b, 0x8a, 0x32, 0xf3, 0xd2,
    0x35, 0xb9, 0x0c, 0x48, 0xb6, 0x2b, 0x3f, 0x29, 0x2b, 0x35, 0xb9, 0x04, 0x49, 0x9b, 0x73, 0x7e,
    0x51, 0xaa, 0x5e, 0xa0, 0x3f, 0x58, 0x18, 0xd3, 0x02, 0xe2, 0x8d, 0xd7, 0x83, 0xea, 0x05, 0x5b,
    0xa3, 0xa9, 0x6b, 0x07, 0x35, 0x82, 0x14, 0x13, 0x0a, 0xf2, 0x73, 0x32, 0x4b, 0x52, 0xf3, 0x80,
    0xf2, 0x30, 0x43, 0x70, 0x6a, 0xd6, 0x43, 0xd6, 0x1d, 0x00, 0xd7, 0x47, 0x8a, 0x6d, 0xc5, 0xa9,
    0x48, 0x1a, 0x21, 0x81, 0x83, 0x70, 0x80, 0x15, 0xa9, 0x36, 0x6b, 0x72, 0x01, 0x00, 0x6c, 0x65,
    0xba, 0x8f
};
#endif

PyTypeObject *init_QAccessibleAnnouncementEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAnnouncementEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAnnouncementEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QAccessibleAnnouncementEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]))));

    _Sbk_QAccessibleAnnouncementEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAccessibleAnnouncementEvent",
        "QAccessibleAnnouncementEvent*",
        &Sbk_QAccessibleAnnouncementEvent_spec,
        &Shiboken::callCppDestructor< QAccessibleAnnouncementEvent >,
        Sbk_QAccessibleAnnouncementEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAccessibleAnnouncementEvent_TypeF(); // references _Sbk_QAccessibleAnnouncementEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAccessibleAnnouncementEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAccessibleAnnouncementEvent_SignatureBytes, QAccessibleAnnouncementEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAccessibleAnnouncementEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAnnouncementEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAccessibleAnnouncementEvent_PythonToCpp_QAccessibleAnnouncementEvent_PTR,
        is_QAccessibleAnnouncementEvent_PythonToCpp_QAccessibleAnnouncementEvent_PTR_Convertible,
        QAccessibleAnnouncementEvent_PTR_CppToPython_QAccessibleAnnouncementEvent);

    Shiboken::Conversions::registerConverterName(converter, "QAccessibleAnnouncementEvent");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleAnnouncementEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleAnnouncementEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAccessibleAnnouncementEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAccessibleAnnouncementEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAccessibleAnnouncementEvent_TypeF(), &Sbk_QAccessibleAnnouncementEvent_typeDiscovery);

    qRegisterMetaType< ::QAccessibleAnnouncementEvent *>();

    return pyType;
}
