// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qaccessibleattributesinterface_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qaccessible_base.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAccessibleAttributesInterfaceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAccessibleAttributesInterfaceWrapper::QAccessibleAttributesInterfaceWrapper()
{
}

::QList<QAccessible::Attribute> QAccessibleAttributesInterfaceWrapper::attributeKeys() const
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleAttributesInterface.attributeKeys");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "attributeKeys";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleAttributesInterface.attributeKeys");
        return {};
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAccessibleAttributesInterface", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QAccessible_Attribute_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAccessibleAttributesInterface", funcName, "list", Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QList<QAccessible::Attribute> cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QVariant QAccessibleAttributesInterfaceWrapper::attributeValue(::QAccessible::Attribute key) const
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleAttributesInterface.attributeValue");
        return ::QVariant();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QVariant();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "attributeValue";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleAttributesInterface.attributeValue");
        return ::QVariant();
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Attribute_IDX])))->converter, &key)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Attribute_IDX])))->converter, &key)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAccessibleAttributesInterface", funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAccessibleAttributesInterface", funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QAccessibleAttributesInterfaceWrapper::~QAccessibleAttributesInterfaceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAccessibleAttributesInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAttributesInterface_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QAccessibleAttributesInterface");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAccessibleAttributesInterface >()))
        return -1;

    QAccessibleAttributesInterfaceWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAttributesInterface_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QAccessibleAttributesInterface()
        cptr = new QAccessibleAttributesInterfaceWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAccessibleAttributesInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAccessibleAttributesInterfaceFunc_attributeKeys(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleAttributesInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAttributesInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // attributeKeys()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QAccessibleAttributesInterface.attributeKeys");
            return {};
        }
        QList<QAccessible::Attribute> cppResult = const_cast<const ::QAccessibleAttributesInterface *>(cppSelf)->attributeKeys();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QAccessible_Attribute_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleAttributesInterfaceFunc_attributeValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleAttributesInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAttributesInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAccessibleAttributesInterface::attributeValue(QAccessible::Attribute)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Attribute_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // attributeValue(QAccessible::Attribute)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "attributeValue", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAttributesInterface_IDX]);

    // Call function/method
    {
        ::QAccessible::Attribute cppArg0{QAccessible::Attribute::Custom};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // attributeValue(QAccessible::Attribute)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAccessibleAttributesInterface.attributeValue");
                return {};
            }
            QVariant cppResult = const_cast<const ::QAccessibleAttributesInterface *>(cppSelf)->attributeValue(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAccessibleAttributesInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAccessibleAttributesInterface_methods[] = {
    {"attributeKeys", reinterpret_cast<PyCFunction>(Sbk_QAccessibleAttributesInterfaceFunc_attributeKeys), METH_NOARGS, nullptr},
    {"attributeValue", reinterpret_cast<PyCFunction>(Sbk_QAccessibleAttributesInterfaceFunc_attributeValue), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAccessibleAttributesInterface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAccessibleAttributesInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAttributesInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAccessibleAttributesInterfaceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAccessibleAttributesInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAccessibleAttributesInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAccessibleAttributesInterface_Type = nullptr;
static PyTypeObject *Sbk_QAccessibleAttributesInterface_TypeF(void)
{
    return _Sbk_QAccessibleAttributesInterface_Type;
}

static PyType_Slot Sbk_QAccessibleAttributesInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAccessibleAttributesInterface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAccessibleAttributesInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAccessibleAttributesInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAccessibleAttributesInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAccessibleAttributesInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAccessibleAttributesInterface_spec = {
    "2:PySide6.QtGui.QAccessibleAttributesInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAccessibleAttributesInterface_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAccessibleAttributesInterface_PythonToCpp_QAccessibleAttributesInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAccessibleAttributesInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAccessibleAttributesInterface_PythonToCpp_QAccessibleAttributesInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAccessibleAttributesInterface_TypeF()))
        return QAccessibleAttributesInterface_PythonToCpp_QAccessibleAttributesInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAccessibleAttributesInterface_PTR_CppToPython_QAccessibleAttributesInterface(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QAccessibleAttributesInterface *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QAccessibleAttributesInterface_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAccessibleAttributesInterface_SignatureStrings[] = {
    "PySide6.QtGui.QAccessibleAttributesInterface(self)",
    "PySide6.QtGui.QAccessibleAttributesInterface.attributeKeys(self)->QList[PySide6.QtGui.QAccessible.Attribute]",
    "PySide6.QtGui.QAccessibleAttributesInterface.attributeValue(self,key:PySide6.QtGui.QAccessible.Attribute)->QVariant",
    nullptr}; // Sentinel
#else
static constexpr size_t QAccessibleAttributesInterface_SignatureByteSize = 113;
static constexpr uint8_t QAccessibleAttributesInterface_SignatureBytes[113] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f, 0xcd, 0xd4,
    0x0b, 0x74, 0x4c, 0x4e, 0x4e, 0x2d, 0x2e, 0xce, 0x4c, 0xca, 0x49, 0x75, 0x2c, 0x29, 0x29, 0xca,
    0x4c, 0x2a, 0x2d, 0x49, 0x2d, 0xf6, 0xcc, 0x2b, 0x49, 0x2d, 0x4a, 0x4b, 0x4c, 0x4e, 0xd5, 0x28,
    0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x0a, 0x20, 0x41, 0x8b, 0x5e, 0x22, 0x4c, 0xcc, 0x3b, 0xb5, 0xb2,
    0x18, 0x62, 0x80, 0xae, 0x5d, 0xa0, 0x4f, 0x66, 0x71, 0x49, 0x34, 0x4e, 0x73, 0xf4, 0xe0, 0x06,
    0xc5, 0x92, 0x69, 0x59, 0x58, 0x62, 0x4e, 0x29, 0xc4, 0xb9, 0x3a, 0xd9, 0xa9, 0x95, 0x56, 0x44,
    0xd8, 0x04, 0x72, 0x55, 0x58, 0x62, 0x51, 0x66, 0x62, 0x5e, 0x09, 0x17, 0x00, 0x64, 0x5c, 0x66,
    0x16
};
#endif

PyTypeObject *init_QAccessibleAttributesInterface(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAttributesInterface_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAttributesInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_QAccessibleAttributesInterface_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAccessibleAttributesInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAccessibleAttributesInterface",
        "QAccessibleAttributesInterface*",
        &Sbk_QAccessibleAttributesInterface_spec,
        &Shiboken::callCppDestructor< QAccessibleAttributesInterface >,
        Sbk_QAccessibleAttributesInterface_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAccessibleAttributesInterface_TypeF(); // references _Sbk_QAccessibleAttributesInterface_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAccessibleAttributesInterface_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAccessibleAttributesInterface_SignatureBytes, QAccessibleAttributesInterface_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAccessibleAttributesInterface_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleAttributesInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAccessibleAttributesInterface_PythonToCpp_QAccessibleAttributesInterface_PTR,
        is_QAccessibleAttributesInterface_PythonToCpp_QAccessibleAttributesInterface_PTR_Convertible,
        QAccessibleAttributesInterface_PTR_CppToPython_QAccessibleAttributesInterface);

    Shiboken::Conversions::registerConverterName(converter, "QAccessibleAttributesInterface");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleAttributesInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleAttributesInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAccessibleAttributesInterface).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAccessibleAttributesInterfaceWrapper).name());

    qRegisterMetaType< ::QAccessibleAttributesInterface *>();

    return pyType;
}
