// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qaccessibleeditabletextinterface_wrapper.h"

// Argument includes
#include <QString>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAccessibleEditableTextInterfaceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAccessibleEditableTextInterfaceWrapper::QAccessibleEditableTextInterfaceWrapper()
{
}

void QAccessibleEditableTextInterfaceWrapper::deleteText(int startOffset, int endOffset)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleEditableTextInterface.deleteText");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "deleteText";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleEditableTextInterface.deleteText");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &startOffset),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &endOffset)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(ii)",
        startOffset,
        endOffset
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAccessibleEditableTextInterface", funcName);
        return;
    }
}

void QAccessibleEditableTextInterfaceWrapper::insertText(int offset, const ::QString & text)
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleEditableTextInterface.insertText");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "insertText";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleEditableTextInterface.insertText");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &offset),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &text)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(iN)",
        offset,
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &text)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAccessibleEditableTextInterface", funcName);
        return;
    }
}

void QAccessibleEditableTextInterfaceWrapper::replaceText(int startOffset, int endOffset, const ::QString & text)
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleEditableTextInterface.replaceText");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "replaceText";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAccessibleEditableTextInterface.replaceText");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &startOffset),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &endOffset),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &text)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(iiN)",
        startOffset,
        endOffset,
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &text)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAccessibleEditableTextInterface", funcName);
        return;
    }
}

QAccessibleEditableTextInterfaceWrapper::~QAccessibleEditableTextInterfaceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAccessibleEditableTextInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEditableTextInterface_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QAccessibleEditableTextInterface");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAccessibleEditableTextInterface >()))
        return -1;

    QAccessibleEditableTextInterfaceWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEditableTextInterface_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QAccessibleEditableTextInterface()
        cptr = new QAccessibleEditableTextInterfaceWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAccessibleEditableTextInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAccessibleEditableTextInterfaceFunc_deleteText(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleEditableTextInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEditableTextInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "deleteText", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAccessibleEditableTextInterface::deleteText(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // deleteText(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "deleteText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEditableTextInterface_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // deleteText(int,int)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAccessibleEditableTextInterface.deleteText");
                return {};
            }
            cppSelf->deleteText(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAccessibleEditableTextInterfaceFunc_insertText(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleEditableTextInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEditableTextInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertText", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAccessibleEditableTextInterface::insertText(int,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // insertText(int,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEditableTextInterface_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertText(int,QString)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAccessibleEditableTextInterface.insertText");
                return {};
            }
            cppSelf->insertText(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAccessibleEditableTextInterfaceFunc_replaceText(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleEditableTextInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEditableTextInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "replaceText", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAccessibleEditableTextInterface::replaceText(int,int,QString)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // replaceText(int,int,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "replaceText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEditableTextInterface_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // replaceText(int,int,QString)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAccessibleEditableTextInterface.replaceText");
                return {};
            }
            cppSelf->replaceText(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QAccessibleEditableTextInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAccessibleEditableTextInterface_methods[] = {
    {"deleteText", reinterpret_cast<PyCFunction>(Sbk_QAccessibleEditableTextInterfaceFunc_deleteText), METH_VARARGS, nullptr},
    {"insertText", reinterpret_cast<PyCFunction>(Sbk_QAccessibleEditableTextInterfaceFunc_insertText), METH_VARARGS, nullptr},
    {"replaceText", reinterpret_cast<PyCFunction>(Sbk_QAccessibleEditableTextInterfaceFunc_replaceText), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAccessibleEditableTextInterface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAccessibleEditableTextInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEditableTextInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAccessibleEditableTextInterfaceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAccessibleEditableTextInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAccessibleEditableTextInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAccessibleEditableTextInterface_Type = nullptr;
static PyTypeObject *Sbk_QAccessibleEditableTextInterface_TypeF(void)
{
    return _Sbk_QAccessibleEditableTextInterface_Type;
}

static PyType_Slot Sbk_QAccessibleEditableTextInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAccessibleEditableTextInterface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAccessibleEditableTextInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAccessibleEditableTextInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAccessibleEditableTextInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAccessibleEditableTextInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAccessibleEditableTextInterface_spec = {
    "2:PySide6.QtGui.QAccessibleEditableTextInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAccessibleEditableTextInterface_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAccessibleEditableTextInterface_PythonToCpp_QAccessibleEditableTextInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAccessibleEditableTextInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAccessibleEditableTextInterface_PythonToCpp_QAccessibleEditableTextInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAccessibleEditableTextInterface_TypeF()))
        return QAccessibleEditableTextInterface_PythonToCpp_QAccessibleEditableTextInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAccessibleEditableTextInterface_PTR_CppToPython_QAccessibleEditableTextInterface(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QAccessibleEditableTextInterface *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QAccessibleEditableTextInterface_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAccessibleEditableTextInterface_SignatureStrings[] = {
    "PySide6.QtGui.QAccessibleEditableTextInterface(self)",
    "PySide6.QtGui.QAccessibleEditableTextInterface.deleteText(self,startOffset:int,endOffset:int)",
    "PySide6.QtGui.QAccessibleEditableTextInterface.insertText(self,offset:int,text:QString)",
    "PySide6.QtGui.QAccessibleEditableTextInterface.replaceText(self,startOffset:int,endOffset:int,text:QString)",
    nullptr}; // Sentinel
#else
static constexpr size_t QAccessibleEditableTextInterface_SignatureByteSize = 128;
static constexpr uint8_t QAccessibleEditableTextInterface_SignatureBytes[128] = {
    0x78, 0xda, 0x95, 0x8e, 0xb1, 0x0a, 0x02, 0x31, 0x18, 0x83, 0x77, 0x9f, 0x44, 0xe1, 0xe8, 0xe8,
    0x70, 0xdb, 0x0d, 0x22, 0x4e, 0x5e, 0x39, 0x5f, 0xa0, 0xb6, 0xa9, 0xfc, 0x50, 0xaa, 0xf4, 0x8f,
    0xa0, 0x6f, 0x7f, 0xe5, 0x96, 0x82, 0x93, 0x9d, 0x42, 0x02, 0xf9, 0x92, 0xf9, 0xbb, 0x48, 0xc0,
    0xd1, 0x58, 0x9e, 0xdf, 0x62, 0xec, 0xe4, 0x3d, 0x54, 0xe5, 0x9e, 0x70, 0x0a, 0x42, 0x57, 0xf5,
    0x86, 0x0f, 0x2f, 0x99, 0x28, 0xd1, 0x79, 0xec, 0x15, 0x29, 0x1e, 0x76, 0x73, 0x57, 0xc9, 0x04,
    0x24, 0x70, 0xcb, 0xb6, 0xfe, 0xa0, 0x74, 0x85, 0xd7, 0x18, 0x15, 0x1c, 0x25, 0x73, 0x40, 0x0e,
    0xcd, 0x75, 0xd3, 0x25, 0x2b, 0x0a, 0x1b, 0xfd, 0xd9, 0xc0, 0xac, 0xe1, 0x68, 0x17, 0x16, 0xc9,
    0x8f, 0x6e, 0x6e, 0xc1, 0x2b, 0x55, 0xfd, 0xf3, 0xf6, 0xcf, 0xd6, 0x0a, 0xcc, 0xd7, 0x80, 0x1e
};
#endif

PyTypeObject *init_QAccessibleEditableTextInterface(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEditableTextInterface_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEditableTextInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_QAccessibleEditableTextInterface_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAccessibleEditableTextInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAccessibleEditableTextInterface",
        "QAccessibleEditableTextInterface*",
        &Sbk_QAccessibleEditableTextInterface_spec,
        &Shiboken::callCppDestructor< QAccessibleEditableTextInterface >,
        Sbk_QAccessibleEditableTextInterface_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAccessibleEditableTextInterface_TypeF(); // references _Sbk_QAccessibleEditableTextInterface_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAccessibleEditableTextInterface_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAccessibleEditableTextInterface_SignatureBytes, QAccessibleEditableTextInterface_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAccessibleEditableTextInterface_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEditableTextInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAccessibleEditableTextInterface_PythonToCpp_QAccessibleEditableTextInterface_PTR,
        is_QAccessibleEditableTextInterface_PythonToCpp_QAccessibleEditableTextInterface_PTR_Convertible,
        QAccessibleEditableTextInterface_PTR_CppToPython_QAccessibleEditableTextInterface);

    Shiboken::Conversions::registerConverterName(converter, "QAccessibleEditableTextInterface");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleEditableTextInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleEditableTextInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAccessibleEditableTextInterface).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAccessibleEditableTextInterfaceWrapper).name());

    qRegisterMetaType< ::QAccessibleEditableTextInterface *>();

    return pyType;
}
