// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qaccessibleevent_wrapper.h"

// Argument includes
#include <QtGui/qaccessible.h>
#include <QtGui/qaccessible_base.h>
#include <qobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAccessibleEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAccessibleEventWrapper::QAccessibleEventWrapper(::QAccessibleInterface * iface, ::QAccessible::Event typ) : QAccessibleEvent(iface, typ)
{
}

QAccessibleEventWrapper::QAccessibleEventWrapper(::QObject * obj, ::QAccessible::Event typ) : QAccessibleEvent(obj, typ)
{
}

::QAccessibleInterface * QAccessibleEventWrapper::accessibleInterface() const
{
    if (m_PyMethodCache[0])
        return this->::QAccessibleEvent::accessibleInterface();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "accessibleInterface";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QAccessibleEvent::accessibleInterface();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAccessibleEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAccessibleEvent", funcName, Shiboken::SbkType< QAccessibleInterface >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QAccessibleInterface *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QAccessibleEventWrapper::~QAccessibleEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAccessibleEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAccessibleEvent >()))
        return -1;

    QAccessibleEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAccessibleEvent", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAccessibleEvent::QAccessibleEvent(QAccessibleInterface*,QAccessible::Event)
    // 1: QAccessibleEvent::QAccessibleEvent(QObject*,QAccessible::Event)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Event_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 1; // QAccessibleEvent(QObject*,QAccessible::Event)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Event_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // QAccessibleEvent(QAccessibleInterface*,QAccessible::Event)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAccessibleEvent(QAccessibleInterface *iface, QAccessible::Event typ)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAccessibleInterface *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QAccessible::Event cppArg1 = static_cast< ::QAccessible::Event>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleEvent(QAccessibleInterface*,QAccessible::Event)
                cptr = new QAccessibleEventWrapper(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // QAccessibleEvent(QObject *obj, QAccessible::Event typ)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QAccessible::Event cppArg1 = static_cast< ::QAccessible::Event>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleEvent(QObject*,QAccessible::Event)
                cptr = new QAccessibleEventWrapper(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAccessibleEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAccessibleEventFunc_accessibleInterface(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // accessibleInterface()const
        QAccessibleInterface * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QAccessibleEvent *>(cppSelf)->::QAccessibleEvent::accessibleInterface()
            : const_cast<const ::QAccessibleEvent *>(cppSelf)->accessibleInterface();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleEventFunc_child(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // child()const
        int cppResult = const_cast<const ::QAccessibleEvent *>(cppSelf)->child();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleEventFunc_object(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // object()const
        QObject * cppResult = const_cast<const ::QAccessibleEvent *>(cppSelf)->object();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleEventFunc_setChild(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAccessibleEvent::setChild(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setChild(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setChild", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setChild(int)
            cppSelf->setChild(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAccessibleEventFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QAccessible::Event cppResult = const_cast<const ::QAccessibleEvent *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessible_Event_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleEventFunc_uniqueId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // uniqueId()const
        unsigned int cppResult = const_cast<const ::QAccessibleEvent *>(cppSelf)->uniqueId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAccessibleEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAccessibleEvent_methods[] = {
    {"accessibleInterface", reinterpret_cast<PyCFunction>(Sbk_QAccessibleEventFunc_accessibleInterface), METH_NOARGS, nullptr},
    {"child", reinterpret_cast<PyCFunction>(Sbk_QAccessibleEventFunc_child), METH_NOARGS, nullptr},
    {"object", reinterpret_cast<PyCFunction>(Sbk_QAccessibleEventFunc_object), METH_NOARGS, nullptr},
    {"setChild", reinterpret_cast<PyCFunction>(Sbk_QAccessibleEventFunc_setChild), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QAccessibleEventFunc_type), METH_NOARGS, nullptr},
    {"uniqueId", reinterpret_cast<PyCFunction>(Sbk_QAccessibleEventFunc_uniqueId), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAccessibleEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAccessibleEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAccessibleEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAccessibleEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAccessibleEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QAccessibleEvent__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAccessibleEvent_Type = nullptr;
static PyTypeObject *Sbk_QAccessibleEvent_TypeF(void)
{
    return _Sbk_QAccessibleEvent_Type;
}

static PyType_Slot Sbk_QAccessibleEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QAccessibleEvent__repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAccessibleEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAccessibleEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAccessibleEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAccessibleEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAccessibleEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAccessibleEvent_spec = {
    "2:PySide6.QtGui.QAccessibleEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAccessibleEvent_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAccessibleEvent_PythonToCpp_QAccessibleEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAccessibleEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAccessibleEvent_PythonToCpp_QAccessibleEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAccessibleEvent_TypeF()))
        return QAccessibleEvent_PythonToCpp_QAccessibleEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAccessibleEvent_PTR_CppToPython_QAccessibleEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QAccessibleEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QAccessibleEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAccessibleEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QAccessibleEvent(self,iface:PySide6.QtGui.QAccessibleInterface,typ:PySide6.QtGui.QAccessible.Event)",
    "0:PySide6.QtGui.QAccessibleEvent(self,obj:PySide6.QtCore.QObject,typ:PySide6.QtGui.QAccessible.Event)",
    "PySide6.QtGui.QAccessibleEvent.accessibleInterface(self)->PySide6.QtGui.QAccessibleInterface",
    "PySide6.QtGui.QAccessibleEvent.child(self)->int",
    "PySide6.QtGui.QAccessibleEvent.object(self)->PySide6.QtCore.QObject",
    "PySide6.QtGui.QAccessibleEvent.setChild(self,chld:int)",
    "PySide6.QtGui.QAccessibleEvent.type(self)->PySide6.QtGui.QAccessible.Event",
    "PySide6.QtGui.QAccessibleEvent.uniqueId(self)->unsigned int",
    nullptr}; // Sentinel
#else
static constexpr size_t QAccessibleEvent_SignatureByteSize = 175;
static constexpr uint8_t QAccessibleEvent_SignatureBytes[175] = {
    0x78, 0xda, 0x8d, 0x90, 0xc1, 0x0a, 0x82, 0x40, 0x14, 0x45, 0xf7, 0x7d, 0x45, 0xcb, 0x04, 0x1b,
    0x6a, 0xd3, 0xc2, 0x45, 0x10, 0x12, 0xe2, 0xaa, 0x86, 0xbe, 0xc0, 0x99, 0x79, 0xe6, 0x93, 0x61,
    0x2c, 0xe7, 0x4d, 0xe0, 0xdf, 0x97, 0x13, 0x89, 0x20, 0x36, 0xee, 0x2f, 0xe7, 0xdc, 0x7b, 0xf7,
    0xc9, 0xb5, 0xbb, 0xa1, 0x82, 0x03, 0xe3, 0x94, 0x39, 0x64, 0xfc, 0x24, 0x25, 0x58, 0x8b, 0x42,
    0xc3, 0xf9, 0x05, 0x86, 0x36, 0x16, 0x74, 0x19, 0x63, 0x59, 0x48, 0x98, 0x4f, 0xe6, 0x86, 0xa0,
    0xed, 0x23, 0x31, 0x75, 0x8f, 0xf9, 0x18, 0xf3, 0xc4, 0x68, 0xb5, 0x5b, 0xe4, 0x6c, 0x44, 0x3d,
    0xca, 0xa5, 0x4d, 0x0b, 0x8c, 0x5f, 0x44, 0x0d, 0x92, 0x96, 0x59, 0xfe, 0x3b, 0x58, 0x31, 0x6d,
    0xef, 0xbd, 0xd1, 0xf6, 0x18, 0xde, 0x19, 0x82, 0xcb, 0x0a, 0xb5, 0xfa, 0xe1, 0xd0, 0x50, 0x28,
    0xdf, 0xf8, 0x5d, 0x53, 0xff, 0x78, 0x75, 0x88, 0x61, 0x81, 0xd2, 0x41, 0x1b, 0xcb, 0x4a, 0xab,
    0x04, 0x17, 0xfc, 0xf0, 0xf9, 0x32, 0x3c, 0xfc, 0xfb, 0x69, 0x08, 0xe5, 0x0c, 0x3e, 0x1d, 0xe4,
    0xc3, 0x70, 0x67, 0x2c, 0xde, 0x0d, 0xa8, 0x75, 0xff, 0xc0, 0x1b, 0xce, 0xe5, 0xdc, 0x40
};
#endif

PyTypeObject *init_QAccessibleEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QAccessibleEvent_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAccessibleEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAccessibleEvent",
        "QAccessibleEvent*",
        &Sbk_QAccessibleEvent_spec,
        &Shiboken::callCppDestructor< QAccessibleEvent >,
        Sbk_QAccessibleEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAccessibleEvent_TypeF(); // references _Sbk_QAccessibleEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAccessibleEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAccessibleEvent_SignatureBytes, QAccessibleEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAccessibleEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAccessibleEvent_PythonToCpp_QAccessibleEvent_PTR,
        is_QAccessibleEvent_PythonToCpp_QAccessibleEvent_PTR_Convertible,
        QAccessibleEvent_PTR_CppToPython_QAccessibleEvent);

    Shiboken::Conversions::registerConverterName(converter, "QAccessibleEvent");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAccessibleEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAccessibleEventWrapper).name());

    qRegisterMetaType< ::QAccessibleEvent *>();

    return pyType;
}
