// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qaccessibletablemodelchangeevent_wrapper.h"

// Argument includes
#include <QtGui/qaccessible.h>
#include <QtGui/qaccessible_base.h>
#include <qobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAccessibleTableModelChangeEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAccessibleTableModelChangeEventWrapper::QAccessibleTableModelChangeEventWrapper(::QAccessibleInterface * iface, ::QAccessibleTableModelChangeEvent::ModelChangeType changeType) : QAccessibleTableModelChangeEvent(iface, changeType)
{
}

QAccessibleTableModelChangeEventWrapper::QAccessibleTableModelChangeEventWrapper(::QObject * obj, ::QAccessibleTableModelChangeEvent::ModelChangeType changeType) : QAccessibleTableModelChangeEvent(obj, changeType)
{
}

::QAccessibleInterface * QAccessibleTableModelChangeEventWrapper::accessibleInterface() const
{
    if (m_PyMethodCache[0])
        return this->::QAccessibleEvent::accessibleInterface();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "accessibleInterface";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QAccessibleEvent::accessibleInterface();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAccessibleTableModelChangeEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAccessibleTableModelChangeEvent", funcName, Shiboken::SbkType< QAccessibleInterface >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QAccessibleInterface *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QAccessibleTableModelChangeEventWrapper::~QAccessibleTableModelChangeEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAccessibleTableModelChangeEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAccessibleTableModelChangeEvent >()))
        return -1;

    QAccessibleTableModelChangeEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAccessibleTableModelChangeEvent", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAccessibleTableModelChangeEvent::QAccessibleTableModelChangeEvent(QAccessibleInterface*,QAccessibleTableModelChangeEvent::ModelChangeType)
    // 1: QAccessibleTableModelChangeEvent::QAccessibleTableModelChangeEvent(QObject*,QAccessibleTableModelChangeEvent::ModelChangeType)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_ModelChangeType_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 1; // QAccessibleTableModelChangeEvent(QObject*,QAccessibleTableModelChangeEvent::ModelChangeType)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_ModelChangeType_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // QAccessibleTableModelChangeEvent(QAccessibleInterface*,QAccessibleTableModelChangeEvent::ModelChangeType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAccessibleTableModelChangeEvent(QAccessibleInterface *iface, QAccessibleTableModelChangeEvent::ModelChangeType changeType)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAccessibleInterface *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QAccessibleTableModelChangeEvent::ModelChangeType cppArg1{QAccessibleTableModelChangeEvent::ModelReset};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleTableModelChangeEvent(QAccessibleInterface*,QAccessibleTableModelChangeEvent::ModelChangeType)
                cptr = new QAccessibleTableModelChangeEventWrapper(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // QAccessibleTableModelChangeEvent(QObject *obj, QAccessibleTableModelChangeEvent::ModelChangeType changeType)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QAccessibleTableModelChangeEvent::ModelChangeType cppArg1{QAccessibleTableModelChangeEvent::ModelReset};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleTableModelChangeEvent(QObject*,QAccessibleTableModelChangeEvent::ModelChangeType)
                cptr = new QAccessibleTableModelChangeEventWrapper(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAccessibleTableModelChangeEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAccessibleTableModelChangeEventFunc_firstColumn(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTableModelChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // firstColumn()const
        int cppResult = const_cast<const ::QAccessibleTableModelChangeEvent *>(cppSelf)->firstColumn();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleTableModelChangeEventFunc_firstRow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTableModelChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // firstRow()const
        int cppResult = const_cast<const ::QAccessibleTableModelChangeEvent *>(cppSelf)->firstRow();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleTableModelChangeEventFunc_lastColumn(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTableModelChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastColumn()const
        int cppResult = const_cast<const ::QAccessibleTableModelChangeEvent *>(cppSelf)->lastColumn();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleTableModelChangeEventFunc_lastRow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTableModelChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastRow()const
        int cppResult = const_cast<const ::QAccessibleTableModelChangeEvent *>(cppSelf)->lastRow();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleTableModelChangeEventFunc_modelChangeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTableModelChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // modelChangeType()const
        QAccessibleTableModelChangeEvent::ModelChangeType cppResult = const_cast<const ::QAccessibleTableModelChangeEvent *>(cppSelf)->modelChangeType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_ModelChangeType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleTableModelChangeEventFunc_setFirstColumn(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTableModelChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAccessibleTableModelChangeEvent::setFirstColumn(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setFirstColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFirstColumn", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFirstColumn(int)
            cppSelf->setFirstColumn(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAccessibleTableModelChangeEventFunc_setFirstRow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTableModelChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAccessibleTableModelChangeEvent::setFirstRow(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setFirstRow(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFirstRow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFirstRow(int)
            cppSelf->setFirstRow(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAccessibleTableModelChangeEventFunc_setLastColumn(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTableModelChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAccessibleTableModelChangeEvent::setLastColumn(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLastColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLastColumn", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLastColumn(int)
            cppSelf->setLastColumn(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAccessibleTableModelChangeEventFunc_setLastRow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTableModelChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAccessibleTableModelChangeEvent::setLastRow(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLastRow(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLastRow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLastRow(int)
            cppSelf->setLastRow(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAccessibleTableModelChangeEventFunc_setModelChangeType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTableModelChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAccessibleTableModelChangeEvent::setModelChangeType(QAccessibleTableModelChangeEvent::ModelChangeType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_ModelChangeType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setModelChangeType(QAccessibleTableModelChangeEvent::ModelChangeType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setModelChangeType", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]);

    // Call function/method
    {
        ::QAccessibleTableModelChangeEvent::ModelChangeType cppArg0{QAccessibleTableModelChangeEvent::ModelReset};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setModelChangeType(QAccessibleTableModelChangeEvent::ModelChangeType)
            cppSelf->setModelChangeType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QAccessibleTableModelChangeEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QAccessibleTableModelChangeEvent_EnumFlagInfo[] = {
    "ModelChangeType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAccessibleTableModelChangeEvent_methods[] = {
    {"firstColumn", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTableModelChangeEventFunc_firstColumn), METH_NOARGS, nullptr},
    {"firstRow", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTableModelChangeEventFunc_firstRow), METH_NOARGS, nullptr},
    {"lastColumn", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTableModelChangeEventFunc_lastColumn), METH_NOARGS, nullptr},
    {"lastRow", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTableModelChangeEventFunc_lastRow), METH_NOARGS, nullptr},
    {"modelChangeType", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTableModelChangeEventFunc_modelChangeType), METH_NOARGS, nullptr},
    {"setFirstColumn", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTableModelChangeEventFunc_setFirstColumn), METH_O, nullptr},
    {"setFirstRow", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTableModelChangeEventFunc_setFirstRow), METH_O, nullptr},
    {"setLastColumn", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTableModelChangeEventFunc_setLastColumn), METH_O, nullptr},
    {"setLastRow", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTableModelChangeEventFunc_setLastRow), METH_O, nullptr},
    {"setModelChangeType", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTableModelChangeEventFunc_setModelChangeType), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAccessibleTableModelChangeEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAccessibleTableModelChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAccessibleTableModelChangeEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAccessibleTableModelChangeEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAccessibleTableModelChangeEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAccessibleTableModelChangeEvent_Type = nullptr;
static PyTypeObject *Sbk_QAccessibleTableModelChangeEvent_TypeF(void)
{
    return _Sbk_QAccessibleTableModelChangeEvent_Type;
}

static PyType_Slot Sbk_QAccessibleTableModelChangeEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAccessibleTableModelChangeEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAccessibleTableModelChangeEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAccessibleTableModelChangeEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAccessibleTableModelChangeEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAccessibleTableModelChangeEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAccessibleTableModelChangeEvent_spec = {
    "2:PySide6.QtGui.QAccessibleTableModelChangeEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAccessibleTableModelChangeEvent_slots
};

} //extern "C"

static void *Sbk_QAccessibleTableModelChangeEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QAccessibleEvent *>(cptr)->type() == QAccessible::TableModelChanged)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAccessibleTableModelChangeEvent_ModelChangeType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAccessibleTableModelChangeEvent::ModelChangeType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAccessibleTableModelChangeEvent::ModelChangeType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAccessibleTableModelChangeEvent_ModelChangeType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_ModelChangeType_IDX])))
        return Enum_PythonToCpp_QAccessibleTableModelChangeEvent_ModelChangeType;
    return {};
}

static PyObject *QAccessibleTableModelChangeEvent_ModelChangeType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAccessibleTableModelChangeEvent::ModelChangeType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAccessibleTableModelChangeEvent::ModelChangeType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_ModelChangeType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAccessibleTableModelChangeEvent_PythonToCpp_QAccessibleTableModelChangeEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAccessibleTableModelChangeEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAccessibleTableModelChangeEvent_PythonToCpp_QAccessibleTableModelChangeEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAccessibleTableModelChangeEvent_TypeF()))
        return QAccessibleTableModelChangeEvent_PythonToCpp_QAccessibleTableModelChangeEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAccessibleTableModelChangeEvent_PTR_CppToPython_QAccessibleTableModelChangeEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QAccessibleTableModelChangeEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QAccessibleTableModelChangeEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAccessibleTableModelChangeEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QAccessibleTableModelChangeEvent(self,iface:PySide6.QtGui.QAccessibleInterface,changeType:PySide6.QtGui.QAccessibleTableModelChangeEvent.ModelChangeType)",
    "0:PySide6.QtGui.QAccessibleTableModelChangeEvent(self,obj:PySide6.QtCore.QObject,changeType:PySide6.QtGui.QAccessibleTableModelChangeEvent.ModelChangeType)",
    "PySide6.QtGui.QAccessibleTableModelChangeEvent.firstColumn(self)->int",
    "PySide6.QtGui.QAccessibleTableModelChangeEvent.firstRow(self)->int",
    "PySide6.QtGui.QAccessibleTableModelChangeEvent.lastColumn(self)->int",
    "PySide6.QtGui.QAccessibleTableModelChangeEvent.lastRow(self)->int",
    "PySide6.QtGui.QAccessibleTableModelChangeEvent.modelChangeType(self)->PySide6.QtGui.QAccessibleTableModelChangeEvent.ModelChangeType",
    "PySide6.QtGui.QAccessibleTableModelChangeEvent.setFirstColumn(self,col:int)",
    "PySide6.QtGui.QAccessibleTableModelChangeEvent.setFirstRow(self,row:int)",
    "PySide6.QtGui.QAccessibleTableModelChangeEvent.setLastColumn(self,col:int)",
    "PySide6.QtGui.QAccessibleTableModelChangeEvent.setLastRow(self,row:int)",
    "PySide6.QtGui.QAccessibleTableModelChangeEvent.setModelChangeType(self,changeType:PySide6.QtGui.QAccessibleTableModelChangeEvent.ModelChangeType)",
    nullptr}; // Sentinel
#else
static constexpr size_t QAccessibleTableModelChangeEvent_SignatureByteSize = 203;
static constexpr uint8_t QAccessibleTableModelChangeEvent_SignatureBytes[203] = {
    0x78, 0xda, 0xad, 0x93, 0x41, 0x0b, 0x82, 0x30, 0x18, 0x86, 0xef, 0xfd, 0x92, 0x84, 0x35, 0xea,
    0xd2, 0xc1, 0x43, 0x10, 0x52, 0x11, 0x28, 0x65, 0xf9, 0x07, 0xe6, 0xfa, 0xac, 0xc9, 0xdc, 0x62,
    0x9b, 0x89, 0xff, 0x3e, 0x15, 0x04, 0x8b, 0x3a, 0x38, 0x77, 0xd9, 0x61, 0xec, 0x7d, 0xf6, 0xec,
    0x7b, 0xd9, 0xca, 0x3f, 0xd7, 0x57, 0x76, 0x83, 0x35, 0x8e, 0xcd, 0xa1, 0x64, 0x38, 0xde, 0x52,
    0x0a, 0x5a, 0xb3, 0x94, 0x43, 0x42, 0x9a, 0x25, 0x92, 0x37, 0xe0, 0xc1, 0x83, 0x88, 0x3b, 0xec,
    0x5e, 0x20, 0xcc, 0x5c, 0x03, 0xcf, 0x10, 0xcb, 0x08, 0x85, 0xff, 0xc9, 0xa3, 0x30, 0xa0, 0xda,
    0x23, 0x88, 0x76, 0xc9, 0xa4, 0x7e, 0xc2, 0xc8, 0x7b, 0xf0, 0x60, 0xa3, 0x8d, 0x7b, 0xb3, 0xa5,
    0x95, 0xa9, 0x4c, 0xf3, 0x41, 0x2e, 0x90, 0x0a, 0x70, 0x7c, 0x4a, 0x73, 0xa0, 0xc6, 0xa5, 0xdb,
    0xc8, 0x7c, 0xc6, 0x94, 0x6e, 0x5c, 0x78, 0x59, 0x88, 0xce, 0xd2, 0x5b, 0x6c, 0x98, 0x30, 0x56,
    0x94, 0x8b, 0xac, 0x26, 0x20, 0x38, 0x71, 0xe0, 0xd1, 0x42, 0xa6, 0x69, 0x14, 0x9f, 0xf3, 0xec,
    0x49, 0xd3, 0x5a, 0x19, 0x2b, 0xa1, 0xc1, 0xec, 0xbf, 0x7a, 0x41, 0x54, 0x72, 0xbf, 0x79, 0x8f,
    0x67, 0xcb, 0xea, 0xc7, 0x82, 0x94, 0xac, 0x6c, 0x41, 0x21, 0x71, 0xe6, 0x14, 0x12, 0x37, 0x4a,
    0xd1, 0x8f, 0xbe, 0x5c, 0x7e, 0xa7, 0x37, 0x03, 0x83, 0xae, 0x6b
};
#endif

PyTypeObject *init_QAccessibleTableModelChangeEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QAccessibleTableModelChangeEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]))));

    _Sbk_QAccessibleTableModelChangeEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAccessibleTableModelChangeEvent",
        "QAccessibleTableModelChangeEvent*",
        &Sbk_QAccessibleTableModelChangeEvent_spec,
        &Shiboken::callCppDestructor< QAccessibleTableModelChangeEvent >,
        Sbk_QAccessibleTableModelChangeEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAccessibleTableModelChangeEvent_TypeF(); // references _Sbk_QAccessibleTableModelChangeEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAccessibleTableModelChangeEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAccessibleTableModelChangeEvent_SignatureBytes, QAccessibleTableModelChangeEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAccessibleTableModelChangeEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAccessibleTableModelChangeEvent_PythonToCpp_QAccessibleTableModelChangeEvent_PTR,
        is_QAccessibleTableModelChangeEvent_PythonToCpp_QAccessibleTableModelChangeEvent_PTR_Convertible,
        QAccessibleTableModelChangeEvent_PTR_CppToPython_QAccessibleTableModelChangeEvent);

    Shiboken::Conversions::registerConverterName(converter, "QAccessibleTableModelChangeEvent");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleTableModelChangeEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleTableModelChangeEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAccessibleTableModelChangeEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAccessibleTableModelChangeEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAccessibleTableModelChangeEvent_TypeF(), &Sbk_QAccessibleTableModelChangeEvent_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAccessibleTableModelChangeEvent_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ModelChangeType'.
    const char *ModelChangeType_Initializer[] = {
        "ModelReset",
        "DataChanged",
        "RowsInserted",
        "ColumnsInserted",
        "RowsRemoved",
        "ColumnsRemoved",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ModelChangeType_InitializerValues[] = {
        uint8_t(QAccessibleTableModelChangeEvent::ModelChangeType::ModelReset),      //  0x00  0
        uint8_t(QAccessibleTableModelChangeEvent::ModelChangeType::DataChanged),     //  0x01  1
        uint8_t(QAccessibleTableModelChangeEvent::ModelChangeType::RowsInserted),    //  0x02  2
        uint8_t(QAccessibleTableModelChangeEvent::ModelChangeType::ColumnsInserted), //  0x03  3
        uint8_t(QAccessibleTableModelChangeEvent::ModelChangeType::RowsRemoved),     //  0x04  4
        uint8_t(QAccessibleTableModelChangeEvent::ModelChangeType::ColumnsRemoved)   //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAccessibleTableModelChangeEvent_TypeF(),
        "2:PySide6.QtGui.QAccessibleTableModelChangeEvent.ModelChangeType",
        ModelChangeType_Initializer, ModelChangeType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTableModelChangeEvent_ModelChangeType_IDX].type = EType;
    // Register converter for enum 'QAccessibleTableModelChangeEvent::ModelChangeType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAccessibleTableModelChangeEvent_ModelChangeType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAccessibleTableModelChangeEvent_ModelChangeType,
            is_Enum_PythonToCpp_QAccessibleTableModelChangeEvent_ModelChangeType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAccessibleTableModelChangeEvent::ModelChangeType");
        Shiboken::Conversions::registerConverterAlias(converter, "ModelChangeType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ModelChangeType' enum.

    qRegisterMetaType< ::QAccessibleTableModelChangeEvent *>();
    qRegisterMetaType< ::QAccessibleTableModelChangeEvent::ModelChangeType >("QAccessibleTableModelChangeEvent::ModelChangeType");

    return pyType;
}
