// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qaccessibletextcursorevent_wrapper.h"

// Argument includes
#include <QtGui/qaccessible.h>
#include <QtGui/qaccessible_base.h>
#include <qobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAccessibleTextCursorEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAccessibleTextCursorEventWrapper::QAccessibleTextCursorEventWrapper(::QAccessibleInterface * iface, int cursorPos) : QAccessibleTextCursorEvent(iface, cursorPos)
{
}

QAccessibleTextCursorEventWrapper::QAccessibleTextCursorEventWrapper(::QObject * obj, int cursorPos) : QAccessibleTextCursorEvent(obj, cursorPos)
{
}

::QAccessibleInterface * QAccessibleTextCursorEventWrapper::accessibleInterface() const
{
    if (m_PyMethodCache[0])
        return this->::QAccessibleEvent::accessibleInterface();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "accessibleInterface";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QAccessibleEvent::accessibleInterface();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAccessibleTextCursorEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAccessibleTextCursorEvent", funcName, Shiboken::SbkType< QAccessibleInterface >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QAccessibleInterface *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QAccessibleTextCursorEventWrapper::~QAccessibleTextCursorEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAccessibleTextCursorEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAccessibleTextCursorEvent >()))
        return -1;

    QAccessibleTextCursorEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAccessibleTextCursorEvent", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAccessibleTextCursorEvent::QAccessibleTextCursorEvent(QAccessibleInterface*,int)
    // 1: QAccessibleTextCursorEvent::QAccessibleTextCursorEvent(QObject*,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 1; // QAccessibleTextCursorEvent(QObject*,int)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // QAccessibleTextCursorEvent(QAccessibleInterface*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextCursorEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextCursorEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAccessibleTextCursorEvent(QAccessibleInterface *iface, int cursorPos)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAccessibleInterface *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleTextCursorEvent(QAccessibleInterface*,int)
                cptr = new QAccessibleTextCursorEventWrapper(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // QAccessibleTextCursorEvent(QObject *obj, int cursorPos)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleTextCursorEvent(QObject*,int)
                cptr = new QAccessibleTextCursorEventWrapper(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAccessibleTextCursorEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextCursorEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAccessibleTextCursorEventFunc_cursorPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTextCursorEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextCursorEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cursorPosition()const
        int cppResult = const_cast<const ::QAccessibleTextCursorEvent *>(cppSelf)->cursorPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleTextCursorEventFunc_setCursorPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTextCursorEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextCursorEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAccessibleTextCursorEvent::setCursorPosition(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setCursorPosition(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCursorPosition", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextCursorEvent_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCursorPosition(int)
            cppSelf->setCursorPosition(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QAccessibleTextCursorEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAccessibleTextCursorEvent_methods[] = {
    {"cursorPosition", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTextCursorEventFunc_cursorPosition), METH_NOARGS, nullptr},
    {"setCursorPosition", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTextCursorEventFunc_setCursorPosition), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAccessibleTextCursorEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAccessibleTextCursorEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextCursorEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAccessibleTextCursorEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAccessibleTextCursorEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAccessibleTextCursorEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAccessibleTextCursorEvent_Type = nullptr;
static PyTypeObject *Sbk_QAccessibleTextCursorEvent_TypeF(void)
{
    return _Sbk_QAccessibleTextCursorEvent_Type;
}

static PyType_Slot Sbk_QAccessibleTextCursorEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAccessibleTextCursorEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAccessibleTextCursorEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAccessibleTextCursorEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAccessibleTextCursorEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAccessibleTextCursorEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAccessibleTextCursorEvent_spec = {
    "2:PySide6.QtGui.QAccessibleTextCursorEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAccessibleTextCursorEvent_slots
};

} //extern "C"

static void *Sbk_QAccessibleTextCursorEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QAccessibleEvent *>(cptr)->type() == QAccessible::TextCaretMoved)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAccessibleTextCursorEvent_PythonToCpp_QAccessibleTextCursorEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAccessibleTextCursorEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAccessibleTextCursorEvent_PythonToCpp_QAccessibleTextCursorEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAccessibleTextCursorEvent_TypeF()))
        return QAccessibleTextCursorEvent_PythonToCpp_QAccessibleTextCursorEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAccessibleTextCursorEvent_PTR_CppToPython_QAccessibleTextCursorEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QAccessibleTextCursorEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QAccessibleTextCursorEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAccessibleTextCursorEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QAccessibleTextCursorEvent(self,iface:PySide6.QtGui.QAccessibleInterface,cursorPos:int)",
    "0:PySide6.QtGui.QAccessibleTextCursorEvent(self,obj:PySide6.QtCore.QObject,cursorPos:int)",
    "PySide6.QtGui.QAccessibleTextCursorEvent.cursorPosition(self)->int",
    "PySide6.QtGui.QAccessibleTextCursorEvent.setCursorPosition(self,position:int)",
    nullptr}; // Sentinel
#else
static constexpr size_t QAccessibleTextCursorEvent_SignatureByteSize = 138;
static constexpr uint8_t QAccessibleTextCursorEvent_SignatureBytes[138] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x74, 0x4c, 0x4e, 0x4e, 0x2d, 0x2e, 0xce, 0x4c, 0xca, 0x49, 0x0d, 0x49, 0xad,
    0x28, 0x71, 0x2e, 0x2d, 0x2a, 0xce, 0x2f, 0x72, 0x2d, 0x4b, 0xcd, 0x2b, 0xd1, 0x28, 0x4e, 0xcd,
    0x49, 0xd3, 0xc9, 0x4c, 0x4b, 0x4c, 0x4e, 0xc5, 0xad, 0xc7, 0x33, 0xaf, 0x24, 0xb5, 0x08, 0xa4,
    0x44, 0x27, 0x19, 0xac, 0x33, 0x20, 0xbf, 0xd8, 0x2a, 0x33, 0xaf, 0x44, 0x93, 0xcb, 0x80, 0x44,
    0x7b, 0xf2, 0x93, 0xb2, 0x90, 0x74, 0x38, 0xe7, 0x17, 0xa5, 0xea, 0x05, 0xfa, 0x27, 0x65, 0xa5,
    0x26, 0x97, 0xa0, 0x9b, 0x4c, 0xac, 0xb9, 0x7a, 0x70, 0x7d, 0x99, 0x25, 0x99, 0xf9, 0x79, 0x60,
    0x6b, 0x34, 0x75, 0xed, 0x80, 0x66, 0x10, 0x6f, 0x44, 0x71, 0x2a, 0x94, 0x8b, 0x62, 0x8a, 0x4e,
    0x01, 0x94, 0x07, 0x71, 0x10, 0x00, 0x7e, 0x28, 0x7d, 0x5d
};
#endif

PyTypeObject *init_QAccessibleTextCursorEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextCursorEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextCursorEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QAccessibleTextCursorEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]))));

    _Sbk_QAccessibleTextCursorEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAccessibleTextCursorEvent",
        "QAccessibleTextCursorEvent*",
        &Sbk_QAccessibleTextCursorEvent_spec,
        &Shiboken::callCppDestructor< QAccessibleTextCursorEvent >,
        Sbk_QAccessibleTextCursorEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAccessibleTextCursorEvent_TypeF(); // references _Sbk_QAccessibleTextCursorEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAccessibleTextCursorEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAccessibleTextCursorEvent_SignatureBytes, QAccessibleTextCursorEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAccessibleTextCursorEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextCursorEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAccessibleTextCursorEvent_PythonToCpp_QAccessibleTextCursorEvent_PTR,
        is_QAccessibleTextCursorEvent_PythonToCpp_QAccessibleTextCursorEvent_PTR_Convertible,
        QAccessibleTextCursorEvent_PTR_CppToPython_QAccessibleTextCursorEvent);

    Shiboken::Conversions::registerConverterName(converter, "QAccessibleTextCursorEvent");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleTextCursorEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleTextCursorEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAccessibleTextCursorEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAccessibleTextCursorEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAccessibleTextCursorEvent_TypeF(), &Sbk_QAccessibleTextCursorEvent_typeDiscovery);

    qRegisterMetaType< ::QAccessibleTextCursorEvent *>();

    return pyType;
}
