// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qaccessibletextinsertevent_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qaccessible.h>
#include <qobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAccessibleTextInsertEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAccessibleTextInsertEventWrapper::QAccessibleTextInsertEventWrapper(::QAccessibleInterface * iface, int position, const ::QString & text) : QAccessibleTextInsertEvent(iface, position, text)
{
}

QAccessibleTextInsertEventWrapper::QAccessibleTextInsertEventWrapper(::QObject * obj, int position, const ::QString & text) : QAccessibleTextInsertEvent(obj, position, text)
{
}

::QAccessibleInterface * QAccessibleTextInsertEventWrapper::accessibleInterface() const
{
    if (m_PyMethodCache[0])
        return this->::QAccessibleEvent::accessibleInterface();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "accessibleInterface";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QAccessibleEvent::accessibleInterface();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAccessibleTextInsertEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAccessibleTextInsertEvent", funcName, Shiboken::SbkType< QAccessibleInterface >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QAccessibleInterface *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QAccessibleTextInsertEventWrapper::~QAccessibleTextInsertEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAccessibleTextInsertEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAccessibleTextInsertEvent >()))
        return -1;

    QAccessibleTextInsertEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAccessibleTextInsertEvent", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAccessibleTextInsertEvent::QAccessibleTextInsertEvent(QAccessibleInterface*,int,QString)
    // 1: QAccessibleTextInsertEvent::QAccessibleTextInsertEvent(QObject*,int,QString)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 1; // QAccessibleTextInsertEvent(QObject*,int,QString)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // QAccessibleTextInsertEvent(QAccessibleInterface*,int,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextInsertEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextInsertEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAccessibleTextInsertEvent(QAccessibleInterface *iface, int position, const QString &text)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAccessibleInterface *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleTextInsertEvent(QAccessibleInterface*,int,QString)
                cptr = new QAccessibleTextInsertEventWrapper(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // QAccessibleTextInsertEvent(QObject *obj, int position, const QString &text)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleTextInsertEvent(QObject*,int,QString)
                cptr = new QAccessibleTextInsertEventWrapper(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAccessibleTextInsertEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextInsertEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAccessibleTextInsertEventFunc_changePosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTextInsertEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextInsertEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // changePosition()const
        int cppResult = const_cast<const ::QAccessibleTextInsertEvent *>(cppSelf)->changePosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleTextInsertEventFunc_textInserted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTextInsertEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextInsertEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textInserted()const
        QString cppResult = const_cast<const ::QAccessibleTextInsertEvent *>(cppSelf)->textInserted();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAccessibleTextInsertEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAccessibleTextInsertEvent_methods[] = {
    {"changePosition", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTextInsertEventFunc_changePosition), METH_NOARGS, nullptr},
    {"textInserted", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTextInsertEventFunc_textInserted), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAccessibleTextInsertEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAccessibleTextInsertEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextInsertEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAccessibleTextInsertEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAccessibleTextInsertEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAccessibleTextInsertEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAccessibleTextInsertEvent_Type = nullptr;
static PyTypeObject *Sbk_QAccessibleTextInsertEvent_TypeF(void)
{
    return _Sbk_QAccessibleTextInsertEvent_Type;
}

static PyType_Slot Sbk_QAccessibleTextInsertEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAccessibleTextInsertEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAccessibleTextInsertEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAccessibleTextInsertEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAccessibleTextInsertEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAccessibleTextInsertEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAccessibleTextInsertEvent_spec = {
    "2:PySide6.QtGui.QAccessibleTextInsertEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAccessibleTextInsertEvent_slots
};

} //extern "C"

static void *Sbk_QAccessibleTextInsertEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QAccessibleEvent *>(cptr)->type() == QAccessible::TextInserted)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAccessibleTextInsertEvent_PythonToCpp_QAccessibleTextInsertEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAccessibleTextInsertEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAccessibleTextInsertEvent_PythonToCpp_QAccessibleTextInsertEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAccessibleTextInsertEvent_TypeF()))
        return QAccessibleTextInsertEvent_PythonToCpp_QAccessibleTextInsertEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAccessibleTextInsertEvent_PTR_CppToPython_QAccessibleTextInsertEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QAccessibleTextInsertEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QAccessibleTextInsertEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAccessibleTextInsertEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QAccessibleTextInsertEvent(self,iface:PySide6.QtGui.QAccessibleInterface,position:int,text:QString)",
    "0:PySide6.QtGui.QAccessibleTextInsertEvent(self,obj:PySide6.QtCore.QObject,position:int,text:QString)",
    "PySide6.QtGui.QAccessibleTextInsertEvent.changePosition(self)->int",
    "PySide6.QtGui.QAccessibleTextInsertEvent.textInserted(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QAccessibleTextInsertEvent_SignatureByteSize = 149;
static constexpr uint8_t QAccessibleTextInsertEvent_SignatureBytes[149] = {
    0x78, 0xda, 0x95, 0x8e, 0xc1, 0x0a, 0x82, 0x40, 0x14, 0x45, 0xf7, 0x7e, 0x49, 0x82, 0x0d, 0xb5,
    0x69, 0x31, 0x8b, 0x20, 0x22, 0xc2, 0x55, 0x0e, 0xf6, 0x03, 0x3a, 0x5e, 0xed, 0x89, 0xbc, 0x91,
    0x99, 0x57, 0xd4, 0xdf, 0x67, 0x61, 0xd1, 0xa6, 0xb0, 0xe5, 0x85, 0x7b, 0xcf, 0xb9, 0x4b, 0x9d,
    0xdd, 0x72, 0xaa, 0xb0, 0x52, 0x46, 0xf6, 0x67, 0x52, 0x66, 0x63, 0x2d, 0x42, 0xa0, 0xb2, 0xc3,
    0x11, 0x57, 0x49, 0x39, 0xc0, 0xcb, 0xee, 0x02, 0x96, 0x59, 0x40, 0x57, 0x27, 0x54, 0x17, 0x16,
    0xdf, 0x37, 0x29, 0x0b, 0xfc, 0xa3, 0x92, 0xf4, 0x2e, 0x90, 0x90, 0x63, 0x4d, 0x2c, 0x89, 0x0c,
    0x28, 0x6d, 0x72, 0xf1, 0xc4, 0x4d, 0x1c, 0x2d, 0xfe, 0x74, 0xba, 0xb2, 0xfd, 0x58, 0x6c, 0x9d,
    0x87, 0x32, 0x87, 0xb2, 0x85, 0x95, 0x5f, 0x96, 0xa9, 0x0e, 0x65, 0x4f, 0x05, 0x37, 0xc8, 0x46,
    0xd2, 0x53, 0x19, 0xcf, 0xd7, 0x03, 0x70, 0x3a, 0x42, 0xde, 0x19, 0xd5, 0x0b, 0x30, 0x1e, 0x89,
    0xee, 0x03, 0x81, 0x82, 0x22
};
#endif

PyTypeObject *init_QAccessibleTextInsertEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextInsertEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextInsertEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QAccessibleTextInsertEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextCursorEvent_IDX]))));

    _Sbk_QAccessibleTextInsertEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAccessibleTextInsertEvent",
        "QAccessibleTextInsertEvent*",
        &Sbk_QAccessibleTextInsertEvent_spec,
        &Shiboken::callCppDestructor< QAccessibleTextInsertEvent >,
        Sbk_QAccessibleTextInsertEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAccessibleTextInsertEvent_TypeF(); // references _Sbk_QAccessibleTextInsertEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAccessibleTextInsertEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAccessibleTextInsertEvent_SignatureBytes, QAccessibleTextInsertEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAccessibleTextInsertEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextInsertEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAccessibleTextInsertEvent_PythonToCpp_QAccessibleTextInsertEvent_PTR,
        is_QAccessibleTextInsertEvent_PythonToCpp_QAccessibleTextInsertEvent_PTR_Convertible,
        QAccessibleTextInsertEvent_PTR_CppToPython_QAccessibleTextInsertEvent);

    Shiboken::Conversions::registerConverterName(converter, "QAccessibleTextInsertEvent");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleTextInsertEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleTextInsertEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAccessibleTextInsertEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAccessibleTextInsertEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAccessibleTextInsertEvent_TypeF(), &Sbk_QAccessibleTextInsertEvent_typeDiscovery);

    qRegisterMetaType< ::QAccessibleTextInsertEvent *>();

    return pyType;
}
