// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qaccessibletextremoveevent_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qaccessible.h>
#include <qobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAccessibleTextRemoveEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAccessibleTextRemoveEventWrapper::QAccessibleTextRemoveEventWrapper(::QAccessibleInterface * iface, int position, const ::QString & text) : QAccessibleTextRemoveEvent(iface, position, text)
{
}

QAccessibleTextRemoveEventWrapper::QAccessibleTextRemoveEventWrapper(::QObject * obj, int position, const ::QString & text) : QAccessibleTextRemoveEvent(obj, position, text)
{
}

::QAccessibleInterface * QAccessibleTextRemoveEventWrapper::accessibleInterface() const
{
    if (m_PyMethodCache[0])
        return this->::QAccessibleEvent::accessibleInterface();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "accessibleInterface";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QAccessibleEvent::accessibleInterface();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAccessibleTextRemoveEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAccessibleTextRemoveEvent", funcName, Shiboken::SbkType< QAccessibleInterface >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QAccessibleInterface *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QAccessibleTextRemoveEventWrapper::~QAccessibleTextRemoveEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAccessibleTextRemoveEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAccessibleTextRemoveEvent >()))
        return -1;

    QAccessibleTextRemoveEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAccessibleTextRemoveEvent", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAccessibleTextRemoveEvent::QAccessibleTextRemoveEvent(QAccessibleInterface*,int,QString)
    // 1: QAccessibleTextRemoveEvent::QAccessibleTextRemoveEvent(QObject*,int,QString)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 1; // QAccessibleTextRemoveEvent(QObject*,int,QString)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // QAccessibleTextRemoveEvent(QAccessibleInterface*,int,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextRemoveEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextRemoveEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAccessibleTextRemoveEvent(QAccessibleInterface *iface, int position, const QString &text)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAccessibleInterface *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleTextRemoveEvent(QAccessibleInterface*,int,QString)
                cptr = new QAccessibleTextRemoveEventWrapper(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // QAccessibleTextRemoveEvent(QObject *obj, int position, const QString &text)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleTextRemoveEvent(QObject*,int,QString)
                cptr = new QAccessibleTextRemoveEventWrapper(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAccessibleTextRemoveEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextRemoveEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAccessibleTextRemoveEventFunc_changePosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTextRemoveEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextRemoveEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // changePosition()const
        int cppResult = const_cast<const ::QAccessibleTextRemoveEvent *>(cppSelf)->changePosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleTextRemoveEventFunc_textRemoved(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTextRemoveEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextRemoveEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textRemoved()const
        QString cppResult = const_cast<const ::QAccessibleTextRemoveEvent *>(cppSelf)->textRemoved();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAccessibleTextRemoveEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAccessibleTextRemoveEvent_methods[] = {
    {"changePosition", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTextRemoveEventFunc_changePosition), METH_NOARGS, nullptr},
    {"textRemoved", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTextRemoveEventFunc_textRemoved), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAccessibleTextRemoveEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAccessibleTextRemoveEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextRemoveEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAccessibleTextRemoveEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAccessibleTextRemoveEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAccessibleTextRemoveEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAccessibleTextRemoveEvent_Type = nullptr;
static PyTypeObject *Sbk_QAccessibleTextRemoveEvent_TypeF(void)
{
    return _Sbk_QAccessibleTextRemoveEvent_Type;
}

static PyType_Slot Sbk_QAccessibleTextRemoveEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAccessibleTextRemoveEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAccessibleTextRemoveEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAccessibleTextRemoveEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAccessibleTextRemoveEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAccessibleTextRemoveEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAccessibleTextRemoveEvent_spec = {
    "2:PySide6.QtGui.QAccessibleTextRemoveEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAccessibleTextRemoveEvent_slots
};

} //extern "C"

static void *Sbk_QAccessibleTextRemoveEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QAccessibleEvent *>(cptr)->type() == QAccessible::TextRemoved)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAccessibleTextRemoveEvent_PythonToCpp_QAccessibleTextRemoveEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAccessibleTextRemoveEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAccessibleTextRemoveEvent_PythonToCpp_QAccessibleTextRemoveEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAccessibleTextRemoveEvent_TypeF()))
        return QAccessibleTextRemoveEvent_PythonToCpp_QAccessibleTextRemoveEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAccessibleTextRemoveEvent_PTR_CppToPython_QAccessibleTextRemoveEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QAccessibleTextRemoveEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QAccessibleTextRemoveEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAccessibleTextRemoveEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QAccessibleTextRemoveEvent(self,iface:PySide6.QtGui.QAccessibleInterface,position:int,text:QString)",
    "0:PySide6.QtGui.QAccessibleTextRemoveEvent(self,obj:PySide6.QtCore.QObject,position:int,text:QString)",
    "PySide6.QtGui.QAccessibleTextRemoveEvent.changePosition(self)->int",
    "PySide6.QtGui.QAccessibleTextRemoveEvent.textRemoved(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QAccessibleTextRemoveEvent_SignatureByteSize = 150;
static constexpr uint8_t QAccessibleTextRemoveEvent_SignatureBytes[150] = {
    0x78, 0xda, 0x95, 0x8e, 0x41, 0x0a, 0xc2, 0x30, 0x10, 0x45, 0xf7, 0x3d, 0x89, 0x85, 0x1a, 0x74,
    0xe3, 0x22, 0x0b, 0x41, 0x44, 0xa4, 0x2b, 0x1b, 0xeb, 0x05, 0x9a, 0xf4, 0xb7, 0x4e, 0xa9, 0x89,
    0x24, 0x63, 0xd1, 0xdb, 0x5b, 0xa5, 0x8a, 0x1b, 0xa5, 0x2e, 0x07, 0xfe, 0x7b, 0x6f, 0xe6, 0x32,
    0xbb, 0xe5, 0x54, 0x62, 0x21, 0x14, 0x6f, 0x2f, 0x24, 0xd4, 0xca, 0x18, 0x84, 0x40, 0xba, 0xc5,
    0x01, 0x57, 0xde, 0xe3, 0xe4, 0x3a, 0x6c, 0x3a, 0x58, 0x9e, 0x04, 0xb4, 0x55, 0x42, 0x55, 0x61,
    0xf0, 0x9d, 0x49, 0x2d, 0xc3, 0x3f, 0x26, 0xc9, 0xd9, 0x05, 0x62, 0x72, 0x56, 0x92, 0xe5, 0x84,
    0x7b, 0x95, 0x54, 0x39, 0x7b, 0xb2, 0x75, 0x1c, 0xcd, 0xfe, 0x6c, 0x3a, 0xdd, 0x7c, 0x10, 0x6b,
    0xe7, 0x21, 0xd4, 0x4e, 0x37, 0x30, 0xfc, 0xab, 0x32, 0xb6, 0x21, 0xcc, 0xb1, 0xb0, 0x35, 0xb2,
    0xc1, 0xf4, 0x4c, 0xc6, 0xd3, 0x65, 0x2f, 0x1c, 0xaf, 0xe0, 0xf7, 0x5d, 0xbe, 0xf8, 0xe1, 0x8f,
    0xe8, 0x0e, 0x6e, 0x29, 0x81, 0x9a
};
#endif

PyTypeObject *init_QAccessibleTextRemoveEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextRemoveEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextRemoveEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QAccessibleTextRemoveEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextCursorEvent_IDX]))));

    _Sbk_QAccessibleTextRemoveEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAccessibleTextRemoveEvent",
        "QAccessibleTextRemoveEvent*",
        &Sbk_QAccessibleTextRemoveEvent_spec,
        &Shiboken::callCppDestructor< QAccessibleTextRemoveEvent >,
        Sbk_QAccessibleTextRemoveEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAccessibleTextRemoveEvent_TypeF(); // references _Sbk_QAccessibleTextRemoveEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAccessibleTextRemoveEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAccessibleTextRemoveEvent_SignatureBytes, QAccessibleTextRemoveEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAccessibleTextRemoveEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextRemoveEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAccessibleTextRemoveEvent_PythonToCpp_QAccessibleTextRemoveEvent_PTR,
        is_QAccessibleTextRemoveEvent_PythonToCpp_QAccessibleTextRemoveEvent_PTR_Convertible,
        QAccessibleTextRemoveEvent_PTR_CppToPython_QAccessibleTextRemoveEvent);

    Shiboken::Conversions::registerConverterName(converter, "QAccessibleTextRemoveEvent");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleTextRemoveEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleTextRemoveEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAccessibleTextRemoveEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAccessibleTextRemoveEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAccessibleTextRemoveEvent_TypeF(), &Sbk_QAccessibleTextRemoveEvent_typeDiscovery);

    qRegisterMetaType< ::QAccessibleTextRemoveEvent *>();

    return pyType;
}
