// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qaccessiblevaluechangeevent_wrapper.h"

// Argument includes
#include <QtGui/qaccessible.h>
#include <QtGui/qaccessible_base.h>
#include <qobject.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAccessibleValueChangeEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAccessibleValueChangeEventWrapper::QAccessibleValueChangeEventWrapper(::QAccessibleInterface * iface, const ::QVariant & val) : QAccessibleValueChangeEvent(iface, val)
{
}

QAccessibleValueChangeEventWrapper::QAccessibleValueChangeEventWrapper(::QObject * obj, const ::QVariant & val) : QAccessibleValueChangeEvent(obj, val)
{
}

::QAccessibleInterface * QAccessibleValueChangeEventWrapper::accessibleInterface() const
{
    if (m_PyMethodCache[0])
        return this->::QAccessibleEvent::accessibleInterface();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "accessibleInterface";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QAccessibleEvent::accessibleInterface();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAccessibleValueChangeEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAccessibleValueChangeEvent", funcName, Shiboken::SbkType< QAccessibleInterface >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QAccessibleInterface *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QAccessibleValueChangeEventWrapper::~QAccessibleValueChangeEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAccessibleValueChangeEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAccessibleValueChangeEvent >()))
        return -1;

    QAccessibleValueChangeEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAccessibleValueChangeEvent", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAccessibleValueChangeEvent::QAccessibleValueChangeEvent(QAccessibleInterface*,QVariant)
    // 1: QAccessibleValueChangeEvent::QAccessibleValueChangeEvent(QObject*,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 1; // QAccessibleValueChangeEvent(QObject*,QVariant)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // QAccessibleValueChangeEvent(QAccessibleInterface*,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleValueChangeEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleValueChangeEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAccessibleValueChangeEvent(QAccessibleInterface *iface, const QVariant &val)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAccessibleInterface *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleValueChangeEvent(QAccessibleInterface*,QVariant)
                cptr = new QAccessibleValueChangeEventWrapper(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // QAccessibleValueChangeEvent(QObject *obj, const QVariant &val)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleValueChangeEvent(QObject*,QVariant)
                cptr = new QAccessibleValueChangeEventWrapper(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAccessibleValueChangeEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleValueChangeEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAccessibleValueChangeEventFunc_setValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleValueChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleValueChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAccessibleValueChangeEvent::setValue(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setValue(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setValue", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleValueChangeEvent_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValue(QVariant)
            cppSelf->setValue(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAccessibleValueChangeEventFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleValueChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleValueChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // value()const
        QVariant cppResult = const_cast<const ::QAccessibleValueChangeEvent *>(cppSelf)->value();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAccessibleValueChangeEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAccessibleValueChangeEvent_methods[] = {
    {"setValue", reinterpret_cast<PyCFunction>(Sbk_QAccessibleValueChangeEventFunc_setValue), METH_O, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QAccessibleValueChangeEventFunc_value), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAccessibleValueChangeEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAccessibleValueChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleValueChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAccessibleValueChangeEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAccessibleValueChangeEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAccessibleValueChangeEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAccessibleValueChangeEvent_Type = nullptr;
static PyTypeObject *Sbk_QAccessibleValueChangeEvent_TypeF(void)
{
    return _Sbk_QAccessibleValueChangeEvent_Type;
}

static PyType_Slot Sbk_QAccessibleValueChangeEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAccessibleValueChangeEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAccessibleValueChangeEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAccessibleValueChangeEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAccessibleValueChangeEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAccessibleValueChangeEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAccessibleValueChangeEvent_spec = {
    "2:PySide6.QtGui.QAccessibleValueChangeEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAccessibleValueChangeEvent_slots
};

} //extern "C"

static void *Sbk_QAccessibleValueChangeEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QAccessibleEvent *>(cptr)->type() == QAccessible::ValueChanged)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAccessibleValueChangeEvent_PythonToCpp_QAccessibleValueChangeEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAccessibleValueChangeEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAccessibleValueChangeEvent_PythonToCpp_QAccessibleValueChangeEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAccessibleValueChangeEvent_TypeF()))
        return QAccessibleValueChangeEvent_PythonToCpp_QAccessibleValueChangeEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAccessibleValueChangeEvent_PTR_CppToPython_QAccessibleValueChangeEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QAccessibleValueChangeEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QAccessibleValueChangeEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAccessibleValueChangeEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QAccessibleValueChangeEvent(self,iface:PySide6.QtGui.QAccessibleInterface,val:QVariant)",
    "0:PySide6.QtGui.QAccessibleValueChangeEvent(self,obj:PySide6.QtCore.QObject,val:QVariant)",
    "PySide6.QtGui.QAccessibleValueChangeEvent.setValue(self,val:QVariant)",
    "PySide6.QtGui.QAccessibleValueChangeEvent.value(self)->QVariant",
    nullptr}; // Sentinel
#else
static constexpr size_t QAccessibleValueChangeEvent_SignatureByteSize = 131;
static constexpr uint8_t QAccessibleValueChangeEvent_SignatureBytes[131] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x74, 0x4c, 0x4e, 0x4e, 0x2d, 0x2e, 0xce, 0x4c, 0xca, 0x49, 0x0d, 0x4b, 0xcc,
    0x29, 0x4d, 0x75, 0xce, 0x48, 0xcc, 0x4b, 0x4f, 0x75, 0x2d, 0x4b, 0xcd, 0x2b, 0xd1, 0x28, 0x4e,
    0xcd, 0x49, 0xd3, 0xc9, 0x4c, 0x4b, 0x4c, 0x4e, 0xc5, 0xad, 0xc9, 0x33, 0xaf, 0x24, 0xb5, 0x08,
    0xa4, 0x44, 0xa7, 0x2c, 0x31, 0xc7, 0x2a, 0x30, 0x2c, 0xb1, 0x28, 0x33, 0x31, 0xaf, 0x44, 0x93,
    0xcb, 0x80, 0x54, 0x7b, 0xf2, 0x93, 0xb2, 0x90, 0xb4, 0x38, 0xe7, 0x17, 0xa5, 0xea, 0x05, 0xfa,
    0x27, 0x65, 0xa5, 0x26, 0x97, 0xa0, 0x99, 0x4c, 0xb4, 0xb9, 0x7a, 0xc5, 0xa9, 0x25, 0x60, 0x31,
    0x88, 0x05, 0xe4, 0x9a, 0x52, 0x06, 0x37, 0x42, 0x53, 0xd7, 0x0e, 0x66, 0x00, 0x17, 0x00, 0xec,
    0x67, 0x76, 0x51
};
#endif

PyTypeObject *init_QAccessibleValueChangeEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleValueChangeEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleValueChangeEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QAccessibleValueChangeEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleEvent_IDX]))));

    _Sbk_QAccessibleValueChangeEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAccessibleValueChangeEvent",
        "QAccessibleValueChangeEvent*",
        &Sbk_QAccessibleValueChangeEvent_spec,
        &Shiboken::callCppDestructor< QAccessibleValueChangeEvent >,
        Sbk_QAccessibleValueChangeEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAccessibleValueChangeEvent_TypeF(); // references _Sbk_QAccessibleValueChangeEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAccessibleValueChangeEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAccessibleValueChangeEvent_SignatureBytes, QAccessibleValueChangeEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAccessibleValueChangeEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleValueChangeEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAccessibleValueChangeEvent_PythonToCpp_QAccessibleValueChangeEvent_PTR,
        is_QAccessibleValueChangeEvent_PythonToCpp_QAccessibleValueChangeEvent_PTR_Convertible,
        QAccessibleValueChangeEvent_PTR_CppToPython_QAccessibleValueChangeEvent);

    Shiboken::Conversions::registerConverterName(converter, "QAccessibleValueChangeEvent");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleValueChangeEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleValueChangeEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAccessibleValueChangeEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAccessibleValueChangeEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAccessibleValueChangeEvent_TypeF(), &Sbk_QAccessibleValueChangeEvent_typeDiscovery);

    qRegisterMetaType< ::QAccessibleValueChangeEvent *>();

    return pyType;
}
