// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qbackingstore_wrapper.h"

// Argument includes
#include <QtGui/qpaintdevice.h>
#include <QtGui/qregion.h>
#include <QtGui/qwindow.h>
#include <qpoint.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBackingStore_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBackingStore >()))
        return -1;

    ::QBackingStore *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QBackingStore", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBackingStore::QBackingStore(QWindow*)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QBackingStore(QWindow*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWindow *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QBackingStore(QWindow*)
            cptr = new ::QBackingStore(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QBackingStore >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QBackingStoreFunc_beginPaint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBackingStore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBackingStore::beginPaint(QRegion)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), (pyArg)))) {
        overloadId = 0; // beginPaint(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "beginPaint", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRegion cppArg0_local;
        ::QRegion *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // beginPaint(QRegion)
            cppSelf->beginPaint(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBackingStoreFunc_endPaint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBackingStore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // endPaint()
        cppSelf->endPaint();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBackingStoreFunc_flush(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBackingStore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "flush", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:flush", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBackingStore::flush(QRegion,QWindow*=,const QPoint&=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // flush(QRegion,QWindow*,QPoint)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // flush(QRegion,QWindow*,QPoint)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[2])))) {
                overloadId = 0; // flush(QRegion,QWindow*,QPoint)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "flush", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_window = Shiboken::String::createStaticString("window");
            if (PyDict_Contains(kwds, key_window) != 0) {
                value = PyDict_GetItem(kwds, key_window);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_window);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "flush", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "flush", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_window);
            }
            static PyObject *const key_offset = Shiboken::String::createStaticString("offset");
            if (PyDict_Contains(kwds, key_offset) != 0) {
                value = PyDict_GetItem(kwds, key_offset);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_offset);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "flush", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "flush", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_offset);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "flush", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRegion cppArg0_local;
        ::QRegion *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QWindow *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPoint cppArg2_local = QPoint();
        ::QPoint *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // flush(QRegion,QWindow*,QPoint)
            cppSelf->flush(*cppArg0, cppArg1, *cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBackingStoreFunc_hasStaticContents(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBackingStore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasStaticContents()const
        bool cppResult = const_cast<const ::QBackingStore *>(cppSelf)->hasStaticContents();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBackingStoreFunc_paintDevice(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBackingStore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // paintDevice()
        QPaintDevice * cppResult = cppSelf->paintDevice();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBackingStoreFunc_resize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBackingStore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBackingStore::resize(QSize)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
        overloadId = 0; // resize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resize", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSize cppArg0_local;
        ::QSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // resize(QSize)
            cppSelf->resize(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBackingStoreFunc_scroll(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBackingStore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "scroll", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBackingStore::scroll(QRegion,int,int)->bool
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // scroll(QRegion,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "scroll", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRegion cppArg0_local;
        ::QRegion *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // scroll(QRegion,int,int)
            bool cppResult = cppSelf->scroll(*cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBackingStoreFunc_setStaticContents(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBackingStore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBackingStore::setStaticContents(QRegion)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), (pyArg)))) {
        overloadId = 0; // setStaticContents(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStaticContents", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRegion cppArg0_local;
        ::QRegion *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setStaticContents(QRegion)
            cppSelf->setStaticContents(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBackingStoreFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBackingStore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        QSize cppResult = const_cast<const ::QBackingStore *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBackingStoreFunc_staticContents(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBackingStore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // staticContents()const
        QRegion cppResult = const_cast<const ::QBackingStore *>(cppSelf)->staticContents();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBackingStoreFunc_window(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBackingStore *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // window()const
        QWindow * cppResult = const_cast<const ::QBackingStore *>(cppSelf)->window();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QBackingStore_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBackingStore_methods[] = {
    {"beginPaint", reinterpret_cast<PyCFunction>(Sbk_QBackingStoreFunc_beginPaint), METH_O, nullptr},
    {"endPaint", reinterpret_cast<PyCFunction>(Sbk_QBackingStoreFunc_endPaint), METH_NOARGS, nullptr},
    {"flush", reinterpret_cast<PyCFunction>(Sbk_QBackingStoreFunc_flush), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"hasStaticContents", reinterpret_cast<PyCFunction>(Sbk_QBackingStoreFunc_hasStaticContents), METH_NOARGS, nullptr},
    {"paintDevice", reinterpret_cast<PyCFunction>(Sbk_QBackingStoreFunc_paintDevice), METH_NOARGS, nullptr},
    {"resize", reinterpret_cast<PyCFunction>(Sbk_QBackingStoreFunc_resize), METH_O, nullptr},
    {"scroll", reinterpret_cast<PyCFunction>(Sbk_QBackingStoreFunc_scroll), METH_VARARGS, nullptr},
    {"setStaticContents", reinterpret_cast<PyCFunction>(Sbk_QBackingStoreFunc_setStaticContents), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QBackingStoreFunc_size), METH_NOARGS, nullptr},
    {"staticContents", reinterpret_cast<PyCFunction>(Sbk_QBackingStoreFunc_staticContents), METH_NOARGS, nullptr},
    {"window", reinterpret_cast<PyCFunction>(Sbk_QBackingStoreFunc_window), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QBackingStore_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBackingStore_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBackingStore_Type = nullptr;
static PyTypeObject *Sbk_QBackingStore_TypeF(void)
{
    return _Sbk_QBackingStore_Type;
}

static PyType_Slot Sbk_QBackingStore_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBackingStore_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBackingStore_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBackingStore_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBackingStore_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBackingStore_spec = {
    "2:PySide6.QtGui.QBackingStore",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBackingStore_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBackingStore_PythonToCpp_QBackingStore_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBackingStore_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBackingStore_PythonToCpp_QBackingStore_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBackingStore_TypeF()))
        return QBackingStore_PythonToCpp_QBackingStore_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBackingStore_PTR_CppToPython_QBackingStore(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QBackingStore_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBackingStore_SignatureStrings[] = {
    "PySide6.QtGui.QBackingStore(self,window:PySide6.QtGui.QWindow)",
    "PySide6.QtGui.QBackingStore.beginPaint(self,arg__1:typing.Union[PySide6.QtGui.QRegion, PySide6.QtGui.QBitmap, PySide6.QtGui.QPolygon, PySide6.QtCore.QRect])",
    "PySide6.QtGui.QBackingStore.endPaint(self)",
    "PySide6.QtGui.QBackingStore.flush(self,region:typing.Union[PySide6.QtGui.QRegion, PySide6.QtGui.QBitmap, PySide6.QtGui.QPolygon, PySide6.QtCore.QRect],window:PySide6.QtGui.QWindow=nullptr,offset:PySide6.QtCore.QPoint=QPoint())",
    "PySide6.QtGui.QBackingStore.hasStaticContents(self)->bool",
    "PySide6.QtGui.QBackingStore.paintDevice(self)->PySide6.QtGui.QPaintDevice",
    "PySide6.QtGui.QBackingStore.resize(self,size:PySide6.QtCore.QSize)",
    "PySide6.QtGui.QBackingStore.scroll(self,area:typing.Union[PySide6.QtGui.QRegion, PySide6.QtGui.QBitmap, PySide6.QtGui.QPolygon, PySide6.QtCore.QRect],dx:int,dy:int)->bool",
    "PySide6.QtGui.QBackingStore.setStaticContents(self,region:typing.Union[PySide6.QtGui.QRegion, PySide6.QtGui.QBitmap, PySide6.QtGui.QPolygon, PySide6.QtCore.QRect])",
    "PySide6.QtGui.QBackingStore.size(self)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QBackingStore.staticContents(self)->PySide6.QtGui.QRegion",
    "PySide6.QtGui.QBackingStore.window(self)->PySide6.QtGui.QWindow",
    nullptr}; // Sentinel
#else
static constexpr size_t QBackingStore_SignatureByteSize = 287;
static constexpr uint8_t QBackingStore_SignatureBytes[287] = {
    0x78, 0xda, 0xbd, 0x53, 0xb1, 0x4e, 0xc3, 0x30, 0x10, 0xdd, 0xfb, 0x15, 0x8c, 0xad, 0x14, 0x22,
    0xb1, 0x30, 0x44, 0x2a, 0x03, 0x45, 0x62, 0x75, 0x89, 0x10, 0x03, 0x42, 0x95, 0x9b, 0x5c, 0xd2,
    0x13, 0xe6, 0x1c, 0xd9, 0x17, 0x4a, 0xf8, 0x7a, 0x9c, 0x9a, 0x28, 0x4a, 0x9a, 0x1a, 0xa6, 0x4c,
    0xb6, 0x4e, 0xef, 0x3d, 0xdf, 0x7b, 0x77, 0x16, 0x4d, 0x8a, 0x39, 0xdc, 0xc6, 0x5b, 0x7e, 0xac,
    0x31, 0xde, 0xde, 0xcb, 0xec, 0x1d, 0xa9, 0x4c, 0x59, 0x1b, 0x58, 0x5a, 0x50, 0x45, 0x74, 0x44,
    0xca, 0xf5, 0x31, 0x11, 0x43, 0xdc, 0xcb, 0xa9, 0xba, 0x5a, 0x88, 0xcb, 0xf4, 0x78, 0x0f, 0x25,
    0x92, 0x90, 0x48, 0xec, 0x95, 0xa4, 0x29, 0x77, 0xbb, 0x9b, 0x84, 0x9b, 0xca, 0x41, 0xe2, 0x67,
    0x42, 0x4d, 0xaf, 0x23, 0xfe, 0x93, 0xa3, 0x68, 0x8a, 0xae, 0xc6, 0xb2, 0xc8, 0x1f, 0xb2, 0x3a,
    0x2b, 0x0b, 0xad, 0x9a, 0x72, 0x08, 0xdf, 0xb4, 0x0f, 0x3b, 0x99, 0x8c, 0xdf, 0xc2, 0xcd, 0x01,
    0xe5, 0x7d, 0x6b, 0x61, 0x68, 0xa1, 0x6a, 0x7b, 0xf0, 0x16, 0xcc, 0xa9, 0xbf, 0xd9, 0x2c, 0x04,
    0xc3, 0x5f, 0x53, 0xad, 0x54, 0xc5, 0x26, 0xd2, 0x45, 0x61, 0x81, 0x93, 0xb1, 0x82, 0xd0, 0xce,
    0xde, 0xda, 0x1f, 0xcb, 0x55, 0xd8, 0xe2, 0x41, 0xda, 0x94, 0x25, 0x63, 0xb6, 0xd1, 0xc4, 0x40,
    0x6c, 0x7d, 0x2c, 0xd7, 0x77, 0x7b, 0xad, 0x55, 0x90, 0x59, 0xb5, 0x21, 0x3e, 0xc0, 0x27, 0x66,
    0xd0, 0x71, 0xc6, 0x16, 0x7b, 0x44, 0x50, 0xc9, 0x80, 0xc5, 0xef, 0xdf, 0xa5, 0x6b, 0x6f, 0x67,
    0x86, 0x52, 0x57, 0x0c, 0xdb, 0xb0, 0x99, 0xd1, 0x4a, 0x75, 0xdb, 0x06, 0x72, 0xbe, 0x41, 0xe5,
    0x5f, 0x89, 0x73, 0x19, 0xe5, 0x4d, 0x7b, 0xfc, 0x27, 0x37, 0x37, 0xb1, 0x89, 0xc4, 0xe7, 0x5e,
    0xb0, 0x3f, 0xe2, 0xec, 0xe6, 0x31, 0x18, 0x6a, 0x3f, 0x8c, 0x30, 0x79, 0x72, 0x9f, 0x26, 0xbd,
    0x04, 0x75, 0xfc, 0x17, 0xb8, 0xc0, 0xf7, 0x3f, 0x61, 0xf1, 0x03, 0x5b, 0x17, 0xb1, 0x22
};
#endif

PyTypeObject *init_QBackingStore(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX].type;

    Shiboken::AutoDecRef Sbk_QBackingStore_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QBackingStore_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBackingStore",
        "QBackingStore*",
        &Sbk_QBackingStore_spec,
        &Shiboken::callCppDestructor< ::QBackingStore >,
        Sbk_QBackingStore_Type_bases.object(),
        0);
    auto *pyType = Sbk_QBackingStore_TypeF(); // references _Sbk_QBackingStore_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBackingStore_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBackingStore_SignatureBytes, QBackingStore_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBackingStore_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QBackingStore_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBackingStore_PythonToCpp_QBackingStore_PTR,
        is_QBackingStore_PythonToCpp_QBackingStore_PTR_Convertible,
        QBackingStore_PTR_CppToPython_QBackingStore);

    Shiboken::Conversions::registerConverterName(converter, "QBackingStore");
    Shiboken::Conversions::registerConverterName(converter, "QBackingStore*");
    Shiboken::Conversions::registerConverterName(converter, "QBackingStore&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBackingStore).name());

    qRegisterMetaType< ::QBackingStore *>();

    return pyType;
}
