// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qclipboard_wrapper.h"

// Extra includes
#include <QImage>
#include <QPixmap>

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGui/qclipboard.h>
#include <QtGui/qimage.h>
#include <QtGui/qpixmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qmimedata.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QClipboardFunc_clear(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QClipboard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "clear", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    if (PyArg_ParseTuple(args, "|O:clear", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QClipboard::clear(QClipboard::Mode=)
    if (numArgs == 0) {
        overloadId = 0; // clear(QClipboard::Mode)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // clear(QClipboard::Mode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "clear", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "clear", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "clear", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "clear", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
            }
        }
        ::QClipboard::Mode cppArg0(QClipboard::Mode::Clipboard);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // clear(QClipboard::Mode)
            cppSelf->clear(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QClipboardFunc_image(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QClipboard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "image", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    if (PyArg_ParseTuple(args, "|O:image", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QClipboard::image(QClipboard::Mode=)const->QImage
    if (numArgs == 0) {
        overloadId = 0; // image(QClipboard::Mode)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // image(QClipboard::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "image", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "image", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "image", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "image", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
            }
        }
        ::QClipboard::Mode cppArg0(QClipboard::Mode::Clipboard);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // image(QClipboard::Mode)const
            QImage cppResult = const_cast<const ::QClipboard *>(cppSelf)->image(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QClipboardFunc_mimeData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QClipboard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "mimeData", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    if (PyArg_ParseTuple(args, "|O:mimeData", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QClipboard::mimeData(QClipboard::Mode=)const->const QMimeData*
    if (numArgs == 0) {
        overloadId = 0; // mimeData(QClipboard::Mode)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // mimeData(QClipboard::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mimeData", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "mimeData", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "mimeData", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "mimeData", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
            }
        }
        ::QClipboard::Mode cppArg0(QClipboard::Mode::Clipboard);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mimeData(QClipboard::Mode)const
            const QMimeData * cppResult = const_cast<const ::QClipboard *>(cppSelf)->mimeData(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QClipboardFunc_ownsClipboard(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QClipboard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ownsClipboard()const
        bool cppResult = const_cast<const ::QClipboard *>(cppSelf)->ownsClipboard();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QClipboardFunc_ownsFindBuffer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QClipboard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ownsFindBuffer()const
        bool cppResult = const_cast<const ::QClipboard *>(cppSelf)->ownsFindBuffer();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QClipboardFunc_ownsSelection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QClipboard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ownsSelection()const
        bool cppResult = const_cast<const ::QClipboard *>(cppSelf)->ownsSelection();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QClipboardFunc_pixmap(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QClipboard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "pixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    if (PyArg_ParseTuple(args, "|O:pixmap", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QClipboard::pixmap(QClipboard::Mode=)const->QPixmap
    if (numArgs == 0) {
        overloadId = 0; // pixmap(QClipboard::Mode)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // pixmap(QClipboard::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "pixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "pixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "pixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "pixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
            }
        }
        ::QClipboard::Mode cppArg0(QClipboard::Mode::Clipboard);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // pixmap(QClipboard::Mode)const
            QPixmap cppResult = const_cast<const ::QClipboard *>(cppSelf)->pixmap(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QClipboardFunc_setImage(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QClipboard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setImage", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QClipboard::setImage(PyPathLike)
    // 1: QClipboard::setImage(QImage,QClipboard::Mode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // setImage(QImage,QClipboard::Mode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // setImage(QImage,QClipboard::Mode)
        }
    } else if (numArgs == 1
        && Shiboken::String::checkPath(pyArgs[0])) {
        overloadId = 0; // setImage(PyPathLike)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setImage(PyPathLike path)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // setImage(PyPathLike)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qclipboard-setimage)]
                const auto path = PySide::pyPathToQString(pyArgs[1-1]);
                cppSelf->setImage(QImage(path));
                // END of custom code block [file: ../glue/qtgui.cpp (qclipboard-setimage)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // setImage(const QImage &arg__1, QClipboard::Mode mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "setImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "setImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QImage cppArg0_local;
            ::QImage *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QClipboard::Mode cppArg1(QClipboard::Mode::Clipboard);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setImage(QImage,QClipboard::Mode)
                cppSelf->setImage(*cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QClipboardFunc_setMimeData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QClipboard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setMimeData", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setMimeData", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QClipboard::setMimeData(QMimeData*,QClipboard::Mode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setMimeData(QMimeData*,QClipboard::Mode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setMimeData(QMimeData*,QClipboard::Mode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setMimeData", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setMimeData", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setMimeData", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setMimeData", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QMimeData *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QClipboard::Mode cppArg1(QClipboard::Mode::Clipboard);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMimeData(QMimeData*,QClipboard::Mode)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setMimeData(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[0]);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QClipboardFunc_setPixmap(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QClipboard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setPixmap", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QClipboard::setPixmap(PyPathLike)
    // 1: QClipboard::setPixmap(QPixmap,QClipboard::Mode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // setPixmap(QPixmap,QClipboard::Mode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // setPixmap(QPixmap,QClipboard::Mode)
        }
    } else if (numArgs == 1
        && Shiboken::String::checkPath(pyArgs[0])) {
        overloadId = 0; // setPixmap(PyPathLike)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setPixmap(PyPathLike path)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // setPixmap(PyPathLike)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qclipboard-setpixmap)]
                const auto path = PySide::pyPathToQString(pyArgs[1-1]);
                cppSelf->setPixmap(QPixmap(path));
                // END of custom code block [file: ../glue/qtgui.cpp (qclipboard-setpixmap)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // setPixmap(const QPixmap &arg__1, QClipboard::Mode mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "setPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "setPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPixmap cppArg0_local;
            ::QPixmap *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QClipboard::Mode cppArg1(QClipboard::Mode::Clipboard);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setPixmap(QPixmap,QClipboard::Mode)
                cppSelf->setPixmap(*cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QClipboardFunc_setText(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QClipboard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setText", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QClipboard::setText(QString,QClipboard::Mode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setText(QString,QClipboard::Mode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setText(QString,QClipboard::Mode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QClipboard::Mode cppArg1(QClipboard::Mode::Clipboard);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setText(QString,QClipboard::Mode)
            cppSelf->setText(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QClipboardFunc_supportsFindBuffer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QClipboard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportsFindBuffer()const
        bool cppResult = const_cast<const ::QClipboard *>(cppSelf)->supportsFindBuffer();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QClipboardFunc_supportsSelection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QClipboard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportsSelection()const
        bool cppResult = const_cast<const ::QClipboard *>(cppSelf)->supportsSelection();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QClipboardFunc_text(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QClipboard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "text", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    if (PyArg_ParseTuple(args, "|OO:text", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QClipboard::text(QClipboard::Mode=)const->QString
    // 1: QClipboard::text(QString&,QClipboard::Mode=)const->(retval, subtype)
    if (numArgs == 0) {
        overloadId = 0; // text(QClipboard::Mode)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // text(QString&,QClipboard::Mode)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // text(QString&,QClipboard::Mode)const
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // text(QClipboard::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "text", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // text(QClipboard::Mode mode) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "text", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "text", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "text", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
            }
            ::QClipboard::Mode cppArg0(QClipboard::Mode::Clipboard);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // text(QClipboard::Mode)const
                QString cppResult = const_cast<const ::QClipboard *>(cppSelf)->text(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // text(QString &subtype, QClipboard::Mode mode) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "text", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "text", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "text", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QClipboard::Mode cppArg1(QClipboard::Mode::Clipboard);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // text(QString&,QClipboard::Mode)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qclipboard-text)]
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                ::QString retval_ = cppSelf->text(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = PyTuple_New(2);
                PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &retval_));
                PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppArg0));
                // END of custom code block [file: ../glue/qtgui.cpp (qclipboard-text)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QClipboard_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QClipboard_EnumFlagInfo[] = {
    "Mode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QClipboard_methods[] = {
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QClipboardFunc_clear), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"image", reinterpret_cast<PyCFunction>(Sbk_QClipboardFunc_image), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"mimeData", reinterpret_cast<PyCFunction>(Sbk_QClipboardFunc_mimeData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"ownsClipboard", reinterpret_cast<PyCFunction>(Sbk_QClipboardFunc_ownsClipboard), METH_NOARGS, nullptr},
    {"ownsFindBuffer", reinterpret_cast<PyCFunction>(Sbk_QClipboardFunc_ownsFindBuffer), METH_NOARGS, nullptr},
    {"ownsSelection", reinterpret_cast<PyCFunction>(Sbk_QClipboardFunc_ownsSelection), METH_NOARGS, nullptr},
    {"pixmap", reinterpret_cast<PyCFunction>(Sbk_QClipboardFunc_pixmap), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setImage", reinterpret_cast<PyCFunction>(Sbk_QClipboardFunc_setImage), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setMimeData", reinterpret_cast<PyCFunction>(Sbk_QClipboardFunc_setMimeData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setPixmap", reinterpret_cast<PyCFunction>(Sbk_QClipboardFunc_setPixmap), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setText", reinterpret_cast<PyCFunction>(Sbk_QClipboardFunc_setText), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"supportsFindBuffer", reinterpret_cast<PyCFunction>(Sbk_QClipboardFunc_supportsFindBuffer), METH_NOARGS, nullptr},
    {"supportsSelection", reinterpret_cast<PyCFunction>(Sbk_QClipboardFunc_supportsSelection), METH_NOARGS, nullptr},
    {"text", reinterpret_cast<PyCFunction>(Sbk_QClipboardFunc_text), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QClipboard_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QClipboard_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QClipboard_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QClipboard_Type = nullptr;
static PyTypeObject *Sbk_QClipboard_TypeF(void)
{
    return _Sbk_QClipboard_Type;
}

static PyType_Slot Sbk_QClipboard_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(SbkDeallocWrapperWithPrivateDtor)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QClipboard_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QClipboard_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QClipboard_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QClipboard_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QClipboard_spec = {
    "2:PySide6.QtGui.QClipboard",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QClipboard_slots
};

} //extern "C"

static void *Sbk_QClipboard_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QClipboard *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QClipboard_Mode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QClipboard::Mode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QClipboard::Mode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QClipboard_Mode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))
        return Enum_PythonToCpp_QClipboard_Mode;
    return {};
}

static PyObject *QClipboard_Mode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QClipboard::Mode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QClipboard::Mode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QClipboard_PythonToCpp_QClipboard_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QClipboard_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QClipboard_PythonToCpp_QClipboard_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QClipboard_TypeF()))
        return QClipboard_PythonToCpp_QClipboard_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QClipboard_PTR_CppToPython_QClipboard(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QClipboard *>(const_cast<void *>(cppIn)), Sbk_QClipboard_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QClipboard_SignatureStrings[] = {
    "PySide6.QtGui.QClipboard.clear(self,mode:PySide6.QtGui.QClipboard.Mode=QClipboard.Mode.Clipboard)",
    "PySide6.QtGui.QClipboard.image(self,mode:PySide6.QtGui.QClipboard.Mode=QClipboard.Mode.Clipboard)->PySide6.QtGui.QImage",
    "PySide6.QtGui.QClipboard.mimeData(self,mode:PySide6.QtGui.QClipboard.Mode=QClipboard.Mode.Clipboard)->PySide6.QtCore.QMimeData",
    "PySide6.QtGui.QClipboard.ownsClipboard(self)->bool",
    "PySide6.QtGui.QClipboard.ownsFindBuffer(self)->bool",
    "PySide6.QtGui.QClipboard.ownsSelection(self)->bool",
    "PySide6.QtGui.QClipboard.pixmap(self,mode:PySide6.QtGui.QClipboard.Mode=QClipboard.Mode.Clipboard)->PySide6.QtGui.QPixmap",
    "1:PySide6.QtGui.QClipboard.setImage(self,path:PyPathLike)",
    "0:PySide6.QtGui.QClipboard.setImage(self,arg__1:PySide6.QtGui.QImage,mode:PySide6.QtGui.QClipboard.Mode=QClipboard.Mode.Clipboard)",
    "PySide6.QtGui.QClipboard.setMimeData(self,data:PySide6.QtCore.QMimeData,mode:PySide6.QtGui.QClipboard.Mode=QClipboard.Mode.Clipboard)",
    "1:PySide6.QtGui.QClipboard.setPixmap(self,path:PyPathLike)",
    "0:PySide6.QtGui.QClipboard.setPixmap(self,arg__1:PySide6.QtGui.QPixmap,mode:PySide6.QtGui.QClipboard.Mode=QClipboard.Mode.Clipboard)",
    "PySide6.QtGui.QClipboard.setText(self,arg__1:QString,mode:PySide6.QtGui.QClipboard.Mode=QClipboard.Mode.Clipboard)",
    "PySide6.QtGui.QClipboard.supportsFindBuffer(self)->bool",
    "PySide6.QtGui.QClipboard.supportsSelection(self)->bool",
    "1:PySide6.QtGui.QClipboard.text(self,mode:PySide6.QtGui.QClipboard.Mode=QClipboard.Mode.Clipboard)->QString",
    "0:PySide6.QtGui.QClipboard.text(self,subtype:QString,mode:PySide6.QtGui.QClipboard.Mode=QClipboard.Mode.Clipboard)->Tuple[str, PySide6.QtGui.QClipboard.Mode]",
    nullptr}; // Sentinel
#else
static constexpr size_t QClipboard_SignatureByteSize = 292;
static constexpr uint8_t QClipboard_SignatureBytes[292] = {
    0x78, 0xda, 0xb5, 0x53, 0x4d, 0x6b, 0xc3, 0x30, 0x0c, 0xbd, 0xe7, 0x57, 0xec, 0xb8, 0x42, 0x1b,
    0xd6, 0xcb, 0x0e, 0x85, 0xf5, 0xb0, 0x96, 0x8d, 0xc2, 0x02, 0x0e, 0xe9, 0x6d, 0x8c, 0xe2, 0x34,
    0x4a, 0x66, 0x6a, 0xc7, 0xc6, 0x96, 0x59, 0xfb, 0xef, 0xe7, 0x65, 0x5d, 0xfa, 0xb1, 0x3a, 0xa4,
    0x34, 0x39, 0xd9, 0xc2, 0x7a, 0xef, 0xc9, 0x4f, 0x12, 0xd9, 0x25, 0x2c, 0x83, 0xc7, 0x30, 0xc6,
    0x57, 0xcb, 0xc2, 0x78, 0xc6, 0x99, 0x4a, 0x25, 0xd5, 0x59, 0xb8, 0xe6, 0x40, 0xf5, 0xbd, 0x01,
    0x9e, 0x0f, 0x85, 0xcc, 0x60, 0x42, 0x7c, 0x89, 0x91, 0x7b, 0x7d, 0x3a, 0x8b, 0xc3, 0x3a, 0x1c,
    0x04, 0x5e, 0x20, 0x13, 0xb4, 0x80, 0x0e, 0x14, 0x46, 0xd3, 0x33, 0xe4, 0xe2, 0x87, 0xd8, 0xaf,
    0x2b, 0x98, 0x80, 0x39, 0x45, 0xda, 0xb1, 0xf4, 0x4c, 0x6a, 0x08, 0xe3, 0x68, 0x4f, 0xee, 0x97,
    0x97, 0x5f, 0xa5, 0xa9, 0xa3, 0xaa, 0x06, 0x47, 0x93, 0x4a, 0xc9, 0x9b, 0x21, 0x2f, 0xac, 0xcc,
    0x9e, 0x6d, 0x9e, 0x83, 0x6e, 0x8f, 0x49, 0x80, 0xc3, 0x1a, 0x99, 0x2c, 0xdb, 0x41, 0x14, 0xdb,
    0x0a, 0xaa, 0xfa, 0xe8, 0x08, 0xa9, 0x98, 0x83, 0xb1, 0x9f, 0xd1, 0x00, 0x2e, 0x0e, 0xf3, 0xa0,
    0x28, 0x7e, 0xba, 0x5c, 0xe2, 0x8e, 0x37, 0xb6, 0x81, 0x41, 0xf0, 0xd0, 0x16, 0x49, 0x75, 0xb1,
    0x5a, 0xfd, 0xd3, 0xa9, 0x12, 0xfa, 0x9a, 0x63, 0x57, 0x40, 0x74, 0x32, 0x52, 0x99, 0xbb, 0x4d,
    0x7c, 0x83, 0x71, 0x63, 0x15, 0xcd, 0x16, 0x92, 0xa3, 0x0e, 0x5e, 0xe9, 0xe1, 0x31, 0xf4, 0xb2,
    0x89, 0xbf, 0x19, 0x3d, 0xba, 0xb8, 0x84, 0x2d, 0x9e, 0x14, 0x10, 0x27, 0xa8, 0x59, 0x59, 0xf4,
    0x26, 0x69, 0x95, 0x92, 0x1a, 0xaf, 0x5e, 0xad, 0x3f, 0xdc, 0xe5, 0xf5, 0x6a, 0xe8, 0x10, 0xd6,
    0x1f, 0xbc, 0x71, 0xbd, 0xf6, 0xc6, 0x34, 0xb5, 0xf4, 0xa0, 0x65, 0x6c, 0x8a, 0x3b, 0x05, 0xdd,
    0xb8, 0x39, 0x9a, 0x2e, 0xad, 0xe2, 0xf0, 0x6e, 0x50, 0x0f, 0xef, 0x1a, 0x49, 0x3e, 0x82, 0x6f,
    0xb1, 0xdc, 0x43, 0x1f
};
#endif

PyTypeObject *init_QClipboard(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX].type;

    Shiboken::AutoDecRef Sbk_QClipboard_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QClipboard_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QClipboard",
        "QClipboard*",
        &Sbk_QClipboard_spec,
        nullptr,
        Sbk_QClipboard_Type_bases.object(),
        0);
    auto *pyType = Sbk_QClipboard_TypeF(); // references _Sbk_QClipboard_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QClipboard_SignatureStrings);
#else
    InitSignatureBytes(pyType, QClipboard_SignatureBytes, QClipboard_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QClipboard_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QClipboard_PythonToCpp_QClipboard_PTR,
        is_QClipboard_PythonToCpp_QClipboard_PTR_Convertible,
        QClipboard_PTR_CppToPython_QClipboard);

    Shiboken::Conversions::registerConverterName(converter, "QClipboard");
    Shiboken::Conversions::registerConverterName(converter, "QClipboard*");
    Shiboken::Conversions::registerConverterName(converter, "QClipboard&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QClipboard).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QClipboard_TypeF(), &Sbk_QClipboard_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QClipboard_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Mode'.
    const char *Mode_Initializer[] = {
        "Clipboard",
        "Selection",
        "FindBuffer",
        "LastMode",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Mode_InitializerValues[] = {
        uint8_t(QClipboard::Mode::Clipboard),  //  0x00  0
        uint8_t(QClipboard::Mode::Selection),  //  0x01  1
        uint8_t(QClipboard::Mode::FindBuffer), //  0x02  2
        uint8_t(QClipboard::Mode::LastMode)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QClipboard_TypeF(),
        "2:PySide6.QtGui.QClipboard.Mode",
        Mode_Initializer, Mode_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX].type = EType;
    // Register converter for enum 'QClipboard::Mode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QClipboard_Mode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QClipboard_Mode,
            is_Enum_PythonToCpp_QClipboard_Mode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QClipboard::Mode");
        Shiboken::Conversions::registerConverterAlias(converter, "Mode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Mode' enum.

    PySide::Signal::registerSignals(pyType, &::QClipboard::staticMetaObject);
    qRegisterMetaType< ::QClipboard::Mode >("QClipboard::Mode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QClipboard::staticMetaObject, sizeof(::QClipboard));

    return pyType;
}
