// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qcolortransform_wrapper.h"

// Argument includes
#include <QtGui/qcolor.h>
#include <QtGui/qcolortransform.h>
#include <QtGui/qrgba64.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QColorTransform_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QColorTransform >()))
        return -1;

    ::QColorTransform *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QColorTransform", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QColorTransform::QColorTransform()
    // 1: QColorTransform::QColorTransform(QColorTransform)
    if (numArgs == 0) {
        overloadId = 0; // QColorTransform()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QColorTransform(QColorTransform)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QColorTransform()
        {

            // QColorTransform()
            cptr = new ::QColorTransform();
            break;
        }
        case 1: // QColorTransform(const QColorTransform &colorTransform)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QColorTransform cppArg0_local;
            ::QColorTransform *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QColorTransform(QColorTransform)
                cptr = new ::QColorTransform(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QColorTransform >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QColorTransformFunc_isIdentity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isIdentity()const
        bool cppResult = const_cast<const ::QColorTransform *>(cppSelf)->isIdentity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorTransformFunc_map(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColorTransform::map(QRgba64)const->QRgba64
    // 1: QColorTransform::map(QColor)const->QColor
    // 2: QColorTransform::map(uint)const->unsigned int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 2; // map(uint)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRgba64_IDX]), (pyArg)))) {
        overloadId = 0; // map(QRgba64)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 1; // map(QColor)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "map", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // map(QRgba64 rgba64) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QRgba64 cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // map(QRgba64)const
                QRgba64 cppResult = const_cast<const ::QColorTransform *>(cppSelf)->map(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRgba64_IDX]), &cppResult);
            }
            break;
        }
        case 1: // map(const QColor &color) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QColor cppArg0_local;
            ::QColor *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // map(QColor)const
                QColor cppResult = const_cast<const ::QColorTransform *>(cppSelf)->map(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
            }
            break;
        }
        case 2: // map(unsigned int argb) const
        {
            unsigned int cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // map(uint)const
                unsigned int cppResult = const_cast<const ::QColorTransform *>(cppSelf)->map(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorTransformFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColorTransform::swap(QColorTransform&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QColorTransform&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColorTransform cppArg0_local;
        ::QColorTransform *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QColorTransform&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorTransform__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QColorTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QColorTransform_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QColorTransform_methods[] = {
    {"isIdentity", reinterpret_cast<PyCFunction>(Sbk_QColorTransformFunc_isIdentity), METH_NOARGS, nullptr},
    {"map", reinterpret_cast<PyCFunction>(Sbk_QColorTransformFunc_map), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QColorTransformFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QColorTransform__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QColorTransform_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QColorTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]), (pyArg)))) {
                // operator!=(const QColorTransform &ct2)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QColorTransform cppArg0_local;
                ::QColorTransform *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]), (pyArg)))) {
                // operator==(const QColorTransform &ct2)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QColorTransform cppArg0_local;
                ::QColorTransform *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QColorTransform_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QColorTransform_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QColorTransform_Type = nullptr;
static PyTypeObject *Sbk_QColorTransform_TypeF(void)
{
    return _Sbk_QColorTransform_Type;
}

static PyType_Slot Sbk_QColorTransform_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QColorTransform_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QColorTransform_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QColorTransform_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QColorTransform_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QColorTransform_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QColorTransform_spec = {
    "2:PySide6.QtGui.QColorTransform",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QColorTransform_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QColorTransform_PythonToCpp_QColorTransform_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QColorTransform_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QColorTransform_PythonToCpp_QColorTransform_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QColorTransform_TypeF()))
        return QColorTransform_PythonToCpp_QColorTransform_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QColorTransform_PTR_CppToPython_QColorTransform(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QColorTransform_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QColorTransform_COPY_CppToPython_QColorTransform(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QColorTransform *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QColorTransform_TypeF(), new ::QColorTransform(*source), true, true);
}

// Python to C++ copy conversion.
static void QColorTransform_PythonToCpp_QColorTransform_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QColorTransform *>(cppOut) = *reinterpret_cast< ::QColorTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QColorTransform_PythonToCpp_QColorTransform_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QColorTransform_TypeF()))
        return QColorTransform_PythonToCpp_QColorTransform_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QColorTransform_SignatureStrings[] = {
    "1:PySide6.QtGui.QColorTransform(self)",
    "0:PySide6.QtGui.QColorTransform(self,colorTransform:PySide6.QtGui.QColorTransform)",
    "PySide6.QtGui.QColorTransform.isIdentity(self)->bool",
    "2:PySide6.QtGui.QColorTransform.map(self,rgba64:PySide6.QtGui.QRgba64)->PySide6.QtGui.QRgba64",
    "1:PySide6.QtGui.QColorTransform.map(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])->PySide6.QtGui.QColor",
    "0:PySide6.QtGui.QColorTransform.map(self,argb:unsigned int)->unsigned int",
    "PySide6.QtGui.QColorTransform.swap(self,other:PySide6.QtGui.QColorTransform)",
    "PySide6.QtGui.QColorTransform.__copy__(self)->typing.Self",
    "PySide6.QtGui.QColorTransform.__ne__(self,ct2:PySide6.QtGui.QColorTransform)->bool",
    "PySide6.QtGui.QColorTransform.__eq__(self,ct2:PySide6.QtGui.QColorTransform)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QColorTransform_SignatureByteSize = 250;
static constexpr uint8_t QColorTransform_SignatureBytes[250] = {
    0x78, 0xda, 0xa5, 0x92, 0x3d, 0x4f, 0xc3, 0x30, 0x10, 0x86, 0xf7, 0xfc, 0x8a, 0x8c, 0x54, 0x0a,
    0x16, 0x41, 0xa8, 0x43, 0x06, 0x96, 0x0e, 0x15, 0x52, 0x87, 0x86, 0x00, 0x0b, 0x42, 0x91, 0x93,
    0xb8, 0xe1, 0x24, 0xf7, 0x2e, 0xd8, 0x57, 0xa1, 0xfc, 0x7b, 0xac, 0xb4, 0x16, 0x01, 0xa2, 0xb8,
    0x15, 0x93, 0x75, 0xe7, 0xf7, 0x7d, 0x7c, 0x1f, 0x4e, 0xb3, 0x6d, 0x5f, 0x40, 0xa3, 0x96, 0x22,
    0xe7, 0xf5, 0x01, 0x44, 0xbe, 0x22, 0x4d, 0xe6, 0xc9, 0x48, 0xb4, 0x3b, 0x32, 0xfb, 0x2b, 0xab,
    0xf4, 0x6e, 0x11, 0xdd, 0x9c, 0xa1, 0x4a, 0xea, 0x1f, 0xb9, 0x79, 0xc7, 0x22, 0x9a, 0xbd, 0x16,
    0x60, 0x1f, 0x1a, 0x85, 0x0c, 0xdc, 0x1f, 0x2b, 0xb8, 0xbe, 0xaf, 0x88, 0x74, 0x74, 0x3b, 0x4f,
    0x15, 0x7b, 0xd9, 0x1d, 0x6b, 0x31, 0x6d, 0x25, 0x97, 0x77, 0xbf, 0xd5, 0x8f, 0x43, 0xd6, 0xc1,
    0x26, 0xf3, 0x51, 0x7a, 0x2e, 0x7d, 0xe8, 0x34, 0xe3, 0xbe, 0x03, 0x6c, 0xc5, 0x33, 0x02, 0xe1,
    0xeb, 0x94, 0x33, 0x89, 0xf3, 0x8d, 0x64, 0xc0, 0xb4, 0x60, 0xe3, 0x94, 0x49, 0x3c, 0xf9, 0xac,
    0x53, 0xbd, 0x48, 0x03, 0x12, 0x79, 0x2c, 0x58, 0x91, 0x51, 0xee, 0x10, 0x6b, 0x4d, 0x95, 0xd4,
    0x1e, 0xe7, 0x41, 0x07, 0xb4, 0xd0, 0xa2, 0x6a, 0x62, 0x40, 0x7e, 0xfb, 0xdb, 0xcf, 0x20, 0x0f,
    0x2d, 0xed, 0xbb, 0x1d, 0xe9, 0xa6, 0x95, 0x8d, 0x91, 0x8e, 0x38, 0x0e, 0x03, 0xbb, 0xb2, 0x9f,
    0x1e, 0x44, 0xfc, 0xae, 0xcc, 0xff, 0x16, 0x5f, 0x96, 0x35, 0x75, 0x7d, 0x59, 0xfa, 0xb5, 0x9f,
    0x86, 0x5c, 0xb8, 0x28, 0xe8, 0x44, 0x75, 0xf2, 0x25, 0x35, 0x07, 0x7e, 0x8a, 0xff, 0x50, 0x21,
    0xa4, 0xfa, 0xb8, 0x18, 0xf9, 0x05, 0x9e, 0x5b, 0x2d, 0xfe
};
#endif

PyTypeObject *init_QColorTransform(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX].type;

    Shiboken::AutoDecRef Sbk_QColorTransform_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QColorTransform_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QColorTransform",
        "QColorTransform",
        &Sbk_QColorTransform_spec,
        &Shiboken::callCppDestructor< ::QColorTransform >,
        Sbk_QColorTransform_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QColorTransform_TypeF(); // references _Sbk_QColorTransform_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QColorTransform_SignatureStrings);
#else
    InitSignatureBytes(pyType, QColorTransform_SignatureBytes, QColorTransform_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QColorTransform_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QColorTransform_PythonToCpp_QColorTransform_PTR,
        is_QColorTransform_PythonToCpp_QColorTransform_PTR_Convertible,
        QColorTransform_PTR_CppToPython_QColorTransform,
        QColorTransform_COPY_CppToPython_QColorTransform);

    Shiboken::Conversions::registerConverterName(converter, "QColorTransform");
    Shiboken::Conversions::registerConverterName(converter, "QColorTransform*");
    Shiboken::Conversions::registerConverterName(converter, "QColorTransform&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QColorTransform).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QColorTransform_PythonToCpp_QColorTransform_COPY,
        is_QColorTransform_PythonToCpp_QColorTransform_COPY_Convertible);

    qRegisterMetaType< ::QColorTransform >("QColorTransform");

    return pyType;
}
