// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qconicalgradient_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QConicalGradient_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QConicalGradient >()))
        return -1;

    ::QConicalGradient *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QConicalGradient", 0, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QConicalGradient::QConicalGradient()
    // 1: QConicalGradient::QConicalGradient(QConicalGradient)
    // 2: QConicalGradient::QConicalGradient(QPointF,qreal)
    // 3: QConicalGradient::QConicalGradient(qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // QConicalGradient()
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))) {
        overloadId = 3; // QConicalGradient(qreal,qreal,qreal)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 2; // QConicalGradient(QPointF,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QConicalGradient(QConicalGradient)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QConicalGradient()
        {

            // QConicalGradient()
            cptr = new ::QConicalGradient();
            break;
        }
        case 1: // QConicalGradient(const QConicalGradient &QConicalGradient)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QConicalGradient cppArg0_local;
            ::QConicalGradient *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QConicalGradient(QConicalGradient)
                cptr = new ::QConicalGradient(*cppArg0);
            }
            break;
        }
        case 2: // QConicalGradient(const QPointF &center, qreal startAngle)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QConicalGradient(QPointF,qreal)
                cptr = new ::QConicalGradient(*cppArg0, cppArg1);
            }
            break;
        }
        case 3: // QConicalGradient(qreal cx, qreal cy, qreal startAngle)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QConicalGradient(qreal,qreal,qreal)
                cptr = new ::QConicalGradient(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QConicalGradient >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QConicalGradientFunc_angle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QConicalGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // angle()const
        qreal cppResult = const_cast<const ::QConicalGradient *>(cppSelf)->angle();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QConicalGradientFunc_center(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QConicalGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // center()const
        QPointF cppResult = const_cast<const ::QConicalGradient *>(cppSelf)->center();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QConicalGradientFunc_setAngle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QConicalGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QConicalGradient::setAngle(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setAngle(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAngle", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAngle(qreal)
            cppSelf->setAngle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QConicalGradientFunc_setCenter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QConicalGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setCenter", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QConicalGradient::setCenter(QPointF)
    // 1: QConicalGradient::setCenter(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 1; // setCenter(qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setCenter(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setCenter", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setCenter(const QPointF &center)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setCenter(QPointF)
                cppSelf->setCenter(*cppArg0);
            }
            break;
        }
        case 1: // setCenter(qreal x, qreal y)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setCenter(qreal,qreal)
                cppSelf->setCenter(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QConicalGradient__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QConicalGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QConicalGradient_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QConicalGradient_methods[] = {
    {"angle", reinterpret_cast<PyCFunction>(Sbk_QConicalGradientFunc_angle), METH_NOARGS, nullptr},
    {"center", reinterpret_cast<PyCFunction>(Sbk_QConicalGradientFunc_center), METH_NOARGS, nullptr},
    {"setAngle", reinterpret_cast<PyCFunction>(Sbk_QConicalGradientFunc_setAngle), METH_O, nullptr},
    {"setCenter", reinterpret_cast<PyCFunction>(Sbk_QConicalGradientFunc_setCenter), METH_VARARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QConicalGradient__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QConicalGradient_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QConicalGradient_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QConicalGradient_Type = nullptr;
static PyTypeObject *Sbk_QConicalGradient_TypeF(void)
{
    return _Sbk_QConicalGradient_Type;
}

static PyType_Slot Sbk_QConicalGradient_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QConicalGradient_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QConicalGradient_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QConicalGradient_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QConicalGradient_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QConicalGradient_spec = {
    "2:PySide6.QtGui.QConicalGradient",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QConicalGradient_slots
};

} //extern "C"

static void *Sbk_QConicalGradient_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QGradient *>(cptr)->type() == QGradient::ConicalGradient)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QConicalGradient_PythonToCpp_QConicalGradient_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QConicalGradient_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QConicalGradient_PythonToCpp_QConicalGradient_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QConicalGradient_TypeF()))
        return QConicalGradient_PythonToCpp_QConicalGradient_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QConicalGradient_PTR_CppToPython_QConicalGradient(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QConicalGradient_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QConicalGradient_COPY_CppToPython_QConicalGradient(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QConicalGradient *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QConicalGradient_TypeF(), new ::QConicalGradient(*source), true, true);
}

// Python to C++ copy conversion.
static void QConicalGradient_PythonToCpp_QConicalGradient_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QConicalGradient *>(cppOut) = *reinterpret_cast< ::QConicalGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QConicalGradient_PythonToCpp_QConicalGradient_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QConicalGradient_TypeF()))
        return QConicalGradient_PythonToCpp_QConicalGradient_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QConicalGradient_SignatureStrings[] = {
    "3:PySide6.QtGui.QConicalGradient(self)",
    "2:PySide6.QtGui.QConicalGradient(self,QConicalGradient:PySide6.QtGui.QConicalGradient)",
    "1:PySide6.QtGui.QConicalGradient(self,center:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],startAngle:qreal)",
    "0:PySide6.QtGui.QConicalGradient(self,cx:qreal,cy:qreal,startAngle:qreal)",
    "PySide6.QtGui.QConicalGradient.angle(self)->qreal",
    "PySide6.QtGui.QConicalGradient.center(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QConicalGradient.setAngle(self,angle:qreal)",
    "1:PySide6.QtGui.QConicalGradient.setCenter(self,center:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "0:PySide6.QtGui.QConicalGradient.setCenter(self,x:qreal,y:qreal)",
    "PySide6.QtGui.QConicalGradient.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QConicalGradient_SignatureByteSize = 219;
static constexpr uint8_t QConicalGradient_SignatureBytes[219] = {
    0x78, 0xda, 0xbd, 0x51, 0x4d, 0x0b, 0x82, 0x40, 0x10, 0xbd, 0xfb, 0x2b, 0x3a, 0x26, 0xd8, 0xd2,
    0x07, 0x74, 0xf0, 0x10, 0x84, 0x94, 0x57, 0x45, 0x3a, 0x45, 0x2c, 0x8b, 0x4d, 0xb6, 0xb0, 0xed,
    0xda, 0xba, 0x41, 0xfb, 0xef, 0x53, 0x57, 0x51, 0x4c, 0x5a, 0x4f, 0xdd, 0x66, 0x86, 0x79, 0x6f,
    0xde, 0xbc, 0xb7, 0xf1, 0x23, 0x9d, 0xd0, 0x2b, 0x6c, 0x51, 0xac, 0xc2, 0x17, 0x45, 0x71, 0x20,
    0x38, 0x4d, 0x09, 0x0b, 0x25, 0xb9, 0x52, 0xe0, 0x6a, 0x5e, 0x00, 0xbb, 0xb9, 0xce, 0x7a, 0xca,
    0x9a, 0x37, 0x9c, 0x5a, 0x40, 0xae, 0xb3, 0x9a, 0x44, 0x9b, 0x96, 0x15, 0x48, 0x5f, 0xe9, 0x9c,
    0xf2, 0x0c, 0x9d, 0x38, 0x15, 0xfc, 0xdc, 0xe1, 0x02, 0x21, 0x01, 0xc5, 0x91, 0xa0, 0x5c, 0x1d,
    0xbd, 0xd9, 0xe8, 0xbc, 0x3f, 0xae, 0xcf, 0x44, 0x84, 0x56, 0x94, 0x11, 0x51, 0x77, 0x74, 0x60,
    0xf0, 0x28, 0x0f, 0x5c, 0xbc, 0x42, 0x11, 0xa9, 0xf6, 0x3c, 0x63, 0xe0, 0x3f, 0x25, 0x10, 0xe6,
    0x3a, 0xcb, 0x69, 0xf2, 0xde, 0x66, 0xdf, 0x4b, 0x75, 0x53, 0x7c, 0x33, 0xfd, 0xe6, 0x41, 0xa4,
    0xda, 0x35, 0x56, 0x2f, 0x76, 0x35, 0xc4, 0x86, 0x30, 0x9e, 0xb4, 0x90, 0x71, 0x37, 0x6c, 0x1c,
    0x05, 0x18, 0x91, 0xe6, 0x0d, 0xd2, 0xd7, 0x6b, 0x0b, 0xa6, 0xc2, 0x06, 0x9d, 0x84, 0x3f, 0x45,
    0x64, 0x4f, 0x64, 0xa8, 0xab, 0x8d, 0x46, 0x4f, 0x0c, 0x02, 0xe3, 0x54, 0xe4, 0x1a, 0xe3, 0xd6,
    0xd8, 0xe6, 0xa1, 0xa4, 0xec, 0x9c, 0x0f, 0x37, 0x3e, 0x21, 0x2f
};
#endif

PyTypeObject *init_QConicalGradient(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX].type;

    Shiboken::AutoDecRef Sbk_QConicalGradient_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]))));

    _Sbk_QConicalGradient_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QConicalGradient",
        "QConicalGradient",
        &Sbk_QConicalGradient_spec,
        &Shiboken::callCppDestructor< ::QConicalGradient >,
        Sbk_QConicalGradient_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QConicalGradient_TypeF(); // references _Sbk_QConicalGradient_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QConicalGradient_SignatureStrings);
#else
    InitSignatureBytes(pyType, QConicalGradient_SignatureBytes, QConicalGradient_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QConicalGradient_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QConicalGradient_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QConicalGradient_PythonToCpp_QConicalGradient_PTR,
        is_QConicalGradient_PythonToCpp_QConicalGradient_PTR_Convertible,
        QConicalGradient_PTR_CppToPython_QConicalGradient,
        QConicalGradient_COPY_CppToPython_QConicalGradient);

    Shiboken::Conversions::registerConverterName(converter, "QConicalGradient");
    Shiboken::Conversions::registerConverterName(converter, "QConicalGradient*");
    Shiboken::Conversions::registerConverterName(converter, "QConicalGradient&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QConicalGradient).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QConicalGradient_PythonToCpp_QConicalGradient_COPY,
        is_QConicalGradient_PythonToCpp_QConicalGradient_COPY_Convertible);

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QConicalGradient_TypeF(), &Sbk_QConicalGradient_typeDiscovery);

    qRegisterMetaType< ::QConicalGradient >("QConicalGradient");

    return pyType;
}
