// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qcontextmenuevent_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <QtGui/qinputdevice.h>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QContextMenuEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QContextMenuEventWrapper::QContextMenuEventWrapper(::QContextMenuEvent::Reason reason, const ::QPoint & pos) : QContextMenuEvent(reason, pos)
{
}

QContextMenuEventWrapper::QContextMenuEventWrapper(::QContextMenuEvent::Reason reason, const ::QPoint & pos, const ::QPoint & globalPos, ::QFlags<Qt::KeyboardModifier> modifiers) : QContextMenuEvent(reason, pos, globalPos, modifiers)
{
}

::QContextMenuEvent * QContextMenuEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QContextMenuEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QContextMenuEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QContextMenuEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QContextMenuEvent", funcName, Shiboken::SbkType< QContextMenuEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QContextMenuEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QContextMenuEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QContextMenuEvent", funcName);
        return;
    }
}

void QContextMenuEventWrapper::setTimestamp(quint64 timestamp)
{
    if (m_PyMethodCache[2]) {
        return this->::QInputEvent::setTimestamp(timestamp);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setTimestamp";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QInputEvent::setTimestamp(timestamp);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &timestamp)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(K)",
        timestamp
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QContextMenuEvent", funcName);
        return;
    }
}

QContextMenuEventWrapper::~QContextMenuEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QContextMenuEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QContextMenuEvent >()))
        return -1;

    QContextMenuEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:QContextMenuEvent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QContextMenuEvent::QContextMenuEvent(QContextMenuEvent::Reason,QPoint)
    // 1: QContextMenuEvent::QContextMenuEvent(QContextMenuEvent::Reason,QPoint,QPoint,QFlags<Qt::KeyboardModifier>=)
    // 2: QContextMenuEvent::QContextMenuEvent(QContextMenuEvent)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QContextMenuEvent(QContextMenuEvent)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_Reason_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // QContextMenuEvent(QContextMenuEvent::Reason,QPoint)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // QContextMenuEvent(QContextMenuEvent::Reason,QPoint,QPoint,QFlags<Qt::KeyboardModifier>)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[3])))) {
                overloadId = 1; // QContextMenuEvent(QContextMenuEvent::Reason,QPoint,QPoint,QFlags<Qt::KeyboardModifier>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QContextMenuEvent(QContextMenuEvent::Reason reason, const QPoint &pos)
        {
            Shiboken::Warnings::warnDeprecated("QContextMenuEvent", "QContextMenuEvent(QContextMenuEvent.Reason reason, const QPoint &pos)");
            if (Shiboken::Errors::occurred() != nullptr)
                return -1;
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]);
            }
            ::QContextMenuEvent::Reason cppArg0{QContextMenuEvent::Mouse};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPoint cppArg1_local;
            ::QPoint *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QContextMenuEvent(QContextMenuEvent::Reason,QPoint)
                cptr = new QContextMenuEventWrapper(cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // QContextMenuEvent(QContextMenuEvent::Reason reason, const QPoint &pos, const QPoint &globalPos, QFlags<Qt::KeyboardModifier> modifiers)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifiers = Shiboken::String::createStaticString("modifiers");
                if (PyDict_Contains(kwds, key_modifiers) != 0) {
                    value = PyDict_GetItem(kwds, key_modifiers);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_modifiers);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifiers);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]);
                }
            }
            ::QContextMenuEvent::Reason cppArg0{QContextMenuEvent::Mouse};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPoint cppArg1_local;
            ::QPoint *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QPoint cppArg2_local;
            ::QPoint *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            ::QFlags<Qt::KeyboardModifier> cppArg3(Qt::NoModifier);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QContextMenuEvent(QContextMenuEvent::Reason,QPoint,QPoint,QFlags<Qt::KeyboardModifier>)
                cptr = new QContextMenuEventWrapper(cppArg0, *cppArg1, *cppArg2, cppArg3);
            }
            break;
        }
        case 2: // QContextMenuEvent(const QContextMenuEvent &arg__1)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QContextMenuEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QContextMenuEvent(QContextMenuEvent)
                cptr = new QContextMenuEventWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QContextMenuEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QContextMenuEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clone()const
        QContextMenuEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QContextMenuEvent *>(cppSelf)->::QContextMenuEvent::clone()
            : const_cast<const ::QContextMenuEvent *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QContextMenuEventFunc_globalPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // globalPos()const
        const QPoint & cppResult = const_cast<const ::QContextMenuEvent *>(cppSelf)->globalPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QContextMenuEventFunc_globalX(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // globalX()const
        int cppResult = const_cast<const ::QContextMenuEvent *>(cppSelf)->globalX();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QContextMenuEventFunc_globalY(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // globalY()const
        int cppResult = const_cast<const ::QContextMenuEvent *>(cppSelf)->globalY();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QContextMenuEventFunc_pos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pos()const
        const QPoint & cppResult = const_cast<const ::QContextMenuEvent *>(cppSelf)->pos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QContextMenuEventFunc_reason(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reason()const
        QContextMenuEvent::Reason cppResult = const_cast<const ::QContextMenuEvent *>(cppSelf)->reason();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_Reason_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QContextMenuEventFunc_x(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // x()const
        int cppResult = const_cast<const ::QContextMenuEvent *>(cppSelf)->x();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QContextMenuEventFunc_y(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // y()const
        int cppResult = const_cast<const ::QContextMenuEvent *>(cppSelf)->y();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QContextMenuEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QContextMenuEvent_EnumFlagInfo[] = {
    "Reason:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QContextMenuEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QContextMenuEventFunc_clone), METH_NOARGS, nullptr},
    {"globalPos", reinterpret_cast<PyCFunction>(Sbk_QContextMenuEventFunc_globalPos), METH_NOARGS, nullptr},
    {"globalX", reinterpret_cast<PyCFunction>(Sbk_QContextMenuEventFunc_globalX), METH_NOARGS, nullptr},
    {"globalY", reinterpret_cast<PyCFunction>(Sbk_QContextMenuEventFunc_globalY), METH_NOARGS, nullptr},
    {"pos", reinterpret_cast<PyCFunction>(Sbk_QContextMenuEventFunc_pos), METH_NOARGS, nullptr},
    {"reason", reinterpret_cast<PyCFunction>(Sbk_QContextMenuEventFunc_reason), METH_NOARGS, nullptr},
    {"x", reinterpret_cast<PyCFunction>(Sbk_QContextMenuEventFunc_x), METH_NOARGS, nullptr},
    {"y", reinterpret_cast<PyCFunction>(Sbk_QContextMenuEventFunc_y), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QContextMenuEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QContextMenuEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QContextMenuEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QContextMenuEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QContextMenuEvent_Type = nullptr;
static PyTypeObject *Sbk_QContextMenuEvent_TypeF(void)
{
    return _Sbk_QContextMenuEvent_Type;
}

static PyType_Slot Sbk_QContextMenuEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QContextMenuEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QContextMenuEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QContextMenuEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QContextMenuEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QContextMenuEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QContextMenuEvent_spec = {
    "2:PySide6.QtGui.QContextMenuEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QContextMenuEvent_slots
};

} //extern "C"

static void *Sbk_QContextMenuEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::ContextMenu)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QContextMenuEvent_Reason(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QContextMenuEvent::Reason>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QContextMenuEvent::Reason *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QContextMenuEvent_Reason_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_Reason_IDX])))
        return Enum_PythonToCpp_QContextMenuEvent_Reason;
    return {};
}

static PyObject *QContextMenuEvent_Reason_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QContextMenuEvent::Reason>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QContextMenuEvent::Reason *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_Reason_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QContextMenuEvent_PythonToCpp_QContextMenuEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QContextMenuEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QContextMenuEvent_PythonToCpp_QContextMenuEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QContextMenuEvent_TypeF()))
        return QContextMenuEvent_PythonToCpp_QContextMenuEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QContextMenuEvent_PTR_CppToPython_QContextMenuEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QContextMenuEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QContextMenuEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QContextMenuEvent_SignatureStrings[] = {
    "2:PySide6.QtGui.QContextMenuEvent(self,reason:PySide6.QtGui.QContextMenuEvent.Reason,pos:PySide6.QtCore.QPoint)",
    "1:PySide6.QtGui.QContextMenuEvent(self,reason:PySide6.QtGui.QContextMenuEvent.Reason,pos:PySide6.QtCore.QPoint,globalPos:PySide6.QtCore.QPoint,modifiers:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier)",
    "0:PySide6.QtGui.QContextMenuEvent(self,arg__1:PySide6.QtGui.QContextMenuEvent)",
    "PySide6.QtGui.QContextMenuEvent.clone(self)->PySide6.QtGui.QContextMenuEvent",
    "PySide6.QtGui.QContextMenuEvent.globalPos(self)->PySide6.QtCore.QPoint",
    "PySide6.QtGui.QContextMenuEvent.globalX(self)->int",
    "PySide6.QtGui.QContextMenuEvent.globalY(self)->int",
    "PySide6.QtGui.QContextMenuEvent.pos(self)->PySide6.QtCore.QPoint",
    "PySide6.QtGui.QContextMenuEvent.reason(self)->PySide6.QtGui.QContextMenuEvent.Reason",
    "PySide6.QtGui.QContextMenuEvent.x(self)->int",
    "PySide6.QtGui.QContextMenuEvent.y(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QContextMenuEvent_SignatureByteSize = 193;
static constexpr uint8_t QContextMenuEvent_SignatureBytes[193] = {
    0x78, 0xda, 0x33, 0xb2, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x74, 0xce, 0xcf, 0x2b, 0x49, 0xad, 0x28, 0xf1, 0x4d, 0xcd, 0x2b, 0x75, 0x2d,
    0x4b, 0xcd, 0x2b, 0xd1, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0x29, 0x4a, 0x4d, 0x2c, 0xce, 0xcf, 0x23,
    0xa4, 0x56, 0x2f, 0x08, 0xac, 0x4c, 0xa7, 0x20, 0xbf, 0x18, 0x49, 0xa9, 0x73, 0x7e, 0x51, 0xaa,
    0x5e, 0x60, 0x40, 0x7e, 0x66, 0x5e, 0x89, 0x26, 0x97, 0x21, 0x5d, 0xed, 0xd3, 0x49, 0xcf, 0xc9,
    0x4f, 0x4a, 0xcc, 0x09, 0xc0, 0x29, 0x9f, 0x9b, 0x9f, 0x92, 0x99, 0x96, 0x99, 0x5a, 0x84, 0x29,
    0x5f, 0xa2, 0xe7, 0x9d, 0x5a, 0x99, 0x94, 0x9f, 0x58, 0x94, 0xe2, 0x0b, 0x55, 0x63, 0x0b, 0x14,
    0xf3, 0xcb, 0x87, 0xf1, 0x34, 0xb9, 0x0c, 0x88, 0xf3, 0x4a, 0x62, 0x51, 0x7a, 0x7c, 0x3c, 0x41,
    0x6f, 0x6b, 0x72, 0x11, 0xf2, 0x6b, 0x72, 0x4e, 0x7e, 0x5e, 0x2a, 0xd8, 0x48, 0x4d, 0x5d, 0x3b,
    0x02, 0x8a, 0x09, 0x1a, 0x06, 0x0f, 0x17, 0x4c, 0x03, 0x91, 0x82, 0x87, 0x48, 0x63, 0x22, 0x60,
    0x86, 0x10, 0xaf, 0x25, 0x92, 0x14, 0x2d, 0x05, 0x94, 0x3a, 0x13, 0x92, 0x9a, 0x88, 0x0c, 0x3b,
    0x68, 0xa2, 0x22, 0x68, 0x68, 0x05, 0x29, 0x5e, 0xa8, 0x44, 0x56, 0x0c, 0x00, 0x84, 0xa4, 0x3e,
    0x16
};
#endif

PyTypeObject *init_QContextMenuEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QContextMenuEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]))));

    _Sbk_QContextMenuEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QContextMenuEvent",
        "QContextMenuEvent*",
        &Sbk_QContextMenuEvent_spec,
        &Shiboken::callCppDestructor< QContextMenuEvent >,
        Sbk_QContextMenuEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QContextMenuEvent_TypeF(); // references _Sbk_QContextMenuEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QContextMenuEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QContextMenuEvent_SignatureBytes, QContextMenuEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QContextMenuEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QContextMenuEvent_PythonToCpp_QContextMenuEvent_PTR,
        is_QContextMenuEvent_PythonToCpp_QContextMenuEvent_PTR_Convertible,
        QContextMenuEvent_PTR_CppToPython_QContextMenuEvent);

    Shiboken::Conversions::registerConverterName(converter, "QContextMenuEvent");
    Shiboken::Conversions::registerConverterName(converter, "QContextMenuEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QContextMenuEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QContextMenuEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QContextMenuEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QContextMenuEvent_TypeF(), &Sbk_QContextMenuEvent_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QContextMenuEvent_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Reason'.
    const char *Reason_Initializer[] = {
        "Mouse",
        "Keyboard",
        "Other",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Reason_InitializerValues[] = {
        uint8_t(QContextMenuEvent::Reason::Mouse),    //  0x00  0
        uint8_t(QContextMenuEvent::Reason::Keyboard), //  0x01  1
        uint8_t(QContextMenuEvent::Reason::Other)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QContextMenuEvent_TypeF(),
        "2:PySide6.QtGui.QContextMenuEvent.Reason",
        Reason_Initializer, Reason_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_Reason_IDX].type = EType;
    // Register converter for enum 'QContextMenuEvent::Reason'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QContextMenuEvent_Reason_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QContextMenuEvent_Reason,
            is_Enum_PythonToCpp_QContextMenuEvent_Reason_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QContextMenuEvent::Reason");
        Shiboken::Conversions::registerConverterAlias(converter, "Reason");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Reason' enum.

    qRegisterMetaType< ::QContextMenuEvent::Reason >("QContextMenuEvent::Reason");

    return pyType;
}
