// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qcursor_wrapper.h"

// Extra includes
#include <QPixmap>
#include <Qt>

// Argument includes
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qscreen.h>
#include <qdatastream.h>
#include <qnamespace.h>
#include <qpoint.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCursor_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCursor >()))
        return -1;

    ::QCursor *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:QCursor", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCursor::QCursor()
    // 1: QCursor::QCursor(Qt::CursorShape)
    // 2: QCursor::QCursor(QBitmap,QBitmap,int=,int=)
    // 3: QCursor::QCursor(QCursor)
    // 4: QCursor::QCursor(QPixmap,int=,int=)
    if (numArgs == 0) {
        overloadId = 0; // QCursor()
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBitmap_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBitmap_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // QCursor(QBitmap,QBitmap,int,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 2; // QCursor(QBitmap,QBitmap,int,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                overloadId = 2; // QCursor(QBitmap,QBitmap,int,int)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 4; // QCursor(QPixmap,int,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 4; // QCursor(QPixmap,int,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 4; // QCursor(QPixmap,int,int)
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CursorShape_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // QCursor(Qt::CursorShape)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QCursor(QCursor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QCursor()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);
            }

            // QCursor()
            cptr = new ::QCursor();
            break;
        }
        case 1: // QCursor(Qt::CursorShape shape)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);
            }
            ::Qt::CursorShape cppArg0{Qt::ArrowCursor};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCursor(Qt::CursorShape)
                cptr = new ::QCursor(cppArg0);
            }
            break;
        }
        case 2: // QCursor(const QBitmap &bitmap, const QBitmap &mask, int hotX, int hotY)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_hotX = Shiboken::String::createStaticString("hotX");
                if (PyDict_Contains(kwds, key_hotX) != 0) {
                    value = PyDict_GetItem(kwds, key_hotX);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_hotX);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_hotX);
                }
                static PyObject *const key_hotY = Shiboken::String::createStaticString("hotY");
                if (PyDict_Contains(kwds, key_hotY) != 0) {
                    value = PyDict_GetItem(kwds, key_hotY);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_hotY);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_hotY);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBitmap cppArg0_local;
            ::QBitmap *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QBitmap cppArg1_local;
            ::QBitmap *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            int cppArg2 = -1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCursor(QBitmap,QBitmap,int,int)
                cptr = new ::QCursor(*cppArg0, *cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 3: // QCursor(const QCursor &cursor)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QCursor cppArg0_local;
            ::QCursor *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCursor(QCursor)
                cptr = new ::QCursor(*cppArg0);
            }
            break;
        }
        case 4: // QCursor(const QPixmap &pixmap, int hotX, int hotY)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_hotX = Shiboken::String::createStaticString("hotX");
                if (PyDict_Contains(kwds, key_hotX) != 0) {
                    value = PyDict_GetItem(kwds, key_hotX);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_hotX);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_hotX);
                }
                static PyObject *const key_hotY = Shiboken::String::createStaticString("hotY");
                if (PyDict_Contains(kwds, key_hotY) != 0) {
                    value = PyDict_GetItem(kwds, key_hotY);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_hotY);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_hotY);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPixmap cppArg0_local;
            ::QPixmap *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1 = -1;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = -1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCursor(QPixmap,int,int)
                cptr = new ::QCursor(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCursor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCursorFunc_bitmap(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "bitmap", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCursor::bitmap()const->QBitmap
    // 1: QCursor::bitmap(Qt::ReturnByValueConstant)const->QBitmap
    if (numArgs == 0) {
        overloadId = 0; // bitmap()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ReturnByValueConstant_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // bitmap(Qt::ReturnByValueConstant)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "bitmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // bitmap() const
        {

            // bitmap()const
            QBitmap cppResult = const_cast<const ::QCursor *>(cppSelf)->bitmap();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBitmap_IDX]), &cppResult);
            break;
        }
        case 1: // bitmap(Qt::ReturnByValueConstant arg__1) const
        {
            Shiboken::Warnings::warnDeprecated("QCursor", "bitmap(Qt.ReturnByValueConstant arg__1) const");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            ::Qt::ReturnByValueConstant cppArg0{Qt::ReturnByValue};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bitmap(Qt::ReturnByValueConstant)const
                QBitmap cppResult = const_cast<const ::QCursor *>(cppSelf)->bitmap(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBitmap_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCursorFunc_hotSpot(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hotSpot()const
        QPoint cppResult = const_cast<const ::QCursor *>(cppSelf)->hotSpot();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCursorFunc_mask(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "mask", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCursor::mask()const->QBitmap
    // 1: QCursor::mask(Qt::ReturnByValueConstant)const->QBitmap
    if (numArgs == 0) {
        overloadId = 0; // mask()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ReturnByValueConstant_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // mask(Qt::ReturnByValueConstant)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mask", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // mask() const
        {

            // mask()const
            QBitmap cppResult = const_cast<const ::QCursor *>(cppSelf)->mask();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBitmap_IDX]), &cppResult);
            break;
        }
        case 1: // mask(Qt::ReturnByValueConstant arg__1) const
        {
            Shiboken::Warnings::warnDeprecated("QCursor", "mask(Qt.ReturnByValueConstant arg__1) const");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            ::Qt::ReturnByValueConstant cppArg0{Qt::ReturnByValue};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mask(Qt::ReturnByValueConstant)const
                QBitmap cppResult = const_cast<const ::QCursor *>(cppSelf)->mask(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBitmap_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCursorFunc_pixmap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pixmap()const
        QPixmap cppResult = const_cast<const ::QCursor *>(cppSelf)->pixmap();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCursorFunc_pos(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "pos", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QCursor::pos()->QPoint
    // 1: static QCursor::pos(const QScreen*)->QPoint
    if (numArgs == 0) {
        overloadId = 0; // pos()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), (pyArgs[0])))) {
        overloadId = 1; // pos(const QScreen*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "pos", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // pos()
        {

            // pos()
            QPoint cppResult = ::QCursor::pos();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
            break;
        }
        case 1: // pos(const QScreen *screen)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QScreen *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // pos(const QScreen*)
                QPoint cppResult = ::QCursor::pos(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCursorFunc_setPos(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setPos", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QCursor::setPos(QScreen*,QPoint)
    // 1: static QCursor::setPos(QScreen*,int,int)
    // 2: static QCursor::setPos(QPoint)
    // 3: static QCursor::setPos(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 3; // setPos(int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))) {
        overloadId = 2; // setPos(QPoint)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), (pyArgs[0])))) {
        if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 1; // setPos(QScreen*,int,int)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[1])))) {
            overloadId = 0; // setPos(QScreen*,QPoint)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPos", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setPos(QScreen *screen, const QPoint &p)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QScreen *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPoint cppArg1_local;
            ::QPoint *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setPos(QScreen*,QPoint)
                ::QCursor::setPos(cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // setPos(QScreen *screen, int x, int y)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QScreen *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setPos(QScreen*,int,int)
                ::QCursor::setPos(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 2: // setPos(const QPoint &p)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setPos(QPoint)
                ::QCursor::setPos(*cppArg0);
            }
            break;
        }
        case 3: // setPos(int x, int y)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setPos(int,int)
                ::QCursor::setPos(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCursorFunc_setShape(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCursor::setShape(Qt::CursorShape)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CursorShape_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setShape(Qt::CursorShape)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShape", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);

    // Call function/method
    {
        ::Qt::CursorShape cppArg0{Qt::ArrowCursor};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShape(Qt::CursorShape)
            cppSelf->setShape(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCursorFunc_shape(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shape()const
        Qt::CursorShape cppResult = const_cast<const ::QCursor *>(cppSelf)->shape();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CursorShape_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCursorFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCursor::swap(QCursor&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QCursor&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCursor cppArg0_local;
        ::QCursor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QCursor&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCursor__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCursor_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCursor_methods[] = {
    {"bitmap", reinterpret_cast<PyCFunction>(Sbk_QCursorFunc_bitmap), METH_VARARGS, nullptr},
    {"hotSpot", reinterpret_cast<PyCFunction>(Sbk_QCursorFunc_hotSpot), METH_NOARGS, nullptr},
    {"mask", reinterpret_cast<PyCFunction>(Sbk_QCursorFunc_mask), METH_VARARGS, nullptr},
    {"pixmap", reinterpret_cast<PyCFunction>(Sbk_QCursorFunc_pixmap), METH_NOARGS, nullptr},
    {"pos", reinterpret_cast<PyCFunction>(Sbk_QCursorFunc_pos), METH_VARARGS|METH_STATIC, nullptr},
    {"setPos", reinterpret_cast<PyCFunction>(Sbk_QCursorFunc_setPos), METH_VARARGS|METH_STATIC, nullptr},
    {"setShape", reinterpret_cast<PyCFunction>(Sbk_QCursorFunc_setShape), METH_O, nullptr},
    {"shape", reinterpret_cast<PyCFunction>(Sbk_QCursorFunc_shape), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QCursorFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QCursor__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QCursorFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QCursor::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QCursor)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QCursor) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCursorFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QCursor::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QCursor&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QCursor&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QCursor_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), (pyArg)))) {
                // operator!=(const QCursor &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCursor cppArg0_local;
                ::QCursor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QCursor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCursor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QCursor__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCursor_Type = nullptr;
static PyTypeObject *Sbk_QCursor_TypeF(void)
{
    return _Sbk_QCursor_Type;
}

static PyType_Slot Sbk_QCursor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QCursor__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCursor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCursor_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QCursor_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCursor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCursor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QCursorFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QCursorFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCursor_spec = {
    "2:PySide6.QtGui.QCursor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCursor_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCursor_PythonToCpp_QCursor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCursor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCursor_PythonToCpp_QCursor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCursor_TypeF()))
        return QCursor_PythonToCpp_QCursor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCursor_PTR_CppToPython_QCursor(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QCursor_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QCursor_COPY_CppToPython_QCursor(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QCursor *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QCursor_TypeF(), new ::QCursor(*source), true, true);
}

// Python to C++ copy conversion.
static void QCursor_PythonToCpp_QCursor_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QCursor *>(cppOut) = *reinterpret_cast< ::QCursor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QCursor_PythonToCpp_QCursor_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QCursor_TypeF()))
        return QCursor_PythonToCpp_QCursor_COPY;
    return {};
}

// Implicit conversions.
static void PySide6_QtCore_Qt_CursorShape_PythonToCpp_QCursor(PyObject *pyIn, void *cppOut)
{
    ::Qt::CursorShape cppIn{Qt::ArrowCursor};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CursorShape_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QCursor *>(cppOut) = ::QCursor(cppIn);
}
static PythonToCppFunc is_PySide6_QtCore_Qt_CursorShape_PythonToCpp_QCursor_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CursorShape_IDX]), pyIn))
        return PySide6_QtCore_Qt_CursorShape_PythonToCpp_QCursor;
    return {};
}

static void constQPixmapREF_PythonToCpp_QCursor(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QCursor *>(cppOut) = ::QCursor( *reinterpret_cast< ::QPixmap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQPixmapREF_PythonToCpp_QCursor_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), pyIn))
        return constQPixmapREF_PythonToCpp_QCursor;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCursor_SignatureStrings[] = {
    "4:PySide6.QtGui.QCursor(self)",
    "3:PySide6.QtGui.QCursor(self,shape:PySide6.QtCore.Qt.CursorShape)",
    "2:PySide6.QtGui.QCursor(self,bitmap:typing.Union[PySide6.QtGui.QBitmap, QString],mask:typing.Union[PySide6.QtGui.QBitmap, QString],hotX:int=-1,hotY:int=-1)",
    "1:PySide6.QtGui.QCursor(self,cursor:PySide6.QtGui.QCursor)",
    "0:PySide6.QtGui.QCursor(self,pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage],hotX:int=-1,hotY:int=-1)",
    "1:PySide6.QtGui.QCursor.bitmap(self)->PySide6.QtGui.QBitmap",
    "0:PySide6.QtGui.QCursor.bitmap(self,arg__1:PySide6.QtCore.Qt.ReturnByValueConstant)->PySide6.QtGui.QBitmap",
    "PySide6.QtGui.QCursor.hotSpot(self)->PySide6.QtCore.QPoint",
    "1:PySide6.QtGui.QCursor.mask(self)->PySide6.QtGui.QBitmap",
    "0:PySide6.QtGui.QCursor.mask(self,arg__1:PySide6.QtCore.Qt.ReturnByValueConstant)->PySide6.QtGui.QBitmap",
    "PySide6.QtGui.QCursor.pixmap(self)->PySide6.QtGui.QPixmap",
    "1:PySide6.QtGui.QCursor.pos()->PySide6.QtCore.QPoint",
    "0:PySide6.QtGui.QCursor.pos(screen:PySide6.QtGui.QScreen)->PySide6.QtCore.QPoint",
    "3:PySide6.QtGui.QCursor.setPos(screen:PySide6.QtGui.QScreen,p:PySide6.QtCore.QPoint)",
    "2:PySide6.QtGui.QCursor.setPos(screen:PySide6.QtGui.QScreen,x:int,y:int)",
    "1:PySide6.QtGui.QCursor.setPos(p:PySide6.QtCore.QPoint)",
    "0:PySide6.QtGui.QCursor.setPos(x:int,y:int)",
    "PySide6.QtGui.QCursor.setShape(self,newShape:PySide6.QtCore.Qt.CursorShape)",
    "PySide6.QtGui.QCursor.shape(self)->PySide6.QtCore.Qt.CursorShape",
    "PySide6.QtGui.QCursor.swap(self,other:typing.Union[PySide6.QtGui.QCursor, PySide6.QtCore.Qt.CursorShape, PySide6.QtGui.QPixmap])",
    "PySide6.QtGui.QCursor.__copy__(self)->typing.Self",
    "PySide6.QtGui.QCursor.__lshift__(self,outS:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QCursor.__rshift__(self,inS:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QCursor.__ne__(self,rhs:typing.Union[PySide6.QtGui.QCursor, PySide6.QtCore.Qt.CursorShape, PySide6.QtGui.QPixmap])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QCursor_SignatureByteSize = 404;
static constexpr uint8_t QCursor_SignatureBytes[404] = {
    0x78, 0xda, 0xb5, 0x54, 0x5d, 0x4f, 0xc2, 0x30, 0x14, 0x7d, 0xdf, 0xaf, 0xe0, 0x91, 0x25, 0x65,
    0x61, 0x6a, 0x7c, 0x58, 0x22, 0x0f, 0x60, 0x62, 0x7c, 0x1b, 0x36, 0x1a, 0x8d, 0x21, 0x4b, 0xc1,
    0xc2, 0x1a, 0xb7, 0xb6, 0x69, 0xbb, 0xc0, 0xfe, 0xbd, 0xdb, 0x0a, 0xc8, 0x47, 0xef, 0x00, 0x23,
    0x4f, 0xeb, 0xda, 0x73, 0xce, 0xbd, 0xe7, 0xde, 0xf6, 0xde, 0x45, 0x71, 0x89, 0xd9, 0x17, 0xbd,
    0x0f, 0xc6, 0xe6, 0xa9, 0x60, 0xc1, 0x78, 0x54, 0x28, 0x2d, 0x54, 0x57, 0xd3, 0x6c, 0xee, 0x7b,
    0xb7, 0x2d, 0xa7, 0x48, 0xa7, 0x44, 0xd2, 0x1d, 0xc0, 0x48, 0x28, 0x5a, 0x7d, 0x02, 0x8b, 0xc1,
    0xf5, 0xa9, 0xef, 0xdd, 0xb4, 0x29, 0x4c, 0x99, 0xc9, 0x89, 0x8c, 0x4c, 0x29, 0x19, 0x5f, 0x04,
    0xaf, 0x9c, 0x09, 0xfe, 0x79, 0x00, 0x1f, 0x36, 0x10, 0xd4, 0x19, 0x63, 0xa3, 0x2a, 0xd0, 0x04,
    0xe5, 0x44, 0x7f, 0x5f, 0xc6, 0x48, 0x85, 0x79, 0x8f, 0x18, 0x37, 0x0f, 0xbd, 0xb0, 0x5e, 0x7f,
    0xac, 0xd7, 0xbe, 0x17, 0xb6, 0xe5, 0x36, 0x6b, 0xd6, 0x6e, 0x84, 0xef, 0xf5, 0xdb, 0xa8, 0x92,
    0xad, 0x4e, 0xd9, 0x8a, 0x1b, 0x08, 0xea, 0x1c, 0x6c, 0x3f, 0xe7, 0x64, 0x41, 0x2f, 0xcf, 0x38,
    0xb0, 0x85, 0xb4, 0x4d, 0xeb, 0x0d, 0x9c, 0x05, 0x81, 0x52, 0xde, 0xe5, 0x22, 0xa2, 0x16, 0x49,
    0x12, 0x3a, 0x7a, 0xfa, 0x42, 0x4d, 0xa1, 0xf8, 0xb0, 0x7c, 0x23, 0x59, 0x41, 0x47, 0x82, 0x6b,
    0x43, 0xb8, 0x01, 0x43, 0xb9, 0x03, 0x55, 0x4e, 0xb0, 0x14, 0xe6, 0x38, 0x4b, 0x1b, 0x24, 0x16,
    0x95, 0x4b, 0xd0, 0x61, 0xdd, 0xf6, 0xbf, 0xf9, 0xdb, 0x32, 0xaf, 0xeb, 0xce, 0x36, 0x1d, 0x48,
    0xd1, 0xb6, 0x1b, 0x34, 0x27, 0x85, 0xee, 0x82, 0x15, 0xe9, 0xb7, 0x90, 0xf4, 0x4c, 0x51, 0xca,
    0x0f, 0x01, 0xb8, 0xd9, 0x05, 0x05, 0x81, 0x47, 0x1d, 0x68, 0x6a, 0xe2, 0x13, 0x9a, 0x48, 0x46,
    0x4e, 0x4d, 0xf0, 0x9d, 0x9f, 0x25, 0xba, 0xaa, 0xef, 0x37, 0x2a, 0xa3, 0x46, 0x28, 0x6c, 0x17,
    0x02, 0x13, 0xe8, 0xb7, 0xf3, 0xf6, 0x62, 0x80, 0xc8, 0x66, 0x68, 0xd9, 0xcb, 0xc2, 0xe9, 0x12,
    0x9f, 0x33, 0xe0, 0x00, 0xad, 0xad, 0x90, 0xa3, 0x0d, 0x7b, 0x0a, 0x90, 0xc0, 0x72, 0xf3, 0x26,
    0x85, 0x49, 0xa9, 0x6a, 0x1d, 0x26, 0x96, 0xb2, 0x3b, 0x4c, 0x1c, 0x71, 0x8e, 0x66, 0x8d, 0xbd,
    0x93, 0x13, 0xc8, 0x41, 0x92, 0xcc, 0x84, 0x2c, 0x93, 0x64, 0x63, 0x62, 0x9d, 0x00, 0xae, 0xfe,
    0x40, 0x46, 0xa6, 0x53, 0x36, 0x37, 0x6b, 0x0e, 0x12, 0x85, 0xc1, 0x47, 0xd5, 0x7b, 0x24, 0x86,
    0x54, 0x83, 0x99, 0x92, 0xdc, 0x51, 0x98, 0xdf, 0x43, 0x30, 0x84, 0xda, 0x0b, 0xc1, 0xf8, 0xff,
    0x47, 0xe0, 0x74, 0xa3, 0xae, 0x52, 0x7d, 0xc5, 0xba, 0xf7, 0x06, 0x53, 0x21, 0x32, 0xef, 0x07,
    0x1a, 0x22, 0xa0, 0xe8
};
#endif

PyTypeObject *init_QCursor(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX].type;

    Shiboken::AutoDecRef Sbk_QCursor_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCursor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCursor",
        "QCursor",
        &Sbk_QCursor_spec,
        &Shiboken::callCppDestructor< ::QCursor >,
        Sbk_QCursor_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QCursor_TypeF(); // references _Sbk_QCursor_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCursor_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCursor_SignatureBytes, QCursor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCursor_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCursor_PythonToCpp_QCursor_PTR,
        is_QCursor_PythonToCpp_QCursor_PTR_Convertible,
        QCursor_PTR_CppToPython_QCursor,
        QCursor_COPY_CppToPython_QCursor);

    Shiboken::Conversions::registerConverterName(converter, "QCursor");
    Shiboken::Conversions::registerConverterName(converter, "QCursor*");
    Shiboken::Conversions::registerConverterName(converter, "QCursor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCursor).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QCursor_PythonToCpp_QCursor_COPY,
        is_QCursor_PythonToCpp_QCursor_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_Qt_CursorShape_PythonToCpp_QCursor,
        is_PySide6_QtCore_Qt_CursorShape_PythonToCpp_QCursor_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQPixmapREF_PythonToCpp_QCursor,
        is_constQPixmapREF_PythonToCpp_QCursor_Convertible);

    qRegisterMetaType< ::QCursor >("QCursor");

    return pyType;
}
