// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qdragenterevent_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <qmimedata.h>
#include <qpoint.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDragEnterEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QDragEnterEventWrapper::QDragEnterEventWrapper(const ::QPoint & pos, ::QFlags<Qt::DropAction> actions, const ::QMimeData * data, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers) : QDragEnterEvent(pos, actions, data, buttons, modifiers)
{
}

::QDragEnterEvent * QDragEnterEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QDragEnterEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QDragEnterEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDragEnterEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDragEnterEvent", funcName, Shiboken::SbkType< QDragEnterEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QDragEnterEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QDragEnterEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QDragEnterEvent", funcName);
        return;
    }
}

QDragEnterEventWrapper::~QDragEnterEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDragEnterEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDragEnterEvent >()))
        return -1;

    QDragEnterEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3 || numArgs == 4)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]);

    if (PyArg_UnpackTuple(args, "QDragEnterEvent", 1, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDragEnterEvent::QDragEnterEvent(QDragEnterEvent)
    // 1: QDragEnterEvent::QDragEnterEvent(QPoint,QFlags<Qt::DropAction>,const QMimeData*,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_DropAction_IDX])))->flagsConverter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MouseButton_IDX])))->flagsConverter, (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[4])))) {
        overloadId = 1; // QDragEnterEvent(QPoint,QFlags<Qt::DropAction>,const QMimeData*,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QDragEnterEvent(QDragEnterEvent)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDragEnterEvent(const QDragEnterEvent &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDragEnterEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDragEnterEvent(QDragEnterEvent)
                cptr = new QDragEnterEventWrapper(*cppArg0);
            }
            break;
        }
        case 1: // QDragEnterEvent(const QPoint &pos, QFlags<Qt::DropAction> actions, const QMimeData *data, QFlags<Qt::MouseButton> buttons, QFlags<Qt::KeyboardModifier> modifiers)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QFlags<Qt::DropAction> cppArg1 = QFlags<Qt::DropAction>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QMimeData *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<Qt::MouseButton> cppArg3 = QFlags<Qt::MouseButton>(0);
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QFlags<Qt::KeyboardModifier> cppArg4 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDragEnterEvent(QPoint,QFlags<Qt::DropAction>,const QMimeData*,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
                cptr = new QDragEnterEventWrapper(*cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QDragEnterEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDragEnterEventFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDragEnterEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - repr_qdebug_gui - START
        // TEMPLATE - repr_qdebug - START
        QString result;
        QDebug(&result).nospace() << "<PySide6.QtGui." << cppSelf << '>';
        pyResult = Shiboken::String::fromCString(qPrintable(result));
        // TEMPLATE - repr_qdebug - END
        // TEMPLATE - repr_qdebug_gui - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDragEnterEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDragEnterEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clone()const
        QDragEnterEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QDragEnterEvent *>(cppSelf)->::QDragEnterEvent::clone()
            : const_cast<const ::QDragEnterEvent *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDragEnterEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDragEnterEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QDragEnterEventFunc_clone), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDragEnterEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDragEnterEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDragEnterEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDragEnterEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDragEnterEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDragEnterEvent_Type = nullptr;
static PyTypeObject *Sbk_QDragEnterEvent_TypeF(void)
{
    return _Sbk_QDragEnterEvent_Type;
}

static PyType_Slot Sbk_QDragEnterEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QDragEnterEventFunc___repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDragEnterEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDragEnterEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDragEnterEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDragEnterEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDragEnterEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDragEnterEvent_spec = {
    "2:PySide6.QtGui.QDragEnterEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDragEnterEvent_slots
};

} //extern "C"

static void *Sbk_QDragEnterEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::DragEnter)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDragEnterEvent_PythonToCpp_QDragEnterEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDragEnterEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDragEnterEvent_PythonToCpp_QDragEnterEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDragEnterEvent_TypeF()))
        return QDragEnterEvent_PythonToCpp_QDragEnterEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDragEnterEvent_PTR_CppToPython_QDragEnterEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QDragEnterEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QDragEnterEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDragEnterEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QDragEnterEvent(self,arg__1:PySide6.QtGui.QDragEnterEvent)",
    "0:PySide6.QtGui.QDragEnterEvent(self,pos:PySide6.QtCore.QPoint,actions:PySide6.QtCore.Qt.DropAction,data:PySide6.QtCore.QMimeData,buttons:PySide6.QtCore.Qt.MouseButton,modifiers:PySide6.QtCore.Qt.KeyboardModifier)",
    "PySide6.QtGui.QDragEnterEvent.__repr__(self)->str",
    "PySide6.QtGui.QDragEnterEvent.clone(self)->PySide6.QtGui.QDragEnterEvent",
    nullptr}; // Sentinel
#else
static constexpr size_t QDragEnterEvent_SignatureByteSize = 168;
static constexpr uint8_t QDragEnterEvent_SignatureBytes[168] = {
    0x78, 0xda, 0x8d, 0xcf, 0xc1, 0x0a, 0x82, 0x40, 0x10, 0xc6, 0xf1, 0xbb, 0x4f, 0x92, 0xb0, 0x2d,
    0x79, 0xe9, 0xd0, 0x21, 0xa8, 0x94, 0x0e, 0x21, 0x28, 0x3d, 0xc0, 0xb2, 0xba, 0xa3, 0x2c, 0xe8,
    0x8e, 0xcc, 0x8e, 0x81, 0x6f, 0x5f, 0x2c, 0x05, 0x81, 0x62, 0x9d, 0xff, 0xbf, 0xf9, 0x60, 0x92,
    0x43, 0x31, 0xdd, 0xad, 0x81, 0xbd, 0x2c, 0xf9, 0x3a, 0x5a, 0x59, 0xa6, 0xa4, 0xdb, 0xcc, 0x31,
    0x50, 0xf6, 0x00, 0xc7, 0x1b, 0x0f, 0x5d, 0x23, 0x34, 0xb5, 0x4a, 0x25, 0xeb, 0x32, 0x8e, 0x76,
    0xff, 0x4c, 0x0d, 0xe8, 0xbf, 0xd8, 0x05, 0x09, 0x64, 0x59, 0xa0, 0x75, 0x2c, 0x74, 0xcd, 0x16,
    0xdd, 0xbc, 0xb2, 0x4c, 0x09, 0x87, 0x53, 0xa8, 0xc2, 0x68, 0xd6, 0x33, 0x91, 0xdb, 0x1e, 0xd2,
    0x57, 0x10, 0xd5, 0xc8, 0xbc, 0x3c, 0x91, 0xe3, 0xe8, 0xe1, 0x1c, 0xb2, 0xe8, 0xd1, 0xd8, 0xc6,
    0x02, 0x2d, 0xb9, 0x1b, 0x4c, 0x15, 0x6a, 0x32, 0xf9, 0xdb, 0xc4, 0xd1, 0xea, 0x4f, 0x52, 0x29,
    0x82, 0x81, 0x94, 0x0a, 0xcf, 0xc5, 0xdb, 0xa3, 0x67, 0xfa, 0x71, 0x51, 0x77, 0xe8, 0xe0, 0xc3,
    0x57, 0x69, 0xf4, 0x04, 0x21, 0x96, 0x92, 0xd1
};
#endif

PyTypeObject *init_QDragEnterEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QDragEnterEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragMoveEvent_IDX]))));

    _Sbk_QDragEnterEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDragEnterEvent",
        "QDragEnterEvent*",
        &Sbk_QDragEnterEvent_spec,
        &Shiboken::callCppDestructor< QDragEnterEvent >,
        Sbk_QDragEnterEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDragEnterEvent_TypeF(); // references _Sbk_QDragEnterEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDragEnterEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDragEnterEvent_SignatureBytes, QDragEnterEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDragEnterEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDragEnterEvent_PythonToCpp_QDragEnterEvent_PTR,
        is_QDragEnterEvent_PythonToCpp_QDragEnterEvent_PTR_Convertible,
        QDragEnterEvent_PTR_CppToPython_QDragEnterEvent);

    Shiboken::Conversions::registerConverterName(converter, "QDragEnterEvent");
    Shiboken::Conversions::registerConverterName(converter, "QDragEnterEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QDragEnterEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDragEnterEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QDragEnterEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QDragEnterEvent_TypeF(), &Sbk_QDragEnterEvent_typeDiscovery);


    return pyType;
}
