// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qeventpoint_wrapper.h"

// Argument includes
#include <QtGui/qeventpoint.h>
#include <QtGui/qpointingdevice.h>
#include <QtGui/qvectornd.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QEventPoint_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QEventPoint >()))
        return -1;

    ::QEventPoint *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);
    if (numArgs == 3)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:QEventPoint", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QEventPoint::QEventPoint(QEventPoint)
    // 1: QEventPoint::QEventPoint(int=,const QPointingDevice*=)
    // 2: QEventPoint::QEventPoint(int,QEventPoint::State,QPointF,QPointF)
    if (numArgs == 0) {
        overloadId = 1; // QEventPoint(int,const QPointingDevice*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QEventPoint(int,const QPointingDevice*)
        } else if (numArgs == 4
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_State_IDX])))->converter, (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[3])))) {
            overloadId = 2; // QEventPoint(int,QEventPoint::State,QPointF,QPointF)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QEventPoint(int,const QPointingDevice*)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QEventPoint(QEventPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QEventPoint(const QEventPoint &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QEventPoint cppArg0_local;
            ::QEventPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QEventPoint(QEventPoint)
                cptr = new ::QEventPoint(*cppArg0);
            }
            break;
        }
        case 1: // QEventPoint(int id, const QPointingDevice *device)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_id = Shiboken::String::createStaticString("id");
                if (PyDict_Contains(kwds, key_id) != 0) {
                    value = PyDict_GetItem(kwds, key_id);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_id);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_id);
                }
                static PyObject *const key_device = Shiboken::String::createStaticString("device");
                if (PyDict_Contains(kwds, key_device) != 0) {
                    value = PyDict_GetItem(kwds, key_device);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_device);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_device);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);
                }
            }
            int cppArg0 = -1;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPointingDevice *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QEventPoint(int,const QPointingDevice*)
                cptr = new ::QEventPoint(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QEventPoint(int pointId, QEventPoint::State state, const QPointF &scenePosition, const QPointF &globalPosition)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QEventPoint::State cppArg1{QEventPoint::Unknown};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QPointF cppArg2_local;
            ::QPointF *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QPointF cppArg3_local;
            ::QPointF *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QEventPoint(int,QEventPoint::State,QPointF,QPointF)
                cptr = new ::QEventPoint(cppArg0, cppArg1, *cppArg2, *cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QEventPoint >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QEventPointFunc_device(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // device()const
        const QPointingDevice * cppResult = const_cast<const ::QEventPoint *>(cppSelf)->device();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_ellipseDiameters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ellipseDiameters()const
        QSizeF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->ellipseDiameters();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_globalGrabPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // globalGrabPosition()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->globalGrabPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_globalLastPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // globalLastPosition()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->globalLastPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_globalPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // globalPosition()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->globalPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_globalPressPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // globalPressPosition()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->globalPressPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_grabPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // grabPosition()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->grabPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_id(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // id()const
        int cppResult = const_cast<const ::QEventPoint *>(cppSelf)->id();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_isAccepted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAccepted()const
        bool cppResult = const_cast<const ::QEventPoint *>(cppSelf)->isAccepted();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_lastNormalizedPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QEventPoint", "lastNormalizedPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // lastNormalizedPos()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->lastNormalizedPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_lastPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QEventPoint", "lastPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // lastPos()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->lastPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_lastPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastPosition()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->lastPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_lastScenePos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QEventPoint", "lastScenePos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // lastScenePos()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->lastScenePos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_lastScreenPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QEventPoint", "lastScreenPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // lastScreenPos()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->lastScreenPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_lastTimestamp(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastTimestamp()const
        ulong cppResult = const_cast<const ::QEventPoint *>(cppSelf)->lastTimestamp();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<ulong>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_normalizedPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QEventPoint", "normalizedPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // normalizedPos()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->normalizedPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_normalizedPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // normalizedPosition()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->normalizedPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_pos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QEventPoint", "pos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // pos()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->pos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // position()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->position();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_pressPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pressPosition()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->pressPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_pressTimestamp(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pressTimestamp()const
        ulong cppResult = const_cast<const ::QEventPoint *>(cppSelf)->pressTimestamp();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<ulong>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_pressure(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pressure()const
        qreal cppResult = const_cast<const ::QEventPoint *>(cppSelf)->pressure();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_rotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rotation()const
        qreal cppResult = const_cast<const ::QEventPoint *>(cppSelf)->rotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_sceneGrabPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sceneGrabPosition()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->sceneGrabPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_sceneLastPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sceneLastPosition()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->sceneLastPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_scenePos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QEventPoint", "scenePos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // scenePos()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->scenePos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_scenePosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scenePosition()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->scenePosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_scenePressPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scenePressPosition()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->scenePressPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_screenPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QEventPoint", "screenPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // screenPos()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->screenPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_setAccepted(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setAccepted", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);

    if (PyArg_ParseTuple(args, "|O:setAccepted", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QEventPoint::setAccepted(bool=)
    if (numArgs == 0) {
        overloadId = 0; // setAccepted(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // setAccepted(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setAccepted", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_accepted = Shiboken::String::createStaticString("accepted");
            if (PyDict_Contains(kwds, key_accepted) != 0) {
                value = PyDict_GetItem(kwds, key_accepted);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_accepted);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setAccepted", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "setAccepted", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_accepted);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setAccepted", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAccepted(bool)
            cppSelf->setAccepted(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QEventPointFunc_startNormalizedPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QEventPoint", "startNormalizedPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // startNormalizedPos()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->startNormalizedPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_startPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QEventPoint", "startPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // startPos()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->startPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_startScenePos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QEventPoint", "startScenePos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // startScenePos()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->startScenePos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_startScreenPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QEventPoint", "startScreenPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // startScreenPos()const
        QPointF cppResult = const_cast<const ::QEventPoint *>(cppSelf)->startScreenPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QEventPoint::State cppResult = const_cast<const ::QEventPoint *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_State_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QEventPoint::swap(QEventPoint&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QEventPoint&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEventPoint cppArg0_local;
        ::QEventPoint *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QEventPoint&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QEventPointFunc_timeHeld(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // timeHeld()const
        qreal cppResult = const_cast<const ::QEventPoint *>(cppSelf)->timeHeld();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_timestamp(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // timestamp()const
        ulong cppResult = const_cast<const ::QEventPoint *>(cppSelf)->timestamp();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<ulong>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_uniqueId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // uniqueId()const
        QPointingDeviceUniqueId cppResult = const_cast<const ::QEventPoint *>(cppSelf)->uniqueId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDeviceUniqueId_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPointFunc_velocity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // velocity()const
        QVector2D cppResult = const_cast<const ::QEventPoint *>(cppSelf)->velocity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventPoint__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QEventPoint_PropertyStrings[] = {
    "accepted:isAccepted:",
    "device:",
    "ellipseDiameters:",
    "globalGrabPosition:",
    "globalLastPosition:",
    "globalPosition:",
    "globalPressPosition:",
    "grabPosition:",
    "id:",
    "lastPosition:",
    "lastTimestamp:",
    "position:",
    "pressPosition:",
    "pressTimestamp:",
    "pressure:",
    "rotation:",
    "sceneGrabPosition:",
    "sceneLastPosition:",
    "scenePosition:",
    "scenePressPosition:",
    "state:",
    "timeHeld:",
    "timestamp:",
    "uniqueId:",
    "velocity:",
    nullptr // Sentinel
};

static const char *Sbk_QEventPoint_EnumFlagInfo[] = {
    "State:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QEventPoint_methods[] = {
    {"device", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_device), METH_NOARGS, nullptr},
    {"ellipseDiameters", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_ellipseDiameters), METH_NOARGS, nullptr},
    {"globalGrabPosition", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_globalGrabPosition), METH_NOARGS, nullptr},
    {"globalLastPosition", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_globalLastPosition), METH_NOARGS, nullptr},
    {"globalPosition", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_globalPosition), METH_NOARGS, nullptr},
    {"globalPressPosition", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_globalPressPosition), METH_NOARGS, nullptr},
    {"grabPosition", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_grabPosition), METH_NOARGS, nullptr},
    {"id", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_id), METH_NOARGS, nullptr},
    {"isAccepted", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_isAccepted), METH_NOARGS, nullptr},
    {"lastNormalizedPos", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_lastNormalizedPos), METH_NOARGS, nullptr},
    {"lastPos", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_lastPos), METH_NOARGS, nullptr},
    {"lastPosition", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_lastPosition), METH_NOARGS, nullptr},
    {"lastScenePos", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_lastScenePos), METH_NOARGS, nullptr},
    {"lastScreenPos", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_lastScreenPos), METH_NOARGS, nullptr},
    {"lastTimestamp", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_lastTimestamp), METH_NOARGS, nullptr},
    {"normalizedPos", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_normalizedPos), METH_NOARGS, nullptr},
    {"normalizedPosition", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_normalizedPosition), METH_NOARGS, nullptr},
    {"pos", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_pos), METH_NOARGS, nullptr},
    {"position", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_position), METH_NOARGS, nullptr},
    {"pressPosition", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_pressPosition), METH_NOARGS, nullptr},
    {"pressTimestamp", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_pressTimestamp), METH_NOARGS, nullptr},
    {"pressure", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_pressure), METH_NOARGS, nullptr},
    {"rotation", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_rotation), METH_NOARGS, nullptr},
    {"sceneGrabPosition", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_sceneGrabPosition), METH_NOARGS, nullptr},
    {"sceneLastPosition", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_sceneLastPosition), METH_NOARGS, nullptr},
    {"scenePos", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_scenePos), METH_NOARGS, nullptr},
    {"scenePosition", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_scenePosition), METH_NOARGS, nullptr},
    {"scenePressPosition", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_scenePressPosition), METH_NOARGS, nullptr},
    {"screenPos", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_screenPos), METH_NOARGS, nullptr},
    {"setAccepted", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_setAccepted), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"startNormalizedPos", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_startNormalizedPos), METH_NOARGS, nullptr},
    {"startPos", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_startPos), METH_NOARGS, nullptr},
    {"startScenePos", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_startScenePos), METH_NOARGS, nullptr},
    {"startScreenPos", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_startScreenPos), METH_NOARGS, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_state), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_swap), METH_O, nullptr},
    {"timeHeld", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_timeHeld), METH_NOARGS, nullptr},
    {"timestamp", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_timestamp), METH_NOARGS, nullptr},
    {"uniqueId", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_uniqueId), METH_NOARGS, nullptr},
    {"velocity", reinterpret_cast<PyCFunction>(Sbk_QEventPointFunc_velocity), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QEventPoint__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QEventPoint_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), (pyArg)))) {
                // operator!=(const QEventPoint &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QEventPoint cppArg0_local;
                ::QEventPoint *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), (pyArg)))) {
                // operator==(const QEventPoint &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QEventPoint cppArg0_local;
                ::QEventPoint *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QEventPoint_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QEventPoint_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QEventPoint__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QEventPoint_Type = nullptr;
static PyTypeObject *Sbk_QEventPoint_TypeF(void)
{
    return _Sbk_QEventPoint_Type;
}

static PyType_Slot Sbk_QEventPoint_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QEventPoint__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QEventPoint_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QEventPoint_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QEventPoint_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QEventPoint_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QEventPoint_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QEventPoint_spec = {
    "2:PySide6.QtGui.QEventPoint",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QEventPoint_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QEventPoint_State(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QEventPoint::State>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QEventPoint::State *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QEventPoint_State_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_State_IDX])))
        return Enum_PythonToCpp_QEventPoint_State;
    return {};
}

static PyObject *QEventPoint_State_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QEventPoint::State>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QEventPoint::State *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_State_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QEventPoint_PythonToCpp_QEventPoint_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QEventPoint_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QEventPoint_PythonToCpp_QEventPoint_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QEventPoint_TypeF()))
        return QEventPoint_PythonToCpp_QEventPoint_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QEventPoint_PTR_CppToPython_QEventPoint(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QEventPoint_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QEventPoint_COPY_CppToPython_QEventPoint(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QEventPoint *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QEventPoint_TypeF(), new ::QEventPoint(*source), true, true);
}

// Python to C++ copy conversion.
static void QEventPoint_PythonToCpp_QEventPoint_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QEventPoint *>(cppOut) = *reinterpret_cast< ::QEventPoint *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QEventPoint_PythonToCpp_QEventPoint_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QEventPoint_TypeF()))
        return QEventPoint_PythonToCpp_QEventPoint_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QEventPoint_SignatureStrings[] = {
    "2:PySide6.QtGui.QEventPoint(self,other:PySide6.QtGui.QEventPoint,*:KeywordOnly=None,accepted:bool=None,device:QPointingDevice=None,id:int=None,uniqueId:QPointingDeviceUniqueId=None,state:QEventPoint.State=None,timestamp:ulong=None,pressTimestamp:ulong=None,lastTimestamp:ulong=None,timeHeld:qreal=None,pressure:qreal=None,rotation:qreal=None,ellipseDiameters:QSizeF=None,velocity:QVector2D=None,position:QPointF=None,pressPosition:QPointF=None,grabPosition:QPointF=None,lastPosition:QPointF=None,scenePosition:QPointF=None,scenePressPosition:QPointF=None,sceneGrabPosition:QPointF=None,sceneLastPosition:QPointF=None,globalPosition:QPointF=None,globalPressPosition:QPointF=None,globalGrabPosition:QPointF=None,globalLastPosition:QPointF=None)",
    "1:PySide6.QtGui.QEventPoint(self,id:int=-1,device:PySide6.QtGui.QPointingDevice=nullptr,*:KeywordOnly=None,accepted:bool=None,device:QPointingDevice=None,id:int=None,uniqueId:QPointingDeviceUniqueId=None,state:QEventPoint.State=None,timestamp:ulong=None,pressTimestamp:ulong=None,lastTimestamp:ulong=None,timeHeld:qreal=None,pressure:qreal=None,rotation:qreal=None,ellipseDiameters:QSizeF=None,velocity:QVector2D=None,position:QPointF=None,pressPosition:QPointF=None,grabPosition:QPointF=None,lastPosition:QPointF=None,scenePosition:QPointF=None,scenePressPosition:QPointF=None,sceneGrabPosition:QPointF=None,sceneLastPosition:QPointF=None,globalPosition:QPointF=None,globalPressPosition:QPointF=None,globalGrabPosition:QPointF=None,globalLastPosition:QPointF=None)",
    "0:PySide6.QtGui.QEventPoint(self,pointId:int,state:PySide6.QtGui.QEventPoint.State,scenePosition:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],globalPosition:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],*:KeywordOnly=None,accepted:bool=None,device:QPointingDevice=None,id:int=None,uniqueId:QPointingDeviceUniqueId=None,state:QEventPoint.State=None,timestamp:ulong=None,pressTimestamp:ulong=None,lastTimestamp:ulong=None,timeHeld:qreal=None,pressure:qreal=None,rotation:qreal=None,ellipseDiameters:QSizeF=None,velocity:QVector2D=None,position:QPointF=None,pressPosition:QPointF=None,grabPosition:QPointF=None,lastPosition:QPointF=None,scenePosition:QPointF=None,scenePressPosition:QPointF=None,sceneGrabPosition:QPointF=None,sceneLastPosition:QPointF=None,globalPosition:QPointF=None,globalPressPosition:QPointF=None,globalGrabPosition:QPointF=None,globalLastPosition:QPointF=None)",
    "PySide6.QtGui.QEventPoint.device(self)->PySide6.QtGui.QPointingDevice",
    "PySide6.QtGui.QEventPoint.ellipseDiameters(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtGui.QEventPoint.globalGrabPosition(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.globalLastPosition(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.globalPosition(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.globalPressPosition(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.grabPosition(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.id(self)->int",
    "PySide6.QtGui.QEventPoint.isAccepted(self)->bool",
    "PySide6.QtGui.QEventPoint.lastNormalizedPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.lastPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.lastPosition(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.lastScenePos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.lastScreenPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.lastTimestamp(self)->ulong",
    "PySide6.QtGui.QEventPoint.normalizedPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.normalizedPosition(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.pos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.position(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.pressPosition(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.pressTimestamp(self)->ulong",
    "PySide6.QtGui.QEventPoint.pressure(self)->qreal",
    "PySide6.QtGui.QEventPoint.rotation(self)->qreal",
    "PySide6.QtGui.QEventPoint.sceneGrabPosition(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.sceneLastPosition(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.scenePos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.scenePosition(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.scenePressPosition(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.screenPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.setAccepted(self,accepted:bool=true)",
    "PySide6.QtGui.QEventPoint.startNormalizedPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.startPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.startScenePos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.startScreenPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QEventPoint.state(self)->PySide6.QtGui.QEventPoint.State",
    "PySide6.QtGui.QEventPoint.swap(self,other:PySide6.QtGui.QEventPoint)",
    "PySide6.QtGui.QEventPoint.timeHeld(self)->qreal",
    "PySide6.QtGui.QEventPoint.timestamp(self)->ulong",
    "PySide6.QtGui.QEventPoint.uniqueId(self)->PySide6.QtGui.QPointingDeviceUniqueId",
    "PySide6.QtGui.QEventPoint.velocity(self)->PySide6.QtGui.QVector2D",
    "PySide6.QtGui.QEventPoint.__copy__(self)->typing.Self",
    "PySide6.QtGui.QEventPoint.__ne__(self,other:PySide6.QtGui.QEventPoint)->bool",
    "PySide6.QtGui.QEventPoint.__eq__(self,other:PySide6.QtGui.QEventPoint)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QEventPoint_SignatureByteSize = 651;
static constexpr uint8_t QEventPoint_SignatureBytes[651] = {
    0x78, 0xda, 0xed, 0x58, 0x5b, 0x6f, 0xd3, 0x30, 0x14, 0x7e, 0xe7, 0x57, 0xf0, 0xc8, 0x50, 0x57,
    0xb1, 0x3d, 0xf0, 0x10, 0x09, 0x24, 0x44, 0xd7, 0x31, 0x81, 0x46, 0xab, 0x02, 0x2f, 0x08, 0x45,
    0x6e, 0x72, 0xe8, 0x2c, 0xb9, 0xb6, 0x6b, 0x3b, 0x9b, 0xc2, 0xaf, 0xc7, 0xf1, 0x85, 0xa5, 0x69,
    0xec, 0x76, 0x75, 0x90, 0x40, 0xea, 0x5b, 0x73, 0x2e, 0xdf, 0x89, 0x8f, 0xbf, 0x73, 0x49, 0x2f,
    0xb3, 0x59, 0xbd, 0xc0, 0x25, 0xbc, 0x1e, 0xcf, 0xd5, 0x75, 0x85, 0xc7, 0xf3, 0xab, 0x7b, 0xa0,
    0x6a, 0xc6, 0x30, 0x55, 0x2f, 0x24, 0x90, 0x9f, 0x23, 0xa6, 0xee, 0x40, 0x84, 0x8d, 0x46, 0x2f,
    0xb3, 0x8f, 0x50, 0x3f, 0x30, 0x51, 0x7e, 0xa6, 0xa4, 0x7e, 0x73, 0xcb, 0x28, 0x8c, 0x50, 0x51,
    0x00, 0x57, 0x50, 0x66, 0x4b, 0xc6, 0x88, 0x15, 0x95, 0x70, 0x8f, 0x0b, 0xc8, 0xe6, 0xc6, 0x07,
    0xd3, 0xd5, 0xc4, 0x3c, 0x5b, 0x1d, 0x2e, 0x33, 0x2d, 0xb4, 0xbf, 0x2b, 0x8a, 0x37, 0x15, 0xdc,
    0x94, 0x5d, 0xcb, 0xaf, 0x4e, 0x6e, 0xad, 0xa4, 0x42, 0x4a, 0x83, 0x3d, 0xbe, 0xc5, 0x78, 0xd1,
    0x48, 0xac, 0x52, 0xe1, 0x35, 0x68, 0x83, 0x35, 0xcf, 0x2a, 0xc2, 0xe8, 0xca, 0x0a, 0xb9, 0x00,
    0x29, 0xbf, 0xf4, 0x69, 0x08, 0x92, 0xaa, 0x57, 0xd1, 0xe0, 0x7c, 0x00, 0x52, 0x66, 0x1b, 0x01,
    0x88, 0xb4, 0x60, 0x2a, 0x01, 0x6d, 0x99, 0x60, 0x3a, 0x36, 0x66, 0xb4, 0x2d, 0x03, 0x42, 0x30,
    0x97, 0x30, 0xc1, 0x68, 0x0d, 0x0a, 0x84, 0xcc, 0xe6, 0x0b, 0xfc, 0x0b, 0xa6, 0x56, 0x79, 0x0f,
    0x84, 0x15, 0x58, 0xd5, 0xd9, 0xfc, 0x1b, 0x14, 0x8a, 0x89, 0xcb, 0x89, 0x03, 0x67, 0x12, 0x1b,
    0x20, 0x7b, 0xf6, 0x69, 0x2b, 0xe4, 0xac, 0x57, 0xb5, 0x12, 0x68, 0xd9, 0xaf, 0x69, 0x0e, 0xd5,
    0xaf, 0x91, 0x05, 0x50, 0x88, 0xa9, 0xc2, 0xe1, 0x8c, 0xfe, 0x3a, 0x18, 0xd3, 0xa8, 0x3f, 0x05,
    0x03, 0xaf, 0x08, 0x5b, 0x22, 0x12, 0xd5, 0x45, 0x4e, 0x6a, 0x0c, 0xc2, 0xb1, 0xad, 0x3e, 0x18,
    0xfc, 0xec, 0xd9, 0xc5, 0x3e, 0x9a, 0x3b, 0x12, 0x9e, 0x5f, 0x78, 0xaa, 0x76, 0xec, 0x3b, 0xc4,
    0xa5, 0x15, 0x21, 0x5c, 0x89, 0x13, 0xfb, 0x4f, 0xec, 0xff, 0x0f, 0xd8, 0xff, 0x6a, 0x1f, 0xfb,
    0x79, 0xf3, 0xf3, 0xc6, 0x30, 0xd1, 0xd1, 0x2b, 0xe8, 0x60, 0xc9, 0xd6, 0xc9, 0xa4, 0xaa, 0xb9,
    0x26, 0xeb, 0x58, 0xf3, 0x94, 0xd1, 0xef, 0x8f, 0xae, 0xef, 0x99, 0x00, 0x57, 0x3a, 0xd3, 0xd1,
    0xf3, 0x5e, 0x79, 0x5b, 0x6c, 0x0b, 0x0d, 0x69, 0x29, 0x88, 0x19, 0x52, 0x77, 0xe3, 0x2b, 0x02,
    0x6b, 0x1d, 0xf7, 0x47, 0x37, 0x7d, 0x7f, 0x3b, 0xdc, 0xa9, 0xaa, 0x4f, 0x55, 0xfd, 0xef, 0x57,
    0x75, 0xb8, 0x44, 0x2d, 0x33, 0x4d, 0x69, 0x9f, 0x9d, 0xbf, 0x8d, 0x4e, 0xb2, 0x08, 0x4a, 0xf7,
    0xc2, 0x77, 0xf1, 0x6c, 0x61, 0x19, 0x1a, 0x44, 0x70, 0x76, 0x0f, 0x1a, 0x42, 0xb2, 0xc7, 0xdb,
    0x0b, 0xd5, 0xce, 0x49, 0x22, 0xd4, 0x50, 0x30, 0xed, 0x6b, 0x3e, 0x1e, 0x6b, 0x88, 0x14, 0xe1,
    0xd2, 0xbb, 0xea, 0xa7, 0x98, 0x9d, 0x7c, 0xe7, 0x5a, 0x9a, 0xb7, 0x6f, 0x3a, 0x5b, 0xc4, 0xa1,
    0xa9, 0xbf, 0x5b, 0x26, 0xd6, 0x88, 0xe8, 0xfb, 0x2e, 0xf5, 0x7b, 0x1e, 0xfd, 0x8a, 0xae, 0x92,
    0x53, 0xfd, 0xd3, 0xf2, 0xd4, 0x80, 0x2c, 0x5c, 0xe3, 0x48, 0x04, 0x11, 0x00, 0x34, 0x15, 0xe5,
    0x4f, 0xbb, 0xf6, 0x28, 0xa6, 0x6b, 0x47, 0x9c, 0xe8, 0x20, 0x57, 0xb1, 0x85, 0x92, 0x96, 0x50,
    0x9e, 0xf0, 0x1a, 0x3c, 0x39, 0xf8, 0x20, 0x05, 0xb8, 0x3d, 0x51, 0x0f, 0xbd, 0x09, 0x3f, 0x40,
    0xbd, 0xbd, 0x99, 0x99, 0x11, 0x7b, 0x3f, 0x5c, 0x0f, 0xb5, 0xdf, 0x99, 0x51, 0x47, 0x9f, 0x6f,
    0x67, 0x9c, 0xa5, 0x21, 0xa5, 0x10, 0x6f, 0x6b, 0x66, 0x27, 0xa2, 0x0c, 0x72, 0xf7, 0x32, 0xb9,
    0x8c, 0x25, 0xa8, 0xad, 0x96, 0xda, 0xd9, 0x19, 0x95, 0xa8, 0xa2, 0x43, 0x5b, 0x73, 0x4e, 0x0c,
    0xd4, 0x60, 0x0d, 0x54, 0x32, 0x40, 0x72, 0x77, 0x74, 0x28, 0xc9, 0x79, 0x6d, 0xf6, 0xe0, 0xc0,
    0x32, 0xd3, 0x5d, 0x97, 0x63, 0x30, 0x0f, 0x88, 0x1f, 0xf4, 0x97, 0x56, 0xec, 0x92, 0xfc, 0x02,
    0x7d, 0x68, 0xed, 0xaa, 0xa7, 0x36, 0x13, 0xff, 0xb1, 0x70, 0xd0, 0xf2, 0xe6, 0xbf, 0x20, 0x22,
    0x78, 0x7e, 0x31, 0x0f, 0xe0, 0xf9, 0x6d, 0x3d, 0x82, 0x90, 0xe7, 0x05, 0xe3, 0x75, 0x9e, 0x7b,
    0x04, 0xf7, 0xf1, 0xb5, 0xd0, 0x4f, 0x51, 0x2f, 0x0a, 0xce, 0x67, 0x6f, 0xbe, 0xf7, 0xae, 0x1e,
    0x79, 0x0e, 0x9b, 0x27, 0x82, 0xfd, 0x06, 0x2f, 0xb3, 0x9f, 0x80
};
#endif

PyTypeObject *init_QEventPoint(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX].type;

    Shiboken::AutoDecRef Sbk_QEventPoint_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QEventPoint_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QEventPoint",
        "QEventPoint",
        &Sbk_QEventPoint_spec,
        &Shiboken::callCppDestructor< ::QEventPoint >,
        Sbk_QEventPoint_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QEventPoint_TypeF(); // references _Sbk_QEventPoint_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QEventPoint_SignatureStrings);
#else
    InitSignatureBytes(pyType, QEventPoint_SignatureBytes, QEventPoint_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QEventPoint_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QEventPoint_PythonToCpp_QEventPoint_PTR,
        is_QEventPoint_PythonToCpp_QEventPoint_PTR_Convertible,
        QEventPoint_PTR_CppToPython_QEventPoint,
        QEventPoint_COPY_CppToPython_QEventPoint);

    Shiboken::Conversions::registerConverterName(converter, "QEventPoint");
    Shiboken::Conversions::registerConverterName(converter, "QEventPoint*");
    Shiboken::Conversions::registerConverterName(converter, "QEventPoint&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QEventPoint).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QEventPoint_PythonToCpp_QEventPoint_COPY,
        is_QEventPoint_PythonToCpp_QEventPoint_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QEventPoint_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'State'.
    const char *State_Initializer[] = {
        "Unknown",
        "Stationary",
        "Pressed",
        "Updated",
        "Released",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t State_InitializerValues[] = {
        uint8_t(QEventPoint::State::Unknown),    //  0x00  0
        uint8_t(QEventPoint::State::Stationary), //  0x04  4
        uint8_t(QEventPoint::State::Pressed),    //  0x01  1
        uint8_t(QEventPoint::State::Updated),    //  0x02  2
        uint8_t(QEventPoint::State::Released)    //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QEventPoint_TypeF(),
        "2:PySide6.QtGui.QEventPoint.State",
        State_Initializer, State_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_State_IDX].type = EType;
    // Register converter for enum 'QEventPoint::State'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QEventPoint_State_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QEventPoint_State,
            is_Enum_PythonToCpp_QEventPoint_State_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QEventPoint::State");
        Shiboken::Conversions::registerConverterAlias(converter, "State");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'State' enum.

    qRegisterMetaType< ::QEventPoint >("QEventPoint");
    qRegisterMetaType< ::QEventPoint::State >("QEventPoint::State");

    return pyType;
}
