// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qexposeevent_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <QtGui/qregion.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QExposeEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QExposeEventWrapper::QExposeEventWrapper(const ::QRegion & m_region) : QExposeEvent(m_region)
{
}

::QExposeEvent * QExposeEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QExposeEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QExposeEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QExposeEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QExposeEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QExposeEvent", funcName, Shiboken::SbkType< QExposeEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QExposeEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QExposeEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QExposeEvent", funcName);
        return;
    }
}

QExposeEventWrapper::~QExposeEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QExposeEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QExposeEvent >()))
        return -1;

    QExposeEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QExposeEvent", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QExposeEvent::QExposeEvent(QExposeEvent)
    // 1: QExposeEvent::QExposeEvent(QRegion)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QExposeEvent(QRegion)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QExposeEvent_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QExposeEvent(QExposeEvent)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QExposeEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QExposeEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QExposeEvent(const QExposeEvent &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QExposeEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QExposeEvent(QExposeEvent)
                cptr = new QExposeEventWrapper(*cppArg0);
            }
            break;
        }
        case 1: // QExposeEvent(const QRegion &m_region)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRegion cppArg0_local;
            ::QRegion *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QExposeEvent(QRegion)
                cptr = new QExposeEventWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QExposeEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QExposeEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QExposeEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QExposeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QExposeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clone()const
        QExposeEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QExposeEvent *>(cppSelf)->::QExposeEvent::clone()
            : const_cast<const ::QExposeEvent *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QExposeEvent_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QExposeEventFunc_region(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QExposeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QExposeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QExposeEvent", "region() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // region()const
        const QRegion & cppResult = const_cast<const ::QExposeEvent *>(cppSelf)->region();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QExposeEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QExposeEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QExposeEventFunc_clone), METH_NOARGS, nullptr},
    {"region", reinterpret_cast<PyCFunction>(Sbk_QExposeEventFunc_region), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QExposeEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QExposeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QExposeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QExposeEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QExposeEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QExposeEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QExposeEvent_Type = nullptr;
static PyTypeObject *Sbk_QExposeEvent_TypeF(void)
{
    return _Sbk_QExposeEvent_Type;
}

static PyType_Slot Sbk_QExposeEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QExposeEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QExposeEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QExposeEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QExposeEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QExposeEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QExposeEvent_spec = {
    "2:PySide6.QtGui.QExposeEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QExposeEvent_slots
};

} //extern "C"

static void *Sbk_QExposeEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::Expose)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QExposeEvent_PythonToCpp_QExposeEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QExposeEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QExposeEvent_PythonToCpp_QExposeEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QExposeEvent_TypeF()))
        return QExposeEvent_PythonToCpp_QExposeEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QExposeEvent_PTR_CppToPython_QExposeEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QExposeEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QExposeEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QExposeEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QExposeEvent(self,arg__1:PySide6.QtGui.QExposeEvent)",
    "0:PySide6.QtGui.QExposeEvent(self,m_region:typing.Union[PySide6.QtGui.QRegion, PySide6.QtGui.QBitmap, PySide6.QtGui.QPolygon, PySide6.QtCore.QRect])",
    "PySide6.QtGui.QExposeEvent.clone(self)->PySide6.QtGui.QExposeEvent",
    "PySide6.QtGui.QExposeEvent.region(self)->PySide6.QtGui.QRegion",
    nullptr}; // Sentinel
#else
static constexpr size_t QExposeEvent_SignatureByteSize = 138;
static constexpr uint8_t QExposeEvent_SignatureBytes[138] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x74, 0xad, 0x28, 0xc8, 0x2f, 0x4e, 0x75, 0x2d, 0x4b, 0xcd, 0x2b, 0xd1, 0x28,
    0x4e, 0xcd, 0x49, 0xd3, 0x49, 0x2c, 0x4a, 0x8f, 0x8f, 0x37, 0xc4, 0xa3, 0x4c, 0x93, 0xcb, 0x80,
    0xa0, 0x21, 0xb9, 0xf1, 0x45, 0xa9, 0xe9, 0x99, 0xf9, 0x79, 0x56, 0x25, 0x95, 0x05, 0x99, 0x79,
    0xe9, 0x7a, 0xa1, 0x79, 0x40, 0x4e, 0x34, 0x9a, 0xae, 0x20, 0xb0, 0x12, 0x1d, 0x05, 0x34, 0x61,
    0xa7, 0xcc, 0x92, 0xdc, 0xc4, 0x02, 0x0c, 0xe1, 0x80, 0xfc, 0x9c, 0xca, 0x74, 0x54, 0xe5, 0xce,
    0xf9, 0x45, 0xa9, 0x20, 0x63, 0x92, 0x4b, 0x62, 0x35, 0xb9, 0x70, 0x3b, 0x49, 0x2f, 0x39, 0x27,
    0x3f, 0x2f, 0x15, 0xec, 0x30, 0x4d, 0x5d, 0x3b, 0xdc, 0xea, 0xf0, 0x19, 0x01, 0xf1, 0x0e, 0x0e,
    0x33, 0x20, 0x1e, 0xe1, 0x02, 0x00, 0x89, 0xbf, 0x7a, 0x50
};
#endif

PyTypeObject *init_QExposeEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QExposeEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QExposeEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QExposeEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]))));

    _Sbk_QExposeEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QExposeEvent",
        "QExposeEvent*",
        &Sbk_QExposeEvent_spec,
        &Shiboken::callCppDestructor< QExposeEvent >,
        Sbk_QExposeEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QExposeEvent_TypeF(); // references _Sbk_QExposeEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QExposeEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QExposeEvent_SignatureBytes, QExposeEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QExposeEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QExposeEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QExposeEvent_PythonToCpp_QExposeEvent_PTR,
        is_QExposeEvent_PythonToCpp_QExposeEvent_PTR_Convertible,
        QExposeEvent_PTR_CppToPython_QExposeEvent);

    Shiboken::Conversions::registerConverterName(converter, "QExposeEvent");
    Shiboken::Conversions::registerConverterName(converter, "QExposeEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QExposeEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QExposeEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QExposeEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QExposeEvent_TypeF(), &Sbk_QExposeEvent_typeDiscovery);


    return pyType;
}
