// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qfontinfo_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFontInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFontInfo >()))
        return -1;

    ::QFontInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QFontInfo", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QFontInfo::QFontInfo(QFont)
    // 1: QFontInfo::QFontInfo(QFontInfo)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QFontInfo(QFont)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QFontInfo(QFontInfo)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QFontInfo(const QFont &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QFont cppArg0_local;
            ::QFont *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QFontInfo(QFont)
                cptr = new ::QFontInfo(*cppArg0);
            }
            break;
        }
        case 1: // QFontInfo(const QFontInfo &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QFontInfo cppArg0_local = ::QFontInfo(::QFont());
            ::QFontInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QFontInfo(QFontInfo)
                cptr = new ::QFontInfo(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QFontInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QFontInfoFunc_bold(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bold()const
        bool cppResult = const_cast<const ::QFontInfo *>(cppSelf)->bold();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfoFunc_exactMatch(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // exactMatch()const
        bool cppResult = const_cast<const ::QFontInfo *>(cppSelf)->exactMatch();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfoFunc_family(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // family()const
        QString cppResult = const_cast<const ::QFontInfo *>(cppSelf)->family();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfoFunc_fixedPitch(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fixedPitch()const
        bool cppResult = const_cast<const ::QFontInfo *>(cppSelf)->fixedPitch();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfoFunc_italic(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // italic()const
        bool cppResult = const_cast<const ::QFontInfo *>(cppSelf)->italic();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfoFunc_legacyWeight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QFontInfo", "legacyWeight() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // legacyWeight()const
        int cppResult = const_cast<const ::QFontInfo *>(cppSelf)->legacyWeight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfoFunc_overline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // overline()const
        bool cppResult = const_cast<const ::QFontInfo *>(cppSelf)->overline();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfoFunc_pixelSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pixelSize()const
        int cppResult = const_cast<const ::QFontInfo *>(cppSelf)->pixelSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfoFunc_pointSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pointSize()const
        int cppResult = const_cast<const ::QFontInfo *>(cppSelf)->pointSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfoFunc_pointSizeF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pointSizeF()const
        qreal cppResult = const_cast<const ::QFontInfo *>(cppSelf)->pointSizeF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfoFunc_strikeOut(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // strikeOut()const
        bool cppResult = const_cast<const ::QFontInfo *>(cppSelf)->strikeOut();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfoFunc_style(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // style()const
        QFont::Style cppResult = const_cast<const ::QFontInfo *>(cppSelf)->style();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Style_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfoFunc_styleHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // styleHint()const
        QFont::StyleHint cppResult = const_cast<const ::QFontInfo *>(cppSelf)->styleHint();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleHint_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfoFunc_styleName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // styleName()const
        QString cppResult = const_cast<const ::QFontInfo *>(cppSelf)->styleName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfoFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFontInfo::swap(QFontInfo&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QFontInfo&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFontInfo cppArg0_local = ::QFontInfo(::QFont());
        ::QFontInfo *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QFontInfo&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontInfoFunc_underline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // underline()const
        bool cppResult = const_cast<const ::QFontInfo *>(cppSelf)->underline();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfoFunc_weight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // weight()const
        int cppResult = const_cast<const ::QFontInfo *>(cppSelf)->weight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QFontInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFontInfo_methods[] = {
    {"bold", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_bold), METH_NOARGS, nullptr},
    {"exactMatch", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_exactMatch), METH_NOARGS, nullptr},
    {"family", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_family), METH_NOARGS, nullptr},
    {"fixedPitch", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_fixedPitch), METH_NOARGS, nullptr},
    {"italic", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_italic), METH_NOARGS, nullptr},
    {"legacyWeight", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_legacyWeight), METH_NOARGS, nullptr},
    {"overline", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_overline), METH_NOARGS, nullptr},
    {"pixelSize", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_pixelSize), METH_NOARGS, nullptr},
    {"pointSize", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_pointSize), METH_NOARGS, nullptr},
    {"pointSizeF", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_pointSizeF), METH_NOARGS, nullptr},
    {"strikeOut", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_strikeOut), METH_NOARGS, nullptr},
    {"style", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_style), METH_NOARGS, nullptr},
    {"styleHint", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_styleHint), METH_NOARGS, nullptr},
    {"styleName", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_styleName), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_swap), METH_O, nullptr},
    {"underline", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_underline), METH_NOARGS, nullptr},
    {"weight", reinterpret_cast<PyCFunction>(Sbk_QFontInfoFunc_weight), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QFontInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QFontInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFontInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFontInfo_Type = nullptr;
static PyTypeObject *Sbk_QFontInfo_TypeF(void)
{
    return _Sbk_QFontInfo_Type;
}

static PyType_Slot Sbk_QFontInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFontInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFontInfo_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFontInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFontInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFontInfo_spec = {
    "2:PySide6.QtGui.QFontInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFontInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFontInfo_PythonToCpp_QFontInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFontInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFontInfo_PythonToCpp_QFontInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFontInfo_TypeF()))
        return QFontInfo_PythonToCpp_QFontInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFontInfo_PTR_CppToPython_QFontInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QFontInfo_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QFontInfo_COPY_CppToPython_QFontInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QFontInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QFontInfo_TypeF(), new ::QFontInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QFontInfo_PythonToCpp_QFontInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QFontInfo *>(cppOut) = *reinterpret_cast< ::QFontInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QFontInfo_PythonToCpp_QFontInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QFontInfo_TypeF()))
        return QFontInfo_PythonToCpp_QFontInfo_COPY;
    return {};
}

// Implicit conversions.
static void constQFontREF_PythonToCpp_QFontInfo(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QFontInfo *>(cppOut) = ::QFontInfo( *reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQFontREF_PythonToCpp_QFontInfo_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), pyIn))
        return constQFontREF_PythonToCpp_QFontInfo;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFontInfo_SignatureStrings[] = {
    "1:PySide6.QtGui.QFontInfo(self,arg__1:typing.Union[PySide6.QtGui.QFont, QString, QStringList])",
    "0:PySide6.QtGui.QFontInfo(self,arg__1:PySide6.QtGui.QFontInfo)",
    "PySide6.QtGui.QFontInfo.bold(self)->bool",
    "PySide6.QtGui.QFontInfo.exactMatch(self)->bool",
    "PySide6.QtGui.QFontInfo.family(self)->QString",
    "PySide6.QtGui.QFontInfo.fixedPitch(self)->bool",
    "PySide6.QtGui.QFontInfo.italic(self)->bool",
    "PySide6.QtGui.QFontInfo.legacyWeight(self)->int",
    "PySide6.QtGui.QFontInfo.overline(self)->bool",
    "PySide6.QtGui.QFontInfo.pixelSize(self)->int",
    "PySide6.QtGui.QFontInfo.pointSize(self)->int",
    "PySide6.QtGui.QFontInfo.pointSizeF(self)->qreal",
    "PySide6.QtGui.QFontInfo.strikeOut(self)->bool",
    "PySide6.QtGui.QFontInfo.style(self)->PySide6.QtGui.QFont.Style",
    "PySide6.QtGui.QFontInfo.styleHint(self)->PySide6.QtGui.QFont.StyleHint",
    "PySide6.QtGui.QFontInfo.styleName(self)->QString",
    "PySide6.QtGui.QFontInfo.swap(self,other:typing.Union[PySide6.QtGui.QFontInfo, PySide6.QtGui.QFont])",
    "PySide6.QtGui.QFontInfo.underline(self)->bool",
    "PySide6.QtGui.QFontInfo.weight(self)->int",
    "PySide6.QtGui.QFontInfo.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QFontInfo_SignatureByteSize = 274;
static constexpr uint8_t QFontInfo_SignatureBytes[274] = {
    0x78, 0xda, 0x95, 0x93, 0x3f, 0x6f, 0xc2, 0x30, 0x10, 0xc5, 0xf7, 0x7c, 0x0a, 0xc6, 0x46, 0x4a,
    0xad, 0xb2, 0x74, 0x60, 0xe8, 0x48, 0xa9, 0xd4, 0x3f, 0x44, 0x51, 0xd5, 0xa1, 0x42, 0x96, 0x71,
    0x2e, 0xc9, 0xa9, 0xc6, 0x4e, 0x9d, 0x4b, 0xc1, 0xfd, 0xf4, 0x35, 0x94, 0x30, 0xc5, 0x60, 0x36,
    0x5b, 0xf7, 0x7b, 0x4f, 0xef, 0xac, 0xe7, 0xe9, 0x6c, 0xe9, 0x0a, 0x2c, 0xe1, 0x9e, 0xe5, 0xf4,
    0xd8, 0x23, 0xcb, 0xe7, 0x46, 0xd3, 0x93, 0xae, 0xcc, 0x4d, 0x07, 0xaa, 0xca, 0x84, 0xad, 0x39,
    0x9f, 0xce, 0xc8, 0xb5, 0xa8, 0x6b, 0xf6, 0xae, 0xd1, 0xe8, 0xcf, 0x11, 0x41, 0x36, 0xc9, 0x0b,
    0xb2, 0x1e, 0x39, 0x1d, 0x9e, 0xb1, 0xa3, 0x55, 0x9a, 0xdc, 0x45, 0xd9, 0x07, 0x98, 0x34, 0x09,
    0x0c, 0xd8, 0xda, 0xa8, 0xf2, 0xe0, 0x90, 0xde, 0x3e, 0xac, 0x8d, 0x51, 0x41, 0x10, 0x76, 0x42,
    0xd2, 0x8b, 0x20, 0xd9, 0x44, 0xe1, 0x95, 0xd8, 0xa0, 0x72, 0x03, 0x7a, 0x5c, 0x25, 0x4c, 0xe3,
    0x0e, 0xca, 0x25, 0xc6, 0x9a, 0x23, 0x09, 0x85, 0x32, 0x0a, 0x55, 0x50, 0x0b, 0xe9, 0x3e, 0x00,
    0xeb, 0x86, 0x06, 0x01, 0x6a, 0x0a, 0xf2, 0xe6, 0x07, 0xac, 0x42, 0x0d, 0x51, 0xe6, 0xad, 0x8f,
    0xad, 0x0a, 0xfc, 0x85, 0x18, 0xe7, 0xd6, 0xf8, 0xe9, 0xd5, 0xf0, 0x7c, 0xa0, 0xbf, 0x2d, 0x88,
    0x70, 0x92, 0xce, 0xbf, 0xef, 0x17, 0xbc, 0xf5, 0x14, 0x95, 0xbb, 0x23, 0xa7, 0x4e, 0x31, 0x46,
    0x20, 0x56, 0xec, 0x81, 0xf3, 0xf2, 0x85, 0x0f, 0x78, 0xd1, 0x62, 0x71, 0x6e, 0xc7, 0x83, 0xcd,
    0xab, 0xd8, 0x40, 0x6c, 0x4b, 0xba, 0xad, 0x68, 0xff, 0xdb, 0x6e, 0xa8, 0x01, 0x7b, 0xf1, 0x2f,
    0xed, 0x45, 0xd9, 0x64, 0x64, 0xb0, 0x0a, 0xff, 0x87, 0x5e, 0x97, 0x57, 0x14, 0x60, 0x1b, 0xdd,
    0x2b, 0xce, 0xa5, 0x69, 0x1d, 0xe7, 0x03, 0x7b, 0xcc, 0x5e, 0xf8, 0x5b, 0xf2, 0x07, 0xe2, 0x54,
    0x7c, 0x91
};
#endif

PyTypeObject *init_QFontInfo(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QFontInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QFontInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFontInfo",
        "QFontInfo",
        &Sbk_QFontInfo_spec,
        &Shiboken::callCppDestructor< ::QFontInfo >,
        Sbk_QFontInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QFontInfo_TypeF(); // references _Sbk_QFontInfo_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFontInfo_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFontInfo_SignatureBytes, QFontInfo_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFontInfo_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFontInfo_PythonToCpp_QFontInfo_PTR,
        is_QFontInfo_PythonToCpp_QFontInfo_PTR_Convertible,
        QFontInfo_PTR_CppToPython_QFontInfo,
        QFontInfo_COPY_CppToPython_QFontInfo);

    Shiboken::Conversions::registerConverterName(converter, "QFontInfo");
    Shiboken::Conversions::registerConverterName(converter, "QFontInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QFontInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFontInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QFontInfo_PythonToCpp_QFontInfo_COPY,
        is_QFontInfo_PythonToCpp_QFontInfo_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQFontREF_PythonToCpp_QFontInfo,
        is_constQFontREF_PythonToCpp_QFontInfo_Convertible);


    return pyType;
}
