// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qfontmetrics_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qfont.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qtextoption.h>
#include <qchar.h>
#include <qnamespace.h>
#include <qrect.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFontMetrics_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFontMetrics >()))
        return -1;

    ::QFontMetrics *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QFontMetrics", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QFontMetrics::QFontMetrics(QFont)
    // 1: QFontMetrics::QFontMetrics(QFont,const QPaintDevice*)
    // 2: QFontMetrics::QFontMetrics(QFontMetrics)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QFontMetrics(QFontMetrics)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QFontMetrics(QFont)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QFontMetrics(QFont,const QPaintDevice*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QFontMetrics(const QFont &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QFont cppArg0_local;
            ::QFont *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QFontMetrics(QFont)
                cptr = new ::QFontMetrics(*cppArg0);
            }
            break;
        }
        case 1: // QFontMetrics(const QFont &font, const QPaintDevice *pd)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QFont cppArg0_local;
            ::QFont *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPaintDevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFontMetrics(QFont,const QPaintDevice*)
                cptr = new ::QFontMetrics(*cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QFontMetrics(const QFontMetrics &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QFontMetrics cppArg0_local = ::QFontMetrics(::QFont());
            ::QFontMetrics *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QFontMetrics(QFontMetrics)
                cptr = new ::QFontMetrics(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QFontMetrics >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QFontMetricsFunc_ascent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ascent()const
        int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->ascent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_averageCharWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // averageCharWidth()const
        int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->averageCharWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_boundingRect(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 8));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOOO:boundingRect", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFontMetrics::boundingRect(QRect,int,QString,int=,PyObject=)const->QRect
    // 1: QFontMetrics::boundingRect(QString)const->QRect
    // 2: QFontMetrics::boundingRect(QString,QTextOption)const->QRect
    // 3: QFontMetrics::boundingRect(int,int,int,int,int,QString,int=,PyObject=)const->QRect
    if (numArgs >= 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[5])))) {
        if (numArgs == 6) {
            overloadId = 3; // boundingRect(int,int,int,int,int,QString,int,int*)const
        } else if (numArgs >= 7
            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))) {
            if (numArgs == 7) {
                overloadId = 3; // boundingRect(int,int,int,int,int,QString,int,int*)const
            } else if (numArgs >= 8) {
                overloadId = 3; // boundingRect(int,int,int,int,int,QString,int,int*)const
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // boundingRect(QString)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), (pyArgs[1])))) {
            overloadId = 2; // boundingRect(QString,QTextOption)const
        }
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // boundingRect(QRect,int,QString,int,int*)const
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 0; // boundingRect(QRect,int,QString,int,int*)const
            } else if (numArgs >= 5) {
                overloadId = 0; // boundingRect(QRect,int,QString,int,int*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // boundingRect(const QRect &r, int flags, const QString &text, int tabstops, int *tabarray) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_tabstops = Shiboken::String::createStaticString("tabstops");
                if (PyDict_Contains(kwds, key_tabstops) != 0) {
                    value = PyDict_GetItem(kwds, key_tabstops);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_tabstops);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_tabstops);
                }
                static PyObject *const key_tabarray = Shiboken::String::createStaticString("tabarray");
                if (PyDict_Contains(kwds, key_tabarray) != 0) {
                    value = PyDict_GetItem(kwds, key_tabarray);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_tabarray);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!true)
                            return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_tabarray);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = 0;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // boundingRect(QRect,int,QString,int,int*)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qfontmetrics-boundingrect-2)]
                int *array = nullptr;
                bool errorOccurred = false;

                if (numArgs == 5) {
                    array = Shiboken::sequenceToIntArray(pyArgs[5-1], true);
                    if (PyErr_Occurred()) {
                        delete [] array;
                        errorOccurred = true;
                    }
                }

                if (!errorOccurred) {
                    ::QRect retval = cppSelf->boundingRect((*cppArg0), cppArg1, cppArg2, cppArg3, array);

                    delete [] array;

                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &retval);
                }
                // END of custom code block [file: ../glue/qtgui.cpp (qfontmetrics-boundingrect-2)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // boundingRect(const QString &text) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // boundingRect(QString)const
                QRect cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->boundingRect(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
            }
            break;
        }
        case 2: // boundingRect(const QString &text, const QTextOption &textOption) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTextOption cppArg1_local;
            ::QTextOption *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // boundingRect(QString,QTextOption)const
                QRect cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->boundingRect(cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
            }
            break;
        }
        case 3: // boundingRect(int x, int y, int w, int h, int flags, const QString &text, int tabstops, int *tabarray) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_tabstops = Shiboken::String::createStaticString("tabstops");
                if (PyDict_Contains(kwds, key_tabstops) != 0) {
                    value = PyDict_GetItem(kwds, key_tabstops);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_tabstops);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_tabstops);
                }
                static PyObject *const key_tabarray = Shiboken::String::createStaticString("tabarray");
                if (PyDict_Contains(kwds, key_tabarray) != 0) {
                    value = PyDict_GetItem(kwds, key_tabarray);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_tabarray);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!true)
                            return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_tabarray);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QString cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            int cppArg6 = 0;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // boundingRect(int,int,int,int,int,QString,int,int*)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qfontmetrics-boundingrect-1)]
                int *array = nullptr;
                bool errorOccurred = false;

                if (numArgs == 8) {
                    array = Shiboken::sequenceToIntArray(pyArgs[8-1], true);
                    if (PyErr_Occurred()) {
                        delete [] array;
                        errorOccurred = true;
                    }
                }

                if (!errorOccurred) {
                    ::QRect retval = cppSelf->boundingRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, array);

                    delete [] array;

                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &retval);
                }
                // END of custom code block [file: ../glue/qtgui.cpp (qfontmetrics-boundingrect-1)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_boundingRectChar(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFontMetrics::boundingRect(char)const->QRect
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArg)))) {
        overloadId = 0; // boundingRect(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "boundingRectChar", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // boundingRect(QChar)const
            // Begin code injection
            // TEMPLATE - QFontCharFix - START
            int size = Shiboken::String::len(pyArg);
            if (size == 1) {
                const char *str = Shiboken::String::toCString(pyArg);
                const QChar ch(static_cast<unsigned short>(str[0]));
                ::QRect cppResult = cppSelf->boundingRect(ch);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
            } else {
                PyErr_SetString(PyExc_TypeError, "String must have only one character");
            }
            // TEMPLATE - QFontCharFix - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_capHeight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // capHeight()const
        int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->capHeight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_descent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // descent()const
        int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->descent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_elidedText(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "elidedText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:elidedText", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFontMetrics::elidedText(QString,Qt::TextElideMode,int,int=)const->QString
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TextElideMode_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // elidedText(QString,Qt::TextElideMode,int,int)const
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 0; // elidedText(QString,Qt::TextElideMode,int,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "elidedText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "elidedText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "elidedText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "elidedText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::TextElideMode cppArg1{Qt::ElideLeft};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3 = 0;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // elidedText(QString,Qt::TextElideMode,int,int)const
            QString cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->elidedText(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_fontDpi(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fontDpi()const
        qreal cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->fontDpi();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_height(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // height()const
        int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->height();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_horizontalAdvance(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "horizontalAdvance", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    if (PyArg_ParseTuple(args, "|OO:horizontalAdvance", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFontMetrics::horizontalAdvance(QString,QTextOption)const->int
    // 1: QFontMetrics::horizontalAdvance(QString,int=)const->int
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // horizontalAdvance(QString,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // horizontalAdvance(QString,int)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), (pyArgs[1])))) {
            overloadId = 0; // horizontalAdvance(QString,QTextOption)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "horizontalAdvance", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // horizontalAdvance(const QString &arg__1, const QTextOption &textOption) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "horizontalAdvance", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTextOption cppArg1_local;
            ::QTextOption *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // horizontalAdvance(QString,QTextOption)const
                int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->horizontalAdvance(cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
        case 1: // horizontalAdvance(const QString &arg__1, int len) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_len = Shiboken::String::createStaticString("len");
                if (PyDict_Contains(kwds, key_len) != 0) {
                    value = PyDict_GetItem(kwds, key_len);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_len);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "horizontalAdvance", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "horizontalAdvance", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_len);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "horizontalAdvance", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = -1;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // horizontalAdvance(QString,int)const
                int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->horizontalAdvance(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_horizontalAdvanceChar(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFontMetrics::horizontalAdvance(char)const->int
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArg)))) {
        overloadId = 0; // horizontalAdvance(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "horizontalAdvanceChar", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // horizontalAdvance(QChar)const
            // Begin code injection
            // TEMPLATE - QFontCharFix - START
            int size = Shiboken::String::len(pyArg);
            if (size == 1) {
                const char *str = Shiboken::String::toCString(pyArg);
                const QChar ch(static_cast<unsigned short>(str[0]));
                int cppResult = cppSelf->horizontalAdvance(ch);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            } else {
                PyErr_SetString(PyExc_TypeError, "String must have only one character");
            }
            // TEMPLATE - QFontCharFix - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_inFont(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFontMetrics::inFont(QChar)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArg)))) {
        overloadId = 0; // inFont(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "inFont", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    // Call function/method
    {
        ::QChar cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // inFont(QChar)const
            bool cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->inFont(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_inFontUcs4(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFontMetrics::inFontUcs4(uint)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // inFontUcs4(uint)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "inFontUcs4", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // inFontUcs4(uint)const
            bool cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->inFontUcs4(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_leading(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // leading()const
        int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->leading();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_leftBearing(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFontMetrics::leftBearing(QChar)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArg)))) {
        overloadId = 0; // leftBearing(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "leftBearing", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    // Call function/method
    {
        ::QChar cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // leftBearing(QChar)const
            int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->leftBearing(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_lineSpacing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lineSpacing()const
        int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->lineSpacing();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_lineWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lineWidth()const
        int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->lineWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_maxWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxWidth()const
        int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->maxWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_minLeftBearing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minLeftBearing()const
        int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->minLeftBearing();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_minRightBearing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minRightBearing()const
        int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->minRightBearing();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_overlinePos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // overlinePos()const
        int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->overlinePos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_rightBearing(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFontMetrics::rightBearing(QChar)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArg)))) {
        overloadId = 0; // rightBearing(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rightBearing", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    // Call function/method
    {
        ::QChar cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rightBearing(QChar)const
            int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->rightBearing(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_size(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "size", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:size", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFontMetrics::size(int,QString,int=,PyObject=)const->QSize
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // size(int,QString,int,int*)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // size(int,QString,int,int*)const
            } else if (numArgs >= 4) {
                overloadId = 0; // size(int,QString,int,int*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "size", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_tabstops = Shiboken::String::createStaticString("tabstops");
            if (PyDict_Contains(kwds, key_tabstops) != 0) {
                value = PyDict_GetItem(kwds, key_tabstops);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_tabstops);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "size", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "size", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_tabstops);
            }
            static PyObject *const key_tabarray = Shiboken::String::createStaticString("tabarray");
            if (PyDict_Contains(kwds, key_tabarray) != 0) {
                value = PyDict_GetItem(kwds, key_tabarray);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_tabarray);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "size", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!true)
                        return Shiboken::returnWrongArguments(args, "size", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_tabarray);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "size", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = 0;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // size(int,QString,int,int*)const
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qfontmetrics-size)]
            int *array = nullptr;
            bool errorOccurred = false;

            if (numArgs == 4) {
                array = Shiboken::sequenceToIntArray(pyArgs[4-1], true);
                if (PyErr_Occurred()) {
                    delete [] array;
                    errorOccurred = true;
                }
            }

            if (!errorOccurred) {
                ::QSize retval = cppSelf->size(cppArg0, cppArg1, cppArg2, array);

                delete [] array;

                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &retval);
            }
            // END of custom code block [file: ../glue/qtgui.cpp (qfontmetrics-size)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_strikeOutPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // strikeOutPos()const
        int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->strikeOutPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFontMetrics::swap(QFontMetrics&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QFontMetrics&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFontMetrics cppArg0_local = ::QFontMetrics(::QFont());
        ::QFontMetrics *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QFontMetrics&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontMetricsFunc_tightBoundingRect(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "tightBoundingRect", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFontMetrics::tightBoundingRect(QString)const->QRect
    // 1: QFontMetrics::tightBoundingRect(QString,QTextOption)const->QRect
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // tightBoundingRect(QString)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), (pyArgs[1])))) {
            overloadId = 1; // tightBoundingRect(QString,QTextOption)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "tightBoundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // tightBoundingRect(const QString &text) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // tightBoundingRect(QString)const
                QRect cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->tightBoundingRect(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
            }
            break;
        }
        case 1: // tightBoundingRect(const QString &text, const QTextOption &textOption) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTextOption cppArg1_local;
            ::QTextOption *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // tightBoundingRect(QString,QTextOption)const
                QRect cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->tightBoundingRect(cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_underlinePos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // underlinePos()const
        int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->underlinePos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetricsFunc_xHeight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // xHeight()const
        int cppResult = const_cast<const ::QFontMetrics *>(cppSelf)->xHeight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontMetrics__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QFontMetrics_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFontMetrics_methods[] = {
    {"ascent", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_ascent), METH_NOARGS, nullptr},
    {"averageCharWidth", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_averageCharWidth), METH_NOARGS, nullptr},
    {"boundingRect", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_boundingRect), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"boundingRectChar", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_boundingRectChar), METH_O, nullptr},
    {"capHeight", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_capHeight), METH_NOARGS, nullptr},
    {"descent", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_descent), METH_NOARGS, nullptr},
    {"elidedText", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_elidedText), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"fontDpi", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_fontDpi), METH_NOARGS, nullptr},
    {"height", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_height), METH_NOARGS, nullptr},
    {"horizontalAdvance", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_horizontalAdvance), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"horizontalAdvanceChar", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_horizontalAdvanceChar), METH_O, nullptr},
    {"inFont", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_inFont), METH_O, nullptr},
    {"inFontUcs4", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_inFontUcs4), METH_O, nullptr},
    {"leading", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_leading), METH_NOARGS, nullptr},
    {"leftBearing", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_leftBearing), METH_O, nullptr},
    {"lineSpacing", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_lineSpacing), METH_NOARGS, nullptr},
    {"lineWidth", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_lineWidth), METH_NOARGS, nullptr},
    {"maxWidth", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_maxWidth), METH_NOARGS, nullptr},
    {"minLeftBearing", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_minLeftBearing), METH_NOARGS, nullptr},
    {"minRightBearing", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_minRightBearing), METH_NOARGS, nullptr},
    {"overlinePos", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_overlinePos), METH_NOARGS, nullptr},
    {"rightBearing", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_rightBearing), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_size), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"strikeOutPos", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_strikeOutPos), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_swap), METH_O, nullptr},
    {"tightBoundingRect", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_tightBoundingRect), METH_VARARGS, nullptr},
    {"underlinePos", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_underlinePos), METH_NOARGS, nullptr},
    {"xHeight", reinterpret_cast<PyCFunction>(Sbk_QFontMetricsFunc_xHeight), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QFontMetrics__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QFontMetrics_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), (pyArg)))) {
                // operator!=(const QFontMetrics &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QFontMetrics cppArg0_local = ::QFontMetrics(::QFont());
                ::QFontMetrics *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), (pyArg)))) {
                // operator==(const QFontMetrics &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QFontMetrics cppArg0_local = ::QFontMetrics(::QFont());
                ::QFontMetrics *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QFontMetrics_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFontMetrics_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFontMetrics_Type = nullptr;
static PyTypeObject *Sbk_QFontMetrics_TypeF(void)
{
    return _Sbk_QFontMetrics_Type;
}

static PyType_Slot Sbk_QFontMetrics_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFontMetrics_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFontMetrics_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QFontMetrics_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFontMetrics_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFontMetrics_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFontMetrics_spec = {
    "2:PySide6.QtGui.QFontMetrics",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFontMetrics_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFontMetrics_PythonToCpp_QFontMetrics_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFontMetrics_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFontMetrics_PythonToCpp_QFontMetrics_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFontMetrics_TypeF()))
        return QFontMetrics_PythonToCpp_QFontMetrics_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFontMetrics_PTR_CppToPython_QFontMetrics(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QFontMetrics_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QFontMetrics_COPY_CppToPython_QFontMetrics(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QFontMetrics *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QFontMetrics_TypeF(), new ::QFontMetrics(*source), true, true);
}

// Python to C++ copy conversion.
static void QFontMetrics_PythonToCpp_QFontMetrics_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QFontMetrics *>(cppOut) = *reinterpret_cast< ::QFontMetrics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QFontMetrics_PythonToCpp_QFontMetrics_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QFontMetrics_TypeF()))
        return QFontMetrics_PythonToCpp_QFontMetrics_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFontMetrics_SignatureStrings[] = {
    "2:PySide6.QtGui.QFontMetrics(self,arg__1:typing.Union[PySide6.QtGui.QFont, QString, QStringList])",
    "1:PySide6.QtGui.QFontMetrics(self,font:typing.Union[PySide6.QtGui.QFont, QString, QStringList],pd:PySide6.QtGui.QPaintDevice)",
    "0:PySide6.QtGui.QFontMetrics(self,arg__1:PySide6.QtGui.QFontMetrics)",
    "PySide6.QtGui.QFontMetrics.ascent(self)->int",
    "PySide6.QtGui.QFontMetrics.averageCharWidth(self)->int",
    "3:PySide6.QtGui.QFontMetrics.boundingRect(self,r:PySide6.QtCore.QRect,flags:int,text:QString,tabstops:int=0,tabarray:PyObject=nullptr)->PySide6.QtCore.QRect",
    "2:PySide6.QtGui.QFontMetrics.boundingRect(self,text:QString)->PySide6.QtCore.QRect",
    "1:PySide6.QtGui.QFontMetrics.boundingRect(self,text:QString,textOption:typing.Union[PySide6.QtGui.QTextOption, PySide6.QtCore.Qt.AlignmentFlag])->PySide6.QtCore.QRect",
    "0:PySide6.QtGui.QFontMetrics.boundingRect(self,x:int,y:int,w:int,h:int,flags:int,text:QString,tabstops:int=0,tabarray:PyObject=nullptr)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QFontMetrics.boundingRectChar(self,arg__1:char)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QFontMetrics.capHeight(self)->int",
    "PySide6.QtGui.QFontMetrics.descent(self)->int",
    "PySide6.QtGui.QFontMetrics.elidedText(self,text:QString,mode:PySide6.QtCore.Qt.TextElideMode,width:int,flags:int=0)->QString",
    "PySide6.QtGui.QFontMetrics.fontDpi(self)->qreal",
    "PySide6.QtGui.QFontMetrics.height(self)->int",
    "1:PySide6.QtGui.QFontMetrics.horizontalAdvance(self,arg__1:QString,textOption:typing.Union[PySide6.QtGui.QTextOption, PySide6.QtCore.Qt.AlignmentFlag])->int",
    "0:PySide6.QtGui.QFontMetrics.horizontalAdvance(self,arg__1:QString,len:int=-1)->int",
    "PySide6.QtGui.QFontMetrics.horizontalAdvanceChar(self,arg__1:char)->int",
    "PySide6.QtGui.QFontMetrics.inFont(self,arg__1:QChar)->bool",
    "PySide6.QtGui.QFontMetrics.inFontUcs4(self,ucs4:uint)->bool",
    "PySide6.QtGui.QFontMetrics.leading(self)->int",
    "PySide6.QtGui.QFontMetrics.leftBearing(self,arg__1:QChar)->int",
    "PySide6.QtGui.QFontMetrics.lineSpacing(self)->int",
    "PySide6.QtGui.QFontMetrics.lineWidth(self)->int",
    "PySide6.QtGui.QFontMetrics.maxWidth(self)->int",
    "PySide6.QtGui.QFontMetrics.minLeftBearing(self)->int",
    "PySide6.QtGui.QFontMetrics.minRightBearing(self)->int",
    "PySide6.QtGui.QFontMetrics.overlinePos(self)->int",
    "PySide6.QtGui.QFontMetrics.rightBearing(self,arg__1:QChar)->int",
    "PySide6.QtGui.QFontMetrics.size(self,flags:int,str:QString,tabstops:int=0,tabarray:PyObject=nullptr)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QFontMetrics.strikeOutPos(self)->int",
    "PySide6.QtGui.QFontMetrics.swap(self,other:PySide6.QtGui.QFontMetrics)",
    "1:PySide6.QtGui.QFontMetrics.tightBoundingRect(self,text:QString)->PySide6.QtCore.QRect",
    "0:PySide6.QtGui.QFontMetrics.tightBoundingRect(self,text:QString,textOption:typing.Union[PySide6.QtGui.QTextOption, PySide6.QtCore.Qt.AlignmentFlag])->PySide6.QtCore.QRect",
    "PySide6.QtGui.QFontMetrics.underlinePos(self)->int",
    "PySide6.QtGui.QFontMetrics.xHeight(self)->int",
    "PySide6.QtGui.QFontMetrics.__copy__(self)->typing.Self",
    "PySide6.QtGui.QFontMetrics.__ne__(self,other:PySide6.QtGui.QFontMetrics)->bool",
    "PySide6.QtGui.QFontMetrics.__eq__(self,other:PySide6.QtGui.QFontMetrics)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QFontMetrics_SignatureByteSize = 584;
static constexpr uint8_t QFontMetrics_SignatureBytes[584] = {
    0x78, 0xda, 0xbd, 0x56, 0x5d, 0x6f, 0xda, 0x30, 0x14, 0x7d, 0xe7, 0x57, 0xf4, 0x71, 0x48, 0x69,
    0x14, 0xba, 0x69, 0x0f, 0x91, 0x98, 0xd4, 0xd2, 0x75, 0x7b, 0x68, 0x05, 0x94, 0x55, 0x7b, 0x98,
    0xaa, 0xc8, 0x24, 0x97, 0xc4, 0x9b, 0xb1, 0x53, 0xdb, 0x01, 0xd2, 0x5f, 0xbf, 0xeb, 0x00, 0x1d,
    0x04, 0xe2, 0x24, 0xb4, 0xdd, 0x8b, 0x13, 0xc7, 0xf7, 0x9c, 0x7b, 0xee, 0x87, 0xed, 0x5c, 0xf8,
    0xa3, 0x7c, 0x42, 0x23, 0xf8, 0xec, 0x8e, 0xf5, 0xb7, 0x8c, 0xba, 0xe3, 0x1b, 0xc1, 0xf5, 0x1d,
    0x68, 0x49, 0x43, 0xf5, 0x41, 0x01, 0x9b, 0x39, 0x44, 0xc6, 0x41, 0xd0, 0xf3, 0x75, 0x9e, 0x52,
    0x1e, 0xbb, 0x0f, 0x9c, 0x0a, 0xfe, 0xeb, 0x08, 0xc6, 0x39, 0x1b, 0x4f, 0x10, 0xc5, 0xe3, 0x97,
    0x97, 0x5b, 0xaa, 0xf4, 0x63, 0xb7, 0xd3, 0xab, 0xf5, 0x30, 0xc3, 0x0f, 0xa7, 0xf2, 0x3b, 0x69,
    0x54, 0xe6, 0x1f, 0x11, 0xca, 0xf5, 0x35, 0x2c, 0x68, 0x08, 0xdd, 0x8e, 0xd7, 0x34, 0xbe, 0x6a,
    0xb3, 0x6e, 0xa7, 0x7a, 0xcd, 0x25, 0x2a, 0x04, 0xae, 0x0b, 0xa6, 0xee, 0xf9, 0x17, 0x74, 0x6c,
    0x35, 0x5e, 0x80, 0x24, 0x31, 0x0c, 0x12, 0x22, 0x7f, 0xd2, 0x48, 0x27, 0xbb, 0xb0, 0x8f, 0x16,
    0x05, 0xee, 0x54, 0x64, 0x3c, 0xc2, 0x90, 0xef, 0x21, 0x5c, 0xfb, 0x72, 0xe4, 0x8e, 0xf9, 0x40,
    0x48, 0x70, 0xc7, 0x66, 0xcd, 0x99, 0x31, 0x12, 0x2b, 0x1f, 0xf9, 0x1c, 0x0d, 0x2b, 0xed, 0x6f,
    0x53, 0xa6, 0xc9, 0x54, 0x69, 0x91, 0x16, 0x2b, 0x7d, 0xcf, 0x4c, 0x89, 0x94, 0x24, 0x47, 0x8e,
    0xe1, 0xf4, 0x37, 0xe2, 0xfa, 0x3c, 0x63, 0x2c, 0xd5, 0x12, 0xb5, 0x1c, 0xa3, 0xed, 0x5c, 0xb4,
    0x13, 0xb7, 0xeb, 0xbb, 0x8a, 0xb2, 0x77, 0x3a, 0x65, 0x31, 0x19, 0xa6, 0x1a, 0x3b, 0xc5, 0xda,
    0x36, 0x3f, 0x5e, 0xcc, 0x9c, 0xb3, 0xb2, 0x06, 0xed, 0x5e, 0x32, 0x1a, 0xf3, 0x39, 0x16, 0xef,
    0x06, 0x73, 0xf6, 0x58, 0x25, 0xd3, 0x6b, 0x27, 0x73, 0x55, 0xe4, 0x3e, 0x2f, 0xc6, 0x65, 0x31,
    0x26, 0xc5, 0xf8, 0x4e, 0x75, 0x69, 0xa8, 0xcd, 0x34, 0xdc, 0x5e, 0xb3, 0x87, 0xf8, 0xe1, 0x04,
    0xce, 0x90, 0xa4, 0xdf, 0x81, 0xc6, 0x49, 0xd3, 0x7e, 0x8f, 0xa0, 0xcd, 0xee, 0x00, 0x86, 0x2b,
    0x91, 0x29, 0xda, 0x91, 0x92, 0xcf, 0x45, 0x04, 0xfe, 0x61, 0x11, 0x8d, 0xf5, 0x57, 0x83, 0xbb,
    0xc3, 0x75, 0x67, 0x69, 0x36, 0xd5, 0x7e, 0xbe, 0xfb, 0x1e, 0x3a, 0xde, 0x90, 0xd8, 0x9c, 0x9b,
    0x33, 0xe8, 0x3a, 0xa5, 0x5b, 0xa9, 0x4f, 0x12, 0x08, 0xb3, 0xd9, 0x27, 0x07, 0x79, 0xb0, 0x36,
    0x74, 0x22, 0x24, 0x7d, 0xc6, 0x39, 0x61, 0x97, 0xd1, 0x82, 0xf0, 0x10, 0xf6, 0xca, 0xf1, 0xbe,
    0x7d, 0x6d, 0xc4, 0x79, 0xaf, 0x17, 0xc7, 0x80, 0x17, 0x09, 0x3d, 0xef, 0xd5, 0x97, 0xf2, 0x80,
    0xb1, 0xaa, 0x03, 0x6b, 0x78, 0x28, 0x37, 0xb3, 0x7d, 0x39, 0x83, 0x35, 0x72, 0x2a, 0x04, 0xab,
    0x87, 0x3e, 0x84, 0xea, 0xd3, 0x1a, 0x9e, 0xe1, 0x9b, 0x9f, 0xa1, 0xbf, 0x06, 0x58, 0x06, 0xc4,
    0x6c, 0x9d, 0x86, 0x7d, 0xcb, 0x60, 0xa6, 0xaf, 0x80, 0xc8, 0x2d, 0xa2, 0xac, 0xb4, 0x0e, 0x4e,
    0x39, 0x4c, 0x52, 0x12, 0xb6, 0x70, 0x88, 0x88, 0x83, 0xfb, 0xc3, 0x62, 0x3f, 0x27, 0xab, 0x56,
    0xe6, 0x94, 0xdf, 0x96, 0x42, 0x6a, 0x04, 0xba, 0x37, 0x3b, 0xa2, 0x1d, 0x4a, 0xe0, 0x85, 0x68,
    0xa2, 0x19, 0x09, 0xd5, 0x10, 0x21, 0xcb, 0x4e, 0x5a, 0x66, 0x5b, 0xd1, 0xe7, 0x4d, 0x7b, 0xff,
    0x3b, 0x92, 0x95, 0x96, 0x6f, 0x71, 0x22, 0x4f, 0x90, 0xda, 0xea, 0x1a, 0x1f, 0x7f, 0x60, 0x98,
    0xe9, 0xe6, 0xd1, 0xaa, 0x25, 0x49, 0xd7, 0x6a, 0x85, 0x4e, 0x40, 0x5a, 0x7f, 0x52, 0xac, 0xe7,
    0x8f, 0x2e, 0xd2, 0x76, 0xd2, 0x45, 0xed, 0xbd, 0x92, 0xf7, 0x7f, 0xde, 0xd6, 0x16, 0xa5, 0x28,
    0xb1, 0x6d, 0xaf, 0xad, 0x5a, 0x5d, 0x76, 0x41, 0x10, 0x8a, 0x34, 0x0f, 0x82, 0xad, 0xf9, 0x26,
    0xd6, 0x09, 0xce, 0xec, 0x30, 0x0e, 0x1b, 0x50, 0x7d, 0x91, 0xeb, 0x8f, 0xae, 0x20, 0x80, 0xa7,
    0xb6, 0x74, 0x7f, 0x01, 0x1e, 0x35, 0x4e, 0x4b
};
#endif

PyTypeObject *init_QFontMetrics(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX].type;

    Shiboken::AutoDecRef Sbk_QFontMetrics_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QFontMetrics_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFontMetrics",
        "QFontMetrics",
        &Sbk_QFontMetrics_spec,
        &Shiboken::callCppDestructor< ::QFontMetrics >,
        Sbk_QFontMetrics_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QFontMetrics_TypeF(); // references _Sbk_QFontMetrics_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFontMetrics_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFontMetrics_SignatureBytes, QFontMetrics_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFontMetrics_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFontMetrics_PythonToCpp_QFontMetrics_PTR,
        is_QFontMetrics_PythonToCpp_QFontMetrics_PTR_Convertible,
        QFontMetrics_PTR_CppToPython_QFontMetrics,
        QFontMetrics_COPY_CppToPython_QFontMetrics);

    Shiboken::Conversions::registerConverterName(converter, "QFontMetrics");
    Shiboken::Conversions::registerConverterName(converter, "QFontMetrics*");
    Shiboken::Conversions::registerConverterName(converter, "QFontMetrics&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFontMetrics).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QFontMetrics_PythonToCpp_QFontMetrics_COPY,
        is_QFontMetrics_PythonToCpp_QFontMetrics_COPY_Convertible);


    return pyType;
}
