// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qglyphrun_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qglyphrun.h>
#include <QtGui/qrawfont.h>
#include <qpoint.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGlyphRun_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGlyphRun >()))
        return -1;

    ::QGlyphRun *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QGlyphRun", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGlyphRun::QGlyphRun()
    // 1: QGlyphRun::QGlyphRun(QGlyphRun)
    if (numArgs == 0) {
        overloadId = 0; // QGlyphRun()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QGlyphRun(QGlyphRun)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGlyphRun()
        {

            // QGlyphRun()
            cptr = new ::QGlyphRun();
            break;
        }
        case 1: // QGlyphRun(const QGlyphRun &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGlyphRun cppArg0_local;
            ::QGlyphRun *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGlyphRun(QGlyphRun)
                cptr = new ::QGlyphRun(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGlyphRun >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGlyphRunFunc_boundingRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // boundingRect()const
        QRectF cppResult = const_cast<const ::QGlyphRun *>(cppSelf)->boundingRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGlyphRunFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGlyphRunFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QGlyphRun::GlyphRunFlag> cppResult = const_cast<const ::QGlyphRun *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QGlyphRun_GlyphRunFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGlyphRunFunc_glyphIndexes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // glyphIndexes()const
        QList<quint32> cppResult = const_cast<const ::QGlyphRun *>(cppSelf)->glyphIndexes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_quint32_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGlyphRunFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QGlyphRun *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGlyphRunFunc_isRightToLeft(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRightToLeft()const
        bool cppResult = const_cast<const ::QGlyphRun *>(cppSelf)->isRightToLeft();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGlyphRunFunc_overline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // overline()const
        bool cppResult = const_cast<const ::QGlyphRun *>(cppSelf)->overline();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGlyphRunFunc_positions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // positions()const
        QList<QPointF> cppResult = const_cast<const ::QGlyphRun *>(cppSelf)->positions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPointF_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGlyphRunFunc_rawFont(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rawFont()const
        QRawFont cppResult = const_cast<const ::QGlyphRun *>(cppSelf)->rawFont();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGlyphRunFunc_setBoundingRect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGlyphRun::setBoundingRect(QRectF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
        overloadId = 0; // setBoundingRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBoundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBoundingRect(QRectF)
            cppSelf->setBoundingRect(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGlyphRunFunc_setFlag(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setFlag", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGlyphRun::setFlag(QGlyphRun::GlyphRunFlag,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_GlyphRunFlag_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setFlag(QGlyphRun::GlyphRunFlag,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setFlag(QGlyphRun::GlyphRunFlag,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_enabled = Shiboken::String::createStaticString("enabled");
            if (PyDict_Contains(kwds, key_enabled) != 0) {
                value = PyDict_GetItem(kwds, key_enabled);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_enabled);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_enabled);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);
            }
        }
        ::QGlyphRun::GlyphRunFlag cppArg0 = static_cast< ::QGlyphRun::GlyphRunFlag>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlag(QGlyphRun::GlyphRunFlag,bool)
            cppSelf->setFlag(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGlyphRunFunc_setFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGlyphRun::setFlags(QFlags<QGlyphRun::GlyphRunFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QGlyphRun_GlyphRunFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setFlags(QFlags<QGlyphRun::GlyphRunFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlags", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    // Call function/method
    {
        ::QFlags<QGlyphRun::GlyphRunFlag> cppArg0 = QFlags<QGlyphRun::GlyphRunFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlags(QFlags<QGlyphRun::GlyphRunFlag>)
            cppSelf->setFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGlyphRunFunc_setGlyphIndexes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGlyphRun::setGlyphIndexes(QList<quint32>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_quint32_IDX], (pyArg)))) {
        overloadId = 0; // setGlyphIndexes(QList<quint32>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGlyphIndexes", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    // Call function/method
    {
        ::QList<quint32> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGlyphIndexes(QList<quint32>)
            cppSelf->setGlyphIndexes(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGlyphRunFunc_setOverline(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGlyphRun::setOverline(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setOverline(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOverline", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOverline(bool)
            cppSelf->setOverline(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGlyphRunFunc_setPositions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGlyphRun::setPositions(QList<QPointF>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPointF_IDX], (pyArg)))) {
        overloadId = 0; // setPositions(QList<QPointF>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPositions", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    // Call function/method
    {
        ::QList<QPointF> cppArg0_local;
        ::QList<QPointF> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPositions(QList<QPointF>)
            cppSelf->setPositions(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGlyphRunFunc_setRawData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setRawData", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGlyphRun::setRawData(const quint32*,const QPointF*,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // setRawData(const quint32*,const QPointF*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRawData", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    // Call function/method
    {
        quint32 *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPointF *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRawData(const quint32*,const QPointF*,int)
            cppSelf->setRawData(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGlyphRunFunc_setRawFont(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGlyphRun::setRawFont(QRawFont)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), (pyArg)))) {
        overloadId = 0; // setRawFont(QRawFont)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRawFont", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRawFont cppArg0_local;
        ::QRawFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRawFont(QRawFont)
            cppSelf->setRawFont(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGlyphRunFunc_setRightToLeft(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGlyphRun::setRightToLeft(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setRightToLeft(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRightToLeft", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRightToLeft(bool)
            cppSelf->setRightToLeft(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGlyphRunFunc_setSourceString(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGlyphRun::setSourceString(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setSourceString(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSourceString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSourceString(QString)
            cppSelf->setSourceString(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGlyphRunFunc_setStrikeOut(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGlyphRun::setStrikeOut(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setStrikeOut(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStrikeOut", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStrikeOut(bool)
            cppSelf->setStrikeOut(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGlyphRunFunc_setStringIndexes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGlyphRun::setStringIndexes(QList<qsizetype>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_qsizetype_IDX], (pyArg)))) {
        overloadId = 0; // setStringIndexes(QList<qsizetype>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStringIndexes", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    // Call function/method
    {
        ::QList<qsizetype> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStringIndexes(QList<qsizetype>)
            cppSelf->setStringIndexes(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGlyphRunFunc_setUnderline(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGlyphRun::setUnderline(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setUnderline(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUnderline", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUnderline(bool)
            cppSelf->setUnderline(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGlyphRunFunc_sourceString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sourceString()const
        QString cppResult = const_cast<const ::QGlyphRun *>(cppSelf)->sourceString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGlyphRunFunc_strikeOut(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // strikeOut()const
        bool cppResult = const_cast<const ::QGlyphRun *>(cppSelf)->strikeOut();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGlyphRunFunc_stringIndexes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stringIndexes()const
        QList<qsizetype> cppResult = const_cast<const ::QGlyphRun *>(cppSelf)->stringIndexes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_qsizetype_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGlyphRunFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGlyphRun::swap(QGlyphRun&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QGlyphRun&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGlyphRun cppArg0_local;
        ::QGlyphRun *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QGlyphRun&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGlyphRunFunc_underline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // underline()const
        bool cppResult = const_cast<const ::QGlyphRun *>(cppSelf)->underline();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGlyphRun__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGlyphRun_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QGlyphRun_EnumFlagInfo[] = {
    "GlyphRunFlag:Flag:GlyphRunFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGlyphRun_methods[] = {
    {"boundingRect", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_boundingRect), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_clear), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_flags), METH_NOARGS, nullptr},
    {"glyphIndexes", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_glyphIndexes), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_isEmpty), METH_NOARGS, nullptr},
    {"isRightToLeft", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_isRightToLeft), METH_NOARGS, nullptr},
    {"overline", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_overline), METH_NOARGS, nullptr},
    {"positions", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_positions), METH_NOARGS, nullptr},
    {"rawFont", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_rawFont), METH_NOARGS, nullptr},
    {"setBoundingRect", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_setBoundingRect), METH_O, nullptr},
    {"setFlag", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_setFlag), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_setFlags), METH_O, nullptr},
    {"setGlyphIndexes", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_setGlyphIndexes), METH_O, nullptr},
    {"setOverline", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_setOverline), METH_O, nullptr},
    {"setPositions", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_setPositions), METH_O, nullptr},
    {"setRawData", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_setRawData), METH_VARARGS, nullptr},
    {"setRawFont", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_setRawFont), METH_O, nullptr},
    {"setRightToLeft", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_setRightToLeft), METH_O, nullptr},
    {"setSourceString", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_setSourceString), METH_O, nullptr},
    {"setStrikeOut", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_setStrikeOut), METH_O, nullptr},
    {"setStringIndexes", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_setStringIndexes), METH_O, nullptr},
    {"setUnderline", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_setUnderline), METH_O, nullptr},
    {"sourceString", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_sourceString), METH_NOARGS, nullptr},
    {"strikeOut", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_strikeOut), METH_NOARGS, nullptr},
    {"stringIndexes", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_stringIndexes), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_swap), METH_O, nullptr},
    {"underline", reinterpret_cast<PyCFunction>(Sbk_QGlyphRunFunc_underline), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGlyphRun__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QGlyphRun_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), (pyArg)))) {
                // operator!=(const QGlyphRun &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGlyphRun cppArg0_local;
                ::QGlyphRun *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), (pyArg)))) {
                // operator==(const QGlyphRun &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGlyphRun cppArg0_local;
                ::QGlyphRun *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QGlyphRun_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGlyphRun_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGlyphRun_Type = nullptr;
static PyTypeObject *Sbk_QGlyphRun_TypeF(void)
{
    return _Sbk_QGlyphRun_Type;
}

static PyType_Slot Sbk_QGlyphRun_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGlyphRun_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGlyphRun_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QGlyphRun_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGlyphRun_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGlyphRun_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGlyphRun_spec = {
    "2:PySide6.QtGui.QGlyphRun",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGlyphRun_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QGlyphRun_GlyphRunFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGlyphRun::GlyphRunFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGlyphRun::GlyphRunFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGlyphRun_GlyphRunFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_GlyphRunFlag_IDX])))
        return Enum_PythonToCpp_QGlyphRun_GlyphRunFlag;
    return {};
}

static PyObject *QGlyphRun_GlyphRunFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGlyphRun::GlyphRunFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGlyphRun::GlyphRunFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_GlyphRunFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QGlyphRun_GlyphRunFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QGlyphRun::GlyphRunFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QGlyphRun::GlyphRunFlag> *>(cppOut) = value;

}

static PyObject *QGlyphRun_GlyphRunFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QGlyphRun::GlyphRunFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_GlyphRunFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGlyphRun_PythonToCpp_QGlyphRun_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGlyphRun_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGlyphRun_PythonToCpp_QGlyphRun_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGlyphRun_TypeF()))
        return QGlyphRun_PythonToCpp_QGlyphRun_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGlyphRun_PTR_CppToPython_QGlyphRun(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QGlyphRun_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QGlyphRun_COPY_CppToPython_QGlyphRun(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGlyphRun *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGlyphRun_TypeF(), new ::QGlyphRun(*source), true, true);
}

// Python to C++ copy conversion.
static void QGlyphRun_PythonToCpp_QGlyphRun_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGlyphRun *>(cppOut) = *reinterpret_cast< ::QGlyphRun *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGlyphRun_PythonToCpp_QGlyphRun_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGlyphRun_TypeF()))
        return QGlyphRun_PythonToCpp_QGlyphRun_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGlyphRun_SignatureStrings[] = {
    "1:PySide6.QtGui.QGlyphRun(self)",
    "0:PySide6.QtGui.QGlyphRun(self,other:PySide6.QtGui.QGlyphRun)",
    "PySide6.QtGui.QGlyphRun.boundingRect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QGlyphRun.clear(self)",
    "PySide6.QtGui.QGlyphRun.flags(self)->PySide6.QtGui.QGlyphRun.GlyphRunFlag",
    "PySide6.QtGui.QGlyphRun.glyphIndexes(self)->QList[quint32]",
    "PySide6.QtGui.QGlyphRun.isEmpty(self)->bool",
    "PySide6.QtGui.QGlyphRun.isRightToLeft(self)->bool",
    "PySide6.QtGui.QGlyphRun.overline(self)->bool",
    "PySide6.QtGui.QGlyphRun.positions(self)->QList[PySide6.QtCore.QPointF]",
    "PySide6.QtGui.QGlyphRun.rawFont(self)->PySide6.QtGui.QRawFont",
    "PySide6.QtGui.QGlyphRun.setBoundingRect(self,boundingRect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtGui.QGlyphRun.setFlag(self,flag:PySide6.QtGui.QGlyphRun.GlyphRunFlag,enabled:bool=true)",
    "PySide6.QtGui.QGlyphRun.setFlags(self,flags:PySide6.QtGui.QGlyphRun.GlyphRunFlag)",
    "PySide6.QtGui.QGlyphRun.setGlyphIndexes(self,glyphIndexes:QList[quint32])",
    "PySide6.QtGui.QGlyphRun.setOverline(self,overline:bool)",
    "PySide6.QtGui.QGlyphRun.setPositions(self,positions:QList[PySide6.QtCore.QPointF])",
    "PySide6.QtGui.QGlyphRun.setRawData(self,glyphIndexArray:quint32*,glyphPositionArray:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],size:int)",
    "PySide6.QtGui.QGlyphRun.setRawFont(self,rawFont:PySide6.QtGui.QRawFont)",
    "PySide6.QtGui.QGlyphRun.setRightToLeft(self,on:bool)",
    "PySide6.QtGui.QGlyphRun.setSourceString(self,sourceString:QString)",
    "PySide6.QtGui.QGlyphRun.setStrikeOut(self,strikeOut:bool)",
    "PySide6.QtGui.QGlyphRun.setStringIndexes(self,stringIndexes:QList[qsizetype])",
    "PySide6.QtGui.QGlyphRun.setUnderline(self,underline:bool)",
    "PySide6.QtGui.QGlyphRun.sourceString(self)->QString",
    "PySide6.QtGui.QGlyphRun.strikeOut(self)->bool",
    "PySide6.QtGui.QGlyphRun.stringIndexes(self)->QList[qsizetype]",
    "PySide6.QtGui.QGlyphRun.swap(self,other:PySide6.QtGui.QGlyphRun)",
    "PySide6.QtGui.QGlyphRun.underline(self)->bool",
    "PySide6.QtGui.QGlyphRun.__copy__(self)->typing.Self",
    "PySide6.QtGui.QGlyphRun.__ne__(self,other:PySide6.QtGui.QGlyphRun)->bool",
    "PySide6.QtGui.QGlyphRun.__eq__(self,other:PySide6.QtGui.QGlyphRun)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QGlyphRun_SignatureByteSize = 494;
static constexpr uint8_t QGlyphRun_SignatureBytes[494] = {
    0x78, 0xda, 0xa5, 0x55, 0x4d, 0x4f, 0xe3, 0x30, 0x10, 0xbd, 0xf3, 0x2b, 0x38, 0x52, 0x64, 0x22,
    0x96, 0x95, 0xf6, 0x60, 0x69, 0x57, 0x5a, 0x3e, 0x5a, 0x21, 0x21, 0x91, 0xb4, 0xcb, 0x09, 0x55,
    0x95, 0xdb, 0x4e, 0x5b, 0x6b, 0x83, 0x1d, 0xec, 0xf1, 0xb2, 0xe1, 0xd7, 0xe3, 0xd4, 0x49, 0x9b,
    0xa4, 0xb5, 0x13, 0xc4, 0x29, 0xf6, 0x7c, 0xbc, 0x37, 0x33, 0x7e, 0x76, 0xbe, 0xd1, 0x38, 0x9f,
    0xf0, 0x25, 0xfc, 0x88, 0x12, 0x1c, 0x19, 0x1e, 0x25, 0xa3, 0x34, 0xcf, 0x36, 0x63, 0x23, 0xce,
    0x34, 0xa4, 0xab, 0xc1, 0xc9, 0x65, 0xd0, 0x4f, 0x24, 0x6e, 0x40, 0xf9, 0x42, 0x06, 0x27, 0x1e,
    0x47, 0x34, 0x97, 0x46, 0x2c, 0xb9, 0x58, 0x8f, 0x61, 0x81, 0x8e, 0xe8, 0xe2, 0xd7, 0x3e, 0xf6,
    0x46, 0x2a, 0x88, 0x92, 0xc2, 0x37, 0xf4, 0x22, 0x2c, 0x52, 0x60, 0xaa, 0xac, 0xd1, 0x17, 0xb3,
    0x4a, 0xd9, 0x5a, 0x1f, 0xc2, 0x37, 0x83, 0xaa, 0xc5, 0xd0, 0x06, 0x7b, 0x91, 0xd6, 0xc5, 0xe2,
    0x5e, 0x2c, 0xe1, 0x3f, 0xec, 0x00, 0x93, 0x07, 0xae, 0xf1, 0xf9, 0xd5, 0x70, 0x81, 0xdf, 0xaf,
    0xa6, 0xde, 0x54, 0xae, 0xef, 0x5e, 0x32, 0xcc, 0xab, 0xac, 0xb9, 0x94, 0x69, 0x20, 0x76, 0xcc,
    0xd7, 0x1b, 0xfc, 0x23, 0x1f, 0x60, 0x85, 0xbd, 0x32, 0xe4, 0x3f, 0x50, 0x29, 0x17, 0xd0, 0x2b,
    0x38, 0x93, 0x9a, 0x23, 0x97, 0xa2, 0xd5, 0x42, 0x7b, 0xf0, 0xb1, 0xb4, 0x2d, 0x0d, 0xfd, 0x1d,
    0x29, 0xf6, 0x36, 0x94, 0x02, 0x3d, 0x83, 0x1d, 0x3b, 0xaf, 0x37, 0x5b, 0x03, 0x5e, 0xb7, 0x4f,
    0x9f, 0xd4, 0xf5, 0x40, 0x31, 0xcf, 0xec, 0x32, 0x7a, 0x12, 0xb6, 0xd4, 0xe7, 0xa3, 0xaa, 0x20,
    0xa7, 0xc7, 0xcc, 0xd3, 0x41, 0x88, 0xb4, 0x38, 0x5f, 0x47, 0x56, 0xc8, 0x82, 0xf6, 0x91, 0x03,
    0x01, 0xc1, 0xe6, 0x29, 0x2c, 0x69, 0x31, 0xd5, 0x9f, 0xa8, 0x0c, 0x74, 0x32, 0xe8, 0x3d, 0x85,
    0xee, 0xc5, 0x11, 0x44, 0x1c, 0xb5, 0x65, 0x47, 0xea, 0x42, 0xa4, 0x4d, 0x05, 0x06, 0x91, 0x1e,
    0xeb, 0x3a, 0x21, 0x95, 0x6a, 0xb6, 0x8d, 0x05, 0xf3, 0xe2, 0x86, 0x64, 0xc8, 0x4e, 0x41, 0x34,
    0x28, 0x9d, 0x20, 0xa4, 0x15, 0xc8, 0x2d, 0x43, 0xd6, 0xee, 0xe7, 0xb7, 0x52, 0x2c, 0xa7, 0x65,
    0x33, 0xe7, 0xce, 0x51, 0xb1, 0x3b, 0x5f, 0x50, 0x17, 0x8e, 0xf9, 0x50, 0x18, 0x5b, 0x7b, 0xdd,
    0xbc, 0xad, 0x27, 0x66, 0xd6, 0x0a, 0x2a, 0x66, 0xb8, 0x89, 0xee, 0x52, 0x78, 0x01, 0x81, 0x53,
    0xa2, 0xf9, 0x3b, 0x50, 0x6b, 0xef, 0xaa, 0x7e, 0x27, 0x7e, 0x52, 0xde, 0x04, 0x7a, 0xfc, 0x0a,
    0x84, 0x71, 0x5a, 0x17, 0x9d, 0x48, 0xd1, 0x7d, 0x1a, 0x13, 0x69, 0xd4, 0x02, 0x26, 0xa8, 0xec,
    0x1c, 0x5c, 0x96, 0xae, 0x59, 0x68, 0xe2, 0xbe, 0x61, 0x08, 0x1b, 0xf2, 0x17, 0x1e, 0x4d, 0xc9,
    0xaa, 0xab, 0x6d, 0x0f, 0xf2, 0x2d, 0x78, 0x43, 0x8d, 0xba, 0x6e, 0xaa, 0xe4, 0x58, 0x8c, 0xd1,
    0x1e, 0x15, 0x84, 0x55, 0xf0, 0x64, 0x93, 0x6a, 0x8a, 0x34, 0xd5, 0xb6, 0xab, 0x8e, 0xf6, 0x04,
    0x8a, 0x57, 0xcc, 0x6d, 0xfd, 0x39, 0x8d, 0x96, 0xbb, 0x1e, 0x49, 0x7d, 0xd0, 0xe6, 0xfe, 0xad,
    0xdf, 0xb5, 0xe6, 0xcf, 0x7e, 0x63, 0xd9, 0x97, 0xfe, 0x8c, 0xa6, 0x31, 0x97, 0xae, 0x62, 0x67,
    0xb3, 0x85, 0xcc, 0xf2, 0xd9, 0xac, 0x0a, 0x2e, 0xaf, 0xc8, 0xc4, 0xee, 0x02, 0x39, 0x02, 0xca,
    0x8c, 0x8e, 0x22, 0x3b, 0xc9, 0xe1, 0xf5, 0x53, 0x40, 0x1f, 0xf9, 0x35, 0x07, 0x5e
};
#endif

PyTypeObject *init_QGlyphRun(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX].type;

    Shiboken::AutoDecRef Sbk_QGlyphRun_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGlyphRun_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGlyphRun",
        "QGlyphRun",
        &Sbk_QGlyphRun_spec,
        &Shiboken::callCppDestructor< ::QGlyphRun >,
        Sbk_QGlyphRun_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGlyphRun_TypeF(); // references _Sbk_QGlyphRun_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGlyphRun_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGlyphRun_SignatureBytes, QGlyphRun_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGlyphRun_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGlyphRun_PythonToCpp_QGlyphRun_PTR,
        is_QGlyphRun_PythonToCpp_QGlyphRun_PTR_Convertible,
        QGlyphRun_PTR_CppToPython_QGlyphRun,
        QGlyphRun_COPY_CppToPython_QGlyphRun);

    Shiboken::Conversions::registerConverterName(converter, "QGlyphRun");
    Shiboken::Conversions::registerConverterName(converter, "QGlyphRun*");
    Shiboken::Conversions::registerConverterName(converter, "QGlyphRun&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGlyphRun).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGlyphRun_PythonToCpp_QGlyphRun_COPY,
        is_QGlyphRun_PythonToCpp_QGlyphRun_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QGlyphRun_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'GlyphRunFlag'.
    const char *GlyphRunFlag_Initializer[] = {
        "Overline",
        "Underline",
        "StrikeOut",
        "RightToLeft",
        "SplitLigature",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t GlyphRunFlag_InitializerValues[] = {
        uint8_t(QGlyphRun::GlyphRunFlag::Overline),     //  0x01  1
        uint8_t(QGlyphRun::GlyphRunFlag::Underline),    //  0x02  2
        uint8_t(QGlyphRun::GlyphRunFlag::StrikeOut),    //  0x04  4
        uint8_t(QGlyphRun::GlyphRunFlag::RightToLeft),  //  0x08  8
        uint8_t(QGlyphRun::GlyphRunFlag::SplitLigature) //  0x10  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGlyphRun_TypeF(),
        "2:PySide6.QtGui.QGlyphRun.GlyphRunFlag",
        GlyphRunFlag_Initializer, GlyphRunFlag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_GlyphRunFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QGlyphRun_GlyphRunFlag_IDX].type =
        EType;
    // Register converter for enum 'QGlyphRun::GlyphRunFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGlyphRun_GlyphRunFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGlyphRun_GlyphRunFlag,
            is_Enum_PythonToCpp_QGlyphRun_GlyphRunFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGlyphRun::GlyphRunFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "GlyphRunFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QGlyphRun_GlyphRunFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QGlyphRun_GlyphRunFlag,
            is_Enum_PythonToCpp_QGlyphRun_GlyphRunFlag_Convertible);
        // Register converter for flag 'QFlags<QGlyphRun::GlyphRunFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QGlyphRun::GlyphRunFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QGlyphRun::GlyphRunFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'GlyphRunFlag' enum/flags.

    qRegisterMetaType< ::QGlyphRun >("QGlyphRun");
    qRegisterMetaType< ::QGlyphRun::GlyphRunFlag >("QGlyphRun::GlyphRunFlag");

    return pyType;
}
