// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qguiapplication_wrapper.h"

// Extra includes
#include <QBasicTimer>
#include <QFont>
#include <QFontMetrics>
#include <QIcon>
#include <QLocale>
#include <QPalette>
#include <pysidecleanup.h>
#include <pysideqapp.h>
#include "qtguihelper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtGui/qclipboard.h>
#include <QtGui/qcursor.h>
#include <QtGui/qfont.h>
#include <QtGui/qicon.h>
#include <QtGui/qinputmethod.h>
#include <QtGui/qpalette.h>
#include <QtGui/qscreen.h>
#include <QtGui/qsessionmanager.h>
#include <QtGui/qstylehints.h>
#include <QtGui/qwindow.h>
#include <qabstracteventdispatcher.h>
#include <qabstractnativeeventfilter.h>
#include <qbytearray.h>
#include <qcoreapplication.h>
#include <qcoreevent.h>
#include <qdeadlinetimer.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpermissions.h>
#include <qpoint.h>
#include <qtranslator.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtgui.cpp (qguiapplication-init)]
static void QGuiApplicationConstructor(PyObject *self, PyObject *pyargv, QGuiApplicationWrapper **cptr)
{
    static int argc;
    static char **argv;
    PyObject *stringlist = PyTuple_GetItem(pyargv, 0);
    if (Shiboken::listToArgcArgv(stringlist, &argc, &argv, "PySideApp")) {
        *cptr = new QGuiApplicationWrapper(argc, argv, 0);
        Shiboken::Object::releaseOwnership(reinterpret_cast<SbkObject *>(self));
        PySide::registerCleanupFunction(&PySide::destroyQCoreApplication);
    }
}
// END of custom code block [file: ../glue/qtgui.cpp (qguiapplication-init)]
// ========================================================================
// End of code injection


// Native ---------------------------------------------------------

void QGuiApplicationWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGuiApplicationWrapper::QGuiApplicationWrapper(int & argc, char ** argv, int arg__3) : QGuiApplication(argc, argv, arg__3)
{
}

void QGuiApplicationWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGuiApplication", funcName);
        return;
    }
}

void QGuiApplicationWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGuiApplication", funcName);
        return;
    }
}

void QGuiApplicationWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGuiApplication", funcName);
        return;
    }
}

void QGuiApplicationWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGuiApplication", funcName);
        return;
    }
}

bool QGuiApplicationWrapper::event(::QEvent * arg__1)
{
    if (m_PyMethodCache[4])
        return this->::QGuiApplication::event(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QGuiApplication::event(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGuiApplication", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGuiApplication", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QGuiApplicationWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGuiApplication", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGuiApplication", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QGuiApplicationWrapper::notify(::QObject * arg__1, ::QEvent * arg__2)
{
    if (m_PyMethodCache[6])
        return this->::QGuiApplication::notify(arg__1, arg__2);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "notify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QGuiApplication::notify(arg__1, arg__2);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__2)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__2)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGuiApplication", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGuiApplication", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGuiApplicationWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[7]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGuiApplication", funcName);
        return;
    }
}

const QMetaObject *QGuiApplicationWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QGuiApplication::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QGuiApplicationWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QGuiApplication::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QGuiApplicationWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QGuiApplicationWrapper *>(this));
    return QGuiApplication::qt_metacast(_clname);
}

QGuiApplicationWrapper::~QGuiApplicationWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGuiApplication_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGuiApplication >()))
        return -1;

    QGuiApplicationWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QGuiApplication", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGuiApplication::QGuiApplication()
    // 1: QGuiApplication::QGuiApplication(QStringList)
    if (numArgs == 0) {
        overloadId = 0; // QGuiApplication()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[0])))) {
        overloadId = 1; // QGuiApplication(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGuiApplication()
        {

            // QGuiApplication()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qguiapplication-2)]
            PyObject *empty = PyTuple_New(2);
            if (!PyTuple_SetItem(empty, 0, PyList_New(0))) {
                QGuiApplicationConstructor(self, empty, &cptr);
            }
            // END of custom code block [file: ../glue/qtgui.cpp (qguiapplication-2)]
            // ========================================================================
            // End of code injection

            break;
        }
        case 1: // QGuiApplication(QStringList arguments)
        {
            ::QStringList cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGuiApplication(QStringList)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qguiapplication-1)]
                QGuiApplicationConstructor(self, args, &cptr);
                // END of custom code block [file: ../glue/qtgui.cpp (qguiapplication-1)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QGuiApplication >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QGuiApplicationFunc_allWindows(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // allWindows()
        QList<QWindow*> cppResult = ::QGuiApplication::allWindows();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QWindowPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_applicationDisplayName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // applicationDisplayName()
        QString cppResult = ::QGuiApplication::applicationDisplayName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_applicationState(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // applicationState()
        Qt::ApplicationState cppResult = ::QGuiApplication::applicationState();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ApplicationState_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_changeOverrideCursor(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGuiApplication::changeOverrideCursor(QCursor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), (pyArg)))) {
        overloadId = 0; // changeOverrideCursor(QCursor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "changeOverrideCursor", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCursor cppArg0_local;
        ::QCursor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // changeOverrideCursor(QCursor)
            ::QGuiApplication::changeOverrideCursor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGuiApplicationFunc_clipboard(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clipboard()
        QClipboard * cppResult = ::QGuiApplication::clipboard();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_desktopFileName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // desktopFileName()
        QString cppResult = ::QGuiApplication::desktopFileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_desktopSettingsAware(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // desktopSettingsAware()
        bool cppResult = ::QGuiApplication::desktopSettingsAware();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_devicePixelRatio(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGuiApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // devicePixelRatio()const
        qreal cppResult = const_cast<const ::QGuiApplication *>(cppSelf)->devicePixelRatio();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGuiApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGuiApplication::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_exec(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();

    // Call function/method
    {

        // exec()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        int cppResult = ::QGuiApplication::exec();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_exec_(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGuiApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();

    // Call function/method
    {

        // exec_()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtgui.cpp (qguiapplication-exec)]
        if (PyErr_WarnEx(PyExc_DeprecationWarning,
                         "'exec_' will be removed in the future. "
                         "Use 'exec' instead.",
                         1)) {
            return nullptr;
        }
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        int cppResult = cppSelf->exec();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        // END of custom code block [file: ../glue/qtgui.cpp (qguiapplication-exec)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_focusObject(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // focusObject()
        QObject * cppResult = ::QGuiApplication::focusObject();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_focusWindow(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // focusWindow()
        QWindow * cppResult = ::QGuiApplication::focusWindow();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_font(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // font()
        QFont cppResult = ::QGuiApplication::font();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_highDpiScaleFactorRoundingPolicy(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // highDpiScaleFactorRoundingPolicy()
        Qt::HighDpiScaleFactorRoundingPolicy cppResult = ::QGuiApplication::highDpiScaleFactorRoundingPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_HighDpiScaleFactorRoundingPolicy_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_inputMethod(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // inputMethod()
        QInputMethod * cppResult = ::QGuiApplication::inputMethod();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_isLeftToRight(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLeftToRight()
        bool cppResult = ::QGuiApplication::isLeftToRight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_isRightToLeft(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRightToLeft()
        bool cppResult = ::QGuiApplication::isRightToLeft();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_isSavingSession(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGuiApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSavingSession()const
        bool cppResult = const_cast<const ::QGuiApplication *>(cppSelf)->isSavingSession();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_isSessionRestored(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGuiApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSessionRestored()const
        bool cppResult = const_cast<const ::QGuiApplication *>(cppSelf)->isSessionRestored();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_keyboardModifiers(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // keyboardModifiers()
        QFlags<Qt::KeyboardModifier> cppResult = ::QGuiApplication::keyboardModifiers();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_layoutDirection(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // layoutDirection()
        Qt::LayoutDirection cppResult = ::QGuiApplication::layoutDirection();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_modalWindow(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // modalWindow()
        QWindow * cppResult = ::QGuiApplication::modalWindow();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_mouseButtons(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mouseButtons()
        QFlags<Qt::MouseButton> cppResult = ::QGuiApplication::mouseButtons();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MouseButton_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_nativeInterface(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGuiApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nativeInterface()const
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtgui.cpp (qguiapplication-nativeInterface)]
        bool hasNativeApp = false;
#if QT_CONFIG(xcb)
        if (auto *x11App = cppSelf->nativeInterface<QNativeInterface::QX11Application>()) {
            hasNativeApp = true;
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeInterface_QX11Application_IDX]), x11App);
        }
#endif
        if (!hasNativeApp) {
            Py_INCREF(Py_None);
            pyResult = Py_None;
        }
        // END of custom code block [file: ../glue/qtgui.cpp (qguiapplication-nativeInterface)]
        // ========================================================================
        // End of code injection


        // Ownership transferences.
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_notify(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGuiApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "notify", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCoreApplication::notify(QObject*,QEvent*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        overloadId = 0; // notify(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "notify", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // notify(QObject*,QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGuiApplication::notify(cppArg0, cppArg1)
                : cppSelf->notify(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_overrideCursor(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // overrideCursor()
        QCursor * cppResult = ::QGuiApplication::overrideCursor();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_palette(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // palette()
        QPalette cppResult = ::QGuiApplication::palette();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_platformFunction(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGuiApplication::platformFunction(QByteArray)->QFunctionPointer
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // platformFunction(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "platformFunction", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // platformFunction(QByteArray)
            QFunctionPointer cppResult = ::QGuiApplication::platformFunction(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QFunctionPointer_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_platformName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // platformName()
        QString cppResult = ::QGuiApplication::platformName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_primaryScreen(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // primaryScreen()
        QScreen * cppResult = ::QGuiApplication::primaryScreen();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_queryKeyboardModifiers(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // queryKeyboardModifiers()
        QFlags<Qt::KeyboardModifier> cppResult = ::QGuiApplication::queryKeyboardModifiers();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_quitOnLastWindowClosed(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // quitOnLastWindowClosed()
        bool cppResult = ::QGuiApplication::quitOnLastWindowClosed();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_resolveInterface(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGuiApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "resolveInterface", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCoreApplication::resolveInterface(const char*,int)const->void*
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // resolveInterface(const char*,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "resolveInterface", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resolveInterface(const char*,int)const
            void * cppResult = const_cast<const ::QGuiApplication *>(cppSelf)->resolveInterface(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_restoreOverrideCursor(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // restoreOverrideCursor()
        ::QGuiApplication::restoreOverrideCursor();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGuiApplicationFunc_screenAt(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGuiApplication::screenAt(QPoint)->QScreen*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 0; // screenAt(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "screenAt", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPoint cppArg0_local;
        ::QPoint *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // screenAt(QPoint)
            QScreen * cppResult = ::QGuiApplication::screenAt(*cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_screens(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // screens()
        QList<QScreen*> cppResult = ::QGuiApplication::screens();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QScreenPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_sessionId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGuiApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sessionId()const
        QString cppResult = const_cast<const ::QGuiApplication *>(cppSelf)->sessionId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_sessionKey(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGuiApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sessionKey()const
        QString cppResult = const_cast<const ::QGuiApplication *>(cppSelf)->sessionKey();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_setApplicationDisplayName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGuiApplication::setApplicationDisplayName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setApplicationDisplayName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setApplicationDisplayName", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setApplicationDisplayName(QString)
            ::QGuiApplication::setApplicationDisplayName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGuiApplicationFunc_setBadgeNumber(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGuiApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGuiApplication::setBadgeNumber(qint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // setBadgeNumber(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBadgeNumber", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBadgeNumber(qint64)
            cppSelf->setBadgeNumber(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGuiApplicationFunc_setDesktopFileName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGuiApplication::setDesktopFileName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDesktopFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDesktopFileName", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDesktopFileName(QString)
            ::QGuiApplication::setDesktopFileName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGuiApplicationFunc_setDesktopSettingsAware(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGuiApplication::setDesktopSettingsAware(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDesktopSettingsAware(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDesktopSettingsAware", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDesktopSettingsAware(bool)
            ::QGuiApplication::setDesktopSettingsAware(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGuiApplicationFunc_setFont(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGuiApplication::setFont(QFont)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFont", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setFont(QFont)
            ::QGuiApplication::setFont(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGuiApplicationFunc_setHighDpiScaleFactorRoundingPolicy(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGuiApplication::setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_HighDpiScaleFactorRoundingPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHighDpiScaleFactorRoundingPolicy", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        ::Qt::HighDpiScaleFactorRoundingPolicy cppArg0{Qt::HighDpiScaleFactorRoundingPolicy::Unset};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy)
            ::QGuiApplication::setHighDpiScaleFactorRoundingPolicy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGuiApplicationFunc_setLayoutDirection(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGuiApplication::setLayoutDirection(Qt::LayoutDirection)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setLayoutDirection(Qt::LayoutDirection)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLayoutDirection", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        ::Qt::LayoutDirection cppArg0{Qt::LeftToRight};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLayoutDirection(Qt::LayoutDirection)
            ::QGuiApplication::setLayoutDirection(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGuiApplicationFunc_setOverrideCursor(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGuiApplication::setOverrideCursor(QCursor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), (pyArg)))) {
        overloadId = 0; // setOverrideCursor(QCursor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOverrideCursor", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCursor cppArg0_local;
        ::QCursor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setOverrideCursor(QCursor)
            ::QGuiApplication::setOverrideCursor(*cppArg0);
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qguiapplication-setoverridecursor)]
            auto *cppResult = new QtGuiHelper::QOverrideCursorGuard();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QtGuiHelper_QOverrideCursorGuard_IDX]), cppResult);
            Shiboken::Object::getOwnership(pyResult); // Ensure the guard is removed
            // END of custom code block [file: ../glue/qtgui.cpp (qguiapplication-setoverridecursor)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_setPalette(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGuiApplication::setPalette(QPalette)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArg)))) {
        overloadId = 0; // setPalette(QPalette)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPalette", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPalette cppArg0_local;
        ::QPalette *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPalette(QPalette)
            ::QGuiApplication::setPalette(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGuiApplicationFunc_setQuitOnLastWindowClosed(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGuiApplication::setQuitOnLastWindowClosed(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setQuitOnLastWindowClosed(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setQuitOnLastWindowClosed", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setQuitOnLastWindowClosed(bool)
            ::QGuiApplication::setQuitOnLastWindowClosed(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGuiApplicationFunc_setWindowIcon(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGuiApplication::setWindowIcon(QIcon)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), (pyArg)))) {
        overloadId = 0; // setWindowIcon(QIcon)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWindowIcon", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIcon cppArg0_local;
        ::QIcon *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setWindowIcon(QIcon)
            ::QGuiApplication::setWindowIcon(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGuiApplicationFunc_styleHints(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // styleHints()
        QStyleHints * cppResult = ::QGuiApplication::styleHints();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStyleHints_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_sync(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sync()
        ::QGuiApplication::sync();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGuiApplicationFunc_topLevelAt(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGuiApplication::topLevelAt(QPoint)->QWindow*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 0; // topLevelAt(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "topLevelAt", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPoint cppArg0_local;
        ::QPoint *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // topLevelAt(QPoint)
            QWindow * cppResult = ::QGuiApplication::topLevelAt(*cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_topLevelWindows(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // topLevelWindows()
        QList<QWindow*> cppResult = ::QGuiApplication::topLevelWindows();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QWindowPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGuiApplicationFunc_windowIcon(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // windowIcon()
        QIcon cppResult = ::QGuiApplication::windowIcon();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGuiApplication_PropertyStrings[] = {
    "applicationDisplayName::",
    "desktopFileName::",
    "layoutDirection::",
    "platformName:",
    "primaryScreen:",
    "quitOnLastWindowClosed::",
    "windowIcon::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGuiApplication_methods[] = {
    {"allWindows", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_allWindows), METH_NOARGS|METH_STATIC, nullptr},
    {"applicationDisplayName", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_applicationDisplayName), METH_NOARGS|METH_STATIC, nullptr},
    {"applicationState", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_applicationState), METH_NOARGS|METH_STATIC, nullptr},
    {"changeOverrideCursor", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_changeOverrideCursor), METH_O|METH_STATIC, nullptr},
    {"clipboard", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_clipboard), METH_NOARGS|METH_STATIC, nullptr},
    {"desktopFileName", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_desktopFileName), METH_NOARGS|METH_STATIC, nullptr},
    {"desktopSettingsAware", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_desktopSettingsAware), METH_NOARGS|METH_STATIC, nullptr},
    {"devicePixelRatio", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_devicePixelRatio), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_event), METH_O, nullptr},
    {"exec", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_exec), METH_NOARGS|METH_STATIC, nullptr},
    {"exec_", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_exec_), METH_NOARGS, nullptr},
    {"focusObject", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_focusObject), METH_NOARGS|METH_STATIC, nullptr},
    {"focusWindow", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_focusWindow), METH_NOARGS|METH_STATIC, nullptr},
    {"font", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_font), METH_NOARGS|METH_STATIC, nullptr},
    {"highDpiScaleFactorRoundingPolicy", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_highDpiScaleFactorRoundingPolicy), METH_NOARGS|METH_STATIC, nullptr},
    {"inputMethod", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_inputMethod), METH_NOARGS|METH_STATIC, nullptr},
    {"isLeftToRight", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_isLeftToRight), METH_NOARGS|METH_STATIC, nullptr},
    {"isRightToLeft", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_isRightToLeft), METH_NOARGS|METH_STATIC, nullptr},
    {"isSavingSession", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_isSavingSession), METH_NOARGS, nullptr},
    {"isSessionRestored", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_isSessionRestored), METH_NOARGS, nullptr},
    {"keyboardModifiers", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_keyboardModifiers), METH_NOARGS|METH_STATIC, nullptr},
    {"layoutDirection", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_layoutDirection), METH_NOARGS|METH_STATIC, nullptr},
    {"modalWindow", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_modalWindow), METH_NOARGS|METH_STATIC, nullptr},
    {"mouseButtons", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_mouseButtons), METH_NOARGS|METH_STATIC, nullptr},
    {"nativeInterface", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_nativeInterface), METH_NOARGS, nullptr},
    {"notify", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_notify), METH_VARARGS, nullptr},
    {"overrideCursor", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_overrideCursor), METH_NOARGS|METH_STATIC, nullptr},
    {"palette", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_palette), METH_NOARGS|METH_STATIC, nullptr},
    {"platformFunction", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_platformFunction), METH_O|METH_STATIC, nullptr},
    {"platformName", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_platformName), METH_NOARGS|METH_STATIC, nullptr},
    {"primaryScreen", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_primaryScreen), METH_NOARGS|METH_STATIC, nullptr},
    {"queryKeyboardModifiers", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_queryKeyboardModifiers), METH_NOARGS|METH_STATIC, nullptr},
    {"quitOnLastWindowClosed", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_quitOnLastWindowClosed), METH_NOARGS|METH_STATIC, nullptr},
    {"resolveInterface", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_resolveInterface), METH_VARARGS, nullptr},
    {"restoreOverrideCursor", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_restoreOverrideCursor), METH_NOARGS|METH_STATIC, nullptr},
    {"screenAt", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_screenAt), METH_O|METH_STATIC, nullptr},
    {"screens", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_screens), METH_NOARGS|METH_STATIC, nullptr},
    {"sessionId", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_sessionId), METH_NOARGS, nullptr},
    {"sessionKey", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_sessionKey), METH_NOARGS, nullptr},
    {"setApplicationDisplayName", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_setApplicationDisplayName), METH_O|METH_STATIC, nullptr},
    {"setBadgeNumber", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_setBadgeNumber), METH_O, nullptr},
    {"setDesktopFileName", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_setDesktopFileName), METH_O|METH_STATIC, nullptr},
    {"setDesktopSettingsAware", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_setDesktopSettingsAware), METH_O|METH_STATIC, nullptr},
    {"setFont", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_setFont), METH_O|METH_STATIC, nullptr},
    {"setHighDpiScaleFactorRoundingPolicy", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_setHighDpiScaleFactorRoundingPolicy), METH_O|METH_STATIC, nullptr},
    {"setLayoutDirection", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_setLayoutDirection), METH_O|METH_STATIC, nullptr},
    {"setOverrideCursor", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_setOverrideCursor), METH_O|METH_STATIC, nullptr},
    {"setPalette", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_setPalette), METH_O|METH_STATIC, nullptr},
    {"setQuitOnLastWindowClosed", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_setQuitOnLastWindowClosed), METH_O|METH_STATIC, nullptr},
    {"setWindowIcon", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_setWindowIcon), METH_O|METH_STATIC, nullptr},
    {"styleHints", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_styleHints), METH_NOARGS|METH_STATIC, nullptr},
    {"sync", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_sync), METH_NOARGS|METH_STATIC, nullptr},
    {"topLevelAt", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_topLevelAt), METH_O|METH_STATIC, nullptr},
    {"topLevelWindows", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_topLevelWindows), METH_NOARGS|METH_STATIC, nullptr},
    {"windowIcon", reinterpret_cast<PyCFunction>(Sbk_QGuiApplicationFunc_windowIcon), METH_NOARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGuiApplication_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGuiApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGuiApplicationWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGuiApplication_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGuiApplication_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGuiApplication_Type = nullptr;
static PyTypeObject *Sbk_QGuiApplication_TypeF(void)
{
    return _Sbk_QGuiApplication_Type;
}

static PyType_Slot Sbk_QGuiApplication_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocQAppWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGuiApplication_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGuiApplication_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGuiApplication_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGuiApplication_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGuiApplication_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkQApp_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGuiApplication_spec = {
    "2:PySide6.QtGui.QGuiApplication",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGuiApplication_slots
};

} //extern "C"

static void *Sbk_QGuiApplication_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QGuiApplication *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGuiApplication_PythonToCpp_QGuiApplication_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGuiApplication_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGuiApplication_PythonToCpp_QGuiApplication_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGuiApplication_TypeF()))
        return QGuiApplication_PythonToCpp_QGuiApplication_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGuiApplication_PTR_CppToPython_QGuiApplication(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QGuiApplication *>(const_cast<void *>(cppIn)), Sbk_QGuiApplication_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGuiApplication_SignatureStrings[] = {
    "1:PySide6.QtGui.QGuiApplication(self,*:KeywordOnly=None,windowIcon:QIcon=None,applicationDisplayName:QString=None,desktopFileName:QString=None,layoutDirection:Qt.LayoutDirection=None,platformName:QString=None,quitOnLastWindowClosed:bool=None,primaryScreen:QScreen=None)",
    "0:PySide6.QtGui.QGuiApplication(self,arguments:QStringList,*:KeywordOnly=None,windowIcon:QIcon=None,applicationDisplayName:QString=None,desktopFileName:QString=None,layoutDirection:Qt.LayoutDirection=None,platformName:QString=None,quitOnLastWindowClosed:bool=None,primaryScreen:QScreen=None)",
    "PySide6.QtGui.QGuiApplication.allWindows()->QList[PySide6.QtGui.QWindow]",
    "PySide6.QtGui.QGuiApplication.applicationDisplayName()->QString",
    "PySide6.QtGui.QGuiApplication.applicationState()->PySide6.QtCore.Qt.ApplicationState",
    "PySide6.QtGui.QGuiApplication.changeOverrideCursor(arg__1:typing.Union[PySide6.QtGui.QCursor, PySide6.QtCore.Qt.CursorShape, PySide6.QtGui.QPixmap])",
    "PySide6.QtGui.QGuiApplication.clipboard()->PySide6.QtGui.QClipboard",
    "PySide6.QtGui.QGuiApplication.desktopFileName()->QString",
    "PySide6.QtGui.QGuiApplication.desktopSettingsAware()->bool",
    "PySide6.QtGui.QGuiApplication.devicePixelRatio(self)->qreal",
    "PySide6.QtGui.QGuiApplication.event(self,arg__1:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtGui.QGuiApplication.exec()->int",
    "PySide6.QtGui.QGuiApplication.exec_(self)->int",
    "PySide6.QtGui.QGuiApplication.focusObject()->PySide6.QtCore.QObject",
    "PySide6.QtGui.QGuiApplication.focusWindow()->PySide6.QtGui.QWindow",
    "PySide6.QtGui.QGuiApplication.font()->PySide6.QtGui.QFont",
    "PySide6.QtGui.QGuiApplication.highDpiScaleFactorRoundingPolicy()->PySide6.QtCore.Qt.HighDpiScaleFactorRoundingPolicy",
    "PySide6.QtGui.QGuiApplication.inputMethod()->PySide6.QtGui.QInputMethod",
    "PySide6.QtGui.QGuiApplication.isLeftToRight()->bool",
    "PySide6.QtGui.QGuiApplication.isRightToLeft()->bool",
    "PySide6.QtGui.QGuiApplication.isSavingSession(self)->bool",
    "PySide6.QtGui.QGuiApplication.isSessionRestored(self)->bool",
    "PySide6.QtGui.QGuiApplication.keyboardModifiers()->PySide6.QtCore.Qt.KeyboardModifier",
    "PySide6.QtGui.QGuiApplication.layoutDirection()->PySide6.QtCore.Qt.LayoutDirection",
    "PySide6.QtGui.QGuiApplication.modalWindow()->PySide6.QtGui.QWindow",
    "PySide6.QtGui.QGuiApplication.mouseButtons()->PySide6.QtCore.Qt.MouseButton",
    "PySide6.QtGui.QGuiApplication.nativeInterface(self)->PyObject",
    "PySide6.QtGui.QGuiApplication.notify(self,arg__1:PySide6.QtCore.QObject,arg__2:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtGui.QGuiApplication.overrideCursor()->PySide6.QtGui.QCursor",
    "PySide6.QtGui.QGuiApplication.palette()->PySide6.QtGui.QPalette",
    "PySide6.QtGui.QGuiApplication.platformFunction(function:typing.Union[PySide6.QtCore.QByteArray, char*])->QFunctionPointer",
    "PySide6.QtGui.QGuiApplication.platformName()->QString",
    "PySide6.QtGui.QGuiApplication.primaryScreen()->PySide6.QtGui.QScreen",
    "PySide6.QtGui.QGuiApplication.queryKeyboardModifiers()->PySide6.QtCore.Qt.KeyboardModifier",
    "PySide6.QtGui.QGuiApplication.quitOnLastWindowClosed()->bool",
    "PySide6.QtGui.QGuiApplication.resolveInterface(self,name:char*,revision:int)->void",
    "PySide6.QtGui.QGuiApplication.restoreOverrideCursor()",
    "PySide6.QtGui.QGuiApplication.screenAt(point:PySide6.QtCore.QPoint)->PySide6.QtGui.QScreen",
    "PySide6.QtGui.QGuiApplication.screens()->QList[PySide6.QtGui.QScreen]",
    "PySide6.QtGui.QGuiApplication.sessionId(self)->QString",
    "PySide6.QtGui.QGuiApplication.sessionKey(self)->QString",
    "PySide6.QtGui.QGuiApplication.setApplicationDisplayName(name:QString)",
    "PySide6.QtGui.QGuiApplication.setBadgeNumber(self,number:qint64)",
    "PySide6.QtGui.QGuiApplication.setDesktopFileName(name:QString)",
    "PySide6.QtGui.QGuiApplication.setDesktopSettingsAware(on:bool)",
    "PySide6.QtGui.QGuiApplication.setFont(arg__1:typing.Union[PySide6.QtGui.QFont, QString, QStringList])",
    "PySide6.QtGui.QGuiApplication.setHighDpiScaleFactorRoundingPolicy(policy:PySide6.QtCore.Qt.HighDpiScaleFactorRoundingPolicy)",
    "PySide6.QtGui.QGuiApplication.setLayoutDirection(direction:PySide6.QtCore.Qt.LayoutDirection)",
    "PySide6.QtGui.QGuiApplication.setOverrideCursor(arg__1:typing.Union[PySide6.QtGui.QCursor, PySide6.QtCore.Qt.CursorShape, PySide6.QtGui.QPixmap])->PyObject",
    "PySide6.QtGui.QGuiApplication.setPalette(pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor])",
    "PySide6.QtGui.QGuiApplication.setQuitOnLastWindowClosed(quit:bool)",
    "PySide6.QtGui.QGuiApplication.setWindowIcon(icon:typing.Union[PySide6.QtGui.QIcon, PySide6.QtGui.QPixmap])",
    "PySide6.QtGui.QGuiApplication.styleHints()->PySide6.QtGui.QStyleHints",
    "PySide6.QtGui.QGuiApplication.sync()",
    "PySide6.QtGui.QGuiApplication.topLevelAt(pos:PySide6.QtCore.QPoint)->PySide6.QtGui.QWindow",
    "PySide6.QtGui.QGuiApplication.topLevelWindows()->QList[PySide6.QtGui.QWindow]",
    "PySide6.QtGui.QGuiApplication.windowIcon()->PySide6.QtGui.QIcon",
    nullptr}; // Sentinel
#else
static constexpr size_t QGuiApplication_SignatureByteSize = 938;
static constexpr uint8_t QGuiApplication_SignatureBytes[938] = {
    0x78, 0xda, 0xe5, 0x58, 0x4b, 0x6f, 0xdb, 0x30, 0x0c, 0xbe, 0xef, 0x57, 0xf4, 0x98, 0x16, 0x59,
    0xb0, 0x0e, 0xc3, 0x0e, 0x06, 0x36, 0x20, 0x6d, 0xd6, 0x07, 0x9a, 0xb6, 0x49, 0xbd, 0x61, 0x87,
    0xa1, 0x28, 0x14, 0x9b, 0x49, 0xb4, 0x29, 0xa2, 0x2b, 0xc9, 0xe9, 0xfc, 0xef, 0x47, 0x59, 0x4e,
    0xb2, 0xb8, 0x6a, 0xa5, 0xec, 0x75, 0xd9, 0x25, 0x36, 0x4c, 0x7e, 0x9f, 0x28, 0x8a, 0x2f, 0xe5,
    0x30, 0x19, 0x55, 0x29, 0xcf, 0xe1, 0x6d, 0x6f, 0x6c, 0x4e, 0x4b, 0xde, 0x1b, 0xd3, 0x4f, 0xbf,
    0x28, 0x04, 0xcf, 0x98, 0xe1, 0x28, 0x3b, 0x1a, 0xc4, 0xb4, 0x7b, 0x90, 0x5c, 0x40, 0xf5, 0x80,
    0x2a, 0xbf, 0x96, 0xa2, 0x7a, 0x77, 0x85, 0x12, 0xba, 0x0f, 0x5c, 0xe6, 0xf8, 0x70, 0x9e, 0xa1,
    0x4c, 0xc6, 0xf6, 0xd7, 0x7d, 0x65, 0x1b, 0xe4, 0x80, 0xeb, 0x42, 0xb0, 0xea, 0x8a, 0x2d, 0x20,
    0x19, 0xa7, 0x46, 0x71, 0x39, 0x73, 0x3a, 0x39, 0xe8, 0x6f, 0x06, 0x8b, 0x13, 0x2e, 0xe0, 0xb1,
    0x90, 0x10, 0x58, 0x9a, 0x01, 0x57, 0x90, 0x59, 0x92, 0x64, 0x6c, 0x7a, 0xc3, 0xed, 0x4f, 0x4e,
    0x8f, 0xa8, 0xcd, 0x14, 0xd5, 0xe2, 0x31, 0xc3, 0x7d, 0xc9, 0xcd, 0xb5, 0x1c, 0x32, 0x6d, 0x3e,
    0xd7, 0x26, 0x1e, 0x0b, 0xd4, 0x90, 0x27, 0x13, 0x44, 0xd1, 0x40, 0x15, 0x5f, 0x30, 0x55, 0xa5,
    0x99, 0x02, 0xa0, 0x05, 0xdc, 0xb3, 0x16, 0xed, 0xbf, 0x78, 0x15, 0xe3, 0x0d, 0xa6, 0x66, 0xe5,
    0x02, 0xa4, 0xd1, 0xab, 0x85, 0x87, 0x5c, 0x9b, 0xff, 0xc7, 0x47, 0xcf, 0x7a, 0xa8, 0xc7, 0x84,
    0x70, 0x9c, 0xba, 0xb3, 0xff, 0xf2, 0xfd, 0xd8, 0xba, 0xe6, 0x4b, 0x0b, 0xe1, 0xe4, 0xb7, 0x21,
    0x22, 0xaf, 0x9b, 0x6a, 0x52, 0xb7, 0x95, 0x78, 0x7c, 0x6a, 0x98, 0xa9, 0x91, 0x1b, 0xc4, 0x31,
    0x2a, 0xa0, 0x47, 0xaf, 0xdf, 0xd2, 0x0a, 0x90, 0x66, 0x73, 0x26, 0x67, 0x70, 0xbd, 0x04, 0xa5,
    0x48, 0xeb, 0xb8, 0x54, 0x1a, 0x55, 0x87, 0xe2, 0xe1, 0xee, 0xee, 0x30, 0x31, 0x55, 0x41, 0x56,
    0xf5, 0x3e, 0x49, 0x52, 0x6c, 0x6f, 0xd9, 0x69, 0x76, 0xf7, 0x1e, 0x1b, 0xe0, 0x24, 0xe9, 0x9c,
    0x15, 0xf0, 0xb3, 0xb8, 0x46, 0x8d, 0xf8, 0xf7, 0x05, 0x2b, 0x6e, 0x43, 0x2e, 0xcf, 0x04, 0x2f,
    0x26, 0xc8, 0x54, 0xbe, 0xbd, 0x45, 0xb7, 0xf0, 0x4a, 0x16, 0xe0, 0x68, 0x05, 0x5c, 0xbc, 0x9b,
    0x1b, 0x60, 0x0a, 0xc6, 0x90, 0xb2, 0xee, 0x3f, 0x30, 0x55, 0xa3, 0x6d, 0x2c, 0x05, 0xa1, 0x4b,
    0x9e, 0x01, 0x6d, 0x12, 0xc4, 0x8d, 0xfd, 0x52, 0x67, 0x17, 0x41, 0xef, 0x15, 0xb0, 0x10, 0x16,
    0x96, 0x94, 0x80, 0xeb, 0x74, 0xb4, 0xee, 0x6f, 0xbb, 0xf6, 0x83, 0xd5, 0x88, 0x33, 0x04, 0xbe,
    0x43, 0x66, 0x6d, 0xe6, 0xd2, 0x44, 0x68, 0xde, 0xad, 0xec, 0x0c, 0xab, 0x4f, 0x31, 0x2b, 0xf5,
    0xf5, 0xe4, 0x2b, 0x65, 0xa5, 0x2f, 0xfc, 0x9c, 0x24, 0x86, 0xc3, 0xa5, 0x8c, 0xe7, 0x7c, 0x9d,
    0x20, 0x48, 0x21, 0x8d, 0x07, 0x7b, 0x82, 0xc1, 0x0d, 0xcc, 0xf9, 0x6c, 0x3e, 0x28, 0x78, 0x9a,
    0x31, 0x01, 0x27, 0x2c, 0x33, 0xa8, 0x6e, 0xb0, 0x94, 0x39, 0x9d, 0xf4, 0x08, 0x49, 0xa9, 0xf2,
    0x27, 0xd5, 0x59, 0x00, 0x15, 0x58, 0x94, 0xcb, 0xa2, 0x34, 0x97, 0x60, 0xe6, 0xe8, 0x8b, 0xe8,
    0xf3, 0x8d, 0x34, 0xc4, 0xa3, 0x87, 0x30, 0x35, 0x1f, 0xf1, 0x86, 0xcc, 0x31, 0x91, 0x31, 0xc9,
    0x75, 0xad, 0xfd, 0x11, 0x2d, 0x34, 0x1a, 0x93, 0xb2, 0x25, 0x6d, 0x2e, 0x05, 0xad, 0x57, 0x4d,
    0x22, 0x1a, 0xe9, 0x30, 0x37, 0xa0, 0xc9, 0x4b, 0x90, 0xef, 0x80, 0xfd, 0x06, 0x55, 0x9d, 0xd8,
    0x97, 0x98, 0xf3, 0x29, 0x07, 0xa5, 0xfd, 0x67, 0x71, 0xd1, 0x52, 0x0b, 0xb0, 0xb6, 0x7a, 0x8b,
    0x9f, 0xb3, 0xd5, 0x6d, 0x02, 0x94, 0x0b, 0xcc, 0x99, 0xf8, 0xbd, 0x00, 0x5e, 0x60, 0xa9, 0xe1,
    0xa8, 0x34, 0x06, 0xe5, 0x13, 0xdb, 0xbc, 0xdc, 0x68, 0x04, 0xb8, 0x24, 0x3d, 0x96, 0x70, 0x2e,
    0x0d, 0xa8, 0x29, 0xcb, 0x60, 0xe5, 0xf1, 0x51, 0x15, 0x95, 0x8d, 0x12, 0x0d, 0x9f, 0x56, 0xcf,
    0x16, 0x1e, 0xc7, 0xe3, 0xa4, 0xaf, 0x7f, 0xa7, 0x2c, 0xe1, 0x76, 0x9b, 0xf1, 0x14, 0xf7, 0x5a,
    0x10, 0x60, 0x29, 0x28, 0x09, 0x4d, 0xbb, 0xfd, 0xb9, 0xf6, 0xe2, 0x24, 0x21, 0x7c, 0x33, 0x45,
    0x9c, 0x94, 0xd2, 0x85, 0xc4, 0xb4, 0x79, 0x79, 0xaa, 0xe1, 0xb9, 0x7d, 0x1e, 0x55, 0x06, 0xfa,
    0x4a, 0xb1, 0xaa, 0xbb, 0x47, 0x4d, 0x53, 0x1d, 0xdc, 0xda, 0x8e, 0xb2, 0xe2, 0x18, 0x21, 0xb7,
    0xfe, 0x8f, 0x5c, 0x79, 0xb7, 0x86, 0xb4, 0x35, 0xba, 0x78, 0x76, 0xed, 0x04, 0x01, 0x92, 0xfb,
    0x12, 0x54, 0x75, 0xf1, 0x57, 0x32, 0xcc, 0x3f, 0x7b, 0x45, 0x96, 0x1a, 0x05, 0x1a, 0x45, 0x3b,
    0x7a, 0xbb, 0xd2, 0x0e, 0x78, 0xb5, 0x97, 0xbb, 0x8a, 0x7a, 0xaa, 0x2d, 0x28, 0x09, 0xaf, 0xa3,
    0x6c, 0x89, 0x3c, 0x0f, 0x53, 0xda, 0xd2, 0xd3, 0x9a, 0x69, 0x42, 0x33, 0x87, 0xae, 0xbd, 0xd8,
    0x37, 0x9d, 0xc2, 0x1e, 0xe5, 0xa3, 0x28, 0xaf, 0x0f, 0xf8, 0x17, 0x7d, 0xef, 0xa8, 0x9f, 0x1e,
    0x1f, 0x1d, 0x49, 0x68, 0x7c, 0xd4, 0xae, 0xb0, 0x9e, 0xaf, 0x4b, 0x6a, 0x5c, 0xf4, 0x34, 0x30,
    0x3a, 0xd3, 0x5d, 0x71, 0xa6, 0xef, 0x1f, 0x58, 0xe5, 0x4f, 0xd3, 0xf7, 0x7e, 0x98, 0xe5, 0x88,
    0xe5, 0x33, 0xb8, 0x2a, 0x17, 0x13, 0x50, 0xcd, 0xe1, 0xd6, 0xef, 0xc9, 0x3d, 0x39, 0xf4, 0xed,
    0x9b, 0x08, 0x82, 0x41, 0x6b, 0x92, 0xdb, 0x71, 0xfd, 0x81, 0x6f, 0x9e, 0xa3, 0x78, 0xb2, 0xc1,
    0x19, 0x01, 0xb7, 0x33, 0x45, 0xcc, 0x40, 0x6c, 0xf5, 0xba, 0x7b, 0x8d, 0x59, 0xeb, 0x17, 0x7b,
    0xdc, 0xb7, 0x11, 0xab, 0x84, 0x06, 0x0c, 0x8a, 0x4a, 0xfb, 0x48, 0x76, 0x1f, 0x4d, 0x22, 0x16,
    0x6f, 0x75, 0xbf, 0x4e, 0xbe, 0xbe, 0x88, 0x05, 0x3b, 0x65, 0x04, 0xfb, 0xbf, 0xbe, 0x5b, 0x44,
    0x77, 0x3e, 0xb2, 0xad, 0x69, 0x18, 0x1d, 0x6a, 0x29, 0xcf, 0x5a, 0xd4, 0xe8, 0xf9, 0x4c, 0x3a,
    0x15, 0x38, 0x61, 0xe2, 0x18, 0xc5, 0xb6, 0xc5, 0x6e, 0x23, 0xf6, 0x6b, 0xcc, 0xf1, 0x8f, 0xfd,
    0x25, 0xd4, 0x56, 0xd6, 0xd8, 0x38, 0xfd, 0xbc, 0xbe, 0x9a, 0x77, 0x78, 0xf6, 0x74, 0x2f, 0x73,
    0x13, 0x27, 0x29, 0xfc, 0xea, 0xdd, 0x4c, 0x9b, 0x4a, 0xc0, 0x19, 0xe5, 0xae, 0xf6, 0xb5, 0xa2,
    0xb5, 0x30, 0xc4, 0x52, 0xc9, 0x2c, 0x58, 0x92, 0x29, 0x6b, 0x87, 0x74, 0x2d, 0x12, 0x75, 0x51,
    0xd6, 0xb1, 0x25, 0x39, 0x6a, 0xfe, 0x5a, 0x51, 0xff, 0x99, 0x9b, 0xfd, 0xe6, 0x6f, 0x11, 0xdf,
    0x78, 0x4f, 0x9f, 0x5f, 0xfc, 0x00, 0x01, 0xac, 0xbc, 0x31
};
#endif

PyTypeObject *init_QGuiApplication(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX].type;

    Shiboken::AutoDecRef Sbk_QGuiApplication_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX]))));

    _Sbk_QGuiApplication_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGuiApplication",
        "QGuiApplication*",
        &Sbk_QGuiApplication_spec,
        &Shiboken::callCppDestructor< QGuiApplication >,
        Sbk_QGuiApplication_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGuiApplication_TypeF(); // references _Sbk_QGuiApplication_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGuiApplication_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGuiApplication_SignatureBytes, QGuiApplication_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGuiApplication_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGuiApplication_PythonToCpp_QGuiApplication_PTR,
        is_QGuiApplication_PythonToCpp_QGuiApplication_PTR_Convertible,
        QGuiApplication_PTR_CppToPython_QGuiApplication);

    Shiboken::Conversions::registerConverterName(converter, "QGuiApplication");
    Shiboken::Conversions::registerConverterName(converter, "QGuiApplication*");
    Shiboken::Conversions::registerConverterName(converter, "QGuiApplication&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGuiApplication).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGuiApplicationWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QGuiApplication_TypeF(), &Sbk_QGuiApplication_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QGuiApplication::staticMetaObject);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QGuiApplication::staticMetaObject, sizeof(QGuiApplicationWrapper));

    return pyType;
}

