// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QImageWrapper_H
#define SBK_QImageWrapper_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qimage.h>

class QImageWrapper : public QImage
{
public:
    QImageWrapper(const QImageWrapper &) = delete;
    QImageWrapper& operator=(const QImageWrapper &) = delete;
    QImageWrapper(QImageWrapper &&) = delete;
    QImageWrapper& operator=(QImageWrapper &&) = delete;

    QImageWrapper() noexcept;
    QImageWrapper(const QImage& self) : QImage(self)
    {
    }

    QImageWrapper(const ::QSize & size, ::QImage::Format format);
    QImageWrapper(const ::QString & fileName, const char * format = nullptr);
    QImageWrapper(const char *const xpm[]);
    QImageWrapper(int width, int height, ::QImage::Format format);
    QImageWrapper(uchar * data, int width, int height, ::QImage::Format format, ::QImageCleanupFunction cleanupFunction = nullptr, void * cleanupInfo = nullptr);
    QImageWrapper(uchar * data, int width, int height, qsizetype bytesPerLine, ::QImage::Format format, ::QImageCleanupFunction cleanupFunction = nullptr, void * cleanupInfo = nullptr);
    int devType() const override;
    void initPainter(::QPainter * painter) const override;
    int metric(::QPaintDevice::PaintDeviceMetric metric) const override;
    ::QPaintEngine * paintEngine() const override;
    ::QPaintDevice * redirected(::QPoint * offset) const override;
    ::QPainter * sharedPainter() const override;
    ~QImageWrapper() override;
    static void pysideInitQtMetaTypes();
    void resetPyMethodCache();
private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QImageWrapper_H

