// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qimagereader_wrapper.h"

// Extra includes
#include <QColor>
#include <QImage>
#include <QRect>
#include <QSize>
#include <QStringList>

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtGui/qcolor.h>
#include <QtGui/qimage.h>
#include <QtGui/qimageiohandler.h>
#include <QtGui/qimagereader.h>
#include <qbytearray.h>
#include <qiodevice.h>
#include <qrect.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QImageReader_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QImageReader >()))
        return -1;

    ::QImageReader *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QImageReader", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QImageReader::QImageReader()
    // 1: QImageReader::QImageReader(QIODevice*,const QByteArray&=)
    // 2: QImageReader::QImageReader(QString,const QByteArray&=)
    if (numArgs == 0) {
        overloadId = 0; // QImageReader()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QImageReader(QIODevice*,QByteArray)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QImageReader(QIODevice*,QByteArray)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QImageReader(QString,QByteArray)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QImageReader(QString,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QImageReader()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);
            }

            // QImageReader()
            cptr = new ::QImageReader();
            break;
        }
        case 1: // QImageReader(QIODevice *device, const QByteArray &format)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QByteArray cppArg1_local = QByteArray();
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1]) {
                if (pythonToCpp[1].isValue())
                    pythonToCpp[1](pyArgs[1], &cppArg1_local);
                else
                    pythonToCpp[1](pyArgs[1], &cppArg1);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QImageReader(QIODevice*,QByteArray)
                cptr = new ::QImageReader(cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // QImageReader(const QString &fileName, const QByteArray &format)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QByteArray cppArg1_local = QByteArray();
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1]) {
                if (pythonToCpp[1].isValue())
                    pythonToCpp[1](pyArgs[1], &cppArg1_local);
                else
                    pythonToCpp[1](pyArgs[1], &cppArg1);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QImageReader(QString,QByteArray)
                cptr = new ::QImageReader(cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QImageReader >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QImageReaderFunc_allocationLimit(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // allocationLimit()
        int cppResult = ::QImageReader::allocationLimit();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_autoDetectImageFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoDetectImageFormat()const
        bool cppResult = const_cast<const ::QImageReader *>(cppSelf)->autoDetectImageFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_autoTransform(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoTransform()const
        bool cppResult = const_cast<const ::QImageReader *>(cppSelf)->autoTransform();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_backgroundColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // backgroundColor()const
        QColor cppResult = const_cast<const ::QImageReader *>(cppSelf)->backgroundColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_canRead(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // canRead()const
        bool cppResult = const_cast<const ::QImageReader *>(cppSelf)->canRead();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_clipRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clipRect()const
        QRect cppResult = const_cast<const ::QImageReader *>(cppSelf)->clipRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_currentImageNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentImageNumber()const
        int cppResult = const_cast<const ::QImageReader *>(cppSelf)->currentImageNumber();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_currentImageRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentImageRect()const
        QRect cppResult = const_cast<const ::QImageReader *>(cppSelf)->currentImageRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_decideFormatFromContent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // decideFormatFromContent()const
        bool cppResult = const_cast<const ::QImageReader *>(cppSelf)->decideFormatFromContent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_device(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // device()const
        QIODevice * cppResult = const_cast<const ::QImageReader *>(cppSelf)->device();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QImageReader::ImageReaderError cppResult = const_cast<const ::QImageReader *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_ImageReaderError_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QImageReader *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_fileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileName()const
        QString cppResult = const_cast<const ::QImageReader *>(cppSelf)->fileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // format()const
        QByteArray cppResult = const_cast<const ::QImageReader *>(cppSelf)->format();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_imageCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // imageCount()const
        int cppResult = const_cast<const ::QImageReader *>(cppSelf)->imageCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_imageFormat(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QImageReader *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "imageFormat", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QImageReader::imageFormat()const->QImage::Format
    // 1: static QImageReader::imageFormat(QIODevice*)->QByteArray
    // 2: static QImageReader::imageFormat(QString)->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // imageFormat()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        overloadId = 1; // imageFormat(QIODevice*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 2; // imageFormat(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "imageFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // imageFormat() const
        {

            // imageFormat()const
            QImage::Format cppResult = const_cast<const ::QImageReader *>(cppSelf)->imageFormat();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_Format_IDX])))->converter, &cppResult);
            break;
        }
        case 1: // imageFormat(QIODevice *device)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // imageFormat(QIODevice*)
                QByteArray cppResult = ::QImageReader::imageFormat(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 2: // imageFormat(const QString &fileName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // imageFormat(QString)
                QByteArray cppResult = ::QImageReader::imageFormat(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_imageFormatsForMimeType(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QImageReader::imageFormatsForMimeType(QByteArray)->QList<QByteArray>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // imageFormatsForMimeType(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "imageFormatsForMimeType", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // imageFormatsForMimeType(QByteArray)
            QList<QByteArray> cppResult = ::QImageReader::imageFormatsForMimeType(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QByteArray_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_jumpToImage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageReader::jumpToImage(int)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // jumpToImage(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "jumpToImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // jumpToImage(int)
            bool cppResult = cppSelf->jumpToImage(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_jumpToNextImage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // jumpToNextImage()
        bool cppResult = cppSelf->jumpToNextImage();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_loopCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // loopCount()const
        int cppResult = const_cast<const ::QImageReader *>(cppSelf)->loopCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_nextImageDelay(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nextImageDelay()const
        int cppResult = const_cast<const ::QImageReader *>(cppSelf)->nextImageDelay();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_quality(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // quality()const
        int cppResult = const_cast<const ::QImageReader *>(cppSelf)->quality();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_read(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // read()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        QImage cppResult = cppSelf->read();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_scaledClipRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scaledClipRect()const
        QRect cppResult = const_cast<const ::QImageReader *>(cppSelf)->scaledClipRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_scaledSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scaledSize()const
        QSize cppResult = const_cast<const ::QImageReader *>(cppSelf)->scaledSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_setAllocationLimit(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QImageReader::setAllocationLimit(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setAllocationLimit(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAllocationLimit", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAllocationLimit(int)
            ::QImageReader::setAllocationLimit(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageReaderFunc_setAutoDetectImageFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageReader::setAutoDetectImageFormat(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoDetectImageFormat(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoDetectImageFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoDetectImageFormat(bool)
            cppSelf->setAutoDetectImageFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageReaderFunc_setAutoTransform(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageReader::setAutoTransform(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoTransform(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoTransform", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoTransform(bool)
            cppSelf->setAutoTransform(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageReaderFunc_setBackgroundColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageReader::setBackgroundColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setBackgroundColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBackgroundColor", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackgroundColor(QColor)
            cppSelf->setBackgroundColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageReaderFunc_setClipRect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageReader::setClipRect(QRect)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArg)))) {
        overloadId = 0; // setClipRect(QRect)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setClipRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRect cppArg0_local;
        ::QRect *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setClipRect(QRect)
            cppSelf->setClipRect(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageReaderFunc_setDecideFormatFromContent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageReader::setDecideFormatFromContent(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDecideFormatFromContent(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDecideFormatFromContent", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDecideFormatFromContent(bool)
            cppSelf->setDecideFormatFromContent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageReaderFunc_setDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageReader::setDevice(QIODevice*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDevice", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDevice(QIODevice*)
            cppSelf->setDevice(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageReaderFunc_setFileName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageReader::setFileName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFileName", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFileName(QString)
            cppSelf->setFileName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageReaderFunc_setFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageReader::setFormat(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setFormat(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setFormat(QByteArray)
            cppSelf->setFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageReaderFunc_setQuality(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageReader::setQuality(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setQuality(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setQuality", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setQuality(int)
            cppSelf->setQuality(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageReaderFunc_setScaledClipRect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageReader::setScaledClipRect(QRect)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArg)))) {
        overloadId = 0; // setScaledClipRect(QRect)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setScaledClipRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRect cppArg0_local;
        ::QRect *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setScaledClipRect(QRect)
            cppSelf->setScaledClipRect(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageReaderFunc_setScaledSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageReader::setScaledSize(QSize)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
        overloadId = 0; // setScaledSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setScaledSize", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSize cppArg0_local;
        ::QSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setScaledSize(QSize)
            cppSelf->setScaledSize(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QImageReaderFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        QSize cppResult = const_cast<const ::QImageReader *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_subType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // subType()const
        QByteArray cppResult = const_cast<const ::QImageReader *>(cppSelf)->subType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_supportedImageFormats(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedImageFormats()
        QList<QByteArray> cppResult = ::QImageReader::supportedImageFormats();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QByteArray_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_supportedMimeTypes(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedMimeTypes()
        QList<QByteArray> cppResult = ::QImageReader::supportedMimeTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QByteArray_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_supportedSubTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedSubTypes()const
        QList<QByteArray> cppResult = const_cast<const ::QImageReader *>(cppSelf)->supportedSubTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QByteArray_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_supportsAnimation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportsAnimation()const
        bool cppResult = const_cast<const ::QImageReader *>(cppSelf)->supportsAnimation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_supportsOption(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageReader::supportsOption(QImageIOHandler::ImageOption)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageIOHandler_ImageOption_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // supportsOption(QImageIOHandler::ImageOption)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "supportsOption", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        ::QImageIOHandler::ImageOption cppArg0{QImageIOHandler::Size};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportsOption(QImageIOHandler::ImageOption)const
            bool cppResult = const_cast<const ::QImageReader *>(cppSelf)->supportsOption(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_text(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QImageReader::text(QString)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // text(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "text", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // text(QString)const
            QString cppResult = const_cast<const ::QImageReader *>(cppSelf)->text(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_textKeys(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textKeys()const
        QStringList cppResult = const_cast<const ::QImageReader *>(cppSelf)->textKeys();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QImageReaderFunc_transformation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QImageReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // transformation()const
        QFlags<QImageIOHandler::Transformation> cppResult = const_cast<const ::QImageReader *>(cppSelf)->transformation();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QImageIOHandler_Transformation_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QImageReaderMethod_imageFormat = {"imageFormat", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_imageFormat), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_QImageReader_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QImageReader_EnumFlagInfo[] = {
    "ImageReaderError:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QImageReader_methods[] = {
    {"allocationLimit", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_allocationLimit), METH_NOARGS|METH_STATIC, nullptr},
    {"autoDetectImageFormat", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_autoDetectImageFormat), METH_NOARGS, nullptr},
    {"autoTransform", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_autoTransform), METH_NOARGS, nullptr},
    {"backgroundColor", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_backgroundColor), METH_NOARGS, nullptr},
    {"canRead", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_canRead), METH_NOARGS, nullptr},
    {"clipRect", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_clipRect), METH_NOARGS, nullptr},
    {"currentImageNumber", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_currentImageNumber), METH_NOARGS, nullptr},
    {"currentImageRect", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_currentImageRect), METH_NOARGS, nullptr},
    {"decideFormatFromContent", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_decideFormatFromContent), METH_NOARGS, nullptr},
    {"device", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_device), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_errorString), METH_NOARGS, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_fileName), METH_NOARGS, nullptr},
    {"format", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_format), METH_NOARGS, nullptr},
    {"imageCount", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_imageCount), METH_NOARGS, nullptr},
    {"imageFormat", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_imageFormat), METH_VARARGS|METH_STATIC, nullptr},
    {"imageFormatsForMimeType", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_imageFormatsForMimeType), METH_O|METH_STATIC, nullptr},
    {"jumpToImage", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_jumpToImage), METH_O, nullptr},
    {"jumpToNextImage", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_jumpToNextImage), METH_NOARGS, nullptr},
    {"loopCount", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_loopCount), METH_NOARGS, nullptr},
    {"nextImageDelay", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_nextImageDelay), METH_NOARGS, nullptr},
    {"quality", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_quality), METH_NOARGS, nullptr},
    {"read", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_read), METH_NOARGS, nullptr},
    {"scaledClipRect", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_scaledClipRect), METH_NOARGS, nullptr},
    {"scaledSize", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_scaledSize), METH_NOARGS, nullptr},
    {"setAllocationLimit", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_setAllocationLimit), METH_O|METH_STATIC, nullptr},
    {"setAutoDetectImageFormat", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_setAutoDetectImageFormat), METH_O, nullptr},
    {"setAutoTransform", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_setAutoTransform), METH_O, nullptr},
    {"setBackgroundColor", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_setBackgroundColor), METH_O, nullptr},
    {"setClipRect", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_setClipRect), METH_O, nullptr},
    {"setDecideFormatFromContent", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_setDecideFormatFromContent), METH_O, nullptr},
    {"setDevice", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_setDevice), METH_O, nullptr},
    {"setFileName", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_setFileName), METH_O, nullptr},
    {"setFormat", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_setFormat), METH_O, nullptr},
    {"setQuality", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_setQuality), METH_O, nullptr},
    {"setScaledClipRect", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_setScaledClipRect), METH_O, nullptr},
    {"setScaledSize", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_setScaledSize), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_size), METH_NOARGS, nullptr},
    {"subType", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_subType), METH_NOARGS, nullptr},
    {"supportedImageFormats", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_supportedImageFormats), METH_NOARGS|METH_STATIC, nullptr},
    {"supportedMimeTypes", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_supportedMimeTypes), METH_NOARGS|METH_STATIC, nullptr},
    {"supportedSubTypes", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_supportedSubTypes), METH_NOARGS, nullptr},
    {"supportsAnimation", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_supportsAnimation), METH_NOARGS, nullptr},
    {"supportsOption", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_supportsOption), METH_O, nullptr},
    {"text", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_text), METH_O, nullptr},
    {"textKeys", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_textKeys), METH_NOARGS, nullptr},
    {"transformation", reinterpret_cast<PyCFunction>(Sbk_QImageReaderFunc_transformation), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QImageReader_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QImageReaderMethod_imageFormat = {
        Sbk_QImageReaderMethod_imageFormat.ml_name,
        Sbk_QImageReaderMethod_imageFormat.ml_meth,
        Sbk_QImageReaderMethod_imageFormat.ml_flags & (~METH_STATIC),
        Sbk_QImageReaderMethod_imageFormat.ml_doc,
    };
    if (Shiboken::String::compare(name, "imageFormat") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QImageReaderMethod_imageFormat, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

} // extern "C"

static int Sbk_QImageReader_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QImageReader_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QImageReader_Type = nullptr;
static PyTypeObject *Sbk_QImageReader_TypeF(void)
{
    return _Sbk_QImageReader_Type;
}

static PyType_Slot Sbk_QImageReader_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QImageReader_getattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QImageReader_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QImageReader_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QImageReader_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QImageReader_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QImageReader_spec = {
    "2:PySide6.QtGui.QImageReader",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QImageReader_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QImageReader_ImageReaderError(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QImageReader::ImageReaderError>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QImageReader::ImageReaderError *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QImageReader_ImageReaderError_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_ImageReaderError_IDX])))
        return Enum_PythonToCpp_QImageReader_ImageReaderError;
    return {};
}

static PyObject *QImageReader_ImageReaderError_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QImageReader::ImageReaderError>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QImageReader::ImageReaderError *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_ImageReaderError_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QImageReader_PythonToCpp_QImageReader_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QImageReader_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QImageReader_PythonToCpp_QImageReader_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QImageReader_TypeF()))
        return QImageReader_PythonToCpp_QImageReader_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QImageReader_PTR_CppToPython_QImageReader(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QImageReader_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QImageReader_SignatureStrings[] = {
    "2:PySide6.QtGui.QImageReader(self)",
    "1:PySide6.QtGui.QImageReader(self,device:PySide6.QtCore.QIODevice,format:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray())",
    "0:PySide6.QtGui.QImageReader(self,fileName:QString,format:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray())",
    "PySide6.QtGui.QImageReader.allocationLimit()->int",
    "PySide6.QtGui.QImageReader.autoDetectImageFormat(self)->bool",
    "PySide6.QtGui.QImageReader.autoTransform(self)->bool",
    "PySide6.QtGui.QImageReader.backgroundColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QImageReader.canRead(self)->bool",
    "PySide6.QtGui.QImageReader.clipRect(self)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QImageReader.currentImageNumber(self)->int",
    "PySide6.QtGui.QImageReader.currentImageRect(self)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QImageReader.decideFormatFromContent(self)->bool",
    "PySide6.QtGui.QImageReader.device(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtGui.QImageReader.error(self)->PySide6.QtGui.QImageReader.ImageReaderError",
    "PySide6.QtGui.QImageReader.errorString(self)->QString",
    "PySide6.QtGui.QImageReader.fileName(self)->QString",
    "PySide6.QtGui.QImageReader.format(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtGui.QImageReader.imageCount(self)->int",
    "2:PySide6.QtGui.QImageReader.imageFormat(self)->PySide6.QtGui.QImage.Format",
    "1:PySide6.QtGui.QImageReader.imageFormat(device:PySide6.QtCore.QIODevice)->PySide6.QtCore.QByteArray",
    "0:PySide6.QtGui.QImageReader.imageFormat(fileName:QString)->PySide6.QtCore.QByteArray",
    "PySide6.QtGui.QImageReader.imageFormatsForMimeType(mimeType:typing.Union[PySide6.QtCore.QByteArray, char*])->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtGui.QImageReader.jumpToImage(self,imageNumber:int)->bool",
    "PySide6.QtGui.QImageReader.jumpToNextImage(self)->bool",
    "PySide6.QtGui.QImageReader.loopCount(self)->int",
    "PySide6.QtGui.QImageReader.nextImageDelay(self)->int",
    "PySide6.QtGui.QImageReader.quality(self)->int",
    "PySide6.QtGui.QImageReader.read(self)->PySide6.QtGui.QImage",
    "PySide6.QtGui.QImageReader.scaledClipRect(self)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QImageReader.scaledSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QImageReader.setAllocationLimit(mbLimit:int)",
    "PySide6.QtGui.QImageReader.setAutoDetectImageFormat(self,enabled:bool)",
    "PySide6.QtGui.QImageReader.setAutoTransform(self,enabled:bool)",
    "PySide6.QtGui.QImageReader.setBackgroundColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGui.QImageReader.setClipRect(self,rect:PySide6.QtCore.QRect)",
    "PySide6.QtGui.QImageReader.setDecideFormatFromContent(self,ignored:bool)",
    "PySide6.QtGui.QImageReader.setDevice(self,device:PySide6.QtCore.QIODevice)",
    "PySide6.QtGui.QImageReader.setFileName(self,fileName:QString)",
    "PySide6.QtGui.QImageReader.setFormat(self,format:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtGui.QImageReader.setQuality(self,quality:int)",
    "PySide6.QtGui.QImageReader.setScaledClipRect(self,rect:PySide6.QtCore.QRect)",
    "PySide6.QtGui.QImageReader.setScaledSize(self,size:PySide6.QtCore.QSize)",
    "PySide6.QtGui.QImageReader.size(self)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QImageReader.subType(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtGui.QImageReader.supportedImageFormats()->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtGui.QImageReader.supportedMimeTypes()->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtGui.QImageReader.supportedSubTypes(self)->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtGui.QImageReader.supportsAnimation(self)->bool",
    "PySide6.QtGui.QImageReader.supportsOption(self,option:PySide6.QtGui.QImageIOHandler.ImageOption)->bool",
    "PySide6.QtGui.QImageReader.text(self,key:QString)->QString",
    "PySide6.QtGui.QImageReader.textKeys(self)->QStringList",
    "PySide6.QtGui.QImageReader.transformation(self)->PySide6.QtGui.QImageIOHandler.Transformation",
    nullptr}; // Sentinel
#else
static constexpr size_t QImageReader_SignatureByteSize = 718;
static constexpr uint8_t QImageReader_SignatureBytes[718] = {
    0x78, 0xda, 0xad, 0x56, 0xdf, 0x6f, 0xda, 0x30, 0x10, 0x7e, 0xef, 0x5f, 0xc1, 0x23, 0x4c, 0x29,
    0x6a, 0xab, 0xa9, 0x0f, 0x91, 0x56, 0x89, 0xc2, 0xe8, 0xaa, 0x31, 0x18, 0x84, 0xed, 0x65, 0xe2,
    0xc1, 0x49, 0x0e, 0xe6, 0xd5, 0xb1, 0x33, 0xc7, 0x99, 0x96, 0xfd, 0xf5, 0x73, 0x62, 0x02, 0x49,
    0x20, 0xb6, 0x69, 0xfa, 0x94, 0x53, 0x7c, 0xdf, 0x77, 0xbe, 0x3b, 0xdf, 0x8f, 0x3b, 0xf7, 0x6b,
    0xe6, 0xe1, 0x10, 0xee, 0x87, 0x4b, 0xf1, 0x94, 0xe2, 0xe1, 0xf2, 0x39, 0x42, 0x3b, 0x58, 0x01,
    0x0a, 0x81, 0xf7, 0x13, 0x20, 0xdb, 0xc1, 0xd5, 0xad, 0x49, 0xc5, 0x09, 0xe1, 0x0f, 0x0e, 0xa0,
    0xa2, 0x36, 0x66, 0x1c, 0xa4, 0xde, 0x62, 0x52, 0x1c, 0x38, 0x5b, 0xc6, 0x23, 0x24, 0x5c, 0x91,
    0xc5, 0x98, 0xee, 0x86, 0xdf, 0x28, 0x66, 0xf4, 0x47, 0x53, 0xf9, 0x31, 0x13, 0x30, 0xe2, 0x1c,
    0x65, 0x4e, 0x2f, 0xf8, 0x89, 0xf8, 0xbb, 0xcd, 0x87, 0xe3, 0xaf, 0xfe, 0x60, 0x70, 0x75, 0x63,
    0xbc, 0xc5, 0x16, 0x13, 0x98, 0xa3, 0x08, 0xdc, 0xa5, 0x27, 0xb8, 0x34, 0xf4, 0x26, 0x66, 0xdb,
    0x8d, 0x0e, 0x11, 0x21, 0x2c, 0x40, 0x42, 0xb2, 0xce, 0x70, 0x84, 0x45, 0x7f, 0x70, 0xfd, 0x80,
    0xa9, 0xd0, 0x22, 0x52, 0xc1, 0x26, 0x20, 0x20, 0x10, 0xc5, 0xdf, 0x69, 0x71, 0x3f, 0x15, 0xe5,
    0xeb, 0x07, 0x9f, 0x31, 0x62, 0x02, 0xaf, 0x39, 0xa2, 0x49, 0xee, 0x96, 0x2d, 0xc8, 0x47, 0xc1,
    0xcb, 0x8e, 0xb3, 0x94, 0x86, 0x63, 0x46, 0x18, 0x2f, 0x61, 0x0d, 0x44, 0x71, 0xa6, 0xa3, 0x09,
    0x10, 0xcd, 0x25, 0x5b, 0xab, 0x01, 0xc1, 0xf1, 0x4a, 0x7a, 0x79, 0x6a, 0x4e, 0x05, 0x3d, 0x3f,
    0xd3, 0xe2, 0x53, 0xce, 0x81, 0xaa, 0x20, 0xcd, 0xd3, 0xc8, 0x87, 0xc3, 0xc5, 0x0d, 0x01, 0xae,
    0x02, 0xbb, 0x5c, 0x20, 0x84, 0x40, 0x1e, 0xa9, 0xfc, 0x4c, 0x39, 0x8b, 0xc6, 0x8c, 0x0a, 0xc9,
    0x6b, 0xeb, 0xbf, 0xaa, 0x87, 0x36, 0xe3, 0x65, 0x59, 0xe8, 0x18, 0x80, 0xf3, 0xd6, 0x6c, 0x55,
    0xf5, 0x2a, 0xf2, 0xc7, 0x1c, 0x62, 0xe4, 0x54, 0xa5, 0x51, 0x32, 0xef, 0x2b, 0x45, 0x87, 0x2a,
    0xab, 0xea, 0x12, 0x48, 0xed, 0x5d, 0xb7, 0x56, 0x9c, 0x8e, 0x02, 0xe7, 0xf2, 0x58, 0xbe, 0x5b,
    0x51, 0xcd, 0xfc, 0x9d, 0x6b, 0x82, 0x4c, 0x5b, 0x4c, 0x1f, 0xb5, 0x87, 0x4a, 0x45, 0xdb, 0xd5,
    0x6a, 0x5c, 0x86, 0xe6, 0xa6, 0xf5, 0xf0, 0xc6, 0xd6, 0x48, 0xb3, 0x77, 0x75, 0x8a, 0x9b, 0xe2,
    0x4c, 0xe4, 0xe7, 0x0b, 0x8e, 0x60, 0x9d, 0xc5, 0xd0, 0x8f, 0xf6, 0xc2, 0x85, 0xcd, 0x30, 0xcf,
    0xf7, 0x0c, 0x27, 0xa2, 0x5d, 0x73, 0xa3, 0xbb, 0xcd, 0xaf, 0x34, 0x8a, 0xd7, 0xac, 0xf8, 0xa3,
    0x5a, 0x34, 0x3e, 0x56, 0xb4, 0x2b, 0x13, 0x6a, 0x51, 0x4a, 0x8a, 0x62, 0x0e, 0x7f, 0xc5, 0x91,
    0xc6, 0x02, 0x46, 0x18, 0x8b, 0x4f, 0x9e, 0x8f, 0x46, 0x9f, 0x96, 0x06, 0x26, 0x40, 0x64, 0xe3,
    0xb7, 0x03, 0xfd, 0x4e, 0x11, 0xc1, 0xc2, 0x56, 0x9b, 0x57, 0x1a, 0xe8, 0x39, 0x35, 0x1d, 0x36,
    0x09, 0x10, 0x81, 0x70, 0xdc, 0xb1, 0xad, 0x2a, 0x16, 0x0f, 0xff, 0x6b, 0x6d, 0x4d, 0xf9, 0x99,
    0x96, 0x01, 0xc4, 0xa8, 0x31, 0xf5, 0x22, 0xbf, 0xf8, 0x16, 0xe9, 0x34, 0x41, 0x5b, 0xc7, 0x9f,
    0x03, 0x14, 0xf9, 0xf2, 0x6e, 0x6e, 0x9e, 0x57, 0x1b, 0x9a, 0xfa, 0x20, 0xbc, 0x08, 0xfe, 0x78,
    0x66, 0x24, 0x3a, 0x41, 0x2e, 0xb6, 0x15, 0xc7, 0x71, 0x46, 0x3a, 0xbd, 0xe5, 0x4c, 0xfa, 0x4e,
    0x6f, 0xf7, 0x1b, 0x46, 0xaf, 0xa1, 0xb4, 0xda, 0xf9, 0xe8, 0xfe, 0xbd, 0xd4, 0xfa, 0x8e, 0x38,
    0x46, 0x54, 0x54, 0x15, 0x54, 0x84, 0xc5, 0xf0, 0x89, 0x30, 0x1f, 0x91, 0x92, 0xae, 0x24, 0x4a,
    0x69, 0x82, 0x77, 0x14, 0xc2, 0x9e, 0x8c, 0xe3, 0xc6, 0xe4, 0x42, 0xed, 0x21, 0x38, 0x5c, 0x4a,
    0xee, 0xb9, 0xb7, 0x60, 0xa2, 0x99, 0x68, 0xa6, 0x9c, 0x23, 0x6f, 0x23, 0x89, 0xec, 0x42, 0x3a,
    0x39, 0xce, 0x3b, 0xd3, 0x2e, 0x68, 0xa2, 0x9a, 0x56, 0xc7, 0xcd, 0xc9, 0x4a, 0x67, 0x44, 0x57,
    0x9e, 0xd4, 0xab, 0xb6, 0x3f, 0x93, 0x81, 0x65, 0xa5, 0xe4, 0x9d, 0x7d, 0xfd, 0xdb, 0x3c, 0x7d,
    0xef, 0xb4, 0x80, 0x5f, 0x9f, 0x37, 0xaf, 0x5e, 0xc7, 0x4e, 0x22, 0x25, 0xf7, 0x5c, 0x29, 0xeb,
    0x89, 0xba, 0xf4, 0x81, 0xd4, 0x2f, 0xc6, 0x4a, 0x97, 0x11, 0x9f, 0xa4, 0x71, 0xcc, 0xb8, 0x80,
    0xb0, 0xd2, 0x0c, 0x92, 0x7e, 0xc7, 0x89, 0x73, 0x20, 0x2d, 0x27, 0xdf, 0xdb, 0x31, 0x7a, 0xca,
    0xe7, 0xe4, 0xb0, 0x08, 0x75, 0x27, 0x4d, 0x46, 0x54, 0x4e, 0xc4, 0xbc, 0x97, 0xda, 0xce, 0xb5,
    0x12, 0xb8, 0x88, 0x0f, 0x28, 0x87, 0x15, 0xf2, 0xd9, 0x4d, 0xe3, 0x79, 0xf1, 0x09, 0xd1, 0x90,
    0x94, 0x8b, 0xa2, 0x42, 0x59, 0x98, 0x11, 0x72, 0x1c, 0x2a, 0xf2, 0x17, 0xc8, 0x2a, 0x3b, 0x89,
    0xc5, 0xf2, 0x97, 0x43, 0x3f, 0x43, 0x96, 0x34, 0xf6, 0xc5, 0x3c, 0x58, 0x5a, 0x58, 0xd9, 0xd0,
    0x6b, 0xe1, 0xd0, 0xfb, 0xb4, 0xae, 0x61, 0xae, 0xfe, 0x03, 0x99, 0xb7, 0x43, 0x2f
};
#endif

PyTypeObject *init_QImageReader(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX].type;

    Shiboken::AutoDecRef Sbk_QImageReader_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QImageReader_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QImageReader",
        "QImageReader*",
        &Sbk_QImageReader_spec,
        &Shiboken::callCppDestructor< ::QImageReader >,
        Sbk_QImageReader_Type_bases.object(),
        0);
    auto *pyType = Sbk_QImageReader_TypeF(); // references _Sbk_QImageReader_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QImageReader_SignatureStrings);
#else
    InitSignatureBytes(pyType, QImageReader_SignatureBytes, QImageReader_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QImageReader_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QImageReader_PythonToCpp_QImageReader_PTR,
        is_QImageReader_PythonToCpp_QImageReader_PTR_Convertible,
        QImageReader_PTR_CppToPython_QImageReader);

    Shiboken::Conversions::registerConverterName(converter, "QImageReader");
    Shiboken::Conversions::registerConverterName(converter, "QImageReader*");
    Shiboken::Conversions::registerConverterName(converter, "QImageReader&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QImageReader).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QImageReader_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ImageReaderError'.
    const char *ImageReaderError_Initializer[] = {
        "UnknownError",
        "FileNotFoundError",
        "DeviceError",
        "UnsupportedFormatError",
        "InvalidDataError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ImageReaderError_InitializerValues[] = {
        uint8_t(QImageReader::ImageReaderError::UnknownError),           //  0x00  0
        uint8_t(QImageReader::ImageReaderError::FileNotFoundError),      //  0x01  1
        uint8_t(QImageReader::ImageReaderError::DeviceError),            //  0x02  2
        uint8_t(QImageReader::ImageReaderError::UnsupportedFormatError), //  0x03  3
        uint8_t(QImageReader::ImageReaderError::InvalidDataError)        //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QImageReader_TypeF(),
        "2:PySide6.QtGui.QImageReader.ImageReaderError",
        ImageReaderError_Initializer, ImageReaderError_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QImageReader_ImageReaderError_IDX].type = EType;
    // Register converter for enum 'QImageReader::ImageReaderError'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QImageReader_ImageReaderError_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QImageReader_ImageReaderError,
            is_Enum_PythonToCpp_QImageReader_ImageReaderError_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QImageReader::ImageReaderError");
        Shiboken::Conversions::registerConverterAlias(converter, "ImageReaderError");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ImageReaderError' enum.

    qRegisterMetaType< ::QImageReader *>();
    qRegisterMetaType< ::QImageReader::ImageReaderError >("QImageReader::ImageReaderError");

    return pyType;
}
