// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qinputdevice_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <QtGui/qinputdevice.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qrect.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QInputDeviceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QInputDeviceWrapper::QInputDeviceWrapper(::QObject * parent) : QInputDevice(parent)
{
}

QInputDeviceWrapper::QInputDeviceWrapper(const ::QString & name, qint64 systemId, ::QInputDevice::DeviceType type, const ::QString & seatName, ::QObject * parent) : QInputDevice(name, systemId, type, seatName, parent)
{
}

void QInputDeviceWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QInputDevice", funcName);
        return;
    }
}

void QInputDeviceWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QInputDevice", funcName);
        return;
    }
}

void QInputDeviceWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QInputDevice", funcName);
        return;
    }
}

void QInputDeviceWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QInputDevice", funcName);
        return;
    }
}

bool QInputDeviceWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QInputDevice", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QInputDevice", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QInputDeviceWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QInputDevice", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QInputDevice", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QInputDeviceWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QInputDevice", funcName);
        return;
    }
}

const QMetaObject *QInputDeviceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QInputDevice::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QInputDeviceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QInputDevice::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QInputDeviceWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QInputDeviceWrapper *>(this));
    return QInputDevice::qt_metacast(_clname);
}

QInputDeviceWrapper::~QInputDeviceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QInputDevice_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QInputDevice >()))
        return -1;

    QInputDeviceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:QInputDevice", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QInputDevice::QInputDevice(QObject*=)
    // 1: QInputDevice::QInputDevice(QString,qint64,QInputDevice::DeviceType,const QString&=,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QInputDevice(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QInputDevice(QObject*)
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_DeviceType_IDX])))->converter, (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 1; // QInputDevice(QString,qint64,QInputDevice::DeviceType,QString,QObject*)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 1; // QInputDevice(QString,qint64,QInputDevice::DeviceType,QString,QObject*)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4])))) {
                overloadId = 1; // QInputDevice(QString,qint64,QInputDevice::DeviceType,QString,QObject*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QInputDevice(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QInputDevice(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QInputDeviceWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QInputDeviceWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QInputDevice(const QString &name, qint64 systemId, QInputDevice::DeviceType type, const QString &seatName, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_seatName = Shiboken::String::createStaticString("seatName");
                if (PyDict_Contains(kwds, key_seatName) != 0) {
                    value = PyDict_GetItem(kwds, key_seatName);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_seatName);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_seatName);
                }
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qint64 cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QInputDevice::DeviceType cppArg2{QInputDevice::DeviceType::Unknown};
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3 = QString();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return -1;
            ::QObject *cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QInputDevice(QString,qint64,QInputDevice::DeviceType,QString,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QInputDeviceWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QInputDeviceWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[4], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QInputDevice >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QInputDeviceFunc_availableVirtualGeometry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // availableVirtualGeometry()const
        QRect cppResult = const_cast<const ::QInputDevice *>(cppSelf)->availableVirtualGeometry();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputDeviceFunc_capabilities(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // capabilities()const
        QFlags<QInputDevice::Capability> cppResult = const_cast<const ::QInputDevice *>(cppSelf)->capabilities();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QInputDevice_Capability_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputDeviceFunc_devices(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // devices()
        QList<const QInputDevice*> cppResult = ::QInputDevice::devices();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_constQInputDevicePTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputDeviceFunc_hasCapability(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QInputDevice::hasCapability(QInputDevice::Capability)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_Capability_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // hasCapability(QInputDevice::Capability)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasCapability", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);

    // Call function/method
    {
        ::QInputDevice::Capability cppArg0{QInputDevice::Capability::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasCapability(QInputDevice::Capability)const
            bool cppResult = const_cast<const ::QInputDevice *>(cppSelf)->hasCapability(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputDeviceFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QString cppResult = const_cast<const ::QInputDevice *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputDeviceFunc_primaryKeyboard(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "primaryKeyboard", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);

    if (PyArg_ParseTuple(args, "|O:primaryKeyboard", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QInputDevice::primaryKeyboard(const QString&=)->const QInputDevice*
    if (numArgs == 0) {
        overloadId = 0; // primaryKeyboard(QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // primaryKeyboard(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "primaryKeyboard", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_seatName = Shiboken::String::createStaticString("seatName");
            if (PyDict_Contains(kwds, key_seatName) != 0) {
                value = PyDict_GetItem(kwds, key_seatName);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_seatName);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "primaryKeyboard", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "primaryKeyboard", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_seatName);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "primaryKeyboard", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]);
            }
        }
        ::QString cppArg0 = QString();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // primaryKeyboard(QString)
            const QInputDevice * cppResult = ::QInputDevice::primaryKeyboard(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputDeviceFunc_seatName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // seatName()const
        QString cppResult = const_cast<const ::QInputDevice *>(cppSelf)->seatName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputDeviceFunc_seatNames(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // seatNames()
        QStringList cppResult = ::QInputDevice::seatNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputDeviceFunc_systemId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // systemId()const
        qint64 cppResult = const_cast<const ::QInputDevice *>(cppSelf)->systemId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputDeviceFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QInputDevice::DeviceType cppResult = const_cast<const ::QInputDevice *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_DeviceType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QInputDevice_PropertyStrings[] = {
    "availableVirtualGeometry:",
    "capabilities:",
    "name:",
    "seatName:",
    "systemId:",
    "type:",
    nullptr // Sentinel
};

static const char *Sbk_QInputDevice_EnumFlagInfo[] = {
    "Capability:Flag:Capabilities",
    "DeviceType:Flag:DeviceTypes",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QInputDevice_methods[] = {
    {"availableVirtualGeometry", reinterpret_cast<PyCFunction>(Sbk_QInputDeviceFunc_availableVirtualGeometry), METH_NOARGS, nullptr},
    {"capabilities", reinterpret_cast<PyCFunction>(Sbk_QInputDeviceFunc_capabilities), METH_NOARGS, nullptr},
    {"devices", reinterpret_cast<PyCFunction>(Sbk_QInputDeviceFunc_devices), METH_NOARGS|METH_STATIC, nullptr},
    {"hasCapability", reinterpret_cast<PyCFunction>(Sbk_QInputDeviceFunc_hasCapability), METH_O, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QInputDeviceFunc_name), METH_NOARGS, nullptr},
    {"primaryKeyboard", reinterpret_cast<PyCFunction>(Sbk_QInputDeviceFunc_primaryKeyboard), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"seatName", reinterpret_cast<PyCFunction>(Sbk_QInputDeviceFunc_seatName), METH_NOARGS, nullptr},
    {"seatNames", reinterpret_cast<PyCFunction>(Sbk_QInputDeviceFunc_seatNames), METH_NOARGS|METH_STATIC, nullptr},
    {"systemId", reinterpret_cast<PyCFunction>(Sbk_QInputDeviceFunc_systemId), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QInputDeviceFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QInputDevice_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QInputDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QInputDeviceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

// Rich comparison
static PyObject * Sbk_QInputDevice_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QInputDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), (pyArg)))) {
                // operator==(const QInputDevice &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QInputDevice *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QInputDevice_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QInputDevice_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QInputDevice__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QInputDevice_Type = nullptr;
static PyTypeObject *Sbk_QInputDevice_TypeF(void)
{
    return _Sbk_QInputDevice_Type;
}

static PyType_Slot Sbk_QInputDevice_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QInputDevice__repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QInputDevice_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QInputDevice_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QInputDevice_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QInputDevice_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QInputDevice_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QInputDevice_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QInputDevice_spec = {
    "2:PySide6.QtGui.QInputDevice",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QInputDevice_slots
};

} //extern "C"

static void *Sbk_QInputDevice_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QInputDevice *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QInputDevice_DeviceType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QInputDevice::DeviceType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QInputDevice::DeviceType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QInputDevice_DeviceType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_DeviceType_IDX])))
        return Enum_PythonToCpp_QInputDevice_DeviceType;
    return {};
}

static PyObject *QInputDevice_DeviceType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QInputDevice::DeviceType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QInputDevice::DeviceType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_DeviceType_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QInputDevice_DeviceType(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QInputDevice::DeviceType>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QInputDevice::DeviceType> *>(cppOut) = value;

}

static PyObject *QInputDevice_DeviceType_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QInputDevice::DeviceType> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_DeviceType_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QInputDevice_Capability(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QInputDevice::Capability>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QInputDevice::Capability *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QInputDevice_Capability_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_Capability_IDX])))
        return Enum_PythonToCpp_QInputDevice_Capability;
    return {};
}

static PyObject *QInputDevice_Capability_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QInputDevice::Capability>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QInputDevice::Capability *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_Capability_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QInputDevice_Capability(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QInputDevice::Capability>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QInputDevice::Capability> *>(cppOut) = value;

}

static PyObject *QInputDevice_Capability_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QInputDevice::Capability> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_Capability_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QInputDevice_PythonToCpp_QInputDevice_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QInputDevice_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QInputDevice_PythonToCpp_QInputDevice_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QInputDevice_TypeF()))
        return QInputDevice_PythonToCpp_QInputDevice_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QInputDevice_PTR_CppToPython_QInputDevice(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QInputDevice *>(const_cast<void *>(cppIn)), Sbk_QInputDevice_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QInputDevice_SignatureStrings[] = {
    "1:PySide6.QtGui.QInputDevice(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,name:QString=None,type:QInputDevice.DeviceType=None,capabilities:PySide6.QtGui.QInputDevice.Capability=None,systemId:qint64=None,seatName:QString=None,availableVirtualGeometry:QRect=None)",
    "0:PySide6.QtGui.QInputDevice(self,name:QString,systemId:qint64,type:PySide6.QtGui.QInputDevice.DeviceType,seatName:QString=QString(),parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,name:QString=None,type:QInputDevice.DeviceType=None,capabilities:PySide6.QtGui.QInputDevice.Capability=None,systemId:qint64=None,seatName:QString=None,availableVirtualGeometry:QRect=None)",
    "PySide6.QtGui.QInputDevice.availableVirtualGeometry(self)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QInputDevice.capabilities(self)->PySide6.QtGui.QInputDevice.Capability",
    "PySide6.QtGui.QInputDevice.devices()->QList[PySide6.QtGui.QInputDevice]",
    "PySide6.QtGui.QInputDevice.hasCapability(self,cap:PySide6.QtGui.QInputDevice.Capability)->bool",
    "PySide6.QtGui.QInputDevice.name(self)->QString",
    "PySide6.QtGui.QInputDevice.primaryKeyboard(seatName:QString=QString())->PySide6.QtGui.QInputDevice",
    "PySide6.QtGui.QInputDevice.seatName(self)->QString",
    "PySide6.QtGui.QInputDevice.seatNames()->QStringList",
    "PySide6.QtGui.QInputDevice.systemId(self)->qint64",
    "PySide6.QtGui.QInputDevice.type(self)->PySide6.QtGui.QInputDevice.DeviceType",
    "PySide6.QtGui.QInputDevice.__eq__(self,other:PySide6.QtGui.QInputDevice)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QInputDevice_SignatureByteSize = 339;
static constexpr uint8_t QInputDevice_SignatureBytes[339] = {
    0x78, 0xda, 0xe5, 0x53, 0xc1, 0x4a, 0xc3, 0x40, 0x10, 0xbd, 0xfb, 0x25, 0x89, 0xc4, 0xa0, 0x20,
    0x3d, 0x04, 0xea, 0xa5, 0x42, 0x29, 0x4a, 0x6b, 0xac, 0x78, 0x11, 0x09, 0x9b, 0x64, 0xb4, 0x2b,
    0x9b, 0xdd, 0x74, 0x77, 0x52, 0xd9, 0xbf, 0x37, 0xe9, 0x26, 0x24, 0x34, 0x64, 0xac, 0x67, 0x4f,
    0x0b, 0xc3, 0x9b, 0xf7, 0xe6, 0xcd, 0xbc, 0xbd, 0x89, 0x9e, 0xec, 0x96, 0xe7, 0x30, 0x0b, 0x63,
    0x5c, 0x56, 0x3c, 0x8c, 0x57, 0xb2, 0xac, 0xf0, 0x1e, 0x0e, 0x3c, 0x03, 0xcf, 0x80, 0xf8, 0x08,
    0x4a, 0xa6, 0x41, 0xe2, 0x00, 0xb6, 0x50, 0x1a, 0xc2, 0x78, 0x93, 0x7e, 0x41, 0x86, 0x73, 0x59,
    0x09, 0x51, 0xa2, 0x0e, 0x2e, 0xa3, 0x07, 0xb0, 0xdf, 0x4a, 0xe7, 0x1b, 0x29, 0xec, 0x7c, 0xad,
    0x24, 0x04, 0x92, 0x15, 0x10, 0xc5, 0x5b, 0xd4, 0x5c, 0x7e, 0xba, 0x0a, 0xda, 0xb2, 0xae, 0x0c,
    0x14, 0x42, 0xf7, 0xbc, 0xd4, 0x75, 0x87, 0xc8, 0x58, 0xc9, 0x52, 0x2e, 0x38, 0x72, 0x30, 0xc4,
    0x64, 0xe1, 0xa2, 0xc3, 0xb5, 0x5a, 0xc6, 0x1a, 0x84, 0x62, 0x95, 0x47, 0x7b, 0x2e, 0x71, 0x76,
    0xdb, 0x16, 0x81, 0xe1, 0x7a, 0x34, 0x04, 0x3b, 0x30, 0x2e, 0x58, 0x2a, 0xe0, 0x95, 0x6b, 0xac,
    0x98, 0x58, 0x82, 0x2a, 0x00, 0xb5, 0x8d, 0xe2, 0xe7, 0xc6, 0x50, 0x83, 0xf1, 0x2f, 0xae, 0x7f,
    0x5d, 0xcb, 0xd0, 0xdd, 0xa9, 0xbc, 0x33, 0x4a, 0x8c, 0xdf, 0xdb, 0x1e, 0x0f, 0xd9, 0xbe, 0x9e,
    0xff, 0x3f, 0x37, 0x4f, 0x48, 0x4f, 0xf5, 0x1f, 0x0f, 0xe2, 0x5f, 0xdd, 0x9d, 0x2e, 0xaa, 0x61,
    0xa5, 0xf8, 0x86, 0x96, 0xc7, 0x1c, 0x84, 0x73, 0x8a, 0x34, 0x3f, 0x3e, 0xc6, 0xab, 0xb9, 0xe2,
    0x47, 0x6e, 0xf0, 0x6d, 0x1a, 0xfb, 0x4e, 0xf1, 0xec, 0x98, 0xe9, 0x05, 0x5d, 0xe4, 0xea, 0x79,
    0xcf, 0xbb, 0x4c, 0xad, 0x9d, 0x2a, 0x25, 0x28, 0xfa, 0x26, 0x22, 0x9d, 0xe7, 0xf6, 0x48, 0x14,
    0xbc, 0xd4, 0xbc, 0x60, 0xda, 0xd6, 0x49, 0x4b, 0x15, 0xd3, 0xb9, 0x37, 0x9d, 0x5a, 0x72, 0x87,
    0x94, 0x44, 0x47, 0xf9, 0x87, 0xa9, 0xba, 0x16, 0xb7, 0x6d, 0x87, 0x6f, 0x76, 0x4e, 0xf6, 0xb4,
    0x79, 0xed, 0x64, 0x5c, 0x6c, 0xa9, 0x8e, 0xe6, 0xef, 0x9c, 0x11, 0x8f, 0xfe, 0x43, 0x51, 0x64,
    0x49, 0x02, 0xfb, 0x24, 0x71, 0xf7, 0x54, 0xb8, 0x03, 0x4d, 0x5c, 0xb4, 0x3b, 0xe3, 0x0f, 0xa8,
    0x9e, 0x0a, 0xfb
};
#endif

PyTypeObject *init_QInputDevice(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX].type;

    Shiboken::AutoDecRef Sbk_QInputDevice_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QInputDevice_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QInputDevice",
        "QInputDevice*",
        &Sbk_QInputDevice_spec,
        &Shiboken::callCppDestructor< QInputDevice >,
        Sbk_QInputDevice_Type_bases.object(),
        0);
    auto *pyType = Sbk_QInputDevice_TypeF(); // references _Sbk_QInputDevice_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QInputDevice_SignatureStrings);
#else
    InitSignatureBytes(pyType, QInputDevice_SignatureBytes, QInputDevice_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QInputDevice_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QInputDevice_PythonToCpp_QInputDevice_PTR,
        is_QInputDevice_PythonToCpp_QInputDevice_PTR_Convertible,
        QInputDevice_PTR_CppToPython_QInputDevice);

    Shiboken::Conversions::registerConverterName(converter, "QInputDevice");
    Shiboken::Conversions::registerConverterName(converter, "QInputDevice*");
    Shiboken::Conversions::registerConverterName(converter, "QInputDevice&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QInputDevice).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QInputDeviceWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QInputDevice_TypeF(), &Sbk_QInputDevice_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QInputDevice_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'DeviceType'.
    const char *DeviceType_Initializer[] = {
        "Unknown",
        "Mouse",
        "TouchScreen",
        "TouchPad",
        "Puck",
        "Stylus",
        "Airbrush",
        "Keyboard",
        "AllDevices",
        nullptr};
    // "int32_t" used instead of "int"
    constexpr int32_t DeviceType_InitializerValues[] = {
        int32_t(QInputDevice::DeviceType::Unknown),     //  0x00000000  0
        int32_t(QInputDevice::DeviceType::Mouse),       //  0x00000001  1
        int32_t(QInputDevice::DeviceType::TouchScreen), //  0x00000002  2
        int32_t(QInputDevice::DeviceType::TouchPad),    //  0x00000004  4
        int32_t(QInputDevice::DeviceType::Puck),        //  0x00000008  8
        int32_t(QInputDevice::DeviceType::Stylus),      //  0x00000010  16
        int32_t(QInputDevice::DeviceType::Airbrush),    //  0x00000020  32
        int32_t(QInputDevice::DeviceType::Keyboard),    //  0x00001000  4096
        int32_t(QInputDevice::DeviceType::AllDevices)   //  0x7fffffff  2147483647
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QInputDevice_TypeF(),
        "2:PySide6.QtGui.QInputDevice.DeviceType",
        DeviceType_Initializer, DeviceType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_DeviceType_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QInputDevice_DeviceType_IDX].type =
        EType;
    // Register converter for enum 'QInputDevice::DeviceType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QInputDevice_DeviceType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QInputDevice_DeviceType,
            is_Enum_PythonToCpp_QInputDevice_DeviceType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QInputDevice::DeviceType");
        Shiboken::Conversions::registerConverterAlias(converter, "DeviceType");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QInputDevice_DeviceType_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QInputDevice_DeviceType,
            is_Enum_PythonToCpp_QInputDevice_DeviceType_Convertible);
        // Register converter for flag 'QFlags<QInputDevice::DeviceType>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QInputDevice::DeviceType>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QInputDevice::DeviceTypes");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'DeviceType' enum/flags.

    // Initialization of enum 'Capability'.
    const char *Capability_Initializer[] = {
        "None_",
        "Position",
        "Area",
        "Pressure",
        "Velocity",
        "NormalizedPosition",
        "MouseEmulation",
        "PixelScroll",
        "Scroll",
        "Hover",
        "Rotation",
        "XTilt",
        "YTilt",
        "TangentialPressure",
        "ZPosition",
        "All",
        nullptr};
    // "int32_t" used instead of "int"
    constexpr int32_t Capability_InitializerValues[] = {
        int32_t(QInputDevice::Capability::None),               //  0x00000000  0
        int32_t(QInputDevice::Capability::Position),           //  0x00000001  1
        int32_t(QInputDevice::Capability::Area),               //  0x00000002  2
        int32_t(QInputDevice::Capability::Pressure),           //  0x00000004  4
        int32_t(QInputDevice::Capability::Velocity),           //  0x00000008  8
        int32_t(QInputDevice::Capability::NormalizedPosition), //  0x00000020  32
        int32_t(QInputDevice::Capability::MouseEmulation),     //  0x00000040  64
        int32_t(QInputDevice::Capability::PixelScroll),        //  0x00000080  128
        int32_t(QInputDevice::Capability::Scroll),             //  0x00000100  256
        int32_t(QInputDevice::Capability::Hover),              //  0x00000200  512
        int32_t(QInputDevice::Capability::Rotation),           //  0x00000400  1024
        int32_t(QInputDevice::Capability::XTilt),              //  0x00000800  2048
        int32_t(QInputDevice::Capability::YTilt),              //  0x00001000  4096
        int32_t(QInputDevice::Capability::TangentialPressure), //  0x00002000  8192
        int32_t(QInputDevice::Capability::ZPosition),          //  0x00004000  16384
        int32_t(QInputDevice::Capability::All)                 //  0x7fffffff  2147483647
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QInputDevice_TypeF(),
        "2:PySide6.QtGui.QInputDevice.Capability",
        Capability_Initializer, Capability_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_Capability_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QInputDevice_Capability_IDX].type =
        EType;
    // Register converter for enum 'QInputDevice::Capability'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QInputDevice_Capability_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QInputDevice_Capability,
            is_Enum_PythonToCpp_QInputDevice_Capability_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QInputDevice::Capability");
        Shiboken::Conversions::registerConverterAlias(converter, "Capability");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QInputDevice_Capability_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QInputDevice_Capability,
            is_Enum_PythonToCpp_QInputDevice_Capability_Convertible);
        // Register converter for flag 'QFlags<QInputDevice::Capability>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QInputDevice::Capability>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QInputDevice::Capabilities");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Capability' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QInputDevice::staticMetaObject);
    qRegisterMetaType< ::QInputDevice::DeviceType >("QInputDevice::DeviceType");
    qRegisterMetaType< ::QInputDevice::Capability >("QInputDevice::Capability");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QInputDevice::staticMetaObject, sizeof(QInputDeviceWrapper));

    return pyType;
}
