// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qinputevent_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <QtGui/qinputdevice.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QInputEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QInputEventWrapper::QInputEventWrapper(::QEvent::Type type, const ::QInputDevice * m_dev, ::QFlags<Qt::KeyboardModifier> modifiers) : QInputEvent(type, m_dev, modifiers)
{
}

::QInputEvent * QInputEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QInputEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QInputEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QInputEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QInputEvent", funcName, Shiboken::SbkType< QInputEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QInputEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QInputEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QInputEvent", funcName);
        return;
    }
}

void QInputEventWrapper::setTimestamp(quint64 timestamp)
{
    if (m_PyMethodCache[2]) {
        return this->::QInputEvent::setTimestamp(timestamp);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setTimestamp";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QInputEvent::setTimestamp(timestamp);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &timestamp)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(K)",
        timestamp
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QInputEvent", funcName);
        return;
    }
}

QInputEventWrapper::~QInputEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QInputEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QInputEvent >()))
        return -1;

    QInputEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:QInputEvent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QInputEvent::QInputEvent(QEvent::Type,const QInputDevice*,QFlags<Qt::KeyboardModifier>=)
    // 1: QInputEvent::QInputEvent(QInputEvent)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QInputEvent(QInputEvent)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_Type_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // QInputEvent(QEvent::Type,const QInputDevice*,QFlags<Qt::KeyboardModifier>)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
            overloadId = 0; // QInputEvent(QEvent::Type,const QInputDevice*,QFlags<Qt::KeyboardModifier>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QInputEvent(QEvent::Type type, const QInputDevice *m_dev, QFlags<Qt::KeyboardModifier> modifiers)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifiers = Shiboken::String::createStaticString("modifiers");
                if (PyDict_Contains(kwds, key_modifiers) != 0) {
                    value = PyDict_GetItem(kwds, key_modifiers);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_modifiers);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifiers);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]);
                }
            }
            ::QEvent::Type cppArg0{QEvent::None};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QInputDevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2(Qt::NoModifier);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QInputEvent(QEvent::Type,const QInputDevice*,QFlags<Qt::KeyboardModifier>)
                cptr = new QInputEventWrapper(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // QInputEvent(const QInputEvent &arg__1)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QInputEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QInputEvent(QInputEvent)
                cptr = new QInputEventWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QInputEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QInputEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clone()const
        QInputEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QInputEvent *>(cppSelf)->::QInputEvent::clone()
            : const_cast<const ::QInputEvent *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputEventFunc_device(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // device()const
        const QInputDevice * cppResult = const_cast<const ::QInputEvent *>(cppSelf)->device();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputEventFunc_deviceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // deviceType()const
        QInputDevice::DeviceType cppResult = const_cast<const ::QInputEvent *>(cppSelf)->deviceType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_DeviceType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputEventFunc_modifiers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // modifiers()const
        QFlags<Qt::KeyboardModifier> cppResult = const_cast<const ::QInputEvent *>(cppSelf)->modifiers();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputEventFunc_setModifiers(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QInputEvent::setModifiers(QFlags<Qt::KeyboardModifier>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setModifiers(QFlags<Qt::KeyboardModifier>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setModifiers", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]);

    // Call function/method
    {
        ::QFlags<Qt::KeyboardModifier> cppArg0 = QFlags<Qt::KeyboardModifier>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setModifiers(QFlags<Qt::KeyboardModifier>)
            cppSelf->setModifiers(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QInputEventFunc_setTimestamp(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QInputEvent::setTimestamp(quint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArg)))) {
        overloadId = 0; // setTimestamp(quint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTimestamp", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]);

    // Call function/method
    {
        quint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTimestamp(quint64)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QInputEvent::setTimestamp(cppArg0)
                : cppSelf->setTimestamp(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QInputEventFunc_timestamp(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // timestamp()const
        quint64 cppResult = const_cast<const ::QInputEvent *>(cppSelf)->timestamp();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QInputEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QInputEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QInputEventFunc_clone), METH_NOARGS, nullptr},
    {"device", reinterpret_cast<PyCFunction>(Sbk_QInputEventFunc_device), METH_NOARGS, nullptr},
    {"deviceType", reinterpret_cast<PyCFunction>(Sbk_QInputEventFunc_deviceType), METH_NOARGS, nullptr},
    {"modifiers", reinterpret_cast<PyCFunction>(Sbk_QInputEventFunc_modifiers), METH_NOARGS, nullptr},
    {"setModifiers", reinterpret_cast<PyCFunction>(Sbk_QInputEventFunc_setModifiers), METH_O, nullptr},
    {"setTimestamp", reinterpret_cast<PyCFunction>(Sbk_QInputEventFunc_setTimestamp), METH_O, nullptr},
    {"timestamp", reinterpret_cast<PyCFunction>(Sbk_QInputEventFunc_timestamp), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QInputEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QInputEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QInputEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QInputEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QInputEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QInputEvent_Type = nullptr;
static PyTypeObject *Sbk_QInputEvent_TypeF(void)
{
    return _Sbk_QInputEvent_Type;
}

static PyType_Slot Sbk_QInputEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QInputEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QInputEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QInputEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QInputEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QInputEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QInputEvent_spec = {
    "2:PySide6.QtGui.QInputEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QInputEvent_slots
};

} //extern "C"

static void *Sbk_QInputEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QEvent >())
        return dynamic_cast< ::QInputEvent *>(reinterpret_cast< ::QEvent *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QInputEvent_PythonToCpp_QInputEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QInputEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QInputEvent_PythonToCpp_QInputEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QInputEvent_TypeF()))
        return QInputEvent_PythonToCpp_QInputEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QInputEvent_PTR_CppToPython_QInputEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QInputEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QInputEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QInputEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QInputEvent(self,type:PySide6.QtCore.QEvent.Type,m_dev:PySide6.QtGui.QInputDevice,modifiers:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier)",
    "0:PySide6.QtGui.QInputEvent(self,arg__1:PySide6.QtGui.QInputEvent)",
    "PySide6.QtGui.QInputEvent.clone(self)->PySide6.QtGui.QInputEvent",
    "PySide6.QtGui.QInputEvent.device(self)->PySide6.QtGui.QInputDevice",
    "PySide6.QtGui.QInputEvent.deviceType(self)->PySide6.QtGui.QInputDevice.DeviceType",
    "PySide6.QtGui.QInputEvent.modifiers(self)->PySide6.QtCore.Qt.KeyboardModifier",
    "PySide6.QtGui.QInputEvent.setModifiers(self,modifiers:PySide6.QtCore.Qt.KeyboardModifier)",
    "PySide6.QtGui.QInputEvent.setTimestamp(self,timestamp:quint64)",
    "PySide6.QtGui.QInputEvent.timestamp(self)->quint64",
    nullptr}; // Sentinel
#else
static constexpr size_t QInputEvent_SignatureByteSize = 206;
static constexpr uint8_t QInputEvent_SignatureBytes[206] = {
    0x78, 0xda, 0x95, 0x92, 0x51, 0x0b, 0x82, 0x30, 0x14, 0x85, 0xdf, 0xfd, 0x25, 0x09, 0x36, 0x12,
    0xc2, 0x07, 0xa1, 0x5e, 0x2a, 0x22, 0xc2, 0x48, 0xf2, 0x5d, 0xcc, 0x5d, 0x63, 0xa0, 0xce, 0xb6,
    0xab, 0xe0, 0xbf, 0xcf, 0x4c, 0x25, 0xb1, 0x4d, 0x7a, 0xbc, 0x3b, 0xe7, 0x7c, 0xec, 0x9e, 0xcd,
    0x76, 0xaf, 0xf5, 0x8d, 0x51, 0x70, 0x88, 0x8f, 0xc7, 0x92, 0x11, 0xff, 0x94, 0x17, 0x25, 0x1e,
    0x2a, 0xc8, 0x71, 0x21, 0x21, 0x4d, 0x2c, 0xac, 0x0b, 0xf8, 0xf2, 0xec, 0xb8, 0x00, 0xe2, 0xb7,
    0x3a, 0x09, 0x1a, 0xc9, 0xca, 0x42, 0x0a, 0xd5, 0x4f, 0xc8, 0x1e, 0x2a, 0x16, 0x37, 0x06, 0x4e,
    0x59, 0xc2, 0x40, 0xc8, 0x09, 0x05, 0xc9, 0x19, 0xea, 0x3b, 0x8f, 0x04, 0xf5, 0x3a, 0xcf, 0xa6,
    0x39, 0xbb, 0xf0, 0x7e, 0x32, 0x8d, 0xd5, 0xdc, 0xed, 0x22, 0xf1, 0x08, 0x43, 0x5b, 0xed, 0x32,
    0x0d, 0xa5, 0x44, 0xe2, 0x94, 0xe7, 0xd0, 0x62, 0xcc, 0xe5, 0x56, 0x69, 0xd3, 0x00, 0x68, 0xbb,
    0xa0, 0x8e, 0xf0, 0xa9, 0x60, 0x16, 0xf1, 0x2e, 0x72, 0x1e, 0x43, 0xf6, 0x83, 0x59, 0x43, 0x1c,
    0xea, 0x9e, 0x02, 0x55, 0xad, 0x6b, 0x68, 0x12, 0xd0, 0x1b, 0x01, 0xff, 0x7a, 0x4e, 0x53, 0x4f,
    0x0e, 0x58, 0x06, 0x12, 0xa3, 0xac, 0xe8, 0x7e, 0x5a, 0x3f, 0xba, 0xcf, 0x92, 0xe5, 0xe8, 0xac,
    0x75, 0x71, 0x1c, 0x65, 0x9b, 0x35, 0xbb, 0x8c, 0xf1, 0x02, 0x79, 0x54, 0x02, 0xda
};
#endif

PyTypeObject *init_QInputEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QInputEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]))));

    _Sbk_QInputEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QInputEvent",
        "QInputEvent*",
        &Sbk_QInputEvent_spec,
        &Shiboken::callCppDestructor< QInputEvent >,
        Sbk_QInputEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QInputEvent_TypeF(); // references _Sbk_QInputEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QInputEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QInputEvent_SignatureBytes, QInputEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QInputEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QInputEvent_PythonToCpp_QInputEvent_PTR,
        is_QInputEvent_PythonToCpp_QInputEvent_PTR_Convertible,
        QInputEvent_PTR_CppToPython_QInputEvent);

    Shiboken::Conversions::registerConverterName(converter, "QInputEvent");
    Shiboken::Conversions::registerConverterName(converter, "QInputEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QInputEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QInputEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QInputEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QInputEvent_TypeF(), &Sbk_QInputEvent_typeDiscovery);


    return pyType;
}
