// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qinputmethod_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGui/qinputmethod.h>
#include <QtGui/qtransform.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qlocale.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qrect.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QInputMethodFunc_anchorRectangle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // anchorRectangle()const
        QRectF cppResult = const_cast<const ::QInputMethod *>(cppSelf)->anchorRectangle();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodFunc_commit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // commit()
        cppSelf->commit();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QInputMethodFunc_cursorRectangle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cursorRectangle()const
        QRectF cppResult = const_cast<const ::QInputMethod *>(cppSelf)->cursorRectangle();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodFunc_hide(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hide()
        cppSelf->hide();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QInputMethodFunc_inputDirection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // inputDirection()const
        Qt::LayoutDirection cppResult = const_cast<const ::QInputMethod *>(cppSelf)->inputDirection();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodFunc_inputItemClipRectangle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // inputItemClipRectangle()const
        QRectF cppResult = const_cast<const ::QInputMethod *>(cppSelf)->inputItemClipRectangle();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodFunc_inputItemRectangle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // inputItemRectangle()const
        QRectF cppResult = const_cast<const ::QInputMethod *>(cppSelf)->inputItemRectangle();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodFunc_inputItemTransform(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // inputItemTransform()const
        QTransform cppResult = const_cast<const ::QInputMethod *>(cppSelf)->inputItemTransform();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodFunc_invokeAction(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "invokeAction", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QInputMethod::invokeAction(QInputMethod::Action,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_Action_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // invokeAction(QInputMethod::Action,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "invokeAction", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]);

    // Call function/method
    {
        ::QInputMethod::Action cppArg0{QInputMethod::Click};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // invokeAction(QInputMethod::Action,int)
            cppSelf->invokeAction(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QInputMethodFunc_isAnimating(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAnimating()const
        bool cppResult = const_cast<const ::QInputMethod *>(cppSelf)->isAnimating();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodFunc_isVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isVisible()const
        bool cppResult = const_cast<const ::QInputMethod *>(cppSelf)->isVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodFunc_keyboardRectangle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // keyboardRectangle()const
        QRectF cppResult = const_cast<const ::QInputMethod *>(cppSelf)->keyboardRectangle();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodFunc_locale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // locale()const
        QLocale cppResult = const_cast<const ::QInputMethod *>(cppSelf)->locale();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodFunc_queryFocusObject(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "queryFocusObject", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QInputMethod::queryFocusObject(Qt::InputMethodQuery,QVariant)->QVariant
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // queryFocusObject(Qt::InputMethodQuery,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "queryFocusObject", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]);

    // Call function/method
    {
        ::Qt::InputMethodQuery cppArg0 = static_cast< ::Qt::InputMethodQuery>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // queryFocusObject(Qt::InputMethodQuery,QVariant)
            QVariant cppResult = ::QInputMethod::queryFocusObject(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodFunc_reset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reset()
        cppSelf->reset();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QInputMethodFunc_setInputItemRectangle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QInputMethod::setInputItemRectangle(QRectF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
        overloadId = 0; // setInputItemRectangle(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInputItemRectangle", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setInputItemRectangle(QRectF)
            cppSelf->setInputItemRectangle(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QInputMethodFunc_setInputItemTransform(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QInputMethod::setInputItemTransform(QTransform)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArg)))) {
        overloadId = 0; // setInputItemTransform(QTransform)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInputItemTransform", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTransform cppArg0_local;
        ::QTransform *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setInputItemTransform(QTransform)
            cppSelf->setInputItemTransform(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QInputMethodFunc_setVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QInputMethod::setVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVisible", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVisible(bool)
            cppSelf->setVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QInputMethodFunc_show(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // show()
        cppSelf->show();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QInputMethodFunc_update(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QInputMethod::update(QFlags<Qt::InputMethodQuery>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_InputMethodQuery_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // update(QFlags<Qt::InputMethodQuery>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "update", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX]);

    // Call function/method
    {
        ::QFlags<Qt::InputMethodQuery> cppArg0 = QFlags<Qt::InputMethodQuery>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // update(QFlags<Qt::InputMethodQuery>)
            cppSelf->update(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QInputMethod_PropertyStrings[] = {
    "anchorRectangle:",
    "animating:isAnimating",
    "cursorRectangle:",
    "inputDirection:",
    "inputItemClipRectangle:",
    "keyboardRectangle:",
    "locale:",
    "visible:isVisible",
    nullptr // Sentinel
};

static const char *Sbk_QInputMethod_EnumFlagInfo[] = {
    "Action:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QInputMethod_methods[] = {
    {"anchorRectangle", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_anchorRectangle), METH_NOARGS, nullptr},
    {"commit", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_commit), METH_NOARGS, nullptr},
    {"cursorRectangle", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_cursorRectangle), METH_NOARGS, nullptr},
    {"hide", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_hide), METH_NOARGS, nullptr},
    {"inputDirection", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_inputDirection), METH_NOARGS, nullptr},
    {"inputItemClipRectangle", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_inputItemClipRectangle), METH_NOARGS, nullptr},
    {"inputItemRectangle", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_inputItemRectangle), METH_NOARGS, nullptr},
    {"inputItemTransform", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_inputItemTransform), METH_NOARGS, nullptr},
    {"invokeAction", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_invokeAction), METH_VARARGS, nullptr},
    {"isAnimating", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_isAnimating), METH_NOARGS, nullptr},
    {"isVisible", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_isVisible), METH_NOARGS, nullptr},
    {"keyboardRectangle", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_keyboardRectangle), METH_NOARGS, nullptr},
    {"locale", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_locale), METH_NOARGS, nullptr},
    {"queryFocusObject", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_queryFocusObject), METH_VARARGS|METH_STATIC, nullptr},
    {"reset", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_reset), METH_NOARGS, nullptr},
    {"setInputItemRectangle", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_setInputItemRectangle), METH_O, nullptr},
    {"setInputItemTransform", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_setInputItemTransform), METH_O, nullptr},
    {"setVisible", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_setVisible), METH_O, nullptr},
    {"show", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_show), METH_NOARGS, nullptr},
    {"update", reinterpret_cast<PyCFunction>(Sbk_QInputMethodFunc_update), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QInputMethod_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QInputMethod_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QInputMethod_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QInputMethod_Type = nullptr;
static PyTypeObject *Sbk_QInputMethod_TypeF(void)
{
    return _Sbk_QInputMethod_Type;
}

static PyType_Slot Sbk_QInputMethod_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(SbkDeallocWrapperWithPrivateDtor)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QInputMethod_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QInputMethod_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QInputMethod_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QInputMethod_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QInputMethod_spec = {
    "2:PySide6.QtGui.QInputMethod",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QInputMethod_slots
};

} //extern "C"

static void *Sbk_QInputMethod_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QInputMethod *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QInputMethod_Action(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QInputMethod::Action>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QInputMethod::Action *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QInputMethod_Action_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_Action_IDX])))
        return Enum_PythonToCpp_QInputMethod_Action;
    return {};
}

static PyObject *QInputMethod_Action_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QInputMethod::Action>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QInputMethod::Action *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_Action_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QInputMethod_PythonToCpp_QInputMethod_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QInputMethod_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QInputMethod_PythonToCpp_QInputMethod_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QInputMethod_TypeF()))
        return QInputMethod_PythonToCpp_QInputMethod_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QInputMethod_PTR_CppToPython_QInputMethod(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QInputMethod *>(const_cast<void *>(cppIn)), Sbk_QInputMethod_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QInputMethod_SignatureStrings[] = {
    "PySide6.QtGui.QInputMethod.anchorRectangle(self)->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QInputMethod.commit(self)",
    "PySide6.QtGui.QInputMethod.cursorRectangle(self)->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QInputMethod.hide(self)",
    "PySide6.QtGui.QInputMethod.inputDirection(self)->PySide6.QtCore.Qt.LayoutDirection",
    "PySide6.QtGui.QInputMethod.inputItemClipRectangle(self)->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QInputMethod.inputItemRectangle(self)->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QInputMethod.inputItemTransform(self)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QInputMethod.invokeAction(self,a:PySide6.QtGui.QInputMethod.Action,cursorPosition:int)",
    "PySide6.QtGui.QInputMethod.isAnimating(self)->bool",
    "PySide6.QtGui.QInputMethod.isVisible(self)->bool",
    "PySide6.QtGui.QInputMethod.keyboardRectangle(self)->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QInputMethod.locale(self)->PySide6.QtCore.QLocale",
    "PySide6.QtGui.QInputMethod.queryFocusObject(query:PySide6.QtCore.Qt.InputMethodQuery,argument:QVariant)->QVariant",
    "PySide6.QtGui.QInputMethod.reset(self)",
    "PySide6.QtGui.QInputMethod.setInputItemRectangle(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtGui.QInputMethod.setInputItemTransform(self,transform:PySide6.QtGui.QTransform)",
    "PySide6.QtGui.QInputMethod.setVisible(self,visible:bool)",
    "PySide6.QtGui.QInputMethod.show(self)",
    "PySide6.QtGui.QInputMethod.update(self,queries:PySide6.QtCore.Qt.InputMethodQuery)",
    nullptr}; // Sentinel
#else
static constexpr size_t QInputMethod_SignatureByteSize = 338;
static constexpr uint8_t QInputMethod_SignatureBytes[338] = {
    0x78, 0xda, 0xad, 0x53, 0xcb, 0x6e, 0xc2, 0x30, 0x10, 0xbc, 0xf3, 0x15, 0x3d, 0x82, 0x64, 0x72,
    0xec, 0xc1, 0x07, 0x24, 0x44, 0x45, 0x85, 0x44, 0xd5, 0xa4, 0x0f, 0x2e, 0x55, 0x0f, 0x4e, 0xb2,
    0x90, 0x2d, 0x89, 0x37, 0xf5, 0x83, 0x2a, 0x7f, 0xdf, 0x98, 0x94, 0x47, 0x05, 0x71, 0x90, 0xe0,
    0xe6, 0xf5, 0xce, 0xcc, 0x26, 0x3b, 0xe3, 0xb0, 0x7a, 0xc5, 0x14, 0xee, 0x83, 0xc8, 0x3c, 0x5a,
    0x0c, 0xa2, 0x99, 0x2c, 0xad, 0x79, 0x02, 0x93, 0x51, 0x1a, 0x08, 0x99, 0x64, 0xa4, 0x5e, 0x20,
    0x31, 0x42, 0xae, 0x72, 0xe8, 0x6b, 0xc8, 0x97, 0x83, 0xe1, 0x28, 0xdc, 0x33, 0x26, 0xa4, 0x20,
    0x88, 0x1c, 0x60, 0xda, 0x0b, 0xdb, 0x75, 0x12, 0x2a, 0x0a, 0x34, 0x0d, 0xdd, 0x8b, 0xb3, 0x4a,
    0xdf, 0x62, 0x5e, 0x56, 0x37, 0xba, 0xa7, 0xa1, 0x3b, 0x3f, 0xa0, 0xaa, 0xd5, 0x90, 0x64, 0xdb,
    0x30, 0x13, 0xcc, 0x45, 0x45, 0x47, 0xc0, 0x4e, 0xc9, 0x99, 0x81, 0x62, 0x92, 0x63, 0x79, 0xfd,
    0x7f, 0xec, 0xe5, 0x6e, 0x28, 0xf5, 0xa6, 0x84, 0xd4, 0x4b, 0x52, 0xc5, 0xa9, 0xd4, 0x96, 0xb4,
    0xef, 0xfb, 0xd5, 0x36, 0xb4, 0x86, 0xf1, 0x61, 0x71, 0x4c, 0x70, 0x0f, 0xbc, 0x01, 0xb2, 0xc6,
    0xde, 0x90, 0x34, 0xba, 0x92, 0xa3, 0x34, 0x7e, 0x7f, 0xf4, 0x58, 0x62, 0x21, 0x0c, 0xca, 0xd5,
    0xee, 0x5b, 0x63, 0xa2, 0xdc, 0x4f, 0x59, 0xa0, 0xc6, 0xf8, 0xb0, 0xa7, 0x2e, 0xc2, 0x1a, 0xaa,
    0x98, 0x84, 0x4a, 0xaf, 0x5f, 0x70, 0x4e, 0x89, 0x68, 0xa7, 0xcf, 0xb7, 0x5d, 0x1f, 0xff, 0xdb,
    0x82, 0xaa, 0xa6, 0x94, 0x58, 0xfd, 0x1c, 0x7f, 0xd5, 0xc3, 0xfa, 0xdb, 0x0b, 0x7e, 0x1a, 0xc7,
    0x23, 0x52, 0xe4, 0x20, 0x4c, 0xa8, 0x95, 0x2d, 0x40, 0x1a, 0x1e, 0x2d, 0x84, 0x42, 0x51, 0x6f,
    0x75, 0x38, 0xda, 0x1d, 0x7d, 0x13, 0x15, 0x68, 0xb8, 0xe0, 0x51, 0xd6, 0xa0, 0xd9, 0xf9, 0x1c,
    0x32, 0xf7, 0x22, 0xb8, 0xa9, 0xca, 0xda, 0xa1, 0xe0, 0x5d, 0xd6, 0x9e, 0x7e, 0x9c, 0x5d, 0x1b,
    0xbb, 0x3b, 0x77, 0xfd, 0x79, 0xf1, 0xd4, 0xff, 0x91, 0x65, 0x66, 0x57, 0xf2, 0xb6, 0xe8, 0x76,
    0x29, 0x1f, 0x87, 0x84, 0x6d, 0x9a, 0x82, 0xbb, 0xa8, 0xf8, 0x89, 0x19, 0xfd, 0x74, 0xaf, 0xcb,
    0x96, 0xa9, 0x30, 0x7f, 0xd2, 0xce, 0x42, 0x04, 0x7d, 0x81, 0x89, 0x83, 0xde, 0x2f, 0x02, 0x40,
    0xff, 0x5c
};
#endif

PyTypeObject *init_QInputMethod(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX].type;

    Shiboken::AutoDecRef Sbk_QInputMethod_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QInputMethod_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QInputMethod",
        "QInputMethod*",
        &Sbk_QInputMethod_spec,
        nullptr,
        Sbk_QInputMethod_Type_bases.object(),
        0);
    auto *pyType = Sbk_QInputMethod_TypeF(); // references _Sbk_QInputMethod_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QInputMethod_SignatureStrings);
#else
    InitSignatureBytes(pyType, QInputMethod_SignatureBytes, QInputMethod_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QInputMethod_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QInputMethod_PythonToCpp_QInputMethod_PTR,
        is_QInputMethod_PythonToCpp_QInputMethod_PTR_Convertible,
        QInputMethod_PTR_CppToPython_QInputMethod);

    Shiboken::Conversions::registerConverterName(converter, "QInputMethod");
    Shiboken::Conversions::registerConverterName(converter, "QInputMethod*");
    Shiboken::Conversions::registerConverterName(converter, "QInputMethod&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QInputMethod).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QInputMethod_TypeF(), &Sbk_QInputMethod_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QInputMethod_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Action'.
    const char *Action_Initializer[] = {
        "Click",
        "ContextMenu",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Action_InitializerValues[] = {
        uint8_t(QInputMethod::Action::Click),      //  0x00  0
        uint8_t(QInputMethod::Action::ContextMenu) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QInputMethod_TypeF(),
        "2:PySide6.QtGui.QInputMethod.Action",
        Action_Initializer, Action_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QInputMethod_Action_IDX].type = EType;
    // Register converter for enum 'QInputMethod::Action'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QInputMethod_Action_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QInputMethod_Action,
            is_Enum_PythonToCpp_QInputMethod_Action_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QInputMethod::Action");
        Shiboken::Conversions::registerConverterAlias(converter, "Action");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Action' enum.

    PySide::Signal::registerSignals(pyType, &::QInputMethod::staticMetaObject);
    qRegisterMetaType< ::QInputMethod::Action >("QInputMethod::Action");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QInputMethod::staticMetaObject, sizeof(::QInputMethod));

    return pyType;
}
