// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qinputmethodqueryevent_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <qcoreevent.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QInputMethodQueryEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QInputMethodQueryEventWrapper::QInputMethodQueryEventWrapper(::QFlags<Qt::InputMethodQuery> queries) : QInputMethodQueryEvent(queries)
{
}

::QInputMethodQueryEvent * QInputMethodQueryEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QInputMethodQueryEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QInputMethodQueryEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QInputMethodQueryEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QInputMethodQueryEvent", funcName, Shiboken::SbkType< QInputMethodQueryEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QInputMethodQueryEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QInputMethodQueryEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QInputMethodQueryEvent", funcName);
        return;
    }
}

QInputMethodQueryEventWrapper::~QInputMethodQueryEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QInputMethodQueryEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QInputMethodQueryEvent >()))
        return -1;

    QInputMethodQueryEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QInputMethodQueryEvent", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QInputMethodQueryEvent::QInputMethodQueryEvent(QFlags<Qt::InputMethodQuery>)
    // 1: QInputMethodQueryEvent::QInputMethodQueryEvent(QInputMethodQueryEvent)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QInputMethodQueryEvent(QInputMethodQueryEvent)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_InputMethodQuery_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // QInputMethodQueryEvent(QFlags<Qt::InputMethodQuery>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QInputMethodQueryEvent(QFlags<Qt::InputMethodQuery> queries)
        {
            ::QFlags<Qt::InputMethodQuery> cppArg0 = QFlags<Qt::InputMethodQuery>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QInputMethodQueryEvent(QFlags<Qt::InputMethodQuery>)
                cptr = new QInputMethodQueryEventWrapper(cppArg0);
            }
            break;
        }
        case 1: // QInputMethodQueryEvent(const QInputMethodQueryEvent &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QInputMethodQueryEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QInputMethodQueryEvent(QInputMethodQueryEvent)
                cptr = new QInputMethodQueryEventWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QInputMethodQueryEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QInputMethodQueryEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethodQueryEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clone()const
        QInputMethodQueryEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QInputMethodQueryEvent *>(cppSelf)->::QInputMethodQueryEvent::clone()
            : const_cast<const ::QInputMethodQueryEvent *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodQueryEventFunc_queries(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethodQueryEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // queries()const
        QFlags<Qt::InputMethodQuery> cppResult = const_cast<const ::QInputMethodQueryEvent *>(cppSelf)->queries();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_InputMethodQuery_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodQueryEventFunc_setValue(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethodQueryEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setValue", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QInputMethodQueryEvent::setValue(Qt::InputMethodQuery,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // setValue(Qt::InputMethodQuery,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setValue", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX]);

    // Call function/method
    {
        ::Qt::InputMethodQuery cppArg0 = static_cast< ::Qt::InputMethodQuery>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValue(Qt::InputMethodQuery,QVariant)
            cppSelf->setValue(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QInputMethodQueryEventFunc_value(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethodQueryEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QInputMethodQueryEvent::value(Qt::InputMethodQuery)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // value(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "value", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX]);

    // Call function/method
    {
        ::Qt::InputMethodQuery cppArg0 = static_cast< ::Qt::InputMethodQuery>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // value(Qt::InputMethodQuery)const
            QVariant cppResult = const_cast<const ::QInputMethodQueryEvent *>(cppSelf)->value(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QInputMethodQueryEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QInputMethodQueryEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QInputMethodQueryEventFunc_clone), METH_NOARGS, nullptr},
    {"queries", reinterpret_cast<PyCFunction>(Sbk_QInputMethodQueryEventFunc_queries), METH_NOARGS, nullptr},
    {"setValue", reinterpret_cast<PyCFunction>(Sbk_QInputMethodQueryEventFunc_setValue), METH_VARARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QInputMethodQueryEventFunc_value), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QInputMethodQueryEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QInputMethodQueryEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QInputMethodQueryEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QInputMethodQueryEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QInputMethodQueryEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QInputMethodQueryEvent_Type = nullptr;
static PyTypeObject *Sbk_QInputMethodQueryEvent_TypeF(void)
{
    return _Sbk_QInputMethodQueryEvent_Type;
}

static PyType_Slot Sbk_QInputMethodQueryEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QInputMethodQueryEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QInputMethodQueryEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QInputMethodQueryEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QInputMethodQueryEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QInputMethodQueryEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QInputMethodQueryEvent_spec = {
    "2:PySide6.QtGui.QInputMethodQueryEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QInputMethodQueryEvent_slots
};

} //extern "C"

static void *Sbk_QInputMethodQueryEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::InputMethodQuery)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QInputMethodQueryEvent_PythonToCpp_QInputMethodQueryEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QInputMethodQueryEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QInputMethodQueryEvent_PythonToCpp_QInputMethodQueryEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QInputMethodQueryEvent_TypeF()))
        return QInputMethodQueryEvent_PythonToCpp_QInputMethodQueryEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QInputMethodQueryEvent_PTR_CppToPython_QInputMethodQueryEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QInputMethodQueryEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QInputMethodQueryEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QInputMethodQueryEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QInputMethodQueryEvent(self,queries:PySide6.QtCore.Qt.InputMethodQuery)",
    "0:PySide6.QtGui.QInputMethodQueryEvent(self,arg__1:PySide6.QtGui.QInputMethodQueryEvent)",
    "PySide6.QtGui.QInputMethodQueryEvent.clone(self)->PySide6.QtGui.QInputMethodQueryEvent",
    "PySide6.QtGui.QInputMethodQueryEvent.queries(self)->PySide6.QtCore.Qt.InputMethodQuery",
    "PySide6.QtGui.QInputMethodQueryEvent.setValue(self,query:PySide6.QtCore.Qt.InputMethodQuery,value:QVariant)",
    "PySide6.QtGui.QInputMethodQueryEvent.value(self,query:PySide6.QtCore.Qt.InputMethodQuery)->QVariant",
    nullptr}; // Sentinel
#else
static constexpr size_t QInputMethodQueryEvent_SignatureByteSize = 149;
static constexpr uint8_t QInputMethodQueryEvent_SignatureBytes[149] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0xf4, 0xcc, 0x2b, 0x28, 0x2d, 0xf1, 0x4d, 0x2d, 0xc9, 0xc8, 0x4f, 0x09, 0x2c,
    0x4d, 0x2d, 0xaa, 0x74, 0x2d, 0x4b, 0xcd, 0x2b, 0xd1, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0x29, 0x04,
    0xf2, 0x33, 0x53, 0x8b, 0x91, 0x74, 0x38, 0xe7, 0x17, 0xa5, 0x02, 0x29, 0x3d, 0x74, 0x4d, 0x9a,
    0x5c, 0x06, 0x24, 0x98, 0x9b, 0x58, 0x94, 0x1e, 0x1f, 0x6f, 0x48, 0x94, 0x06, 0x4d, 0x2e, 0x62,
    0x54, 0xe9, 0x25, 0xe7, 0xe4, 0xe7, 0xa5, 0x82, 0x0d, 0xd7, 0xd4, 0xb5, 0x23, 0x46, 0x07, 0x71,
    0xc6, 0x42, 0x03, 0x00, 0xd3, 0x60, 0x5c, 0xe1, 0x40, 0x9c, 0xb1, 0xc5, 0xa9, 0x25, 0x61, 0x89,
    0x39, 0xa5, 0xa9, 0x88, 0x50, 0xae, 0x24, 0x22, 0x8c, 0x75, 0xca, 0x40, 0x7a, 0xac, 0x02, 0xc3,
    0x12, 0x8b, 0x32, 0x13, 0x89, 0x0e, 0x99, 0x32, 0xd2, 0x2d, 0x02, 0xfa, 0x14, 0x66, 0x09, 0x17,
    0x00, 0xcc, 0x47, 0xcd, 0x1c
};
#endif

PyTypeObject *init_QInputMethodQueryEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QInputMethodQueryEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]))));

    _Sbk_QInputMethodQueryEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QInputMethodQueryEvent",
        "QInputMethodQueryEvent*",
        &Sbk_QInputMethodQueryEvent_spec,
        &Shiboken::callCppDestructor< QInputMethodQueryEvent >,
        Sbk_QInputMethodQueryEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QInputMethodQueryEvent_TypeF(); // references _Sbk_QInputMethodQueryEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QInputMethodQueryEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QInputMethodQueryEvent_SignatureBytes, QInputMethodQueryEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QInputMethodQueryEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodQueryEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QInputMethodQueryEvent_PythonToCpp_QInputMethodQueryEvent_PTR,
        is_QInputMethodQueryEvent_PythonToCpp_QInputMethodQueryEvent_PTR_Convertible,
        QInputMethodQueryEvent_PTR_CppToPython_QInputMethodQueryEvent);

    Shiboken::Conversions::registerConverterName(converter, "QInputMethodQueryEvent");
    Shiboken::Conversions::registerConverterName(converter, "QInputMethodQueryEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QInputMethodQueryEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QInputMethodQueryEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QInputMethodQueryEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QInputMethodQueryEvent_TypeF(), &Sbk_QInputMethodQueryEvent_typeDiscovery);


    return pyType;
}
