// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QKeyEventWrapper_H
#define SBK_QKeyEventWrapper_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qevent.h>

class QKeyEventWrapper : public QKeyEvent
{
public:
    QKeyEventWrapper(const QKeyEventWrapper &) = delete;
    QKeyEventWrapper& operator=(const QKeyEventWrapper &) = delete;
    QKeyEventWrapper(QKeyEventWrapper &&) = delete;
    QKeyEventWrapper& operator=(QKeyEventWrapper &&) = delete;

    QKeyEventWrapper(::QEvent::Type type, int key, ::QFlags<Qt::KeyboardModifier> modifiers, const ::QString & text = QString(), bool autorep = false, quint16 count = 1);
    QKeyEventWrapper(::QEvent::Type type, int key, ::QFlags<Qt::KeyboardModifier> modifiers, quint32 nativeScanCode, quint32 nativeVirtualKey, quint32 nativeModifiers, const ::QString & text = QString(), bool autorep = false, quint16 count = 1, const ::QInputDevice * device = QInputDevice::primaryKeyboard());
    QKeyEventWrapper(const QKeyEvent& self) : QKeyEvent(self)
    {
    }

    ::QKeyEvent * clone() const override;
    void setAccepted(bool accepted) override;
    void setTimestamp(quint64 timestamp) override;
    ~QKeyEventWrapper() override;
    static void pysideInitQtMetaTypes();
    void resetPyMethodCache();
private:
    mutable bool m_PyMethodCache[3] = {false, false, false};
};

#endif // SBK_QKeyEventWrapper_H

