// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qkeysequence_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qkeysequence.h>
#include <qdatastream.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QKeySequence_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QKeySequence >()))
        return -1;

    ::QKeySequence *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:QKeySequence", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QKeySequence::QKeySequence()
    // 1: QKeySequence::QKeySequence(QKeyCombination,QKeyCombination=,QKeyCombination=,QKeyCombination=)
    // 2: QKeySequence::QKeySequence(QKeySequence::StandardKey)
    // 3: QKeySequence::QKeySequence(QKeySequence)
    // 4: QKeySequence::QKeySequence(QString,QKeySequence::SequenceFormat=)
    // 5: QKeySequence::QKeySequence(int,int=,int=,int=)
    if (numArgs == 0) {
        overloadId = 0; // QKeySequence()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 4; // QKeySequence(QString,QKeySequence::SequenceFormat)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceFormat_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 4; // QKeySequence(QString,QKeySequence::SequenceFormat)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_StandardKey_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 2; // QKeySequence(QKeySequence::StandardKey)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 5; // QKeySequence(int,int,int,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 5; // QKeySequence(int,int,int,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 5; // QKeySequence(int,int,int,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 5; // QKeySequence(int,int,int,int)
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QKeySequence(QKeyCombination,QKeyCombination,QKeyCombination,QKeyCombination)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // QKeySequence(QKeyCombination,QKeyCombination,QKeyCombination,QKeyCombination)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // QKeySequence(QKeyCombination,QKeyCombination,QKeyCombination,QKeyCombination)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), (pyArgs[3])))) {
                    overloadId = 1; // QKeySequence(QKeyCombination,QKeyCombination,QKeyCombination,QKeyCombination)
                }
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QKeySequence(QKeySequence)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QKeySequence()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
            }

            // QKeySequence()
            cptr = new ::QKeySequence();
            break;
        }
        case 1: // QKeySequence(QKeyCombination k1, QKeyCombination k2, QKeyCombination k3, QKeyCombination k4)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_k2 = Shiboken::String::createStaticString("k2");
                if (PyDict_Contains(kwds, key_k2) != 0) {
                    value = PyDict_GetItem(kwds, key_k2);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_k2);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_k2);
                }
                static PyObject *const key_k3 = Shiboken::String::createStaticString("k3");
                if (PyDict_Contains(kwds, key_k3) != 0) {
                    value = PyDict_GetItem(kwds, key_k3);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_k3);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_k3);
                }
                static PyObject *const key_k4 = Shiboken::String::createStaticString("k4");
                if (PyDict_Contains(kwds, key_k4) != 0) {
                    value = PyDict_GetItem(kwds, key_k4);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_k4);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_k4);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QKeyCombination cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QKeyCombination cppArg1 = QKeyCombination::fromCombined(0);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QKeyCombination cppArg2 = QKeyCombination::fromCombined(0);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QKeyCombination cppArg3 = QKeyCombination::fromCombined(0);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QKeySequence(QKeyCombination,QKeyCombination,QKeyCombination,QKeyCombination)
                cptr = new ::QKeySequence(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 2: // QKeySequence(QKeySequence::StandardKey key)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
            }
            ::QKeySequence::StandardKey cppArg0{QKeySequence::UnknownKey};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QKeySequence(QKeySequence::StandardKey)
                cptr = new ::QKeySequence(cppArg0);
            }
            break;
        }
        case 3: // QKeySequence(const QKeySequence &ks)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QKeySequence cppArg0_local;
            ::QKeySequence *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QKeySequence(QKeySequence)
                cptr = new ::QKeySequence(*cppArg0);
            }
            break;
        }
        case 4: // QKeySequence(const QString &key, QKeySequence::SequenceFormat format)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceFormat_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QKeySequence::SequenceFormat cppArg1(QKeySequence::SequenceFormat::NativeText);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QKeySequence(QString,QKeySequence::SequenceFormat)
                cptr = new ::QKeySequence(cppArg0, cppArg1);
            }
            break;
        }
        case 5: // QKeySequence(int k1, int k2, int k3, int k4)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_k2 = Shiboken::String::createStaticString("k2");
                if (PyDict_Contains(kwds, key_k2) != 0) {
                    value = PyDict_GetItem(kwds, key_k2);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_k2);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_k2);
                }
                static PyObject *const key_k3 = Shiboken::String::createStaticString("k3");
                if (PyDict_Contains(kwds, key_k3) != 0) {
                    value = PyDict_GetItem(kwds, key_k3);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_k3);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_k3);
                }
                static PyObject *const key_k4 = Shiboken::String::createStaticString("k4");
                if (PyDict_Contains(kwds, key_k4) != 0) {
                    value = PyDict_GetItem(kwds, key_k4);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_k4);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_k4);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = 0;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = 0;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QKeySequence(int,int,int,int)
                cptr = new ::QKeySequence(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QKeySequence >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QKeySequenceFunc___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeySequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __reduce__()
        // Begin code injection
        // TEMPLATE - reduce_code - START
        pyResult = Py_BuildValue("(N(iiii))", PyObject_Type(self), (*cppSelf)[0], (*cppSelf)[1], (*cppSelf)[2], (*cppSelf)[3]);
        // TEMPLATE - reduce_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeySequenceFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeySequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtgui.cpp (qkeysequence-repr)]
        auto ObTuple_Type = reinterpret_cast<PyObject *>(&PyTuple_Type);
        auto ObSelf_Type = reinterpret_cast<PyObject *>(Py_TYPE(self));
        Shiboken::AutoDecRef surrogate(PyObject_CallFunctionObjArgs(ObTuple_Type, self, nullptr));
        Shiboken::AutoDecRef argstr(PyObject_Repr(surrogate));
        Shiboken::AutoDecRef name(PyObject_GetAttrString(ObSelf_Type, "__name__"));
        return PyUnicode_Concat(name, argstr);
        // END of custom code block [file: ../glue/qtgui.cpp (qkeysequence-repr)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeySequenceFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeySequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        int cppResult = const_cast<const ::QKeySequence *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeySequenceFunc_fromString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fromString", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QKeySequence::fromString(QString,QKeySequence::SequenceFormat=)->QKeySequence
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromString(QString,QKeySequence::SequenceFormat)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceFormat_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // fromString(QString,QKeySequence::SequenceFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceFormat_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QKeySequence::SequenceFormat cppArg1(QKeySequence::SequenceFormat::PortableText);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromString(QString,QKeySequence::SequenceFormat)
            QKeySequence cppResult = ::QKeySequence::fromString(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeySequenceFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeySequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QKeySequence *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeySequenceFunc_keyBindings(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QKeySequence::keyBindings(QKeySequence::StandardKey)->QList<QKeySequence>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_StandardKey_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // keyBindings(QKeySequence::StandardKey)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyBindings", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

    // Call function/method
    {
        ::QKeySequence::StandardKey cppArg0{QKeySequence::UnknownKey};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyBindings(QKeySequence::StandardKey)
            QList<QKeySequence> cppResult = ::QKeySequence::keyBindings(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QKeySequence_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeySequenceFunc_listFromString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "listFromString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

    if (PyArg_ParseTuple(args, "|OO:listFromString", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QKeySequence::listFromString(QString,QKeySequence::SequenceFormat=)->QList<QKeySequence>
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // listFromString(QString,QKeySequence::SequenceFormat)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceFormat_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // listFromString(QString,QKeySequence::SequenceFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "listFromString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "listFromString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceFormat_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "listFromString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "listFromString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QKeySequence::SequenceFormat cppArg1(QKeySequence::SequenceFormat::PortableText);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // listFromString(QString,QKeySequence::SequenceFormat)
            QList<QKeySequence> cppResult = ::QKeySequence::listFromString(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QKeySequence_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeySequenceFunc_listToString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "listToString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

    if (PyArg_ParseTuple(args, "|OO:listToString", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QKeySequence::listToString(QList<QKeySequence>,QKeySequence::SequenceFormat=)->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QKeySequence_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // listToString(QList<QKeySequence>,QKeySequence::SequenceFormat)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceFormat_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // listToString(QList<QKeySequence>,QKeySequence::SequenceFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "listToString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "listToString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceFormat_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "listToString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "listToString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
            }
        }
        ::QList<QKeySequence> cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QKeySequence::SequenceFormat cppArg1(QKeySequence::SequenceFormat::PortableText);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // listToString(QList<QKeySequence>,QKeySequence::SequenceFormat)
            QString cppResult = ::QKeySequence::listToString(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeySequenceFunc_matches(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeySequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QKeySequence::matches(QKeySequence)const->QKeySequence::SequenceMatch
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), (pyArg)))) {
        overloadId = 0; // matches(QKeySequence)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "matches", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeySequence cppArg0_local;
        ::QKeySequence *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // matches(QKeySequence)const
            QKeySequence::SequenceMatch cppResult = const_cast<const ::QKeySequence *>(cppSelf)->matches(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceMatch_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeySequenceFunc_mnemonic(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QKeySequence::mnemonic(QString)->QKeySequence
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // mnemonic(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mnemonic", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mnemonic(QString)
            QKeySequence cppResult = ::QKeySequence::mnemonic(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeySequenceFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeySequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QKeySequence::swap(QKeySequence&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QKeySequence&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeySequence cppArg0_local;
        ::QKeySequence *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QKeySequence&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QKeySequenceFunc_toString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeySequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

    if (PyArg_ParseTuple(args, "|O:toString", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QKeySequence::toString(QKeySequence::SequenceFormat=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // toString(QKeySequence::SequenceFormat)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceFormat_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // toString(QKeySequence::SequenceFormat)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceFormat_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);
            }
        }
        ::QKeySequence::SequenceFormat cppArg0(QKeySequence::SequenceFormat::PortableText);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toString(QKeySequence::SequenceFormat)const
            QString cppResult = const_cast<const ::QKeySequence *>(cppSelf)->toString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeySequence__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QKeySequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QKeySequence_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QKeySequence_EnumFlagInfo[] = {
    "SequenceFormat:Enum",
    "SequenceMatch:Enum",
    "StandardKey:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QKeySequence_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QKeySequenceFunc___reduce__), METH_NOARGS, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QKeySequenceFunc_count), METH_NOARGS, nullptr},
    {"fromString", reinterpret_cast<PyCFunction>(Sbk_QKeySequenceFunc_fromString), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QKeySequenceFunc_isEmpty), METH_NOARGS, nullptr},
    {"keyBindings", reinterpret_cast<PyCFunction>(Sbk_QKeySequenceFunc_keyBindings), METH_O|METH_STATIC, nullptr},
    {"listFromString", reinterpret_cast<PyCFunction>(Sbk_QKeySequenceFunc_listFromString), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"listToString", reinterpret_cast<PyCFunction>(Sbk_QKeySequenceFunc_listToString), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"matches", reinterpret_cast<PyCFunction>(Sbk_QKeySequenceFunc_matches), METH_O, nullptr},
    {"mnemonic", reinterpret_cast<PyCFunction>(Sbk_QKeySequenceFunc_mnemonic), METH_O|METH_STATIC, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QKeySequenceFunc_swap), METH_O, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QKeySequenceFunc_toString), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QKeySequence__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QKeySequenceFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeySequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QKeySequence::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QKeySequence)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QKeySequence) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeySequenceFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeySequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QKeySequence::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QKeySequence&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QKeySequence&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

PyObject* Sbk_QKeySequenceFunc___getitem__(PyObject *self, Py_ssize_t _i)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeySequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtgui.cpp (qkeysequence-getitem)]
    const Py_ssize_t size = cppSelf->count();
    if (_i < 0 || _i >= size) {
        Shiboken::Errors::setIndexOutOfBounds(_i, 0, size);
        return nullptr;
    }
    QKeyCombination item = (*cppSelf)[_i];
    return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), &item);
    // END of custom code block [file: ../glue/qtgui.cpp (qkeysequence-getitem)]
    // ========================================================================
    // End of code injection

}

// Rich comparison
static PyObject * Sbk_QKeySequence_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QKeySequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), (pyArg)))) {
                // operator!=(const QKeySequence &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QKeySequence cppArg0_local;
                ::QKeySequence *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), (pyArg)))) {
                // operator<(const QKeySequence &ks) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QKeySequence cppArg0_local;
                ::QKeySequence *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), (pyArg)))) {
                // operator<=(const QKeySequence &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QKeySequence cppArg0_local;
                ::QKeySequence *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), (pyArg)))) {
                // operator==(const QKeySequence &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QKeySequence cppArg0_local;
                ::QKeySequence *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), (pyArg)))) {
                // operator>(const QKeySequence &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QKeySequence cppArg0_local;
                ::QKeySequence *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), (pyArg)))) {
                // operator>=(const QKeySequence &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QKeySequence cppArg0_local;
                ::QKeySequence *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QKeySequence_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeySequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QKeySequence_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QKeySequence_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QKeySequence_Type = nullptr;
static PyTypeObject *Sbk_QKeySequence_TypeF(void)
{
    return _Sbk_QKeySequence_Type;
}

static PyType_Slot Sbk_QKeySequence_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QKeySequenceFunc___repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QKeySequence_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QKeySequence_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QKeySequence_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QKeySequence_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QKeySequence_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QKeySequence_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports sequence protocol
    {Py_sq_item,        reinterpret_cast<void *>(&Sbk_QKeySequenceFunc___getitem__)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QKeySequenceFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QKeySequenceFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QKeySequence_spec = {
    "2:PySide6.QtGui.QKeySequence",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QKeySequence_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QKeySequence_StandardKey(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QKeySequence::StandardKey>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QKeySequence::StandardKey *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QKeySequence_StandardKey_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_StandardKey_IDX])))
        return Enum_PythonToCpp_QKeySequence_StandardKey;
    return {};
}

static PyObject *QKeySequence_StandardKey_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QKeySequence::StandardKey>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QKeySequence::StandardKey *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_StandardKey_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QKeySequence_SequenceFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QKeySequence::SequenceFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QKeySequence::SequenceFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QKeySequence_SequenceFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceFormat_IDX])))
        return Enum_PythonToCpp_QKeySequence_SequenceFormat;
    return {};
}

static PyObject *QKeySequence_SequenceFormat_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QKeySequence::SequenceFormat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QKeySequence::SequenceFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceFormat_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QKeySequence_SequenceMatch(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QKeySequence::SequenceMatch>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QKeySequence::SequenceMatch *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QKeySequence_SequenceMatch_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceMatch_IDX])))
        return Enum_PythonToCpp_QKeySequence_SequenceMatch;
    return {};
}

static PyObject *QKeySequence_SequenceMatch_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QKeySequence::SequenceMatch>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QKeySequence::SequenceMatch *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceMatch_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QKeySequence_PythonToCpp_QKeySequence_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QKeySequence_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QKeySequence_PythonToCpp_QKeySequence_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QKeySequence_TypeF()))
        return QKeySequence_PythonToCpp_QKeySequence_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QKeySequence_PTR_CppToPython_QKeySequence(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QKeySequence_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QKeySequence_COPY_CppToPython_QKeySequence(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QKeySequence *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QKeySequence_TypeF(), new ::QKeySequence(*source), true, true);
}

// Python to C++ copy conversion.
static void QKeySequence_PythonToCpp_QKeySequence_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QKeySequence *>(cppOut) = *reinterpret_cast< ::QKeySequence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QKeySequence_PythonToCpp_QKeySequence_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QKeySequence_TypeF()))
        return QKeySequence_PythonToCpp_QKeySequence_COPY;
    return {};
}

// Implicit conversions.
static void PySide6_QtCore_QKeyCombination_PythonToCpp_QKeySequence(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QKeySequence *>(cppOut) = ::QKeySequence( *reinterpret_cast< ::QKeyCombination *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_PySide6_QtCore_QKeyCombination_PythonToCpp_QKeySequence_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), pyIn))
        return PySide6_QtCore_QKeyCombination_PythonToCpp_QKeySequence;
    return {};
}

static void QKeySequence_StandardKey_PythonToCpp_QKeySequence(PyObject *pyIn, void *cppOut)
{
    ::QKeySequence::StandardKey cppIn{QKeySequence::UnknownKey};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_StandardKey_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QKeySequence *>(cppOut) = ::QKeySequence(cppIn);
}
static PythonToCppFunc is_QKeySequence_StandardKey_PythonToCpp_QKeySequence_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_StandardKey_IDX]), pyIn))
        return QKeySequence_StandardKey_PythonToCpp_QKeySequence;
    return {};
}

static void PySide6_QtCore_constQStringREF_PythonToCpp_QKeySequence(PyObject *pyIn, void *cppOut)
{
    ::QString cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QKeySequence *>(cppOut) = ::QKeySequence(cppIn);
}
static PythonToCppFunc is_PySide6_QtCore_constQStringREF_PythonToCpp_QKeySequence_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return PySide6_QtCore_constQStringREF_PythonToCpp_QKeySequence;
    return {};
}

static void int_PythonToCpp_QKeySequence(PyObject *pyIn, void *cppOut)
{
    int cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn, &cppIn);
    *reinterpret_cast<::QKeySequence *>(cppOut) = ::QKeySequence(cppIn);
}
static PythonToCppFunc is_int_PythonToCpp_QKeySequence_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return int_PythonToCpp_QKeySequence;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QKeySequence_SignatureStrings[] = {
    "5:PySide6.QtGui.QKeySequence(self)",
    "4:PySide6.QtGui.QKeySequence(self,k1:typing.Union[PySide6.QtCore.QKeyCombination, PySide6.QtCore.Qt.KeyboardModifier, PySide6.QtCore.Qt.Key],k2:typing.Union[PySide6.QtCore.QKeyCombination, PySide6.QtCore.Qt.KeyboardModifier, PySide6.QtCore.Qt.Key]=QKeyCombination.fromCombined(0),k3:typing.Union[PySide6.QtCore.QKeyCombination, PySide6.QtCore.Qt.KeyboardModifier, PySide6.QtCore.Qt.Key]=QKeyCombination.fromCombined(0),k4:typing.Union[PySide6.QtCore.QKeyCombination, PySide6.QtCore.Qt.KeyboardModifier, PySide6.QtCore.Qt.Key]=QKeyCombination.fromCombined(0))",
    "3:PySide6.QtGui.QKeySequence(self,key:PySide6.QtGui.QKeySequence.StandardKey)",
    "2:PySide6.QtGui.QKeySequence(self,ks:PySide6.QtGui.QKeySequence)",
    "1:PySide6.QtGui.QKeySequence(self,key:QString,format:PySide6.QtGui.QKeySequence.SequenceFormat=QKeySequence.SequenceFormat.NativeText)",
    "0:PySide6.QtGui.QKeySequence(self,k1:int,k2:int=0,k3:int=0,k4:int=0)",
    "PySide6.QtGui.QKeySequence.__reduce__(self)->str",
    "PySide6.QtGui.QKeySequence.__repr__(self)->str",
    "PySide6.QtGui.QKeySequence.count(self)->int",
    "PySide6.QtGui.QKeySequence.fromString(str:QString,format:PySide6.QtGui.QKeySequence.SequenceFormat=QKeySequence.SequenceFormat.PortableText)->PySide6.QtGui.QKeySequence",
    "PySide6.QtGui.QKeySequence.isEmpty(self)->bool",
    "PySide6.QtGui.QKeySequence.keyBindings(key:PySide6.QtGui.QKeySequence.StandardKey)->QList[PySide6.QtGui.QKeySequence]",
    "PySide6.QtGui.QKeySequence.listFromString(str:QString,format:PySide6.QtGui.QKeySequence.SequenceFormat=QKeySequence.SequenceFormat.PortableText)->QList[PySide6.QtGui.QKeySequence]",
    "PySide6.QtGui.QKeySequence.listToString(list:QList[PySide6.QtGui.QKeySequence],format:PySide6.QtGui.QKeySequence.SequenceFormat=QKeySequence.SequenceFormat.PortableText)->QString",
    "PySide6.QtGui.QKeySequence.matches(self,seq:typing.Union[PySide6.QtGui.QKeySequence, PySide6.QtCore.QKeyCombination, PySide6.QtGui.QKeySequence.StandardKey, QString, int])->PySide6.QtGui.QKeySequence.SequenceMatch",
    "PySide6.QtGui.QKeySequence.mnemonic(text:QString)->PySide6.QtGui.QKeySequence",
    "PySide6.QtGui.QKeySequence.swap(self,other:typing.Union[PySide6.QtGui.QKeySequence, PySide6.QtCore.QKeyCombination, PySide6.QtGui.QKeySequence.StandardKey, QString, int])",
    "PySide6.QtGui.QKeySequence.toString(self,format:PySide6.QtGui.QKeySequence.SequenceFormat=QKeySequence.SequenceFormat.PortableText)->QString",
    "PySide6.QtGui.QKeySequence.__copy__(self)->typing.Self",
    "PySide6.QtGui.QKeySequence.__lshift__(self,in:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QKeySequence.__rshift__(self,out:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QKeySequence.__ne__(self,other:typing.Union[PySide6.QtGui.QKeySequence, PySide6.QtCore.QKeyCombination, PySide6.QtGui.QKeySequence.StandardKey, QString, int])->bool",
    "PySide6.QtGui.QKeySequence.__lt__(self,ks:typing.Union[PySide6.QtGui.QKeySequence, PySide6.QtCore.QKeyCombination, PySide6.QtGui.QKeySequence.StandardKey, QString, int])->bool",
    "PySide6.QtGui.QKeySequence.__le__(self,other:typing.Union[PySide6.QtGui.QKeySequence, PySide6.QtCore.QKeyCombination, PySide6.QtGui.QKeySequence.StandardKey, QString, int])->bool",
    "PySide6.QtGui.QKeySequence.__eq__(self,other:typing.Union[PySide6.QtGui.QKeySequence, PySide6.QtCore.QKeyCombination, PySide6.QtGui.QKeySequence.StandardKey, QString, int])->bool",
    "PySide6.QtGui.QKeySequence.__gt__(self,other:typing.Union[PySide6.QtGui.QKeySequence, PySide6.QtCore.QKeyCombination, PySide6.QtGui.QKeySequence.StandardKey, QString, int])->bool",
    "PySide6.QtGui.QKeySequence.__ge__(self,other:typing.Union[PySide6.QtGui.QKeySequence, PySide6.QtCore.QKeyCombination, PySide6.QtGui.QKeySequence.StandardKey, QString, int])->bool",
    "PySide6.QtGui.QKeySequence.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QKeySequence_SignatureByteSize = 503;
static constexpr uint8_t QKeySequence_SignatureBytes[503] = {
    0x78, 0xda, 0xd5, 0x56, 0xc1, 0x6e, 0x9b, 0x40, 0x10, 0xbd, 0xf3, 0x15, 0x3e, 0x82, 0x84, 0x91,
    0x93, 0xb8, 0x3d, 0x58, 0xb2, 0x0f, 0x4d, 0x9b, 0x1e, 0xda, 0x54, 0xb1, 0x48, 0x4f, 0x91, 0x85,
    0xd6, 0x30, 0x0e, 0x2b, 0xc3, 0x2e, 0xde, 0x1d, 0xda, 0xf2, 0xf7, 0x1d, 0x0c, 0xd8, 0x0a, 0x15,
    0x8b, 0xdb, 0xca, 0x89, 0x39, 0x79, 0xd7, 0xfb, 0x66, 0xe6, 0xcd, 0xe3, 0xed, 0xc0, 0xbb, 0xd9,
    0x43, 0xe1, 0xf3, 0x08, 0xde, 0x7b, 0x4b, 0xfc, 0x9c, 0x73, 0x6f, 0xf9, 0x05, 0x0a, 0x1f, 0x76,
    0x39, 0x88, 0x10, 0x6c, 0x0d, 0xc9, 0xc6, 0xb1, 0xa6, 0x7d, 0x10, 0x77, 0x7b, 0x35, 0xc3, 0x22,
    0xe3, 0xe2, 0xd9, 0xfb, 0x2e, 0xb8, 0x14, 0x4f, 0x47, 0xfc, 0xad, 0x54, 0xb0, 0x0f, 0xb8, 0x95,
    0xe9, 0x9a, 0x0b, 0x86, 0x74, 0xec, 0x8e, 0xda, 0xe7, 0xe8, 0x11, 0x62, 0x2d, 0x99, 0x8a, 0xee,
    0x65, 0xc4, 0x37, 0x1c, 0x54, 0x07, 0x66, 0xe5, 0x6e, 0xaf, 0x5f, 0xab, 0xd4, 0xbc, 0x95, 0xcb,
    0xdb, 0x28, 0x99, 0x56, 0x7b, 0x88, 0xec, 0x89, 0xe3, 0x6e, 0x6f, 0x2e, 0x87, 0xca, 0xf4, 0x52,
    0xa8, 0x38, 0xd6, 0x4d, 0xbf, 0x5d, 0xa0, 0x30, 0x60, 0x3c, 0x1f, 0x99, 0x88, 0x88, 0x0a, 0xfd,
    0xe7, 0x58, 0xd7, 0xfd, 0xd9, 0xb4, 0x01, 0xe2, 0x58, 0x57, 0x27, 0xd1, 0x59, 0xfa, 0xa8, 0x48,
    0x3e, 0x77, 0x23, 0x55, 0xca, 0xd0, 0xc8, 0xae, 0x5e, 0xdc, 0xed, 0x91, 0x73, 0xc3, 0x99, 0xf7,
    0x8d, 0x14, 0xfa, 0x01, 0x8f, 0xf0, 0x0b, 0x1d, 0x6b, 0x72, 0xca, 0x25, 0xe2, 0x02, 0x4b, 0x83,
    0xd3, 0xcf, 0x7c, 0x52, 0xda, 0xab, 0x5e, 0x4c, 0xab, 0x85, 0x63, 0x19, 0x68, 0x05, 0x81, 0x82,
    0x28, 0x0f, 0x21, 0x08, 0xaa, 0x5b, 0x3b, 0x5e, 0x68, 0x54, 0x7d, 0x01, 0x99, 0x3a, 0x19, 0x1e,
    0xca, 0x5c, 0x60, 0x83, 0x25, 0x3a, 0x26, 0x6c, 0x69, 0x89, 0x4a, 0x4f, 0x9b, 0xb2, 0x9e, 0x47,
    0xdb, 0x07, 0xa9, 0x90, 0xad, 0x93, 0x4a, 0xdd, 0xf1, 0xa2, 0x3b, 0xa9, 0x89, 0x28, 0xd7, 0x9f,
    0xd2, 0x0c, 0x8b, 0xa6, 0xad, 0xb5, 0x94, 0x89, 0x09, 0x4e, 0x46, 0xf9, 0xc0, 0x45, 0x44, 0xbd,
    0x68, 0xfb, 0x2f, 0x3c, 0x3c, 0x5e, 0x2c, 0xbf, 0x72, 0x8d, 0x4f, 0xdd, 0xf0, 0x95, 0xa9, 0x6a,
    0x42, 0xb1, 0x77, 0xaf, 0xaf, 0xe8, 0x7f, 0x73, 0x7e, 0x94, 0x35, 0xe3, 0x72, 0x33, 0xeb, 0x4d,
    0x77, 0xde, 0x66, 0x2a, 0x2a, 0x26, 0xca, 0x14, 0x15, 0xc6, 0xa0, 0xab, 0xbb, 0xa8, 0x61, 0xd7,
    0x35, 0x50, 0xdb, 0x81, 0x7f, 0x0e, 0xca, 0xee, 0x61, 0x6b, 0xb2, 0x89, 0x3b, 0x6a, 0x9e, 0xea,
    0x88, 0xae, 0xd7, 0xca, 0xe8, 0xe9, 0x43, 0xb7, 0xf7, 0x25, 0x69, 0x63, 0x57, 0x02, 0x52, 0x29,
    0x78, 0x68, 0x23, 0x09, 0xd1, 0xf8, 0xe6, 0x9f, 0xef, 0x8b, 0xfe, 0xc9, 0xb2, 0x4a, 0x20, 0x89,
    0x31, 0xa8, 0xb7, 0x96, 0xc8, 0x44, 0x15, 0x1b, 0xf7, 0xed, 0xe9, 0xbe, 0xb1, 0xb7, 0x82, 0x20,
    0x94, 0x59, 0x71, 0x9c, 0xb5, 0xb5, 0x6e, 0x3e, 0xed, 0xcc, 0x61, 0x89, 0x8e, 0xf9, 0x06, 0xeb,
    0x40, 0x97, 0x8b, 0x59, 0x5b, 0xc8, 0x8f, 0x0c, 0x19, 0xd5, 0x07, 0x96, 0xbe, 0x78, 0xa8, 0xed,
    0xc3, 0x9e, 0x17, 0xc1, 0x8b, 0x2a, 0x32, 0xc7, 0xf3, 0x94, 0x11, 0x70, 0x28, 0x71, 0x09, 0xee,
    0xe9, 0x9f, 0xf7, 0xa4, 0xff, 0x41, 0x15, 0xfa, 0xca, 0x18, 0x02, 0xdf, 0xe1, 0x49, 0x0c, 0xbb,
    0xc1, 0x51, 0x7e, 0xc6, 0xe1, 0x51, 0x1e, 0x9e, 0x31, 0x62, 0xa6, 0xe3, 0xe3, 0xc8, 0x2c, 0x3f,
    0x39, 0x7f, 0x03, 0x3e, 0xf6, 0x44, 0xbe
};
#endif

PyTypeObject *init_QKeySequence(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX].type;

    Shiboken::AutoDecRef Sbk_QKeySequence_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QKeySequence_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QKeySequence",
        "QKeySequence",
        &Sbk_QKeySequence_spec,
        &Shiboken::callCppDestructor< ::QKeySequence >,
        Sbk_QKeySequence_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QKeySequence_TypeF(); // references _Sbk_QKeySequence_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QKeySequence_SignatureStrings);
#else
    InitSignatureBytes(pyType, QKeySequence_SignatureBytes, QKeySequence_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QKeySequence_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QKeySequence_PythonToCpp_QKeySequence_PTR,
        is_QKeySequence_PythonToCpp_QKeySequence_PTR_Convertible,
        QKeySequence_PTR_CppToPython_QKeySequence,
        QKeySequence_COPY_CppToPython_QKeySequence);

    Shiboken::Conversions::registerConverterName(converter, "QKeySequence");
    Shiboken::Conversions::registerConverterName(converter, "QKeySequence*");
    Shiboken::Conversions::registerConverterName(converter, "QKeySequence&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QKeySequence).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QKeySequence_PythonToCpp_QKeySequence_COPY,
        is_QKeySequence_PythonToCpp_QKeySequence_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_QKeyCombination_PythonToCpp_QKeySequence,
        is_PySide6_QtCore_QKeyCombination_PythonToCpp_QKeySequence_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QKeySequence_StandardKey_PythonToCpp_QKeySequence,
        is_QKeySequence_StandardKey_PythonToCpp_QKeySequence_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_constQStringREF_PythonToCpp_QKeySequence,
        is_PySide6_QtCore_constQStringREF_PythonToCpp_QKeySequence_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        int_PythonToCpp_QKeySequence,
        is_int_PythonToCpp_QKeySequence_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QKeySequence_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StandardKey'.
    const char *StandardKey_Initializer[] = {
        "UnknownKey",
        "HelpContents",
        "WhatsThis",
        "Open",
        "Close",
        "Save",
        "New",
        "Delete",
        "Cut",
        "Copy",
        "Paste",
        "Undo",
        "Redo",
        "Back",
        "Forward",
        "Refresh",
        "ZoomIn",
        "ZoomOut",
        "Print",
        "AddTab",
        "NextChild",
        "PreviousChild",
        "Find",
        "FindNext",
        "FindPrevious",
        "Replace",
        "SelectAll",
        "Bold",
        "Italic",
        "Underline",
        "MoveToNextChar",
        "MoveToPreviousChar",
        "MoveToNextWord",
        "MoveToPreviousWord",
        "MoveToNextLine",
        "MoveToPreviousLine",
        "MoveToNextPage",
        "MoveToPreviousPage",
        "MoveToStartOfLine",
        "MoveToEndOfLine",
        "MoveToStartOfBlock",
        "MoveToEndOfBlock",
        "MoveToStartOfDocument",
        "MoveToEndOfDocument",
        "SelectNextChar",
        "SelectPreviousChar",
        "SelectNextWord",
        "SelectPreviousWord",
        "SelectNextLine",
        "SelectPreviousLine",
        "SelectNextPage",
        "SelectPreviousPage",
        "SelectStartOfLine",
        "SelectEndOfLine",
        "SelectStartOfBlock",
        "SelectEndOfBlock",
        "SelectStartOfDocument",
        "SelectEndOfDocument",
        "DeleteStartOfWord",
        "DeleteEndOfWord",
        "DeleteEndOfLine",
        "InsertParagraphSeparator",
        "InsertLineSeparator",
        "SaveAs",
        "Preferences",
        "Quit",
        "FullScreen",
        "Deselect",
        "DeleteCompleteLine",
        "Backspace",
        "Cancel",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StandardKey_InitializerValues[] = {
        uint8_t(QKeySequence::StandardKey::UnknownKey),               //  0x00  0
        uint8_t(QKeySequence::StandardKey::HelpContents),             //  0x01  1
        uint8_t(QKeySequence::StandardKey::WhatsThis),                //  0x02  2
        uint8_t(QKeySequence::StandardKey::Open),                     //  0x03  3
        uint8_t(QKeySequence::StandardKey::Close),                    //  0x04  4
        uint8_t(QKeySequence::StandardKey::Save),                     //  0x05  5
        uint8_t(QKeySequence::StandardKey::New),                      //  0x06  6
        uint8_t(QKeySequence::StandardKey::Delete),                   //  0x07  7
        uint8_t(QKeySequence::StandardKey::Cut),                      //  0x08  8
        uint8_t(QKeySequence::StandardKey::Copy),                     //  0x09  9
        uint8_t(QKeySequence::StandardKey::Paste),                    //  0x0a  10
        uint8_t(QKeySequence::StandardKey::Undo),                     //  0x0b  11
        uint8_t(QKeySequence::StandardKey::Redo),                     //  0x0c  12
        uint8_t(QKeySequence::StandardKey::Back),                     //  0x0d  13
        uint8_t(QKeySequence::StandardKey::Forward),                  //  0x0e  14
        uint8_t(QKeySequence::StandardKey::Refresh),                  //  0x0f  15
        uint8_t(QKeySequence::StandardKey::ZoomIn),                   //  0x10  16
        uint8_t(QKeySequence::StandardKey::ZoomOut),                  //  0x11  17
        uint8_t(QKeySequence::StandardKey::Print),                    //  0x12  18
        uint8_t(QKeySequence::StandardKey::AddTab),                   //  0x13  19
        uint8_t(QKeySequence::StandardKey::NextChild),                //  0x14  20
        uint8_t(QKeySequence::StandardKey::PreviousChild),            //  0x15  21
        uint8_t(QKeySequence::StandardKey::Find),                     //  0x16  22
        uint8_t(QKeySequence::StandardKey::FindNext),                 //  0x17  23
        uint8_t(QKeySequence::StandardKey::FindPrevious),             //  0x18  24
        uint8_t(QKeySequence::StandardKey::Replace),                  //  0x19  25
        uint8_t(QKeySequence::StandardKey::SelectAll),                //  0x1a  26
        uint8_t(QKeySequence::StandardKey::Bold),                     //  0x1b  27
        uint8_t(QKeySequence::StandardKey::Italic),                   //  0x1c  28
        uint8_t(QKeySequence::StandardKey::Underline),                //  0x1d  29
        uint8_t(QKeySequence::StandardKey::MoveToNextChar),           //  0x1e  30
        uint8_t(QKeySequence::StandardKey::MoveToPreviousChar),       //  0x1f  31
        uint8_t(QKeySequence::StandardKey::MoveToNextWord),           //  0x20  32
        uint8_t(QKeySequence::StandardKey::MoveToPreviousWord),       //  0x21  33
        uint8_t(QKeySequence::StandardKey::MoveToNextLine),           //  0x22  34
        uint8_t(QKeySequence::StandardKey::MoveToPreviousLine),       //  0x23  35
        uint8_t(QKeySequence::StandardKey::MoveToNextPage),           //  0x24  36
        uint8_t(QKeySequence::StandardKey::MoveToPreviousPage),       //  0x25  37
        uint8_t(QKeySequence::StandardKey::MoveToStartOfLine),        //  0x26  38
        uint8_t(QKeySequence::StandardKey::MoveToEndOfLine),          //  0x27  39
        uint8_t(QKeySequence::StandardKey::MoveToStartOfBlock),       //  0x28  40
        uint8_t(QKeySequence::StandardKey::MoveToEndOfBlock),         //  0x29  41
        uint8_t(QKeySequence::StandardKey::MoveToStartOfDocument),    //  0x2a  42
        uint8_t(QKeySequence::StandardKey::MoveToEndOfDocument),      //  0x2b  43
        uint8_t(QKeySequence::StandardKey::SelectNextChar),           //  0x2c  44
        uint8_t(QKeySequence::StandardKey::SelectPreviousChar),       //  0x2d  45
        uint8_t(QKeySequence::StandardKey::SelectNextWord),           //  0x2e  46
        uint8_t(QKeySequence::StandardKey::SelectPreviousWord),       //  0x2f  47
        uint8_t(QKeySequence::StandardKey::SelectNextLine),           //  0x30  48
        uint8_t(QKeySequence::StandardKey::SelectPreviousLine),       //  0x31  49
        uint8_t(QKeySequence::StandardKey::SelectNextPage),           //  0x32  50
        uint8_t(QKeySequence::StandardKey::SelectPreviousPage),       //  0x33  51
        uint8_t(QKeySequence::StandardKey::SelectStartOfLine),        //  0x34  52
        uint8_t(QKeySequence::StandardKey::SelectEndOfLine),          //  0x35  53
        uint8_t(QKeySequence::StandardKey::SelectStartOfBlock),       //  0x36  54
        uint8_t(QKeySequence::StandardKey::SelectEndOfBlock),         //  0x37  55
        uint8_t(QKeySequence::StandardKey::SelectStartOfDocument),    //  0x38  56
        uint8_t(QKeySequence::StandardKey::SelectEndOfDocument),      //  0x39  57
        uint8_t(QKeySequence::StandardKey::DeleteStartOfWord),        //  0x3a  58
        uint8_t(QKeySequence::StandardKey::DeleteEndOfWord),          //  0x3b  59
        uint8_t(QKeySequence::StandardKey::DeleteEndOfLine),          //  0x3c  60
        uint8_t(QKeySequence::StandardKey::InsertParagraphSeparator), //  0x3d  61
        uint8_t(QKeySequence::StandardKey::InsertLineSeparator),      //  0x3e  62
        uint8_t(QKeySequence::StandardKey::SaveAs),                   //  0x3f  63
        uint8_t(QKeySequence::StandardKey::Preferences),              //  0x40  64
        uint8_t(QKeySequence::StandardKey::Quit),                     //  0x41  65
        uint8_t(QKeySequence::StandardKey::FullScreen),               //  0x42  66
        uint8_t(QKeySequence::StandardKey::Deselect),                 //  0x43  67
        uint8_t(QKeySequence::StandardKey::DeleteCompleteLine),       //  0x44  68
        uint8_t(QKeySequence::StandardKey::Backspace),                //  0x45  69
        uint8_t(QKeySequence::StandardKey::Cancel)                    //  0x46  70
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QKeySequence_TypeF(),
        "2:PySide6.QtGui.QKeySequence.StandardKey",
        StandardKey_Initializer, StandardKey_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_StandardKey_IDX].type = EType;
    // Register converter for enum 'QKeySequence::StandardKey'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QKeySequence_StandardKey_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QKeySequence_StandardKey,
            is_Enum_PythonToCpp_QKeySequence_StandardKey_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QKeySequence::StandardKey");
        Shiboken::Conversions::registerConverterAlias(converter, "StandardKey");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StandardKey' enum.

    // Initialization of enum 'SequenceFormat'.
    const char *SequenceFormat_Initializer[] = {
        "NativeText",
        "PortableText",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SequenceFormat_InitializerValues[] = {
        uint8_t(QKeySequence::SequenceFormat::NativeText),  //  0x00  0
        uint8_t(QKeySequence::SequenceFormat::PortableText) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QKeySequence_TypeF(),
        "2:PySide6.QtGui.QKeySequence.SequenceFormat",
        SequenceFormat_Initializer, SequenceFormat_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceFormat_IDX].type = EType;
    // Register converter for enum 'QKeySequence::SequenceFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QKeySequence_SequenceFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QKeySequence_SequenceFormat,
            is_Enum_PythonToCpp_QKeySequence_SequenceFormat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QKeySequence::SequenceFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "SequenceFormat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SequenceFormat' enum.

    // Initialization of enum 'SequenceMatch'.
    const char *SequenceMatch_Initializer[] = {
        "NoMatch",
        "PartialMatch",
        "ExactMatch",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SequenceMatch_InitializerValues[] = {
        uint8_t(QKeySequence::SequenceMatch::NoMatch),      //  0x00  0
        uint8_t(QKeySequence::SequenceMatch::PartialMatch), //  0x01  1
        uint8_t(QKeySequence::SequenceMatch::ExactMatch)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QKeySequence_TypeF(),
        "2:PySide6.QtGui.QKeySequence.SequenceMatch",
        SequenceMatch_Initializer, SequenceMatch_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_SequenceMatch_IDX].type = EType;
    // Register converter for enum 'QKeySequence::SequenceMatch'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QKeySequence_SequenceMatch_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QKeySequence_SequenceMatch,
            is_Enum_PythonToCpp_QKeySequence_SequenceMatch_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QKeySequence::SequenceMatch");
        Shiboken::Conversions::registerConverterAlias(converter, "SequenceMatch");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SequenceMatch' enum.

    qRegisterMetaType< ::QKeySequence >("QKeySequence");
    qRegisterMetaType< ::QKeySequence::StandardKey >("QKeySequence::StandardKey");
    qRegisterMetaType< ::QKeySequence::SequenceFormat >("QKeySequence::SequenceFormat");
    qRegisterMetaType< ::QKeySequence::SequenceMatch >("QKeySequence::SequenceMatch");

    return pyType;
}
