// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qlineargradient_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLinearGradient_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLinearGradient >()))
        return -1;

    ::QLinearGradient *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 3)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]);

    if (PyArg_UnpackTuple(args, "QLinearGradient", 0, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLinearGradient::QLinearGradient()
    // 1: QLinearGradient::QLinearGradient(QLinearGradient)
    // 2: QLinearGradient::QLinearGradient(QPointF,QPointF)
    // 3: QLinearGradient::QLinearGradient(qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // QLinearGradient()
    } else if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        overloadId = 3; // QLinearGradient(qreal,qreal,qreal,qreal)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))) {
        overloadId = 2; // QLinearGradient(QPointF,QPointF)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QLinearGradient(QLinearGradient)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QLinearGradient()
        {

            // QLinearGradient()
            cptr = new ::QLinearGradient();
            break;
        }
        case 1: // QLinearGradient(const QLinearGradient &QLinearGradient)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QLinearGradient cppArg0_local;
            ::QLinearGradient *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLinearGradient(QLinearGradient)
                cptr = new ::QLinearGradient(*cppArg0);
            }
            break;
        }
        case 2: // QLinearGradient(const QPointF &start, const QPointF &finalStop)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLinearGradient(QPointF,QPointF)
                cptr = new ::QLinearGradient(*cppArg0, *cppArg1);
            }
            break;
        }
        case 3: // QLinearGradient(qreal xStart, qreal yStart, qreal xFinalStop, qreal yFinalStop)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QLinearGradient(qreal,qreal,qreal,qreal)
                cptr = new ::QLinearGradient(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QLinearGradient >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QLinearGradientFunc_finalStop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLinearGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // finalStop()const
        QPointF cppResult = const_cast<const ::QLinearGradient *>(cppSelf)->finalStop();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLinearGradientFunc_setFinalStop(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLinearGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setFinalStop", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLinearGradient::setFinalStop(QPointF)
    // 1: QLinearGradient::setFinalStop(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 1; // setFinalStop(qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setFinalStop(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFinalStop", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setFinalStop(const QPointF &stop)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setFinalStop(QPointF)
                cppSelf->setFinalStop(*cppArg0);
            }
            break;
        }
        case 1: // setFinalStop(qreal x, qreal y)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setFinalStop(qreal,qreal)
                cppSelf->setFinalStop(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLinearGradientFunc_setStart(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLinearGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setStart", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLinearGradient::setStart(QPointF)
    // 1: QLinearGradient::setStart(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 1; // setStart(qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setStart(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setStart", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setStart(const QPointF &start)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setStart(QPointF)
                cppSelf->setStart(*cppArg0);
            }
            break;
        }
        case 1: // setStart(qreal x, qreal y)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setStart(qreal,qreal)
                cppSelf->setStart(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLinearGradientFunc_start(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLinearGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // start()const
        QPointF cppResult = const_cast<const ::QLinearGradient *>(cppSelf)->start();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLinearGradient__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLinearGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QLinearGradient_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLinearGradient_methods[] = {
    {"finalStop", reinterpret_cast<PyCFunction>(Sbk_QLinearGradientFunc_finalStop), METH_NOARGS, nullptr},
    {"setFinalStop", reinterpret_cast<PyCFunction>(Sbk_QLinearGradientFunc_setFinalStop), METH_VARARGS, nullptr},
    {"setStart", reinterpret_cast<PyCFunction>(Sbk_QLinearGradientFunc_setStart), METH_VARARGS, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QLinearGradientFunc_start), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QLinearGradient__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QLinearGradient_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLinearGradient_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLinearGradient_Type = nullptr;
static PyTypeObject *Sbk_QLinearGradient_TypeF(void)
{
    return _Sbk_QLinearGradient_Type;
}

static PyType_Slot Sbk_QLinearGradient_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLinearGradient_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLinearGradient_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLinearGradient_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLinearGradient_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLinearGradient_spec = {
    "2:PySide6.QtGui.QLinearGradient",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLinearGradient_slots
};

} //extern "C"

static void *Sbk_QLinearGradient_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QGradient *>(cptr)->type() == QGradient::LinearGradient)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLinearGradient_PythonToCpp_QLinearGradient_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLinearGradient_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLinearGradient_PythonToCpp_QLinearGradient_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLinearGradient_TypeF()))
        return QLinearGradient_PythonToCpp_QLinearGradient_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLinearGradient_PTR_CppToPython_QLinearGradient(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QLinearGradient_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QLinearGradient_COPY_CppToPython_QLinearGradient(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QLinearGradient *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QLinearGradient_TypeF(), new ::QLinearGradient(*source), true, true);
}

// Python to C++ copy conversion.
static void QLinearGradient_PythonToCpp_QLinearGradient_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QLinearGradient *>(cppOut) = *reinterpret_cast< ::QLinearGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QLinearGradient_PythonToCpp_QLinearGradient_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QLinearGradient_TypeF()))
        return QLinearGradient_PythonToCpp_QLinearGradient_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QLinearGradient_SignatureStrings[] = {
    "3:PySide6.QtGui.QLinearGradient(self)",
    "2:PySide6.QtGui.QLinearGradient(self,QLinearGradient:PySide6.QtGui.QLinearGradient)",
    "1:PySide6.QtGui.QLinearGradient(self,start:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],finalStop:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "0:PySide6.QtGui.QLinearGradient(self,xStart:qreal,yStart:qreal,xFinalStop:qreal,yFinalStop:qreal)",
    "PySide6.QtGui.QLinearGradient.finalStop(self)->PySide6.QtCore.QPointF",
    "1:PySide6.QtGui.QLinearGradient.setFinalStop(self,stop:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "0:PySide6.QtGui.QLinearGradient.setFinalStop(self,x:qreal,y:qreal)",
    "1:PySide6.QtGui.QLinearGradient.setStart(self,start:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "0:PySide6.QtGui.QLinearGradient.setStart(self,x:qreal,y:qreal)",
    "PySide6.QtGui.QLinearGradient.start(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QLinearGradient.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QLinearGradient_SignatureByteSize = 233;
static constexpr uint8_t QLinearGradient_SignatureBytes[233] = {
    0x78, 0xda, 0xcd, 0x52, 0x3d, 0x0f, 0x82, 0x30, 0x14, 0xdc, 0xfb, 0x2b, 0x1c, 0x25, 0xc1, 0xc6,
    0x8f, 0xc4, 0xc1, 0xc1, 0xc5, 0x08, 0x8b, 0x03, 0x84, 0x38, 0x19, 0xd3, 0x34, 0xfa, 0xd0, 0x26,
    0xd8, 0x62, 0x79, 0x26, 0xf0, 0xef, 0x25, 0x28, 0x88, 0x8a, 0xd0, 0x45, 0xe3, 0xd8, 0x6b, 0xef,
    0xde, 0xbb, 0xbb, 0x4e, 0x66, 0x5e, 0x16, 0x88, 0x3d, 0x4c, 0xa9, 0x8f, 0xee, 0x45, 0x50, 0x7f,
    0x25, 0x24, 0x70, 0xed, 0x6a, 0xbe, 0x17, 0x20, 0xb1, 0x9f, 0x40, 0x14, 0x5a, 0x64, 0x6c, 0xf0,
    0xca, 0x7e, 0x01, 0xdb, 0x29, 0x16, 0x19, 0x99, 0x68, 0x26, 0xc8, 0x35, 0xce, 0x30, 0x8b, 0x85,
    0x3c, 0xd0, 0xb5, 0x14, 0x4a, 0x6e, 0x1e, 0xac, 0x85, 0xd2, 0x40, 0x7d, 0x4f, 0x09, 0x89, 0x8e,
    0xdd, 0x6b, 0xc4, 0xeb, 0x70, 0x31, 0xc4, 0xe3, 0x39, 0x0a, 0xda, 0xe3, 0x78, 0xa4, 0xcb, 0x08,
    0x4e, 0xf9, 0xa4, 0xad, 0x1d, 0x0a, 0xc9, 0xa3, 0x00, 0x55, 0xfc, 0xed, 0x49, 0x16, 0x19, 0x9a,
    0xb8, 0x4e, 0x83, 0xc2, 0xf6, 0x59, 0x03, 0x8f, 0xec, 0xac, 0x7e, 0x48, 0x9d, 0x6a, 0xd5, 0xfb,
    0xed, 0x0b, 0x60, 0x91, 0x56, 0x7d, 0x5a, 0x59, 0xbd, 0x35, 0x3b, 0x98, 0x37, 0x9b, 0xec, 0x6a,
    0x87, 0x26, 0x80, 0xce, 0x93, 0x54, 0x5e, 0xd5, 0x1f, 0xe4, 0xd7, 0xb0, 0x57, 0x5a, 0x26, 0x55,
    0x06, 0x64, 0x60, 0xad, 0x88, 0xfc, 0x87, 0x3f, 0xd0, 0xc8, 0x57, 0x6d, 0xa9, 0x37, 0x4f, 0x1d,
    0xe4, 0x8a, 0xf9, 0xb9, 0xf0, 0x76, 0x05, 0xc6, 0x76, 0x2a, 0xce, 0x18, 0x2b, 0x45, 0xee, 0x79,
    0x04, 0xf9, 0x89, 0x5c, 0x01, 0xfc, 0xbf, 0x85, 0x7a
};
#endif

PyTypeObject *init_QLinearGradient(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX].type;

    Shiboken::AutoDecRef Sbk_QLinearGradient_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]))));

    _Sbk_QLinearGradient_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLinearGradient",
        "QLinearGradient",
        &Sbk_QLinearGradient_spec,
        &Shiboken::callCppDestructor< ::QLinearGradient >,
        Sbk_QLinearGradient_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QLinearGradient_TypeF(); // references _Sbk_QLinearGradient_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QLinearGradient_SignatureStrings);
#else
    InitSignatureBytes(pyType, QLinearGradient_SignatureBytes, QLinearGradient_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLinearGradient_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QLinearGradient_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLinearGradient_PythonToCpp_QLinearGradient_PTR,
        is_QLinearGradient_PythonToCpp_QLinearGradient_PTR_Convertible,
        QLinearGradient_PTR_CppToPython_QLinearGradient,
        QLinearGradient_COPY_CppToPython_QLinearGradient);

    Shiboken::Conversions::registerConverterName(converter, "QLinearGradient");
    Shiboken::Conversions::registerConverterName(converter, "QLinearGradient*");
    Shiboken::Conversions::registerConverterName(converter, "QLinearGradient&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLinearGradient).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLinearGradient_PythonToCpp_QLinearGradient_COPY,
        is_QLinearGradient_PythonToCpp_QLinearGradient_COPY_Convertible);

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QLinearGradient_TypeF(), &Sbk_QLinearGradient_typeDiscovery);

    qRegisterMetaType< ::QLinearGradient >("QLinearGradient");

    return pyType;
}
