// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qmatrix2x3_wrapper.h"

// Argument includes
#include <QtGui/qgenericmatrix.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMatrix2x3_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMatrix2x3 >()))
        return -1;

    ::QMatrix2x3 *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QMatrix2x3", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMatrix2x3::QMatrix2x3()
    // 1: QMatrix2x3::QMatrix2x3(PySequence*)
    // 2: QMatrix2x3::QMatrix2x3(QMatrix2x3)
    if (numArgs == 0) {
        overloadId = 0; // QMatrix2x3()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QMatrix2x3(QMatrix2x3)
    } else if (numArgs == 1
        && Shiboken::String::checkIterableArgument(pyArgs[0])) {
        overloadId = 1; // QMatrix2x3(PySequence*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QMatrix2x3()
        {

            // QMatrix2x3()
            cptr = new ::QMatrix2x3();
            break;
        }
        case 1: // QMatrix2x3(PySequence *elements)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMatrix2x3(PySequence*)
                // Begin code injection
                // TEMPLATE - matrix_constructor - START
                // PYSIDE-795: All PySequences can be made iterable with PySequence_Fast.
                Shiboken::AutoDecRef seq(PySequence_Fast(pyArgs[1-1], "Can't turn into sequence"));
                if (PySequence_Size(seq) == 6) {
                    Shiboken::AutoDecRef fast(PySequence_Fast(seq,
                        "Failed to parse sequence on QMatrix2x3 constructor."));
                    float values[6];
                    for(int i=0; i < 6; i++) {
                        Shiboken::AutoDecRef pv(PySequence_GetItem(fast.object(), i));
                        Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pv, &(values[i]));
                    }
                    cptr = new QMatrix2x3(values);
                }
                // TEMPLATE - matrix_constructor - END
                // End of code injection

            }
            break;
        }
        case 2: // QMatrix2x3(const QMatrix2x3 &QMatrix2x3)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QMatrix2x3 cppArg0_local;
            ::QMatrix2x3 *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QMatrix2x3(QMatrix2x3)
                cptr = new ::QMatrix2x3(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMatrix2x3 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMatrix2x3Func___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix2x3 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __reduce__()
        // Begin code injection
        // TEMPLATE - reduce_code_matrix - START
        QList< float > cppArgs;
        float data[6];
        cppSelf->copyDataTo(data);
        int matrixSize = 6;
        for(int size=0; size < matrixSize; size++)
            cppArgs.append(data[size]);

        PyObject *type = PyObject_Type(self);
        PyObject *args = Py_BuildValue("(N)",
            Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_float_IDX], &cppArgs));
        pyResult = Py_BuildValue("(NN)", type, args);
        // TEMPLATE - reduce_code_matrix - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMatrix2x3Func___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix2x3 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - repr_code_matrix - START
        QByteArray format(Py_TYPE(self)->tp_name);
        format += QByteArrayLiteral("((");

        QList< float > cppArgs;
        float data[6];
        cppSelf->copyDataTo(data);
        int matrixSize = 6;
        for(int size=0; size < matrixSize; size++) {
            if (size > 0)
                format += ", ";
            format += QByteArray::number(data[size]);
        }
        format += "))";

        pyResult = Shiboken::String::fromStringAndSize(format, format.size());
        // TEMPLATE - repr_code_matrix - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMatrix2x3Func_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix2x3 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()
        // Begin code injection
        // TEMPLATE - matrix_data_function - START
        const float* data = cppSelf->constData();
        PyObject *pyData = PyTuple_New(6);
        if (data) {
            for(int i=0; i < 6; i++)
                PyTuple_SetItem(pyData, i, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &data[i]));
        }
        return pyData;
        // TEMPLATE - matrix_data_function - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMatrix2x3Func_fill(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix2x3 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix2x3::fill(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // fill(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fill", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fill(float)
            cppSelf->fill(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMatrix2x3Func_isIdentity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix2x3 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isIdentity()const
        bool cppResult = const_cast<const ::QMatrix2x3 *>(cppSelf)->isIdentity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMatrix2x3Func___call__(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix2x3 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "__call__", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMatrix2x3::operator()(int,int)->float&
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // operator()(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "operator()", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator()(int,int)
            float & cppResult = cppSelf->operator()(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMatrix2x3Func_setToIdentity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix2x3 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // setToIdentity()
        cppSelf->setToIdentity();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMatrix2x3Func_transposed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix2x3 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // transposed()const
        QGenericMatrix<3,2,float> cppResult = const_cast<const ::QMatrix2x3 *>(cppSelf)->transposed();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGenericMatrix_3_2_float_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMatrix2x3__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMatrix2x3 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QMatrix2x3_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMatrix2x3_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QMatrix2x3Func___reduce__), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QMatrix2x3Func_data), METH_NOARGS, nullptr},
    {"fill", reinterpret_cast<PyCFunction>(Sbk_QMatrix2x3Func_fill), METH_O, nullptr},
    {"isIdentity", reinterpret_cast<PyCFunction>(Sbk_QMatrix2x3Func_isIdentity), METH_NOARGS, nullptr},
    {"setToIdentity", reinterpret_cast<PyCFunction>(Sbk_QMatrix2x3Func_setToIdentity), METH_NOARGS, nullptr},
    {"transposed", reinterpret_cast<PyCFunction>(Sbk_QMatrix2x3Func_transposed), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QMatrix2x3__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QMatrix2x3Func___imul__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix2x3 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix2x3::operator*=(float)->QGenericMatrix<2,3,float>&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // operator*=(float)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator*=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator*=(float)
            (*cppSelf) *= cppArg0;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QMatrix2x3Func___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix2x3 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix2x3::operator+=(QGenericMatrix<2,3,float>)->QGenericMatrix<2,3,float>&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGenericMatrix_2_3_float_IDX]), (pyArg)))) {
        overloadId = 0; // operator+=(QGenericMatrix<2,3,float>)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGenericMatrix<2,3,float> cppArg0_local;
        ::QGenericMatrix<2,3,float> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+=(QGenericMatrix<2,3,float>)
            (*cppSelf) += (*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QMatrix2x3Func___isub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix2x3 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix2x3::operator-=(QGenericMatrix<2,3,float>)->QGenericMatrix<2,3,float>&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGenericMatrix_2_3_float_IDX]), (pyArg)))) {
        overloadId = 0; // operator-=(QGenericMatrix<2,3,float>)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGenericMatrix<2,3,float> cppArg0_local;
        ::QGenericMatrix<2,3,float> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator-=(QGenericMatrix<2,3,float>)
            (*cppSelf) -= (*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

// Rich comparison
static PyObject * Sbk_QMatrix2x3_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMatrix2x3 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGenericMatrix_2_3_float_IDX]), (pyArg)))) {
                // operator!=(const QGenericMatrix<2,3,float> &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGenericMatrix<2,3,float> cppArg0_local;
                ::QGenericMatrix<2,3,float> *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGenericMatrix_2_3_float_IDX]), (pyArg)))) {
                // operator==(const QGenericMatrix<2,3,float> &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGenericMatrix<2,3,float> cppArg0_local;
                ::QGenericMatrix<2,3,float> *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QMatrix2x3_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMatrix2x3_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMatrix2x3_Type = nullptr;
static PyTypeObject *Sbk_QMatrix2x3_TypeF(void)
{
    return _Sbk_QMatrix2x3_Type;
}

static PyType_Slot Sbk_QMatrix2x3_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QMatrix2x3Func___repr__)},
    {Py_tp_call,        reinterpret_cast<void *>(&Sbk_QMatrix2x3Func___call__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMatrix2x3_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMatrix2x3_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QMatrix2x3_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMatrix2x3_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMatrix2x3_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QMatrix2x3Func___iadd__)},
    {Py_nb_inplace_multiply,reinterpret_cast<void *>(Sbk_QMatrix2x3Func___imul__)},
    {Py_nb_inplace_subtract,reinterpret_cast<void *>(Sbk_QMatrix2x3Func___isub__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMatrix2x3_spec = {
    "2:PySide6.QtGui.QMatrix2x3",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMatrix2x3_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMatrix2x3_PythonToCpp_QMatrix2x3_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMatrix2x3_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMatrix2x3_PythonToCpp_QMatrix2x3_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMatrix2x3_TypeF()))
        return QMatrix2x3_PythonToCpp_QMatrix2x3_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMatrix2x3_PTR_CppToPython_QMatrix2x3(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QMatrix2x3_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QMatrix2x3_COPY_CppToPython_QMatrix2x3(const void *cppIn)
{
    auto *source = reinterpret_cast<const QMatrix2x3 *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QMatrix2x3_TypeF(), new ::QMatrix2x3(*source), true, true);
}

// Python to C++ copy conversion.
static void QMatrix2x3_PythonToCpp_QMatrix2x3_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<QMatrix2x3 *>(cppOut) = *reinterpret_cast< ::QMatrix2x3 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QMatrix2x3_PythonToCpp_QMatrix2x3_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QMatrix2x3_TypeF()))
        return QMatrix2x3_PythonToCpp_QMatrix2x3_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMatrix2x3_SignatureStrings[] = {
    "2:PySide6.QtGui.QMatrix2x3(self)",
    "1:PySide6.QtGui.QMatrix2x3(self,elements:PySequence)",
    "0:PySide6.QtGui.QMatrix2x3(self,QMatrix2x3:PySide6.QtGui.QMatrix2x3)",
    "PySide6.QtGui.QMatrix2x3.__reduce__(self)->str",
    "PySide6.QtGui.QMatrix2x3.__repr__(self)->str",
    "PySide6.QtGui.QMatrix2x3.data(self)->float",
    "PySide6.QtGui.QMatrix2x3.fill(self,value:float)",
    "PySide6.QtGui.QMatrix2x3.isIdentity(self)->bool",
    "PySide6.QtGui.QMatrix2x3.__call__(self,row:int,column:int)->float",
    "PySide6.QtGui.QMatrix2x3.setToIdentity(self)",
    "PySide6.QtGui.QMatrix2x3.transposed(self)->PySide6.QtGui.QGenericMatrix[3, 2, float]",
    "PySide6.QtGui.QMatrix2x3.__copy__(self)->typing.Self",
    "PySide6.QtGui.QMatrix2x3.__imul__(self,factor:float)->PySide6.QtGui.QGenericMatrix[2, 3, float]",
    "PySide6.QtGui.QMatrix2x3.__iadd__(self,other:PySide6.QtGui.QGenericMatrix[2, 3, float])->PySide6.QtGui.QGenericMatrix[2, 3, float]",
    "PySide6.QtGui.QMatrix2x3.__isub__(self,other:PySide6.QtGui.QGenericMatrix[2, 3, float])->PySide6.QtGui.QGenericMatrix[2, 3, float]",
    "PySide6.QtGui.QMatrix2x3.__ne__(self,other:PySide6.QtGui.QGenericMatrix[2, 3, float])->bool",
    "PySide6.QtGui.QMatrix2x3.__eq__(self,other:PySide6.QtGui.QGenericMatrix[2, 3, float])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QMatrix2x3_SignatureByteSize = 269;
static constexpr uint8_t QMatrix2x3_SignatureBytes[269] = {
    0x78, 0xda, 0xc5, 0x92, 0xc1, 0x6a, 0xc3, 0x30, 0x0c, 0x40, 0xef, 0xf9, 0x8a, 0x1e, 0x17, 0xc8,
    0xc2, 0x9a, 0xc0, 0x0e, 0x39, 0xec, 0x5a, 0x76, 0x18, 0xac, 0xb4, 0xb7, 0x31, 0x82, 0x6b, 0x2b,
    0x9b, 0x40, 0xb1, 0x53, 0x5b, 0xde, 0x9a, 0xbf, 0x5f, 0xda, 0x34, 0x2b, 0x1b, 0xc4, 0x09, 0xdb,
    0x60, 0x37, 0x0b, 0x3f, 0x49, 0x4f, 0x42, 0x59, 0xf1, 0xd8, 0x6e, 0x50, 0xc1, 0x6d, 0xba, 0xe6,
    0x95, 0xc7, 0x74, 0xfd, 0x20, 0xd8, 0xe2, 0x21, 0x3b, 0xe4, 0x57, 0x0e, 0xa8, 0x8a, 0xa3, 0x65,
    0x18, 0x48, 0x80, 0xa0, 0x06, 0xcd, 0xee, 0x88, 0xc1, 0xde, 0x83, 0x96, 0x10, 0x47, 0x37, 0x13,
    0x49, 0x97, 0x78, 0x14, 0x8c, 0xa3, 0xb1, 0x9f, 0xb4, 0x2c, 0x2d, 0x28, 0x2f, 0xa1, 0x2c, 0x7b,
    0xc7, 0xeb, 0x3b, 0xc7, 0x36, 0x8c, 0x37, 0x76, 0x26, 0xac, 0x04, 0x8b, 0x01, 0xac, 0xc8, 0x08,
    0x1e, 0x47, 0x2b, 0x24, 0xea, 0xc7, 0x79, 0x13, 0xe4, 0xa1, 0x38, 0xe1, 0x01, 0x6d, 0x74, 0xf7,
    0xaa, 0xdb, 0x14, 0x72, 0x3b, 0x34, 0xd8, 0x19, 0x43, 0x21, 0x6f, 0x29, 0x88, 0xce, 0xde, 0x89,
    0x35, 0xef, 0x05, 0x6a, 0x4e, 0xa4, 0x21, 0x5f, 0xeb, 0xe3, 0x73, 0xda, 0xd0, 0x01, 0x6f, 0xcd,
    0xd7, 0xa6, 0xe3, 0x30, 0x5b, 0xa1, 0x5d, 0x63, 0x1c, 0xa8, 0x41, 0xef, 0x1b, 0xba, 0x02, 0x0d,
    0x16, 0x65, 0x9f, 0xf1, 0x94, 0x27, 0x8b, 0x2c, 0x59, 0x9c, 0x04, 0x9e, 0x83, 0x33, 0x98, 0xa6,
    0xbd, 0xec, 0x9e, 0xdb, 0x06, 0xf5, 0x4b, 0xba, 0xe9, 0xa2, 0x50, 0x12, 0xd6, 0xfe, 0x73, 0xf0,
    0x4a, 0x48, 0x36, 0xf6, 0xbc, 0xdd, 0x09, 0xa9, 0xce, 0x28, 0x9f, 0x23, 0x85, 0x42, 0xa9, 0xa1,
    0xbe, 0xe1, 0x57, 0xb0, 0xc5, 0xec, 0xb2, 0x7f, 0xa6, 0xe0, 0xfc, 0xee, 0x9f, 0x15, 0x34, 0xfc,
    0x5c, 0x60, 0xea, 0x74, 0x61, 0xff, 0xcb, 0xda, 0x1f, 0xed, 0xb5, 0x97, 0x23
};
#endif

PyTypeObject *init_QMatrix2x3(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX].type;

    Shiboken::AutoDecRef Sbk_QMatrix2x3_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QMatrix2x3_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMatrix2x3",
        "QMatrix2x3",
        &Sbk_QMatrix2x3_spec,
        &Shiboken::callCppDestructor< ::QMatrix2x3 >,
        Sbk_QMatrix2x3_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QMatrix2x3_TypeF(); // references _Sbk_QMatrix2x3_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMatrix2x3_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMatrix2x3_SignatureBytes, QMatrix2x3_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMatrix2x3_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMatrix2x3_PythonToCpp_QMatrix2x3_PTR,
        is_QMatrix2x3_PythonToCpp_QMatrix2x3_PTR_Convertible,
        QMatrix2x3_PTR_CppToPython_QMatrix2x3,
        QMatrix2x3_COPY_CppToPython_QMatrix2x3);

    Shiboken::Conversions::registerConverterName(converter, "QMatrix2x3");
    Shiboken::Conversions::registerConverterName(converter, "QMatrix2x3*");
    Shiboken::Conversions::registerConverterName(converter, "QMatrix2x3&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMatrix2x3).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QMatrix2x3_PythonToCpp_QMatrix2x3_COPY,
        is_QMatrix2x3_PythonToCpp_QMatrix2x3_COPY_Convertible);

    qRegisterMetaType< ::QMatrix2x3 >("QMatrix2x3");

    return pyType;
}
