// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qmatrix3x2_wrapper.h"

// Argument includes
#include <QtGui/qgenericmatrix.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMatrix3x2_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMatrix3x2 >()))
        return -1;

    ::QMatrix3x2 *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QMatrix3x2", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMatrix3x2::QMatrix3x2()
    // 1: QMatrix3x2::QMatrix3x2(PySequence*)
    // 2: QMatrix3x2::QMatrix3x2(QMatrix3x2)
    if (numArgs == 0) {
        overloadId = 0; // QMatrix3x2()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QMatrix3x2(QMatrix3x2)
    } else if (numArgs == 1
        && Shiboken::String::checkIterableArgument(pyArgs[0])) {
        overloadId = 1; // QMatrix3x2(PySequence*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QMatrix3x2()
        {

            // QMatrix3x2()
            cptr = new ::QMatrix3x2();
            break;
        }
        case 1: // QMatrix3x2(PySequence *elements)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMatrix3x2(PySequence*)
                // Begin code injection
                // TEMPLATE - matrix_constructor - START
                // PYSIDE-795: All PySequences can be made iterable with PySequence_Fast.
                Shiboken::AutoDecRef seq(PySequence_Fast(pyArgs[1-1], "Can't turn into sequence"));
                if (PySequence_Size(seq) == 6) {
                    Shiboken::AutoDecRef fast(PySequence_Fast(seq,
                        "Failed to parse sequence on QMatrix3x2 constructor."));
                    float values[6];
                    for(int i=0; i < 6; i++) {
                        Shiboken::AutoDecRef pv(PySequence_GetItem(fast.object(), i));
                        Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pv, &(values[i]));
                    }
                    cptr = new QMatrix3x2(values);
                }
                // TEMPLATE - matrix_constructor - END
                // End of code injection

            }
            break;
        }
        case 2: // QMatrix3x2(const QMatrix3x2 &QMatrix3x2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QMatrix3x2 cppArg0_local;
            ::QMatrix3x2 *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QMatrix3x2(QMatrix3x2)
                cptr = new ::QMatrix3x2(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMatrix3x2 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMatrix3x2Func___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix3x2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __reduce__()
        // Begin code injection
        // TEMPLATE - reduce_code_matrix - START
        QList< float > cppArgs;
        float data[6];
        cppSelf->copyDataTo(data);
        int matrixSize = 6;
        for(int size=0; size < matrixSize; size++)
            cppArgs.append(data[size]);

        PyObject *type = PyObject_Type(self);
        PyObject *args = Py_BuildValue("(N)",
            Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_float_IDX], &cppArgs));
        pyResult = Py_BuildValue("(NN)", type, args);
        // TEMPLATE - reduce_code_matrix - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMatrix3x2Func___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix3x2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - repr_code_matrix - START
        QByteArray format(Py_TYPE(self)->tp_name);
        format += QByteArrayLiteral("((");

        QList< float > cppArgs;
        float data[6];
        cppSelf->copyDataTo(data);
        int matrixSize = 6;
        for(int size=0; size < matrixSize; size++) {
            if (size > 0)
                format += ", ";
            format += QByteArray::number(data[size]);
        }
        format += "))";

        pyResult = Shiboken::String::fromStringAndSize(format, format.size());
        // TEMPLATE - repr_code_matrix - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMatrix3x2Func_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix3x2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()
        // Begin code injection
        // TEMPLATE - matrix_data_function - START
        const float* data = cppSelf->constData();
        PyObject *pyData = PyTuple_New(6);
        if (data) {
            for(int i=0; i < 6; i++)
                PyTuple_SetItem(pyData, i, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &data[i]));
        }
        return pyData;
        // TEMPLATE - matrix_data_function - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMatrix3x2Func_fill(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix3x2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix3x2::fill(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // fill(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fill", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fill(float)
            cppSelf->fill(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMatrix3x2Func_isIdentity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix3x2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isIdentity()const
        bool cppResult = const_cast<const ::QMatrix3x2 *>(cppSelf)->isIdentity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMatrix3x2Func___call__(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix3x2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "__call__", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMatrix3x2::operator()(int,int)->float&
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // operator()(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "operator()", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator()(int,int)
            float & cppResult = cppSelf->operator()(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMatrix3x2Func_setToIdentity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix3x2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // setToIdentity()
        cppSelf->setToIdentity();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMatrix3x2Func_transposed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix3x2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // transposed()const
        QGenericMatrix<2,3,float> cppResult = const_cast<const ::QMatrix3x2 *>(cppSelf)->transposed();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGenericMatrix_2_3_float_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMatrix3x2__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMatrix3x2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QMatrix3x2_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMatrix3x2_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QMatrix3x2Func___reduce__), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QMatrix3x2Func_data), METH_NOARGS, nullptr},
    {"fill", reinterpret_cast<PyCFunction>(Sbk_QMatrix3x2Func_fill), METH_O, nullptr},
    {"isIdentity", reinterpret_cast<PyCFunction>(Sbk_QMatrix3x2Func_isIdentity), METH_NOARGS, nullptr},
    {"setToIdentity", reinterpret_cast<PyCFunction>(Sbk_QMatrix3x2Func_setToIdentity), METH_NOARGS, nullptr},
    {"transposed", reinterpret_cast<PyCFunction>(Sbk_QMatrix3x2Func_transposed), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QMatrix3x2__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QMatrix3x2Func___imul__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix3x2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix3x2::operator*=(float)->QGenericMatrix<3,2,float>&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // operator*=(float)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator*=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator*=(float)
            (*cppSelf) *= cppArg0;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QMatrix3x2Func___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix3x2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix3x2::operator+=(QGenericMatrix<3,2,float>)->QGenericMatrix<3,2,float>&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGenericMatrix_3_2_float_IDX]), (pyArg)))) {
        overloadId = 0; // operator+=(QGenericMatrix<3,2,float>)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGenericMatrix<3,2,float> cppArg0_local;
        ::QGenericMatrix<3,2,float> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+=(QGenericMatrix<3,2,float>)
            (*cppSelf) += (*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QMatrix3x2Func___isub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix3x2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix3x2::operator-=(QGenericMatrix<3,2,float>)->QGenericMatrix<3,2,float>&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGenericMatrix_3_2_float_IDX]), (pyArg)))) {
        overloadId = 0; // operator-=(QGenericMatrix<3,2,float>)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGenericMatrix<3,2,float> cppArg0_local;
        ::QGenericMatrix<3,2,float> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator-=(QGenericMatrix<3,2,float>)
            (*cppSelf) -= (*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

// Rich comparison
static PyObject * Sbk_QMatrix3x2_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMatrix3x2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGenericMatrix_3_2_float_IDX]), (pyArg)))) {
                // operator!=(const QGenericMatrix<3,2,float> &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGenericMatrix<3,2,float> cppArg0_local;
                ::QGenericMatrix<3,2,float> *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGenericMatrix_3_2_float_IDX]), (pyArg)))) {
                // operator==(const QGenericMatrix<3,2,float> &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGenericMatrix<3,2,float> cppArg0_local;
                ::QGenericMatrix<3,2,float> *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QMatrix3x2_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMatrix3x2_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMatrix3x2_Type = nullptr;
static PyTypeObject *Sbk_QMatrix3x2_TypeF(void)
{
    return _Sbk_QMatrix3x2_Type;
}

static PyType_Slot Sbk_QMatrix3x2_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QMatrix3x2Func___repr__)},
    {Py_tp_call,        reinterpret_cast<void *>(&Sbk_QMatrix3x2Func___call__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMatrix3x2_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMatrix3x2_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QMatrix3x2_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMatrix3x2_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMatrix3x2_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QMatrix3x2Func___iadd__)},
    {Py_nb_inplace_multiply,reinterpret_cast<void *>(Sbk_QMatrix3x2Func___imul__)},
    {Py_nb_inplace_subtract,reinterpret_cast<void *>(Sbk_QMatrix3x2Func___isub__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMatrix3x2_spec = {
    "2:PySide6.QtGui.QMatrix3x2",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMatrix3x2_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMatrix3x2_PythonToCpp_QMatrix3x2_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMatrix3x2_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMatrix3x2_PythonToCpp_QMatrix3x2_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMatrix3x2_TypeF()))
        return QMatrix3x2_PythonToCpp_QMatrix3x2_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMatrix3x2_PTR_CppToPython_QMatrix3x2(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QMatrix3x2_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QMatrix3x2_COPY_CppToPython_QMatrix3x2(const void *cppIn)
{
    auto *source = reinterpret_cast<const QMatrix3x2 *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QMatrix3x2_TypeF(), new ::QMatrix3x2(*source), true, true);
}

// Python to C++ copy conversion.
static void QMatrix3x2_PythonToCpp_QMatrix3x2_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<QMatrix3x2 *>(cppOut) = *reinterpret_cast< ::QMatrix3x2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QMatrix3x2_PythonToCpp_QMatrix3x2_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QMatrix3x2_TypeF()))
        return QMatrix3x2_PythonToCpp_QMatrix3x2_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMatrix3x2_SignatureStrings[] = {
    "2:PySide6.QtGui.QMatrix3x2(self)",
    "1:PySide6.QtGui.QMatrix3x2(self,elements:PySequence)",
    "0:PySide6.QtGui.QMatrix3x2(self,QMatrix3x2:PySide6.QtGui.QMatrix3x2)",
    "PySide6.QtGui.QMatrix3x2.__reduce__(self)->str",
    "PySide6.QtGui.QMatrix3x2.__repr__(self)->str",
    "PySide6.QtGui.QMatrix3x2.data(self)->float",
    "PySide6.QtGui.QMatrix3x2.fill(self,value:float)",
    "PySide6.QtGui.QMatrix3x2.isIdentity(self)->bool",
    "PySide6.QtGui.QMatrix3x2.__call__(self,row:int,column:int)->float",
    "PySide6.QtGui.QMatrix3x2.setToIdentity(self)",
    "PySide6.QtGui.QMatrix3x2.transposed(self)->PySide6.QtGui.QGenericMatrix[2, 3, float]",
    "PySide6.QtGui.QMatrix3x2.__copy__(self)->typing.Self",
    "PySide6.QtGui.QMatrix3x2.__imul__(self,factor:float)->PySide6.QtGui.QGenericMatrix[3, 2, float]",
    "PySide6.QtGui.QMatrix3x2.__iadd__(self,other:PySide6.QtGui.QGenericMatrix[3, 2, float])->PySide6.QtGui.QGenericMatrix[3, 2, float]",
    "PySide6.QtGui.QMatrix3x2.__isub__(self,other:PySide6.QtGui.QGenericMatrix[3, 2, float])->PySide6.QtGui.QGenericMatrix[3, 2, float]",
    "PySide6.QtGui.QMatrix3x2.__ne__(self,other:PySide6.QtGui.QGenericMatrix[3, 2, float])->bool",
    "PySide6.QtGui.QMatrix3x2.__eq__(self,other:PySide6.QtGui.QGenericMatrix[3, 2, float])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QMatrix3x2_SignatureByteSize = 269;
static constexpr uint8_t QMatrix3x2_SignatureBytes[269] = {
    0x78, 0xda, 0xc5, 0x92, 0xc1, 0x4e, 0xc3, 0x30, 0x0c, 0x40, 0xef, 0xfd, 0x8a, 0x1d, 0xa9, 0x14,
    0x2a, 0xe8, 0x24, 0x0e, 0x3d, 0x70, 0x9d, 0x38, 0x20, 0x31, 0x8d, 0x1b, 0x42, 0x55, 0x96, 0xb8,
    0x60, 0x29, 0x8d, 0xbb, 0xc4, 0x81, 0xf5, 0xef, 0xe9, 0xd6, 0x95, 0x09, 0xa4, 0xa6, 0x15, 0x20,
    0x71, 0x8b, 0x95, 0x67, 0xfb, 0xd9, 0x72, 0x5e, 0x3c, 0xb4, 0x1b, 0xd4, 0x70, 0x93, 0xad, 0x79,
    0x15, 0x30, 0x5b, 0xdf, 0x4b, 0x76, 0xb8, 0x5f, 0xee, 0xf3, 0x0b, 0x0f, 0xa6, 0x4a, 0x93, 0xeb,
    0x38, 0x20, 0xc0, 0x40, 0x0d, 0x96, 0xfd, 0x01, 0x83, 0x5d, 0x00, 0xab, 0x20, 0x4d, 0xae, 0x26,
    0x92, 0xce, 0xf1, 0x28, 0x98, 0x26, 0x63, 0x3f, 0x59, 0x59, 0x3a, 0xd0, 0x41, 0x41, 0x59, 0xf6,
    0x8e, 0x97, 0xb7, 0x9e, 0x5d, 0x1c, 0x6f, 0xdc, 0x4c, 0x58, 0x4b, 0x96, 0x03, 0x58, 0x19, 0x92,
    0x3c, 0x8e, 0x56, 0x68, 0x4c, 0x3f, 0xce, 0x9b, 0x34, 0x01, 0x8a, 0x23, 0x1e, 0xd1, 0x46, 0x7f,
    0xa7, 0xbb, 0x4d, 0x21, 0xb7, 0x43, 0x83, 0x2d, 0x91, 0x89, 0x79, 0x2b, 0x69, 0xcc, 0xc9, 0x5b,
    0x38, 0x7a, 0x2f, 0xd0, 0xb2, 0x50, 0x64, 0x42, 0x6d, 0x0f, 0xcf, 0x69, 0x43, 0x0f, 0xfc, 0x48,
    0x5f, 0x9b, 0x8e, 0xc3, 0xec, 0xa4, 0xf5, 0x0d, 0x79, 0xd0, 0x83, 0xde, 0x37, 0x74, 0x05, 0x16,
    0x1c, 0xaa, 0x3e, 0xe3, 0x29, 0x17, 0x8b, 0xa5, 0x58, 0x1c, 0x05, 0x9e, 0xa3, 0x33, 0x50, 0xd3,
    0x9e, 0x77, 0xcf, 0x6d, 0x83, 0xf6, 0x25, 0xdb, 0x74, 0x51, 0x2c, 0x09, 0xeb, 0xf0, 0x39, 0x78,
    0x25, 0x15, 0x93, 0x3b, 0x6d, 0x77, 0x42, 0xaa, 0x33, 0xca, 0xe7, 0x48, 0xa1, 0xd4, 0x7a, 0xa8,
    0x4f, 0xfc, 0x0a, 0xae, 0x98, 0x5d, 0xf6, 0xcf, 0x14, 0x7c, 0xd8, 0xfe, 0xb3, 0x82, 0x85, 0x9f,
    0x0b, 0x4c, 0x9d, 0x2e, 0xec, 0x7e, 0x59, 0xfb, 0x03, 0xed, 0xed, 0x97, 0x23
};
#endif

PyTypeObject *init_QMatrix3x2(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX].type;

    Shiboken::AutoDecRef Sbk_QMatrix3x2_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QMatrix3x2_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMatrix3x2",
        "QMatrix3x2",
        &Sbk_QMatrix3x2_spec,
        &Shiboken::callCppDestructor< ::QMatrix3x2 >,
        Sbk_QMatrix3x2_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QMatrix3x2_TypeF(); // references _Sbk_QMatrix3x2_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMatrix3x2_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMatrix3x2_SignatureBytes, QMatrix3x2_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMatrix3x2_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMatrix3x2_PythonToCpp_QMatrix3x2_PTR,
        is_QMatrix3x2_PythonToCpp_QMatrix3x2_PTR_Convertible,
        QMatrix3x2_PTR_CppToPython_QMatrix3x2,
        QMatrix3x2_COPY_CppToPython_QMatrix3x2);

    Shiboken::Conversions::registerConverterName(converter, "QMatrix3x2");
    Shiboken::Conversions::registerConverterName(converter, "QMatrix3x2*");
    Shiboken::Conversions::registerConverterName(converter, "QMatrix3x2&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMatrix3x2).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QMatrix3x2_PythonToCpp_QMatrix3x2_COPY,
        is_QMatrix3x2_PythonToCpp_QMatrix3x2_COPY_Convertible);

    qRegisterMetaType< ::QMatrix3x2 >("QMatrix3x2");

    return pyType;
}
