// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qmouseevent_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <QtGui/qpointingdevice.h>
#include <qcoreevent.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QMouseEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QMouseEventWrapper::QMouseEventWrapper(::QEvent::Type type, const ::QPointF & localPos, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, const ::QPointingDevice * device) : QMouseEvent(type, localPos, button, buttons, modifiers, device)
{
}

QMouseEventWrapper::QMouseEventWrapper(::QEvent::Type type, const ::QPointF & localPos, const ::QPointF & globalPos, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, const ::QPointingDevice * device) : QMouseEvent(type, localPos, globalPos, button, buttons, modifiers, device)
{
}

QMouseEventWrapper::QMouseEventWrapper(::QEvent::Type type, const ::QPointF & localPos, const ::QPointF & scenePos, const ::QPointF & globalPos, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, ::Qt::MouseEventSource source, const ::QPointingDevice * device) : QMouseEvent(type, localPos, scenePos, globalPos, button, buttons, modifiers, source, device)
{
}

QMouseEventWrapper::QMouseEventWrapper(::QEvent::Type type, const ::QPointF & localPos, const ::QPointF & scenePos, const ::QPointF & globalPos, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, const ::QPointingDevice * device) : QMouseEvent(type, localPos, scenePos, globalPos, button, buttons, modifiers, device)
{
}

::QMouseEvent * QMouseEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QMouseEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QMouseEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QMouseEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QMouseEvent", funcName, Shiboken::SbkType< QMouseEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QMouseEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QMouseEventWrapper::isBeginEvent() const
{
    if (m_PyMethodCache[1])
        return this->::QSinglePointEvent::isBeginEvent();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isBeginEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSinglePointEvent::isBeginEvent();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QMouseEvent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QMouseEvent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QMouseEventWrapper::isEndEvent() const
{
    if (m_PyMethodCache[2])
        return this->::QSinglePointEvent::isEndEvent();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isEndEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QSinglePointEvent::isEndEvent();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QMouseEvent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QMouseEvent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QMouseEventWrapper::isUpdateEvent() const
{
    if (m_PyMethodCache[3])
        return this->::QSinglePointEvent::isUpdateEvent();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isUpdateEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QSinglePointEvent::isUpdateEvent();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QMouseEvent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QMouseEvent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QMouseEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[4]) {
        return this->::QPointerEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QPointerEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QMouseEvent", funcName);
        return;
    }
}

void QMouseEventWrapper::setTimestamp(quint64 timestamp)
{
    if (m_PyMethodCache[5]) {
        return this->::QPointerEvent::setTimestamp(timestamp);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setTimestamp";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QPointerEvent::setTimestamp(timestamp);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &timestamp)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(K)",
        timestamp
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QMouseEvent", funcName);
        return;
    }
}

QMouseEventWrapper::~QMouseEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMouseEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMouseEvent >()))
        return -1;

    QMouseEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[9];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 9));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);
    if (numArgs == 2 || numArgs == 3 || numArgs == 4)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOOOO:QMouseEvent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMouseEvent::QMouseEvent(QEvent::Type,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,const QPointingDevice*=)
    // 1: QMouseEvent::QMouseEvent(QEvent::Type,QPointF,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,const QPointingDevice*=)
    // 2: QMouseEvent::QMouseEvent(QEvent::Type,QPointF,QPointF,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,Qt::MouseEventSource,const QPointingDevice*=)
    // 3: QMouseEvent::QMouseEvent(QEvent::Type,QPointF,QPointF,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,const QPointingDevice*=)
    // 4: QMouseEvent::QMouseEvent(QMouseEvent)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArgs[0])))) {
        overloadId = 4; // QMouseEvent(QMouseEvent)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_Type_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))) {
        if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[2])))) {
            if (numArgs >= 7
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[3])))
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseButton_IDX])))->converter, (pyArgs[4])))
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MouseButton_IDX])))->flagsConverter, (pyArgs[5])))
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[6])))) {
                if (numArgs == 7) {
                    overloadId = 3; // QMouseEvent(QEvent::Type,QPointF,QPointF,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,const QPointingDevice*)
                } else if (numArgs >= 8
                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), (pyArgs[7])))) {
                    overloadId = 3; // QMouseEvent(QEvent::Type,QPointF,QPointF,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,const QPointingDevice*)
                } else if (numArgs >= 8
                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseEventSource_IDX])))->converter, (pyArgs[7])))) {
                    if (numArgs == 8) {
                        overloadId = 2; // QMouseEvent(QEvent::Type,QPointF,QPointF,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,Qt::MouseEventSource,const QPointingDevice*)
                    } else if (numArgs >= 9
                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), (pyArgs[8])))) {
                        overloadId = 2; // QMouseEvent(QEvent::Type,QPointF,QPointF,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,Qt::MouseEventSource,const QPointingDevice*)
                    }
                }
            } else if (numArgs >= 6
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseButton_IDX])))->converter, (pyArgs[3])))
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MouseButton_IDX])))->flagsConverter, (pyArgs[4])))
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[5])))) {
                if (numArgs == 6) {
                    overloadId = 1; // QMouseEvent(QEvent::Type,QPointF,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,const QPointingDevice*)
                } else if (numArgs >= 7
                    && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), (pyArgs[6])))) {
                    overloadId = 1; // QMouseEvent(QEvent::Type,QPointF,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,const QPointingDevice*)
                }
            }
        } else if (numArgs >= 5
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseButton_IDX])))->converter, (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MouseButton_IDX])))->flagsConverter, (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[4])))) {
            if (numArgs == 5) {
                overloadId = 0; // QMouseEvent(QEvent::Type,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,const QPointingDevice*)
            } else if (numArgs >= 6
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), (pyArgs[5])))) {
                overloadId = 0; // QMouseEvent(QEvent::Type,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,const QPointingDevice*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QMouseEvent(QEvent::Type type, const QPointF &localPos, Qt::MouseButton button, QFlags<Qt::MouseButton> buttons, QFlags<Qt::KeyboardModifier> modifiers, const QPointingDevice *device)
        {
            Shiboken::Warnings::warnDeprecated("QMouseEvent", "QMouseEvent(QEvent.Type type, const QPointF &localPos, Qt.MouseButton button, QFlags<Qt.MouseButton> buttons, QFlags<Qt.KeyboardModifier> modifiers, const QPointingDevice *device)");
            if (Shiboken::Errors::occurred() != nullptr)
                return -1;
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_device = Shiboken::String::createStaticString("device");
                if (PyDict_Contains(kwds, key_device) != 0) {
                    value = PyDict_GetItem(kwds, key_device);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_device);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_device);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);
                }
            }
            ::QEvent::Type cppArg0{QEvent::None};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::Qt::MouseButton cppArg2{Qt::NoButton};
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<Qt::MouseButton> cppArg3 = QFlags<Qt::MouseButton>(0);
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QFlags<Qt::KeyboardModifier> cppArg4 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return -1;
            ::QPointingDevice *cppArg5 = const_cast<::QPointingDevice *>(QPointingDevice::primaryPointingDevice());
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMouseEvent(QEvent::Type,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,const QPointingDevice*)
                cptr = new QMouseEventWrapper(cppArg0, *cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
        case 1: // QMouseEvent(QEvent::Type type, const QPointF &localPos, const QPointF &globalPos, Qt::MouseButton button, QFlags<Qt::MouseButton> buttons, QFlags<Qt::KeyboardModifier> modifiers, const QPointingDevice *device)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_device = Shiboken::String::createStaticString("device");
                if (PyDict_Contains(kwds, key_device) != 0) {
                    value = PyDict_GetItem(kwds, key_device);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_device);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_device);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);
                }
            }
            ::QEvent::Type cppArg0{QEvent::None};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QPointF cppArg2_local;
            ::QPointF *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            ::Qt::MouseButton cppArg3{Qt::NoButton};
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QFlags<Qt::MouseButton> cppArg4 = QFlags<Qt::MouseButton>(0);
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QFlags<Qt::KeyboardModifier> cppArg5 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return -1;
            ::QPointingDevice *cppArg6 = const_cast<::QPointingDevice *>(QPointingDevice::primaryPointingDevice());
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMouseEvent(QEvent::Type,QPointF,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,const QPointingDevice*)
                cptr = new QMouseEventWrapper(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
            }
            break;
        }
        case 2: // QMouseEvent(QEvent::Type type, const QPointF &localPos, const QPointF &scenePos, const QPointF &globalPos, Qt::MouseButton button, QFlags<Qt::MouseButton> buttons, QFlags<Qt::KeyboardModifier> modifiers, Qt::MouseEventSource source, const QPointingDevice *device)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_device = Shiboken::String::createStaticString("device");
                if (PyDict_Contains(kwds, key_device) != 0) {
                    value = PyDict_GetItem(kwds, key_device);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_device);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_device);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);
                }
            }
            ::QEvent::Type cppArg0{QEvent::None};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QPointF cppArg2_local;
            ::QPointF *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QPointF cppArg3_local;
            ::QPointF *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);

            ::Qt::MouseButton cppArg4{Qt::NoButton};
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QFlags<Qt::MouseButton> cppArg5 = QFlags<Qt::MouseButton>(0);
            pythonToCpp[5](pyArgs[5], &cppArg5);
            ::QFlags<Qt::KeyboardModifier> cppArg6 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[6](pyArgs[6], &cppArg6);
            ::Qt::MouseEventSource cppArg7{Qt::MouseEventNotSynthesized};
            pythonToCpp[7](pyArgs[7], &cppArg7);
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return -1;
            ::QPointingDevice *cppArg8 = const_cast<::QPointingDevice *>(QPointingDevice::primaryPointingDevice());
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMouseEvent(QEvent::Type,QPointF,QPointF,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,Qt::MouseEventSource,const QPointingDevice*)
                cptr = new QMouseEventWrapper(cppArg0, *cppArg1, *cppArg2, *cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
            }
            break;
        }
        case 3: // QMouseEvent(QEvent::Type type, const QPointF &localPos, const QPointF &scenePos, const QPointF &globalPos, Qt::MouseButton button, QFlags<Qt::MouseButton> buttons, QFlags<Qt::KeyboardModifier> modifiers, const QPointingDevice *device)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_device = Shiboken::String::createStaticString("device");
                if (PyDict_Contains(kwds, key_device) != 0) {
                    value = PyDict_GetItem(kwds, key_device);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_device);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_device);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);
                }
            }
            ::QEvent::Type cppArg0{QEvent::None};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QPointF cppArg2_local;
            ::QPointF *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QPointF cppArg3_local;
            ::QPointF *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);

            ::Qt::MouseButton cppArg4{Qt::NoButton};
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QFlags<Qt::MouseButton> cppArg5 = QFlags<Qt::MouseButton>(0);
            pythonToCpp[5](pyArgs[5], &cppArg5);
            ::QFlags<Qt::KeyboardModifier> cppArg6 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return -1;
            ::QPointingDevice *cppArg7 = const_cast<::QPointingDevice *>(QPointingDevice::primaryPointingDevice());
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMouseEvent(QEvent::Type,QPointF,QPointF,QPointF,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,const QPointingDevice*)
                cptr = new QMouseEventWrapper(cppArg0, *cppArg1, *cppArg2, *cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
            }
            break;
        }
        case 4: // QMouseEvent(const QMouseEvent &arg__1)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QMouseEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMouseEvent(QMouseEvent)
                cptr = new QMouseEventWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QMouseEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMouseEventFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMouseEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - repr_qdebug_gui - START
        // TEMPLATE - repr_qdebug - START
        QString result;
        QDebug(&result).nospace() << "<PySide6.QtGui." << cppSelf << '>';
        pyResult = Shiboken::String::fromCString(qPrintable(result));
        // TEMPLATE - repr_qdebug - END
        // TEMPLATE - repr_qdebug_gui - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMouseEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMouseEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clone()const
        QMouseEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QMouseEvent *>(cppSelf)->::QMouseEvent::clone()
            : const_cast<const ::QMouseEvent *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMouseEventFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMouseEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<Qt::MouseEventFlag> cppResult = const_cast<const ::QMouseEvent *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MouseEventFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMouseEventFunc_globalPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMouseEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QMouseEvent", "globalPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // globalPos()const
        QPoint cppResult = const_cast<const ::QMouseEvent *>(cppSelf)->globalPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMouseEventFunc_globalX(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMouseEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QMouseEvent", "globalX() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // globalX()const
        int cppResult = const_cast<const ::QMouseEvent *>(cppSelf)->globalX();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMouseEventFunc_globalY(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMouseEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QMouseEvent", "globalY() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // globalY()const
        int cppResult = const_cast<const ::QMouseEvent *>(cppSelf)->globalY();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMouseEventFunc_localPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMouseEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QMouseEvent", "localPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // localPos()const
        QPointF cppResult = const_cast<const ::QMouseEvent *>(cppSelf)->localPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMouseEventFunc_pos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMouseEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QMouseEvent", "pos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // pos()const
        QPoint cppResult = const_cast<const ::QMouseEvent *>(cppSelf)->pos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMouseEventFunc_screenPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMouseEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QMouseEvent", "screenPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // screenPos()const
        QPointF cppResult = const_cast<const ::QMouseEvent *>(cppSelf)->screenPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMouseEventFunc_source(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMouseEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // source()const
        Qt::MouseEventSource cppResult = const_cast<const ::QMouseEvent *>(cppSelf)->source();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseEventSource_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMouseEventFunc_windowPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMouseEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QMouseEvent", "windowPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // windowPos()const
        QPointF cppResult = const_cast<const ::QMouseEvent *>(cppSelf)->windowPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMouseEventFunc_x(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMouseEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QMouseEvent", "x() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // x()const
        int cppResult = const_cast<const ::QMouseEvent *>(cppSelf)->x();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMouseEventFunc_y(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMouseEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QMouseEvent", "y() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // y()const
        int cppResult = const_cast<const ::QMouseEvent *>(cppSelf)->y();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QMouseEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMouseEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QMouseEventFunc_clone), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QMouseEventFunc_flags), METH_NOARGS, nullptr},
    {"globalPos", reinterpret_cast<PyCFunction>(Sbk_QMouseEventFunc_globalPos), METH_NOARGS, nullptr},
    {"globalX", reinterpret_cast<PyCFunction>(Sbk_QMouseEventFunc_globalX), METH_NOARGS, nullptr},
    {"globalY", reinterpret_cast<PyCFunction>(Sbk_QMouseEventFunc_globalY), METH_NOARGS, nullptr},
    {"localPos", reinterpret_cast<PyCFunction>(Sbk_QMouseEventFunc_localPos), METH_NOARGS, nullptr},
    {"pos", reinterpret_cast<PyCFunction>(Sbk_QMouseEventFunc_pos), METH_NOARGS, nullptr},
    {"screenPos", reinterpret_cast<PyCFunction>(Sbk_QMouseEventFunc_screenPos), METH_NOARGS, nullptr},
    {"source", reinterpret_cast<PyCFunction>(Sbk_QMouseEventFunc_source), METH_NOARGS, nullptr},
    {"windowPos", reinterpret_cast<PyCFunction>(Sbk_QMouseEventFunc_windowPos), METH_NOARGS, nullptr},
    {"x", reinterpret_cast<PyCFunction>(Sbk_QMouseEventFunc_x), METH_NOARGS, nullptr},
    {"y", reinterpret_cast<PyCFunction>(Sbk_QMouseEventFunc_y), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QMouseEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QMouseEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QMouseEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QMouseEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMouseEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMouseEvent_Type = nullptr;
static PyTypeObject *Sbk_QMouseEvent_TypeF(void)
{
    return _Sbk_QMouseEvent_Type;
}

static PyType_Slot Sbk_QMouseEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QMouseEventFunc___repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QMouseEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMouseEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMouseEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMouseEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMouseEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMouseEvent_spec = {
    "2:PySide6.QtGui.QMouseEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMouseEvent_slots
};

} //extern "C"

static void *Sbk_QMouseEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::MouseButtonDblClick ||  reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::MouseButtonPress ||  reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::MouseButtonRelease ||  reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::MouseMove)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMouseEvent_PythonToCpp_QMouseEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMouseEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMouseEvent_PythonToCpp_QMouseEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMouseEvent_TypeF()))
        return QMouseEvent_PythonToCpp_QMouseEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMouseEvent_PTR_CppToPython_QMouseEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QMouseEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QMouseEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMouseEvent_SignatureStrings[] = {
    "4:PySide6.QtGui.QMouseEvent(self,type:PySide6.QtCore.QEvent.Type,localPos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],button:PySide6.QtCore.Qt.MouseButton,buttons:PySide6.QtCore.Qt.MouseButton,modifiers:PySide6.QtCore.Qt.KeyboardModifier,device:PySide6.QtGui.QPointingDevice=QPointingDevice.primaryPointingDevice())",
    "3:PySide6.QtGui.QMouseEvent(self,type:PySide6.QtCore.QEvent.Type,localPos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],globalPos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],button:PySide6.QtCore.Qt.MouseButton,buttons:PySide6.QtCore.Qt.MouseButton,modifiers:PySide6.QtCore.Qt.KeyboardModifier,device:PySide6.QtGui.QPointingDevice=QPointingDevice.primaryPointingDevice())",
    "2:PySide6.QtGui.QMouseEvent(self,type:PySide6.QtCore.QEvent.Type,localPos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],scenePos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],globalPos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],button:PySide6.QtCore.Qt.MouseButton,buttons:PySide6.QtCore.Qt.MouseButton,modifiers:PySide6.QtCore.Qt.KeyboardModifier,source:PySide6.QtCore.Qt.MouseEventSource,device:PySide6.QtGui.QPointingDevice=QPointingDevice.primaryPointingDevice())",
    "1:PySide6.QtGui.QMouseEvent(self,type:PySide6.QtCore.QEvent.Type,localPos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],scenePos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],globalPos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],button:PySide6.QtCore.Qt.MouseButton,buttons:PySide6.QtCore.Qt.MouseButton,modifiers:PySide6.QtCore.Qt.KeyboardModifier,device:PySide6.QtGui.QPointingDevice=QPointingDevice.primaryPointingDevice())",
    "0:PySide6.QtGui.QMouseEvent(self,arg__1:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtGui.QMouseEvent.__repr__(self)->str",
    "PySide6.QtGui.QMouseEvent.clone(self)->PySide6.QtGui.QMouseEvent",
    "PySide6.QtGui.QMouseEvent.flags(self)->PySide6.QtCore.Qt.MouseEventFlag",
    "PySide6.QtGui.QMouseEvent.globalPos(self)->PySide6.QtCore.QPoint",
    "PySide6.QtGui.QMouseEvent.globalX(self)->int",
    "PySide6.QtGui.QMouseEvent.globalY(self)->int",
    "PySide6.QtGui.QMouseEvent.localPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QMouseEvent.pos(self)->PySide6.QtCore.QPoint",
    "PySide6.QtGui.QMouseEvent.screenPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QMouseEvent.source(self)->PySide6.QtCore.Qt.MouseEventSource",
    "PySide6.QtGui.QMouseEvent.windowPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QMouseEvent.x(self)->int",
    "PySide6.QtGui.QMouseEvent.y(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QMouseEvent_SignatureByteSize = 349;
static constexpr uint8_t QMouseEvent_SignatureBytes[349] = {
    0x78, 0xda, 0xed, 0x94, 0xdf, 0x4b, 0xc3, 0x30, 0x10, 0xc7, 0xdf, 0xf7, 0x57, 0xf8, 0xb8, 0x42,
    0x0d, 0xfe, 0xc2, 0x87, 0x81, 0x3e, 0xa8, 0xab, 0x0f, 0x32, 0xe8, 0x98, 0x82, 0x22, 0x52, 0xd2,
    0xf6, 0x56, 0x03, 0x69, 0xae, 0x24, 0xe9, 0x66, 0xff, 0x7b, 0x4b, 0xb6, 0x49, 0xd7, 0xad, 0x69,
    0x71, 0x7b, 0x19, 0xf4, 0x31, 0x77, 0x9f, 0x7c, 0x73, 0xb9, 0xfb, 0x26, 0x37, 0x23, 0xbf, 0x98,
    0xb1, 0x18, 0x6e, 0xc9, 0x54, 0x3f, 0xe7, 0x8c, 0x4c, 0x27, 0x98, 0x2b, 0x18, 0x2f, 0x40, 0xe8,
    0xa1, 0x02, 0x3e, 0x77, 0x75, 0x91, 0x41, 0x85, 0x79, 0x44, 0x09, 0x64, 0x6a, 0xf2, 0xe4, 0xb5,
    0x4c, 0xb9, 0x1c, 0x23, 0xca, 0x7d, 0x54, 0xa3, 0x12, 0x64, 0x22, 0x21, 0x6f, 0x82, 0xa1, 0xf8,
    0xac, 0x6f, 0xf0, 0x91, 0x09, 0xed, 0xb9, 0x67, 0x7b, 0xe3, 0xd5, 0xb0, 0xa9, 0xc1, 0xa7, 0x65,
    0x14, 0xa4, 0x4f, 0xf5, 0x37, 0x19, 0x73, 0x48, 0xcb, 0xc3, 0xbe, 0xdc, 0x30, 0xd7, 0x1a, 0xc5,
    0x4e, 0x29, 0x9a, 0x98, 0x8a, 0x1f, 0x4c, 0x76, 0x0d, 0xa9, 0x16, 0x2a, 0xc5, 0x98, 0xcd, 0x19,
    0xc8, 0x7d, 0xdc, 0x0b, 0x14, 0x21, 0x52, 0x19, 0x4f, 0xd6, 0x8c, 0x1b, 0xc3, 0x82, 0x45, 0x50,
    0x6f, 0x93, 0x29, 0xbc, 0xbc, 0xef, 0x93, 0xc9, 0xde, 0xd5, 0xd6, 0x24, 0x93, 0x2c, 0xa5, 0xb2,
    0xd8, 0x8e, 0x0e, 0x1d, 0x67, 0x70, 0x7d, 0x32, 0xfd, 0x4e, 0x38, 0x86, 0xfd, 0x64, 0xbb, 0x4f,
    0xf6, 0xea, 0x64, 0x26, 0xab, 0x22, 0x10, 0xd0, 0x5b, 0xe8, 0x18, 0x16, 0x52, 0x98, 0xcb, 0x08,
    0x9a, 0x14, 0xcd, 0x70, 0x67, 0x06, 0x39, 0xb2, 0xd9, 0x2e, 0x7b, 0xb3, 0xf5, 0xff, 0xd5, 0x61,
    0x16, 0xba, 0x68, 0xb3, 0x10, 0x95, 0x49, 0x10, 0x58, 0x8c, 0xe6, 0x0c, 0x1a, 0x53, 0x24, 0x08,
    0x24, 0x64, 0x32, 0x08, 0x8c, 0x92, 0x73, 0x7e, 0xaf, 0xb4, 0xb4, 0xd0, 0x11, 0x47, 0x01, 0x1b,
    0xb4, 0x11, 0xb3, 0x08, 0xcc, 0x39, 0x4d, 0xd4, 0xae, 0xc0, 0xee, 0x63, 0xf4, 0x4a, 0xd0, 0xa2,
    0xf3, 0xe7, 0xa1, 0x26, 0x2d, 0xd3, 0xc6, 0x56, 0x81, 0xf7, 0xcd, 0xf6, 0x2e, 0xf0, 0x47, 0x37,
    0x78, 0xf3, 0x60, 0xad, 0x95, 0x79, 0x16, 0x81, 0xec, 0xff, 0xb7, 0x52, 0x91, 0x04, 0x10, 0x87,
    0x1c, 0xbe, 0xfa, 0x27, 0xbb, 0x4c, 0x68, 0xf5, 0x5d, 0x5a, 0xa4, 0x96, 0x4c, 0xc4, 0xb8, 0x3c,
    0xa4, 0x98, 0x9f, 0x6e, 0x1d, 0x2f, 0xaa, 0xd8, 0x2f, 0xf5, 0x6a, 0x02, 0xf4
};
#endif

PyTypeObject *init_QMouseEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QMouseEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSinglePointEvent_IDX]))));

    _Sbk_QMouseEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMouseEvent",
        "QMouseEvent*",
        &Sbk_QMouseEvent_spec,
        &Shiboken::callCppDestructor< QMouseEvent >,
        Sbk_QMouseEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QMouseEvent_TypeF(); // references _Sbk_QMouseEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMouseEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMouseEvent_SignatureBytes, QMouseEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMouseEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMouseEvent_PythonToCpp_QMouseEvent_PTR,
        is_QMouseEvent_PythonToCpp_QMouseEvent_PTR_Convertible,
        QMouseEvent_PTR_CppToPython_QMouseEvent);

    Shiboken::Conversions::registerConverterName(converter, "QMouseEvent");
    Shiboken::Conversions::registerConverterName(converter, "QMouseEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QMouseEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMouseEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QMouseEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QMouseEvent_TypeF(), &Sbk_QMouseEvent_typeDiscovery);


    return pyType;
}
