// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qnativegestureevent_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <QtGui/qpointingdevice.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QNativeGestureEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QNativeGestureEventWrapper::QNativeGestureEventWrapper(::Qt::NativeGestureType type, const ::QPointingDevice * dev, const ::QPointF & localPos, const ::QPointF & scenePos, const ::QPointF & globalPos, qreal value, quint64 sequenceId, quint64 intArgument) : QNativeGestureEvent(type, dev, localPos, scenePos, globalPos, value, sequenceId, intArgument)
{
}

QNativeGestureEventWrapper::QNativeGestureEventWrapper(::Qt::NativeGestureType type, const ::QPointingDevice * dev, int fingerCount, const ::QPointF & localPos, const ::QPointF & scenePos, const ::QPointF & globalPos, qreal value, const ::QPointF & delta, quint64 sequenceId) : QNativeGestureEvent(type, dev, fingerCount, localPos, scenePos, globalPos, value, delta, sequenceId)
{
}

::QNativeGestureEvent * QNativeGestureEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QNativeGestureEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QNativeGestureEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNativeGestureEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNativeGestureEvent", funcName, Shiboken::SbkType< QNativeGestureEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNativeGestureEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QNativeGestureEventWrapper::isBeginEvent() const
{
    if (m_PyMethodCache[1])
        return this->::QSinglePointEvent::isBeginEvent();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isBeginEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSinglePointEvent::isBeginEvent();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNativeGestureEvent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNativeGestureEvent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QNativeGestureEventWrapper::isEndEvent() const
{
    if (m_PyMethodCache[2])
        return this->::QSinglePointEvent::isEndEvent();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isEndEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QSinglePointEvent::isEndEvent();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNativeGestureEvent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNativeGestureEvent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QNativeGestureEventWrapper::isUpdateEvent() const
{
    if (m_PyMethodCache[3])
        return this->::QSinglePointEvent::isUpdateEvent();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isUpdateEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QSinglePointEvent::isUpdateEvent();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNativeGestureEvent", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNativeGestureEvent", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QNativeGestureEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[4]) {
        return this->::QPointerEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QPointerEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNativeGestureEvent", funcName);
        return;
    }
}

void QNativeGestureEventWrapper::setTimestamp(quint64 timestamp)
{
    if (m_PyMethodCache[5]) {
        return this->::QPointerEvent::setTimestamp(timestamp);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setTimestamp";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QPointerEvent::setTimestamp(timestamp);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &timestamp)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(K)",
        timestamp
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QNativeGestureEvent", funcName);
        return;
    }
}

QNativeGestureEventWrapper::~QNativeGestureEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNativeGestureEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNativeGestureEvent >()))
        return -1;

    QNativeGestureEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[9];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 9));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]);
    if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5 || numArgs == 6 || numArgs == 7)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOOOO:QNativeGestureEvent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNativeGestureEvent::QNativeGestureEvent(Qt::NativeGestureType,const QPointingDevice*,QPointF,QPointF,QPointF,qreal,quint64,quint64)
    // 1: QNativeGestureEvent::QNativeGestureEvent(Qt::NativeGestureType,const QPointingDevice*,int,QPointF,QPointF,QPointF,qreal,QPointF,quint64=)
    // 2: QNativeGestureEvent::QNativeGestureEvent(QNativeGestureEvent)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QNativeGestureEvent(QNativeGestureEvent)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_NativeGestureType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), (pyArgs[1])))) {
        if (numArgs >= 8
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[5])))
            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[6])))
            && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[7])))) {
            if (numArgs == 8) {
                overloadId = 1; // QNativeGestureEvent(Qt::NativeGestureType,const QPointingDevice*,int,QPointF,QPointF,QPointF,qreal,QPointF,quint64)
            } else if (numArgs >= 9
                && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArgs[8])))) {
                overloadId = 1; // QNativeGestureEvent(Qt::NativeGestureType,const QPointingDevice*,int,QPointF,QPointF,QPointF,qreal,QPointF,quint64)
            }
        } else if (numArgs == 8
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[5])))
            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArgs[6])))
            && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArgs[7])))) {
            overloadId = 0; // QNativeGestureEvent(Qt::NativeGestureType,const QPointingDevice*,QPointF,QPointF,QPointF,qreal,quint64,quint64)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QNativeGestureEvent(Qt::NativeGestureType type, const QPointingDevice *dev, const QPointF &localPos, const QPointF &scenePos, const QPointF &globalPos, qreal value, quint64 sequenceId, quint64 intArgument)
        {
            Shiboken::Warnings::warnDeprecated("QNativeGestureEvent", "QNativeGestureEvent(Qt.NativeGestureType type, const QPointingDevice *dev, const QPointF &localPos, const QPointF &scenePos, const QPointF &globalPos, qreal value, quint64 sequenceId, quint64 intArgument)");
            if (Shiboken::Errors::occurred() != nullptr)
                return -1;
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]);
            }
            ::Qt::NativeGestureType cppArg0{Qt::BeginNativeGesture};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPointingDevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QPointF cppArg2_local;
            ::QPointF *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QPointF cppArg3_local;
            ::QPointF *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (!Shiboken::Object::isValid(pyArgs[4]))
                return -1;
            ::QPointF cppArg4_local;
            ::QPointF *cppArg4 = &cppArg4_local;
            if (pythonToCpp[4].isValue())
                pythonToCpp[4](pyArgs[4], &cppArg4_local);
            else
                pythonToCpp[4](pyArgs[4], &cppArg4);

            qreal cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            quint64 cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            quint64 cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNativeGestureEvent(Qt::NativeGestureType,const QPointingDevice*,QPointF,QPointF,QPointF,qreal,quint64,quint64)
                cptr = new QNativeGestureEventWrapper(cppArg0, cppArg1, *cppArg2, *cppArg3, *cppArg4, cppArg5, cppArg6, cppArg7);
            }
            break;
        }
        case 1: // QNativeGestureEvent(Qt::NativeGestureType type, const QPointingDevice *dev, int fingerCount, const QPointF &localPos, const QPointF &scenePos, const QPointF &globalPos, qreal value, const QPointF &delta, quint64 sequenceId)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sequenceId = Shiboken::String::createStaticString("sequenceId");
                if (PyDict_Contains(kwds, key_sequenceId) != 0) {
                    value = PyDict_GetItem(kwds, key_sequenceId);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_sequenceId);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sequenceId);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]);
                }
            }
            ::Qt::NativeGestureType cppArg0{Qt::BeginNativeGesture};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPointingDevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QPointF cppArg3_local;
            ::QPointF *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (!Shiboken::Object::isValid(pyArgs[4]))
                return -1;
            ::QPointF cppArg4_local;
            ::QPointF *cppArg4 = &cppArg4_local;
            if (pythonToCpp[4].isValue())
                pythonToCpp[4](pyArgs[4], &cppArg4_local);
            else
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (!Shiboken::Object::isValid(pyArgs[5]))
                return -1;
            ::QPointF cppArg5_local;
            ::QPointF *cppArg5 = &cppArg5_local;
            if (pythonToCpp[5].isValue())
                pythonToCpp[5](pyArgs[5], &cppArg5_local);
            else
                pythonToCpp[5](pyArgs[5], &cppArg5);

            qreal cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return -1;
            ::QPointF cppArg7_local;
            ::QPointF *cppArg7 = &cppArg7_local;
            if (pythonToCpp[7].isValue())
                pythonToCpp[7](pyArgs[7], &cppArg7_local);
            else
                pythonToCpp[7](pyArgs[7], &cppArg7);

            quint64 cppArg8 = UINT64_MAX;
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNativeGestureEvent(Qt::NativeGestureType,const QPointingDevice*,int,QPointF,QPointF,QPointF,qreal,QPointF,quint64)
                cptr = new QNativeGestureEventWrapper(cppArg0, cppArg1, cppArg2, *cppArg3, *cppArg4, *cppArg5, cppArg6, *cppArg7, cppArg8);
            }
            break;
        }
        case 2: // QNativeGestureEvent(const QNativeGestureEvent &arg__1)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNativeGestureEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNativeGestureEvent(QNativeGestureEvent)
                cptr = new QNativeGestureEventWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QNativeGestureEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QNativeGestureEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeGestureEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clone()const
        QNativeGestureEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QNativeGestureEvent *>(cppSelf)->::QNativeGestureEvent::clone()
            : const_cast<const ::QNativeGestureEvent *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeGestureEventFunc_delta(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeGestureEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // delta()const
        QPointF cppResult = const_cast<const ::QNativeGestureEvent *>(cppSelf)->delta();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeGestureEventFunc_fingerCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeGestureEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fingerCount()const
        int cppResult = const_cast<const ::QNativeGestureEvent *>(cppSelf)->fingerCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeGestureEventFunc_gestureType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeGestureEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // gestureType()const
        Qt::NativeGestureType cppResult = const_cast<const ::QNativeGestureEvent *>(cppSelf)->gestureType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_NativeGestureType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeGestureEventFunc_globalPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeGestureEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QNativeGestureEvent", "globalPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // globalPos()const
        const QPoint cppResult = const_cast<const ::QNativeGestureEvent *>(cppSelf)->globalPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeGestureEventFunc_localPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeGestureEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QNativeGestureEvent", "localPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // localPos()const
        QPointF cppResult = const_cast<const ::QNativeGestureEvent *>(cppSelf)->localPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeGestureEventFunc_pos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeGestureEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QNativeGestureEvent", "pos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // pos()const
        const QPoint cppResult = const_cast<const ::QNativeGestureEvent *>(cppSelf)->pos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeGestureEventFunc_screenPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeGestureEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QNativeGestureEvent", "screenPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // screenPos()const
        QPointF cppResult = const_cast<const ::QNativeGestureEvent *>(cppSelf)->screenPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeGestureEventFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeGestureEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // value()const
        qreal cppResult = const_cast<const ::QNativeGestureEvent *>(cppSelf)->value();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNativeGestureEventFunc_windowPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNativeGestureEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QNativeGestureEvent", "windowPos() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // windowPos()const
        QPointF cppResult = const_cast<const ::QNativeGestureEvent *>(cppSelf)->windowPos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNativeGestureEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNativeGestureEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QNativeGestureEventFunc_clone), METH_NOARGS, nullptr},
    {"delta", reinterpret_cast<PyCFunction>(Sbk_QNativeGestureEventFunc_delta), METH_NOARGS, nullptr},
    {"fingerCount", reinterpret_cast<PyCFunction>(Sbk_QNativeGestureEventFunc_fingerCount), METH_NOARGS, nullptr},
    {"gestureType", reinterpret_cast<PyCFunction>(Sbk_QNativeGestureEventFunc_gestureType), METH_NOARGS, nullptr},
    {"globalPos", reinterpret_cast<PyCFunction>(Sbk_QNativeGestureEventFunc_globalPos), METH_NOARGS, nullptr},
    {"localPos", reinterpret_cast<PyCFunction>(Sbk_QNativeGestureEventFunc_localPos), METH_NOARGS, nullptr},
    {"pos", reinterpret_cast<PyCFunction>(Sbk_QNativeGestureEventFunc_pos), METH_NOARGS, nullptr},
    {"screenPos", reinterpret_cast<PyCFunction>(Sbk_QNativeGestureEventFunc_screenPos), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QNativeGestureEventFunc_value), METH_NOARGS, nullptr},
    {"windowPos", reinterpret_cast<PyCFunction>(Sbk_QNativeGestureEventFunc_windowPos), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QNativeGestureEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QNativeGestureEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QNativeGestureEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QNativeGestureEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNativeGestureEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNativeGestureEvent_Type = nullptr;
static PyTypeObject *Sbk_QNativeGestureEvent_TypeF(void)
{
    return _Sbk_QNativeGestureEvent_Type;
}

static PyType_Slot Sbk_QNativeGestureEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QNativeGestureEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNativeGestureEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNativeGestureEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNativeGestureEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNativeGestureEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNativeGestureEvent_spec = {
    "2:PySide6.QtGui.QNativeGestureEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNativeGestureEvent_slots
};

} //extern "C"

static void *Sbk_QNativeGestureEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::NativeGesture)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNativeGestureEvent_PythonToCpp_QNativeGestureEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNativeGestureEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNativeGestureEvent_PythonToCpp_QNativeGestureEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNativeGestureEvent_TypeF()))
        return QNativeGestureEvent_PythonToCpp_QNativeGestureEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNativeGestureEvent_PTR_CppToPython_QNativeGestureEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QNativeGestureEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QNativeGestureEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QNativeGestureEvent_SignatureStrings[] = {
    "2:PySide6.QtGui.QNativeGestureEvent(self,type:PySide6.QtCore.Qt.NativeGestureType,dev:PySide6.QtGui.QPointingDevice,localPos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],scenePos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],globalPos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],value:qreal,sequenceId:quint64,intArgument:quint64)",
    "1:PySide6.QtGui.QNativeGestureEvent(self,type:PySide6.QtCore.Qt.NativeGestureType,dev:PySide6.QtGui.QPointingDevice,fingerCount:int,localPos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],scenePos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],globalPos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],value:qreal,delta:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],sequenceId:quint64=UINT64_MAX)",
    "0:PySide6.QtGui.QNativeGestureEvent(self,arg__1:PySide6.QtGui.QNativeGestureEvent)",
    "PySide6.QtGui.QNativeGestureEvent.clone(self)->PySide6.QtGui.QNativeGestureEvent",
    "PySide6.QtGui.QNativeGestureEvent.delta(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QNativeGestureEvent.fingerCount(self)->int",
    "PySide6.QtGui.QNativeGestureEvent.gestureType(self)->PySide6.QtCore.Qt.NativeGestureType",
    "PySide6.QtGui.QNativeGestureEvent.globalPos(self)->PySide6.QtCore.QPoint",
    "PySide6.QtGui.QNativeGestureEvent.localPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QNativeGestureEvent.pos(self)->PySide6.QtCore.QPoint",
    "PySide6.QtGui.QNativeGestureEvent.screenPos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QNativeGestureEvent.value(self)->qreal",
    "PySide6.QtGui.QNativeGestureEvent.windowPos(self)->PySide6.QtCore.QPointF",
    nullptr}; // Sentinel
#else
static constexpr size_t QNativeGestureEvent_SignatureByteSize = 323;
static constexpr uint8_t QNativeGestureEvent_SignatureBytes[323] = {
    0x78, 0xda, 0xed, 0x93, 0x4d, 0x4b, 0xc3, 0x30, 0x18, 0xc7, 0xef, 0xfb, 0x14, 0x1e, 0x2d, 0xc4,
    0xa2, 0x32, 0x7a, 0x28, 0x28, 0x8c, 0x39, 0xc7, 0x0e, 0x8e, 0x0e, 0x37, 0x10, 0x44, 0x4a, 0x6c,
    0xff, 0xab, 0x81, 0x98, 0xac, 0x69, 0xd2, 0xb1, 0x6f, 0x6f, 0x56, 0x29, 0x76, 0x2f, 0xda, 0xc0,
    0xe6, 0xbc, 0x78, 0x49, 0xc2, 0xc3, 0x3f, 0xbf, 0xe7, 0xfd, 0x3a, 0x8c, 0x56, 0x8f, 0x2c, 0x45,
    0xe0, 0x4f, 0xf4, 0xd0, 0x30, 0x7f, 0x32, 0xa6, 0x9a, 0x95, 0x18, 0xa2, 0xd0, 0x46, 0x61, 0x50,
    0x42, 0xe8, 0xf3, 0x02, 0x7c, 0x4e, 0xf4, 0x6a, 0x81, 0x86, 0xb6, 0x2f, 0x15, 0xec, 0xe5, 0x6f,
    0xc8, 0xa7, 0x56, 0x43, 0x52, 0x94, 0xdb, 0xcc, 0x48, 0x32, 0xa1, 0x99, 0xc8, 0xee, 0x50, 0xb2,
    0x04, 0x84, 0xcb, 0x84, 0xf2, 0x48, 0x16, 0xa1, 0x65, 0x5a, 0xab, 0x3f, 0x13, 0x4c, 0x8a, 0xe7,
    0x6d, 0x76, 0xf5, 0xe9, 0x9e, 0x9c, 0xed, 0xb5, 0x37, 0xcd, 0x9f, 0x2e, 0xa8, 0xb5, 0x42, 0x45,
    0x54, 0xbf, 0xf9, 0x03, 0x8e, 0x77, 0x1b, 0xf7, 0x0b, 0x29, 0x12, 0x08, 0x9c, 0xc2, 0x51, 0xc6,
    0xe5, 0xeb, 0x69, 0x52, 0x2a, 0x29, 0x37, 0x08, 0x73, 0x05, 0xca, 0x49, 0x81, 0xdc, 0x40, 0x24,
    0x18, 0xa5, 0x61, 0x6e, 0xac, 0x36, 0xe8, 0x12, 0x7b, 0xf6, 0x54, 0x66, 0xd6, 0xda, 0xda, 0xe6,
    0x75, 0xae, 0xfe, 0xa0, 0xc7, 0x73, 0xfb, 0x84, 0xea, 0x4b, 0x63, 0x03, 0x59, 0x27, 0xf7, 0xdf,
    0xf3, 0xe3, 0xf4, 0x3c, 0x05, 0xd7, 0xf4, 0xf7, 0x8b, 0xb8, 0x33, 0x59, 0x37, 0xb3, 0xd1, 0x78,
    0x1a, 0x74, 0xe3, 0x87, 0xde, 0x93, 0xd7, 0xb9, 0x74, 0x1d, 0x28, 0xaa, 0xb2, 0x38, 0x76, 0x18,
    0x3f, 0xaf, 0xd3, 0x2a, 0xf1, 0x13, 0x2e, 0x05, 0x2a, 0xac, 0x77, 0x71, 0xdb, 0x2a, 0x77, 0x00,
    0x56, 0xa5, 0xdc, 0x05, 0x36, 0x8b, 0xe8, 0x40, 0x69, 0x0c, 0x7a, 0xcd, 0x62, 0x4e, 0xee, 0xb3,
    0xaf, 0x7d, 0xfa, 0x2e, 0x88, 0x3d, 0xab, 0xe7, 0x02, 0xae, 0x07, 0xf3, 0xc7, 0xdc, 0x1c, 0x40,
    0xf5, 0xce, 0x1e, 0x5c, 0xa3, 0xc5, 0xe1, 0xb1, 0x14, 0x89, 0x02, 0xc4, 0x31, 0x82, 0xa9, 0xb6,
    0xa9, 0xa6, 0x54, 0x4b, 0xe5, 0xf0, 0x69, 0xc9, 0x44, 0x2a, 0x97, 0xed, 0xee, 0x3f, 0x00, 0xe0,
    0x81, 0xa1, 0x88
};
#endif

PyTypeObject *init_QNativeGestureEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QNativeGestureEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSinglePointEvent_IDX]))));

    _Sbk_QNativeGestureEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNativeGestureEvent",
        "QNativeGestureEvent*",
        &Sbk_QNativeGestureEvent_spec,
        &Shiboken::callCppDestructor< QNativeGestureEvent >,
        Sbk_QNativeGestureEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QNativeGestureEvent_TypeF(); // references _Sbk_QNativeGestureEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QNativeGestureEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QNativeGestureEvent_SignatureBytes, QNativeGestureEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNativeGestureEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QNativeGestureEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNativeGestureEvent_PythonToCpp_QNativeGestureEvent_PTR,
        is_QNativeGestureEvent_PythonToCpp_QNativeGestureEvent_PTR_Convertible,
        QNativeGestureEvent_PTR_CppToPython_QNativeGestureEvent);

    Shiboken::Conversions::registerConverterName(converter, "QNativeGestureEvent");
    Shiboken::Conversions::registerConverterName(converter, "QNativeGestureEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QNativeGestureEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNativeGestureEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QNativeGestureEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QNativeGestureEvent_TypeF(), &Sbk_QNativeGestureEvent_typeDiscovery);


    return pyType;
}
