// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qpageranges_range_wrapper.h"

// Argument includes
#include <QtGui/qpageranges.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPageRanges_Range_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPageRanges::Range >()))
        return -1;

    ::QPageRanges::Range *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Range", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Range::Range()
    // 1: Range::Range(QPageRanges::Range)
    if (numArgs == 0) {
        overloadId = 0; // Range()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Range(QPageRanges::Range)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Range()
        {

            // Range()
            cptr = new ::QPageRanges::Range();
            break;
        }
        case 1: // Range(const QPageRanges::Range &Range)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPageRanges::Range cppArg0_local;
            ::QPageRanges::Range *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Range(QPageRanges::Range)
                cptr = new ::QPageRanges::Range(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPageRanges::Range >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPageRanges_RangeFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPageRanges::Range *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Range::contains(int)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // contains(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contains", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contains(int)const
            bool cppResult = const_cast<const ::QPageRanges::Range *>(cppSelf)->contains(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPageRanges_Range__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPageRanges::Range *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPageRanges_Range_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPageRanges_Range_methods[] = {
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QPageRanges_RangeFunc_contains), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QPageRanges_Range__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QPageRanges_Range_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPageRanges::Range *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), (pyArg)))) {
                // operator!=(QPageRanges::Range rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPageRanges::Range cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), (pyArg)))) {
                // operator<(QPageRanges::Range rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPageRanges::Range cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf < (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), (pyArg)))) {
                // operator==(QPageRanges::Range rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPageRanges::Range cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

static PyObject *Sbk_QPageRanges_Range_get_from(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPageRanges::Range *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->from;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QPageRanges_Range_set_from(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QPageRanges::Range *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("from");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("from", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->from;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->from = cppOut_local;

    return 0;
}

static PyObject *Sbk_QPageRanges_Range_get_to(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPageRanges::Range *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->to;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QPageRanges_Range_set_to(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QPageRanges::Range *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("to");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("to", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->to;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->to = cppOut_local;

    return 0;
}

// Getters and Setters for Range
static PyGetSetDef Sbk_QPageRanges_Range_getsetlist[] = {
    {const_cast<char *>("from_"), Sbk_QPageRanges_Range_get_from, Sbk_QPageRanges_Range_set_from, nullptr, nullptr},
    {const_cast<char *>("to"), Sbk_QPageRanges_Range_get_to, Sbk_QPageRanges_Range_set_to, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QPageRanges_Range_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPageRanges_Range_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPageRanges_Range_Type = nullptr;
static PyTypeObject *Sbk_QPageRanges_Range_TypeF(void)
{
    return _Sbk_QPageRanges_Range_Type;
}

static PyType_Slot Sbk_QPageRanges_Range_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPageRanges_Range_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPageRanges_Range_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QPageRanges_Range_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPageRanges_Range_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QPageRanges_Range_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPageRanges_Range_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPageRanges_Range_spec = {
    "2:PySide6.QtGui.QPageRanges.Range",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPageRanges_Range_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Range_PythonToCpp_Range_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPageRanges_Range_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Range_PythonToCpp_Range_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPageRanges_Range_TypeF()))
        return Range_PythonToCpp_Range_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Range_PTR_CppToPython_Range(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QPageRanges_Range_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *Range_COPY_CppToPython_Range(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QPageRanges::Range *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QPageRanges_Range_TypeF(), new ::QPageRanges::Range(*source), true, true);
}

// Python to C++ copy conversion.
static void Range_PythonToCpp_Range_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPageRanges::Range *>(cppOut) = *reinterpret_cast< ::QPageRanges::Range *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Range_PythonToCpp_Range_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QPageRanges_Range_TypeF()))
        return Range_PythonToCpp_Range_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPageRanges_Range_SignatureStrings[] = {
    "1:PySide6.QtGui.QPageRanges.Range(self)",
    "0:PySide6.QtGui.QPageRanges.Range(self,Range:PySide6.QtGui.QPageRanges.Range)",
    "PySide6.QtGui.QPageRanges.Range.contains(self,pageNumber:int)->bool",
    "PySide6.QtGui.QPageRanges.Range.__copy__(self)->typing.Self",
    "PySide6.QtGui.QPageRanges.Range.__ne__(self,rhs:PySide6.QtGui.QPageRanges.Range)->bool",
    "PySide6.QtGui.QPageRanges.Range.__lt__(self,rhs:PySide6.QtGui.QPageRanges.Range)->bool",
    "PySide6.QtGui.QPageRanges.Range.__eq__(self,rhs:PySide6.QtGui.QPageRanges.Range)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QPageRanges_Range_SignatureByteSize = 137;
static constexpr uint8_t QPageRanges_Range_SignatureBytes[137] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x0c, 0x48, 0x4c, 0x4f, 0x0d, 0x4a, 0xcc, 0x4b, 0x4f, 0x2d, 0xd6, 0x03, 0x53,
    0x1a, 0xc5, 0xa9, 0x39, 0x69, 0x9a, 0x5c, 0x06, 0x44, 0xa9, 0xd3, 0x01, 0x33, 0x09, 0x29, 0xd5,
    0xe4, 0x22, 0xa0, 0x40, 0x2f, 0x39, 0x3f, 0xaf, 0x24, 0x31, 0x33, 0xaf, 0x18, 0x62, 0x68, 0x01,
    0x50, 0xda, 0xaf, 0x34, 0x37, 0x29, 0xb5, 0xc8, 0x2a, 0x33, 0xaf, 0x44, 0x53, 0xd7, 0x2e, 0x29,
    0x3f, 0x3f, 0x87, 0xa0, 0x19, 0xf1, 0xf1, 0xc9, 0xf9, 0x05, 0x95, 0xf1, 0xf1, 0x10, 0x0f, 0xe8,
    0xda, 0x95, 0x54, 0x16, 0x64, 0xe6, 0xa5, 0xeb, 0x05, 0x03, 0x79, 0x44, 0xe8, 0xcd, 0x4b, 0x85,
    0xea, 0xd4, 0x29, 0xca, 0x28, 0x26, 0xe8, 0x21, 0xa2, 0x9d, 0x94, 0x53, 0x42, 0x13, 0x63, 0x53,
    0x0b, 0xc9, 0x30, 0x16, 0x00, 0xea, 0x29, 0xb1, 0x80
};
#endif

PyTypeObject *init_QPageRanges_Range(PyObject *enclosingClass)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX].type;

    Shiboken::AutoDecRef Sbk_QPageRanges_Range_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPageRanges_Range_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Range",
        "QPageRanges::Range",
        &Sbk_QPageRanges_Range_spec,
        &Shiboken::callCppDestructor< ::QPageRanges::Range >,
        Sbk_QPageRanges_Range_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QPageRanges_Range_TypeF(); // references _Sbk_QPageRanges_Range_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPageRanges_Range_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPageRanges_Range_SignatureBytes, QPageRanges_Range_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPageRanges_Range_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Range_PythonToCpp_Range_PTR,
        is_Range_PythonToCpp_Range_PTR_Convertible,
        Range_PTR_CppToPython_Range,
        Range_COPY_CppToPython_Range);

    Shiboken::Conversions::registerConverterName(converter, "QPageRanges::Range");
    Shiboken::Conversions::registerConverterName(converter, "QPageRanges::Range*");
    Shiboken::Conversions::registerConverterName(converter, "QPageRanges::Range&");
    Shiboken::Conversions::registerConverterAlias(converter, "Range");
    Shiboken::Conversions::registerConverterAlias(converter, "Range*");
    Shiboken::Conversions::registerConverterAlias(converter, "Range&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPageRanges::Range).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Range_PythonToCpp_Range_COPY,
        is_Range_PythonToCpp_Range_COPY_Convertible);

    qRegisterMetaType< ::QPageRanges::Range >("Range");
    qRegisterMetaType< ::QPageRanges::Range >("QPageRanges::Range");

    return pyType;
}
