// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qpaintengine_wrapper.h"

// Extra includes
#include <QVarLengthArray>

// Argument includes
#include <QtGui/qimage.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <qline.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPaintEngineWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPaintEngineWrapper::QPaintEngineWrapper(::QFlags<QPaintEngine::PaintEngineFeature> features) : QPaintEngine(features)
{
}

bool QPaintEngineWrapper::begin(::QPaintDevice * pdev)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QPaintEngine.begin");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "begin";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QPaintEngine.begin");
        return false;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), pdev)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), pdev)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPaintEngine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPoint QPaintEngineWrapper::coordinateOffset() const
{
    if (m_PyMethodCache[1])
        return this->::QPaintEngine::coordinateOffset();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "coordinateOffset";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QPaintEngine::coordinateOffset();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPaintEngine", funcName, Shiboken::SbkType< QPoint >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QPoint cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPixmap QPaintEngineWrapper::createPixmap(::QSize size)
{
    if (m_PyMethodCache[2])
        return this->::QPaintEngine::createPixmap(size);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createPixmap";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QPaintEngine::createPixmap(size);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &size)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &size)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPaintEngine", funcName, Shiboken::SbkType< QPixmap >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QPixmap cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPixmap QPaintEngineWrapper::createPixmapFromImage(::QImage image, ::QFlags<Qt::ImageConversionFlag> flags)
{
    if (m_PyMethodCache[3])
        return this->::QPaintEngine::createPixmapFromImage(image, flags);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createPixmapFromImage";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QPaintEngine::createPixmapFromImage(image, flags);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), &image),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, &flags)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), &image),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, &flags)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPaintEngine", funcName, Shiboken::SbkType< QPixmap >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QPixmap cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPaintEngineWrapper::drawEllipse(const ::QRect & r)
{
    if (m_PyMethodCache[4]) {
        return this->::QPaintEngine::drawEllipse(r);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawEllipse";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QPaintEngine::drawEllipse(r);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &r)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &r)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

void QPaintEngineWrapper::drawEllipse(const ::QRectF & r)
{
    if (m_PyMethodCache[5]) {
        return this->::QPaintEngine::drawEllipse(r);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawEllipse";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QPaintEngine::drawEllipse(r);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &r)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &r)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

void QPaintEngineWrapper::drawImage(const ::QRectF & r, const ::QImage & pm, const ::QRectF & sr, ::QFlags<Qt::ImageConversionFlag> flags)
{
    if (m_PyMethodCache[6]) {
        return this->::QPaintEngine::drawImage(r, pm, sr, flags);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawImage";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QPaintEngine::drawImage(r, pm, sr, flags);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &r),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), &pm),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &sr),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, &flags)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNNN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &r),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), &pm),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &sr),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, &flags)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

void QPaintEngineWrapper::drawLines(const ::QLine * lines, int lineCount)
{
    if (m_PyMethodCache[7]) {
        return this->::QPaintEngine::drawLines(lines, lineCount);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawLines";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QPaintEngine::drawLines(lines, lineCount);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), lines),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &lineCount)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(Ni)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), lines),
        lineCount
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

void QPaintEngineWrapper::drawLines(const ::QLineF * lines, int lineCount)
{
    if (m_PyMethodCache[8]) {
        return this->::QPaintEngine::drawLines(lines, lineCount);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawLines";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QPaintEngine::drawLines(lines, lineCount);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), lines),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &lineCount)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(Ni)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), lines),
        lineCount
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

void QPaintEngineWrapper::drawPath(const ::QPainterPath & path)
{
    if (m_PyMethodCache[9]) {
        return this->::QPaintEngine::drawPath(path);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawPath";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QPaintEngine::drawPath(path);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), &path)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), &path)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

void QPaintEngineWrapper::drawPixmap(const ::QRectF & r, const ::QPixmap & pm, const ::QRectF & sr)
{
    if (m_PyMethodCache[10]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QPaintEngine.drawPixmap");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawPixmap";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        Shiboken::Errors::setPureVirtualMethodError("QPaintEngine.drawPixmap");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &r),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &pm),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &sr)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &r),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &pm),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &sr)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

void QPaintEngineWrapper::drawPoints(const ::QPoint * points, int pointCount)
{
    if (m_PyMethodCache[11]) {
        return this->::QPaintEngine::drawPoints(points, pointCount);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawPoints";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QPaintEngine::drawPoints(points, pointCount);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), points),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &pointCount)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(Ni)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), points),
        pointCount
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

void QPaintEngineWrapper::drawPoints(const ::QPointF * points, int pointCount)
{
    if (m_PyMethodCache[12]) {
        return this->::QPaintEngine::drawPoints(points, pointCount);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawPoints";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        gil.release();
        return this->::QPaintEngine::drawPoints(points, pointCount);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), points),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &pointCount)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(Ni)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), points),
        pointCount
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

void QPaintEngineWrapper::drawPolygon(const ::QPoint * points, int pointCount, ::QPaintEngine::PolygonDrawMode mode)
{
    if (m_PyMethodCache[13]) {
        return this->::QPaintEngine::drawPolygon(points, pointCount, mode);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawPolygon";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QPaintEngine::drawPolygon(points, pointCount, mode);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), points),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &pointCount),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_PolygonDrawMode_IDX])))->converter, &mode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NiN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), points),
        pointCount,
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_PolygonDrawMode_IDX])))->converter, &mode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

void QPaintEngineWrapper::drawPolygon(const ::QPointF * points, int pointCount, ::QPaintEngine::PolygonDrawMode mode)
{
    if (m_PyMethodCache[14]) {
        return this->::QPaintEngine::drawPolygon(points, pointCount, mode);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawPolygon";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QPaintEngine::drawPolygon(points, pointCount, mode);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), points),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &pointCount),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_PolygonDrawMode_IDX])))->converter, &mode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NiN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), points),
        pointCount,
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_PolygonDrawMode_IDX])))->converter, &mode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

void QPaintEngineWrapper::drawRects(const ::QRect * rects, int rectCount)
{
    if (m_PyMethodCache[15]) {
        return this->::QPaintEngine::drawRects(rects, rectCount);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawRects";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[15] = true;
        gil.release();
        return this->::QPaintEngine::drawRects(rects, rectCount);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), rects),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &rectCount)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(Ni)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), rects),
        rectCount
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

void QPaintEngineWrapper::drawRects(const ::QRectF * rects, int rectCount)
{
    if (m_PyMethodCache[16]) {
        return this->::QPaintEngine::drawRects(rects, rectCount);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawRects";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[16] = true;
        gil.release();
        return this->::QPaintEngine::drawRects(rects, rectCount);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), rects),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &rectCount)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(Ni)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), rects),
        rectCount
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

void QPaintEngineWrapper::drawTextItem(const ::QPointF & p, const ::QTextItem & textItem)
{
    if (m_PyMethodCache[17]) {
        return this->::QPaintEngine::drawTextItem(p, textItem);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawTextItem";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[17] = true;
        gil.release();
        return this->::QPaintEngine::drawTextItem(p, textItem);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &p),
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX]), &textItem)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &p),
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX]), &textItem)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

void QPaintEngineWrapper::drawTiledPixmap(const ::QRectF & r, const ::QPixmap & pixmap, const ::QPointF & s)
{
    if (m_PyMethodCache[18]) {
        return this->::QPaintEngine::drawTiledPixmap(r, pixmap, s);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawTiledPixmap";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[18] = true;
        gil.release();
        return this->::QPaintEngine::drawTiledPixmap(r, pixmap, s);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &r),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &pixmap),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &s)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &r),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &pixmap),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &s)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

bool QPaintEngineWrapper::end()
{
    if (m_PyMethodCache[19]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QPaintEngine.end");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "end";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[19] = true;
        Shiboken::Errors::setPureVirtualMethodError("QPaintEngine.end");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPaintEngine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPaintEngine::Type QPaintEngineWrapper::type() const
{
    if (m_PyMethodCache[20]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QPaintEngine.type");
        return QPaintEngine::X11;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QPaintEngine::X11;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "type";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[20] = true;
        Shiboken::Errors::setPureVirtualMethodError("QPaintEngine.type");
        return QPaintEngine::X11;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return QPaintEngine::X11;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_Type_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPaintEngine", funcName, Shiboken::SbkType< QPaintEngine::Type >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QPaintEngine::X11;
    }
    ::QPaintEngine::Type cppResult{QPaintEngine::X11};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPaintEngineWrapper::updateState(const ::QPaintEngineState & state)
{
    if (m_PyMethodCache[21]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QPaintEngine.updateState");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "updateState";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[21] = true;
        Shiboken::Errors::setPureVirtualMethodError("QPaintEngine.updateState");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), &state)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), &state)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPaintEngine", funcName);
        return;
    }
}

QPaintEngineWrapper::~QPaintEngineWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPaintEngine_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QPaintEngine");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPaintEngine >()))
        return -1;

    QPaintEngineWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    if (PyArg_ParseTuple(args, "|O:QPaintEngine", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPaintEngine::QPaintEngine(QFlags<QPaintEngine::PaintEngineFeature>=)
    if (numArgs == 0) {
        overloadId = 0; // QPaintEngine(QFlags<QPaintEngine::PaintEngineFeature>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPaintEngine_PaintEngineFeature_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // QPaintEngine(QFlags<QPaintEngine::PaintEngineFeature>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_features = Shiboken::String::createStaticString("features");
            if (PyDict_Contains(kwds, key_features) != 0) {
                value = PyDict_GetItem(kwds, key_features);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_features);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPaintEngine_PaintEngineFeature_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_features);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);
            }
        }
        ::QFlags<QPaintEngine::PaintEngineFeature> cppArg0 = QPaintEngine::PaintEngineFeatures();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QPaintEngine(QFlags<QPaintEngine::PaintEngineFeature>)
            cptr = new QPaintEngineWrapper(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPaintEngine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPaintEngineFunc_begin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintEngine::begin(QPaintDevice*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), (pyArg)))) {
        overloadId = 0; // begin(QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "begin", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPaintDevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // begin(QPaintDevice*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QPaintEngine.begin");
                return {};
            }
            bool cppResult = cppSelf->begin(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineFunc_clearDirty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintEngine::clearDirty(QFlags<QPaintEngine::DirtyFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPaintEngine_DirtyFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // clearDirty(QFlags<QPaintEngine::DirtyFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "clearDirty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        ::QFlags<QPaintEngine::DirtyFlag> cppArg0 = QFlags<QPaintEngine::DirtyFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // clearDirty(QFlags<QPaintEngine::DirtyFlag>)
            cppSelf->clearDirty(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_coordinateOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // coordinateOffset()const
        QPoint cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QPaintEngine *>(cppSelf)->::QPaintEngine::coordinateOffset()
            : const_cast<const ::QPaintEngine *>(cppSelf)->coordinateOffset();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineFunc_createPixmap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintEngine::createPixmap(QSize)->QPixmap
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
        overloadId = 0; // createPixmap(QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSize cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createPixmap(QSize)
            QPixmap cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPaintEngine::createPixmap(cppArg0)
                : cppSelf->createPixmap(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineFunc_createPixmapFromImage(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "createPixmapFromImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    if (PyArg_ParseTuple(args, "|OO:createPixmapFromImage", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPaintEngine::createPixmapFromImage(QImage,QFlags<Qt::ImageConversionFlag>=)->QPixmap
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // createPixmapFromImage(QImage,QFlags<Qt::ImageConversionFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // createPixmapFromImage(QImage,QFlags<Qt::ImageConversionFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createPixmapFromImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "createPixmapFromImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "createPixmapFromImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "createPixmapFromImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QImage cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::ImageConversionFlag> cppArg1(Qt::AutoColor);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createPixmapFromImage(QImage,QFlags<Qt::ImageConversionFlag>)
            QPixmap cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPaintEngine::createPixmapFromImage(cppArg0, cppArg1)
                : cppSelf->createPixmapFromImage(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineFunc_drawEllipse(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintEngine::drawEllipse(QRectF)
    // 1: QPaintEngine::drawEllipse(QRect)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArg)))) {
        overloadId = 1; // drawEllipse(QRect)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
        overloadId = 0; // drawEllipse(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "drawEllipse", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawEllipse(const QRectF &r)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawEllipse(QRectF)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QPaintEngine::drawEllipse(*cppArg0)
                    : cppSelf->drawEllipse(*cppArg0);
            }
            break;
        }
        case 1: // drawEllipse(const QRect &r)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawEllipse(QRect)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QPaintEngine::drawEllipse(*cppArg0)
                    : cppSelf->drawEllipse(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_drawImage(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:drawImage", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPaintEngine::drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>=)
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, (pyArgs[3])))) {
            overloadId = 0; // drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QImage cppArg1_local;
        ::QImage *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRectF cppArg2_local;
        ::QRectF *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        ::QFlags<Qt::ImageConversionFlag> cppArg3(Qt::AutoColor);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPaintEngine::drawImage(*cppArg0, *cppArg1, *cppArg2, cppArg3)
                : cppSelf->drawImage(*cppArg0, *cppArg1, *cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_drawLines(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawLines", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPaintEngine::drawLines(const QLineF*,int)
    // 1: QPaintEngine::drawLines(const QLine*,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 1; // drawLines(const QLine*,int)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // drawLines(const QLineF*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawLines", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawLines(const QLineF *lines, int lineCount)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QLineF *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawLines(const QLineF*,int)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QPaintEngine::drawLines(cppArg0, cppArg1)
                    : cppSelf->drawLines(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // drawLines(const QLine *lines, int lineCount)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QLine *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawLines(const QLine*,int)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QPaintEngine::drawLines(cppArg0, cppArg1)
                    : cppSelf->drawLines(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_drawPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintEngine::drawPath(QPainterPath)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), (pyArg)))) {
        overloadId = 0; // drawPath(QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "drawPath", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPainterPath cppArg0_local;
        ::QPainterPath *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // drawPath(QPainterPath)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPaintEngine::drawPath(*cppArg0)
                : cppSelf->drawPath(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_drawPixmap(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawPixmap", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPaintEngine::drawPixmap(QRectF,QPixmap,QRectF)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[2])))) {
        overloadId = 0; // drawPixmap(QRectF,QPixmap,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPixmap cppArg1_local;
        ::QPixmap *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRectF cppArg2_local;
        ::QRectF *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // drawPixmap(QRectF,QPixmap,QRectF)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QPaintEngine.drawPixmap");
                return {};
            }
            cppSelf->drawPixmap(*cppArg0, *cppArg1, *cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_drawPoints(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawPoints", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPaintEngine::drawPoints(const QPointF*,int)
    // 1: QPaintEngine::drawPoints(const QPoint*,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 1; // drawPoints(const QPoint*,int)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // drawPoints(const QPointF*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawPoints", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawPoints(const QPointF *points, int pointCount)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPoints(const QPointF*,int)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QPaintEngine::drawPoints(cppArg0, cppArg1)
                    : cppSelf->drawPoints(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // drawPoints(const QPoint *points, int pointCount)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPoints(const QPoint*,int)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QPaintEngine::drawPoints(cppArg0, cppArg1)
                    : cppSelf->drawPoints(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_drawPolygon(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawPolygon", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPaintEngine::drawPolygon(const QPointF*,int,QPaintEngine::PolygonDrawMode)
    // 1: QPaintEngine::drawPolygon(const QPoint*,int,QPaintEngine::PolygonDrawMode)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_PolygonDrawMode_IDX])))->converter, (pyArgs[2])))) {
        overloadId = 1; // drawPolygon(const QPoint*,int,QPaintEngine::PolygonDrawMode)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_PolygonDrawMode_IDX])))->converter, (pyArgs[2])))) {
        overloadId = 0; // drawPolygon(const QPointF*,int,QPaintEngine::PolygonDrawMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawPolygon", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawPolygon(const QPointF *points, int pointCount, QPaintEngine::PolygonDrawMode mode)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QPaintEngine::PolygonDrawMode cppArg2{QPaintEngine::OddEvenMode};
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPolygon(const QPointF*,int,QPaintEngine::PolygonDrawMode)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QPaintEngine::drawPolygon(cppArg0, cppArg1, cppArg2)
                    : cppSelf->drawPolygon(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // drawPolygon(const QPoint *points, int pointCount, QPaintEngine::PolygonDrawMode mode)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QPaintEngine::PolygonDrawMode cppArg2{QPaintEngine::OddEvenMode};
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPolygon(const QPoint*,int,QPaintEngine::PolygonDrawMode)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QPaintEngine::drawPolygon(cppArg0, cppArg1, cppArg2)
                    : cppSelf->drawPolygon(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_drawRects(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawRects", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPaintEngine::drawRects(const QRectF*,int)
    // 1: QPaintEngine::drawRects(const QRect*,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 1; // drawRects(const QRect*,int)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // drawRects(const QRectF*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawRects", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawRects(const QRectF *rects, int rectCount)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawRects(const QRectF*,int)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QPaintEngine::drawRects(cppArg0, cppArg1)
                    : cppSelf->drawRects(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // drawRects(const QRect *rects, int rectCount)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawRects(const QRect*,int)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QPaintEngine::drawRects(cppArg0, cppArg1)
                    : cppSelf->drawRects(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_drawTextItem(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawTextItem", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPaintEngine::drawTextItem(QPointF,QTextItem)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX]), (pyArgs[1])))) {
        overloadId = 0; // drawTextItem(QPointF,QTextItem)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawTextItem", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTextItem *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // drawTextItem(QPointF,QTextItem)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPaintEngine::drawTextItem(*cppArg0, *cppArg1)
                : cppSelf->drawTextItem(*cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_drawTiledPixmap(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawTiledPixmap", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPaintEngine::drawTiledPixmap(QRectF,QPixmap,QPointF)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[2])))) {
        overloadId = 0; // drawTiledPixmap(QRectF,QPixmap,QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawTiledPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPixmap cppArg1_local;
        ::QPixmap *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPointF cppArg2_local;
        ::QPointF *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // drawTiledPixmap(QRectF,QPixmap,QPointF)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPaintEngine::drawTiledPixmap(*cppArg0, *cppArg1, *cppArg2)
                : cppSelf->drawTiledPixmap(*cppArg0, *cppArg1, *cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_end(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // end()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QPaintEngine.end");
            return {};
        }
        bool cppResult = cppSelf->end();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineFunc_hasFeature(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintEngine::hasFeature(QFlags<QPaintEngine::PaintEngineFeature>)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPaintEngine_PaintEngineFeature_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // hasFeature(QFlags<QPaintEngine::PaintEngineFeature>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasFeature", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        ::QFlags<QPaintEngine::PaintEngineFeature> cppArg0 = QFlags<QPaintEngine::PaintEngineFeature>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasFeature(QFlags<QPaintEngine::PaintEngineFeature>)const
            bool cppResult = const_cast<const ::QPaintEngine *>(cppSelf)->hasFeature(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineFunc_isActive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isActive()const
        bool cppResult = const_cast<const ::QPaintEngine *>(cppSelf)->isActive();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineFunc_isExtended(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isExtended()const
        bool cppResult = const_cast<const ::QPaintEngine *>(cppSelf)->isExtended();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineFunc_paintDevice(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // paintDevice()const
        QPaintDevice * cppResult = const_cast<const ::QPaintEngine *>(cppSelf)->paintDevice();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineFunc_painter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // painter()const
        QPainter * cppResult = const_cast<const ::QPaintEngine *>(cppSelf)->painter();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineFunc_setActive(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintEngine::setActive(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setActive(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setActive", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActive(bool)
            cppSelf->setActive(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_setDirty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintEngine::setDirty(QFlags<QPaintEngine::DirtyFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPaintEngine_DirtyFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setDirty(QFlags<QPaintEngine::DirtyFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDirty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        ::QFlags<QPaintEngine::DirtyFlag> cppArg0 = QFlags<QPaintEngine::DirtyFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDirty(QFlags<QPaintEngine::DirtyFlag>)
            cppSelf->setDirty(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_setSystemClip(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintEngine::setSystemClip(QRegion)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), (pyArg)))) {
        overloadId = 0; // setSystemClip(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSystemClip", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRegion cppArg0_local;
        ::QRegion *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSystemClip(QRegion)
            cppSelf->setSystemClip(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_setSystemRect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintEngine::setSystemRect(QRect)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArg)))) {
        overloadId = 0; // setSystemRect(QRect)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSystemRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRect cppArg0_local;
        ::QRect *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSystemRect(QRect)
            cppSelf->setSystemRect(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_syncState(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // syncState()
        cppSelf->syncState();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPaintEngineFunc_systemClip(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // systemClip()const
        QRegion cppResult = const_cast<const ::QPaintEngine *>(cppSelf)->systemClip();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineFunc_systemRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // systemRect()const
        QRect cppResult = const_cast<const ::QPaintEngine *>(cppSelf)->systemRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineFunc_testDirty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintEngine::testDirty(QFlags<QPaintEngine::DirtyFlag>)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPaintEngine_DirtyFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // testDirty(QFlags<QPaintEngine::DirtyFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "testDirty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        ::QFlags<QPaintEngine::DirtyFlag> cppArg0 = QFlags<QPaintEngine::DirtyFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // testDirty(QFlags<QPaintEngine::DirtyFlag>)
            bool cppResult = cppSelf->testDirty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QPaintEngine.type");
            return {};
        }
        QPaintEngine::Type cppResult = const_cast<const ::QPaintEngine *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineFunc_updateState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintEngine::updateState(QPaintEngineState)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), (pyArg)))) {
        overloadId = 0; // updateState(QPaintEngineState)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "updateState", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPaintEngineState *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateState(QPaintEngineState)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QPaintEngine.updateState");
                return {};
            }
            cppSelf->updateState(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QPaintEngine_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QPaintEngine_EnumFlagInfo[] = {
    "DirtyFlag:Flag:DirtyFlags",
    "PaintEngineFeature:Flag:PaintEngineFeatures",
    "PolygonDrawMode:Enum",
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPaintEngine_methods[] = {
    {"begin", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_begin), METH_O, nullptr},
    {"clearDirty", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_clearDirty), METH_O, nullptr},
    {"coordinateOffset", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_coordinateOffset), METH_NOARGS, nullptr},
    {"createPixmap", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_createPixmap), METH_O, nullptr},
    {"createPixmapFromImage", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_createPixmapFromImage), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"drawEllipse", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_drawEllipse), METH_O, nullptr},
    {"drawImage", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_drawImage), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"drawLines", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_drawLines), METH_VARARGS, nullptr},
    {"drawPath", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_drawPath), METH_O, nullptr},
    {"drawPixmap", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_drawPixmap), METH_VARARGS, nullptr},
    {"drawPoints", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_drawPoints), METH_VARARGS, nullptr},
    {"drawPolygon", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_drawPolygon), METH_VARARGS, nullptr},
    {"drawRects", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_drawRects), METH_VARARGS, nullptr},
    {"drawTextItem", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_drawTextItem), METH_VARARGS, nullptr},
    {"drawTiledPixmap", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_drawTiledPixmap), METH_VARARGS, nullptr},
    {"end", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_end), METH_NOARGS, nullptr},
    {"hasFeature", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_hasFeature), METH_O, nullptr},
    {"isActive", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_isActive), METH_NOARGS, nullptr},
    {"isExtended", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_isExtended), METH_NOARGS, nullptr},
    {"paintDevice", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_paintDevice), METH_NOARGS, nullptr},
    {"painter", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_painter), METH_NOARGS, nullptr},
    {"setActive", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_setActive), METH_O, nullptr},
    {"setDirty", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_setDirty), METH_O, nullptr},
    {"setSystemClip", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_setSystemClip), METH_O, nullptr},
    {"setSystemRect", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_setSystemRect), METH_O, nullptr},
    {"syncState", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_syncState), METH_NOARGS, nullptr},
    {"systemClip", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_systemClip), METH_NOARGS, nullptr},
    {"systemRect", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_systemRect), METH_NOARGS, nullptr},
    {"testDirty", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_testDirty), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_type), METH_NOARGS, nullptr},
    {"updateState", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineFunc_updateState), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPaintEngine_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPaintEngineWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QPaintEngine_get_state(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), cppSelf->state);
    return pyOut;
}
static int Sbk_QPaintEngine_set_state(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("state");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("state", "QPaintEngineState");
        return -1;
    }

    auto *&cppOut_ptr = cppSelf->state;
    pythonToCpp(pyIn, &cppOut_ptr);

    Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "state", pyIn);
    return 0;
}

static PyObject *Sbk_QPaintEngine_get_gccaps(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPaintEngine_PaintEngineFeature_IDX])))->flagsConverter, &cppSelf->gccaps);
    return pyOut;
}
static int Sbk_QPaintEngine_set_gccaps(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("gccaps");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPaintEngine_PaintEngineFeature_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("gccaps", "PaintEngineFeatures");
        return -1;
    }

    auto cppOut_local = cppSelf->gccaps;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->gccaps = cppOut_local;

    return 0;
}

static PyObject *Sbk_QPaintEngine_get_active(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    uint cppOut_local = cppSelf->active;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QPaintEngine_set_active(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("active");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("active", "uint");
        return -1;
    }

    auto cppOut_local = cppSelf->active;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->active = cppOut_local;

    return 0;
}

static PyObject *Sbk_QPaintEngine_get_selfDestruct(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    uint cppOut_local = cppSelf->selfDestruct;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QPaintEngine_set_selfDestruct(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("selfDestruct");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("selfDestruct", "uint");
        return -1;
    }

    auto cppOut_local = cppSelf->selfDestruct;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->selfDestruct = cppOut_local;

    return 0;
}

static PyObject *Sbk_QPaintEngine_get_extended(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    uint cppOut_local = cppSelf->extended;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QPaintEngine_set_extended(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QPaintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("extended");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("extended", "uint");
        return -1;
    }

    auto cppOut_local = cppSelf->extended;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->extended = cppOut_local;

    return 0;
}

// Getters and Setters for QPaintEngine
static PyGetSetDef Sbk_QPaintEngine_getsetlist[] = {
    {const_cast<char *>("state"), Sbk_QPaintEngine_get_state, Sbk_QPaintEngine_set_state, nullptr, nullptr},
    {const_cast<char *>("gccaps"), Sbk_QPaintEngine_get_gccaps, Sbk_QPaintEngine_set_gccaps, nullptr, nullptr},
    {const_cast<char *>("active"), Sbk_QPaintEngine_get_active, Sbk_QPaintEngine_set_active, nullptr, nullptr},
    {const_cast<char *>("selfDestruct"), Sbk_QPaintEngine_get_selfDestruct, Sbk_QPaintEngine_set_selfDestruct, nullptr, nullptr},
    {const_cast<char *>("extended"), Sbk_QPaintEngine_get_extended, Sbk_QPaintEngine_set_extended, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QPaintEngine_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPaintEngine_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPaintEngine_Type = nullptr;
static PyTypeObject *Sbk_QPaintEngine_TypeF(void)
{
    return _Sbk_QPaintEngine_Type;
}

static PyType_Slot Sbk_QPaintEngine_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPaintEngine_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPaintEngine_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPaintEngine_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPaintEngine_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QPaintEngine_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPaintEngine_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPaintEngine_spec = {
    "2:PySide6.QtGui.QPaintEngine",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPaintEngine_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QPaintEngine_PaintEngineFeature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPaintEngine::PaintEngineFeature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPaintEngine::PaintEngineFeature *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPaintEngine_PaintEngineFeature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_PaintEngineFeature_IDX])))
        return Enum_PythonToCpp_QPaintEngine_PaintEngineFeature;
    return {};
}

static PyObject *QPaintEngine_PaintEngineFeature_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPaintEngine::PaintEngineFeature>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPaintEngine::PaintEngineFeature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_PaintEngineFeature_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QPaintEngine_PaintEngineFeature(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QPaintEngine::PaintEngineFeature>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QPaintEngine::PaintEngineFeature> *>(cppOut) = value;

}

static PyObject *QPaintEngine_PaintEngineFeature_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QPaintEngine::PaintEngineFeature> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_PaintEngineFeature_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QPaintEngine_DirtyFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPaintEngine::DirtyFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPaintEngine::DirtyFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPaintEngine_DirtyFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_DirtyFlag_IDX])))
        return Enum_PythonToCpp_QPaintEngine_DirtyFlag;
    return {};
}

static PyObject *QPaintEngine_DirtyFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPaintEngine::DirtyFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPaintEngine::DirtyFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_DirtyFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QPaintEngine_DirtyFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QPaintEngine::DirtyFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QPaintEngine::DirtyFlag> *>(cppOut) = value;

}

static PyObject *QPaintEngine_DirtyFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QPaintEngine::DirtyFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_DirtyFlag_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QPaintEngine_PolygonDrawMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPaintEngine::PolygonDrawMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPaintEngine::PolygonDrawMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPaintEngine_PolygonDrawMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_PolygonDrawMode_IDX])))
        return Enum_PythonToCpp_QPaintEngine_PolygonDrawMode;
    return {};
}

static PyObject *QPaintEngine_PolygonDrawMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPaintEngine::PolygonDrawMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPaintEngine::PolygonDrawMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_PolygonDrawMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QPaintEngine_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPaintEngine::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPaintEngine::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPaintEngine_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_Type_IDX])))
        return Enum_PythonToCpp_QPaintEngine_Type;
    return {};
}

static PyObject *QPaintEngine_Type_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPaintEngine::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPaintEngine::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_Type_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPaintEngine_PythonToCpp_QPaintEngine_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPaintEngine_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPaintEngine_PythonToCpp_QPaintEngine_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPaintEngine_TypeF()))
        return QPaintEngine_PythonToCpp_QPaintEngine_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPaintEngine_PTR_CppToPython_QPaintEngine(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QPaintEngine *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QPaintEngine_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPaintEngine_SignatureStrings[] = {
    "PySide6.QtGui.QPaintEngine(self,features:PySide6.QtGui.QPaintEngine.PaintEngineFeature=QPaintEngine.PaintEngineFeatures())",
    "PySide6.QtGui.QPaintEngine.begin(self,pdev:PySide6.QtGui.QPaintDevice)->bool",
    "PySide6.QtGui.QPaintEngine.clearDirty(self,df:PySide6.QtGui.QPaintEngine.DirtyFlag)",
    "PySide6.QtGui.QPaintEngine.coordinateOffset(self)->PySide6.QtCore.QPoint",
    "PySide6.QtGui.QPaintEngine.createPixmap(self,size:PySide6.QtCore.QSize)->PySide6.QtGui.QPixmap",
    "PySide6.QtGui.QPaintEngine.createPixmapFromImage(self,image:PySide6.QtGui.QImage,flags:PySide6.QtCore.Qt.ImageConversionFlag=Qt.AutoColor)->PySide6.QtGui.QPixmap",
    "1:PySide6.QtGui.QPaintEngine.drawEllipse(self,r:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "0:PySide6.QtGui.QPaintEngine.drawEllipse(self,r:PySide6.QtCore.QRect)",
    "PySide6.QtGui.QPaintEngine.drawImage(self,r:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],pm:PySide6.QtGui.QImage,sr:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],flags:PySide6.QtCore.Qt.ImageConversionFlag=Qt.AutoColor)",
    "1:PySide6.QtGui.QPaintEngine.drawLines(self,lines:typing.Union[PySide6.QtCore.QLineF, PySide6.QtCore.QLine],lineCount:int)",
    "0:PySide6.QtGui.QPaintEngine.drawLines(self,lines:PySide6.QtCore.QLine,lineCount:int)",
    "PySide6.QtGui.QPaintEngine.drawPath(self,path:PySide6.QtGui.QPainterPath)",
    "PySide6.QtGui.QPaintEngine.drawPixmap(self,r:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],pm:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage],sr:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "1:PySide6.QtGui.QPaintEngine.drawPoints(self,points:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],pointCount:int)",
    "0:PySide6.QtGui.QPaintEngine.drawPoints(self,points:PySide6.QtCore.QPoint,pointCount:int)",
    "1:PySide6.QtGui.QPaintEngine.drawPolygon(self,points:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],pointCount:int,mode:PySide6.QtGui.QPaintEngine.PolygonDrawMode)",
    "0:PySide6.QtGui.QPaintEngine.drawPolygon(self,points:PySide6.QtCore.QPoint,pointCount:int,mode:PySide6.QtGui.QPaintEngine.PolygonDrawMode)",
    "1:PySide6.QtGui.QPaintEngine.drawRects(self,rects:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],rectCount:int)",
    "0:PySide6.QtGui.QPaintEngine.drawRects(self,rects:PySide6.QtCore.QRect,rectCount:int)",
    "PySide6.QtGui.QPaintEngine.drawTextItem(self,p:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],textItem:PySide6.QtGui.QTextItem)",
    "PySide6.QtGui.QPaintEngine.drawTiledPixmap(self,r:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage],s:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "PySide6.QtGui.QPaintEngine.end(self)->bool",
    "PySide6.QtGui.QPaintEngine.hasFeature(self,feature:PySide6.QtGui.QPaintEngine.PaintEngineFeature)->bool",
    "PySide6.QtGui.QPaintEngine.isActive(self)->bool",
    "PySide6.QtGui.QPaintEngine.isExtended(self)->bool",
    "PySide6.QtGui.QPaintEngine.paintDevice(self)->PySide6.QtGui.QPaintDevice",
    "PySide6.QtGui.QPaintEngine.painter(self)->PySide6.QtGui.QPainter",
    "PySide6.QtGui.QPaintEngine.setActive(self,newState:bool)",
    "PySide6.QtGui.QPaintEngine.setDirty(self,df:PySide6.QtGui.QPaintEngine.DirtyFlag)",
    "PySide6.QtGui.QPaintEngine.setSystemClip(self,baseClip:typing.Union[PySide6.QtGui.QRegion, PySide6.QtGui.QBitmap, PySide6.QtGui.QPolygon, PySide6.QtCore.QRect])",
    "PySide6.QtGui.QPaintEngine.setSystemRect(self,rect:PySide6.QtCore.QRect)",
    "PySide6.QtGui.QPaintEngine.syncState(self)",
    "PySide6.QtGui.QPaintEngine.systemClip(self)->PySide6.QtGui.QRegion",
    "PySide6.QtGui.QPaintEngine.systemRect(self)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QPaintEngine.testDirty(self,df:PySide6.QtGui.QPaintEngine.DirtyFlag)->bool",
    "PySide6.QtGui.QPaintEngine.type(self)->PySide6.QtGui.QPaintEngine.Type",
    "PySide6.QtGui.QPaintEngine.updateState(self,state:PySide6.QtGui.QPaintEngineState)",
    nullptr}; // Sentinel
#else
static constexpr size_t QPaintEngine_SignatureByteSize = 674;
static constexpr uint8_t QPaintEngine_SignatureBytes[674] = {
    0x78, 0xda, 0xc5, 0x57, 0x4d, 0x6f, 0xdb, 0x30, 0x0c, 0xbd, 0xe7, 0x57, 0xec, 0x58, 0x03, 0x9e,
    0xd1, 0x5d, 0x76, 0x08, 0xd0, 0x01, 0x5d, 0x3e, 0x86, 0x02, 0x1b, 0x96, 0x36, 0xdd, 0x69, 0xc8,
    0xc1, 0xb1, 0xe9, 0x54, 0x80, 0x2c, 0x19, 0x92, 0x92, 0xc6, 0xfb, 0xf5, 0xa3, 0x64, 0x77, 0x71,
    0x6c, 0x45, 0xb2, 0xeb, 0x16, 0x3b, 0x45, 0x91, 0xc9, 0xc7, 0xc7, 0x47, 0x4a, 0xa6, 0x57, 0xe5,
    0x9a, 0xa4, 0xf0, 0x39, 0xba, 0x57, 0xdf, 0xf6, 0x24, 0xba, 0x5f, 0xc5, 0x84, 0xa9, 0x05, 0xdb,
    0x11, 0x06, 0x57, 0x12, 0x68, 0x16, 0x66, 0x10, 0xab, 0xbd, 0x00, 0x39, 0x5d, 0x5d, 0x34, 0x8c,
    0x1a, 0xeb, 0x65, 0x65, 0x7e, 0xe3, 0x79, 0x2e, 0xaf, 0x82, 0x60, 0xe2, 0x40, 0xdc, 0x02, 0xfe,
    0x54, 0x04, 0x8a, 0x14, 0x0e, 0xd6, 0xe0, 0x73, 0x38, 0x90, 0x04, 0x82, 0x8f, 0x5f, 0xb6, 0x9c,
    0x53, 0x17, 0x58, 0x42, 0x21, 0x16, 0x73, 0x22, 0x54, 0x59, 0x21, 0xa6, 0x99, 0x2b, 0x19, 0x63,
    0xb8, 0xa4, 0xf1, 0xce, 0x49, 0x30, 0xe1, 0x5c, 0xa4, 0x84, 0xc5, 0x0a, 0x7e, 0x66, 0x99, 0x04,
    0x65, 0x90, 0x91, 0xcb, 0xc9, 0x65, 0xc6, 0x05, 0xa0, 0x0f, 0x47, 0x1f, 0x27, 0x90, 0x40, 0x45,
    0x60, 0x45, 0x8e, 0x79, 0x5c, 0x54, 0xf4, 0x24, 0xf9, 0x03, 0xd3, 0x36, 0xce, 0x1a, 0x37, 0xcf,
    0xe0, 0x2b, 0x20, 0xe3, 0xd6, 0x17, 0x7e, 0x29, 0x78, 0x7e, 0x97, 0xc7, 0xbb, 0xba, 0xb2, 0x44,
    0x2f, 0xdb, 0x4a, 0x98, 0xe7, 0x61, 0x86, 0xe9, 0xcb, 0x0e, 0x07, 0x15, 0x99, 0xa7, 0x33, 0xce,
    0x0e, 0x20, 0x24, 0xe1, 0x4c, 0xab, 0x74, 0x83, 0xdb, 0xb7, 0x7b, 0xc5, 0x67, 0x9c, 0x72, 0x71,
    0x91, 0xe1, 0x27, 0x97, 0xe2, 0xa9, 0x88, 0x9f, 0x17, 0x94, 0x92, 0x42, 0xd6, 0xcc, 0xc4, 0x54,
    0x95, 0x05, 0x61, 0xbb, 0xe8, 0x17, 0xc3, 0x28, 0xbf, 0xdb, 0x3c, 0x1e, 0x20, 0x51, 0xcb, 0xf0,
    0x83, 0x6d, 0x7b, 0x13, 0x4c, 0xae, 0x07, 0x86, 0xb2, 0xc1, 0x38, 0x4b, 0xaf, 0x31, 0x1a, 0x32,
    0x8e, 0x20, 0x1b, 0x16, 0xb9, 0x5d, 0x7f, 0x39, 0x06, 0xf4, 0xd5, 0xc5, 0xf3, 0x57, 0xe9, 0x3b,
    0x2e, 0x64, 0x95, 0x36, 0xd5, 0x4b, 0x37, 0x4b, 0x6d, 0x6d, 0x61, 0xa9, 0xb7, 0x37, 0xc6, 0x7f,
    0xc6, 0xf7, 0x4c, 0x4d, 0x31, 0x44, 0x8f, 0xaa, 0x75, 0x42, 0xdb, 0x60, 0xdb, 0xa8, 0x1e, 0xcc,
    0x55, 0xac, 0x9e, 0xea, 0x4b, 0x06, 0x57, 0x56, 0x06, 0x20, 0xb4, 0x91, 0x1f, 0xa9, 0x71, 0x7e,
    0x47, 0x36, 0xc4, 0x05, 0xe7, 0xc6, 0x69, 0x6a, 0x3a, 0x9f, 0x9a, 0x66, 0x33, 0xaa, 0x6b, 0x7a,
    0x14, 0xdf, 0x5c, 0x65, 0x75, 0x09, 0x0a, 0xb3, 0x76, 0x87, 0x33, 0xf6, 0x96, 0x78, 0x66, 0xbf,
    0x93, 0x43, 0x43, 0xed, 0x68, 0x41, 0x21, 0x07, 0xa6, 0xe5, 0xd0, 0xa6, 0x43, 0xba, 0xc4, 0xc2,
    0xd1, 0x1e, 0xbe, 0x8d, 0xdc, 0x23, 0x7b, 0x5a, 0xee, 0x38, 0xfb, 0x8f, 0xe9, 0x87, 0x39, 0x4f,
    0xc1, 0xf9, 0x1a, 0xae, 0x28, 0xce, 0x91, 0xed, 0x0f, 0x34, 0xed, 0x25, 0x57, 0x37, 0xa9, 0x3e,
    0x7a, 0x0d, 0xa7, 0xe2, 0xd5, 0x57, 0x77, 0x61, 0x5d, 0x38, 0xa1, 0x97, 0x23, 0x0e, 0x91, 0xf6,
    0x1f, 0xd2, 0x34, 0x9d, 0xd0, 0x36, 0xd8, 0x36, 0xaa, 0x07, 0xf3, 0x11, 0x8e, 0xea, 0x4e, 0x41,
    0x5e, 0x4b, 0xfb, 0xee, 0xad, 0xa2, 0xea, 0x78, 0xed, 0x5c, 0x5f, 0x78, 0xf8, 0x09, 0x13, 0x0a,
    0xe9, 0x9b, 0x5d, 0x63, 0x06, 0x67, 0xcc, 0x55, 0xf6, 0xde, 0x82, 0x39, 0xf5, 0x00, 0x96, 0xbe,
    0xcc, 0x73, 0xbe, 0xd9, 0xf2, 0x29, 0x96, 0xf5, 0x48, 0x7b, 0x36, 0x2e, 0x0f, 0x9b, 0x96, 0x7b,
    0xc4, 0x21, 0xf2, 0x36, 0x51, 0xe4, 0x00, 0x7d, 0x79, 0x11, 0xb9, 0x38, 0x2a, 0xcc, 0x03, 0x7a,
    0x67, 0x52, 0x9c, 0x66, 0xea, 0xee, 0x30, 0xdb, 0x9e, 0xba, 0xbd, 0x40, 0x20, 0x5c, 0x20, 0x20,
    0x5c, 0x00, 0x38, 0x4e, 0x37, 0x92, 0x0d, 0x19, 0x3c, 0xaf, 0x15, 0x0e, 0xb1, 0x53, 0x9d, 0x41,
    0xe0, 0x71, 0x7c, 0xe3, 0x31, 0x1f, 0x11, 0xd7, 0xa5, 0xc4, 0xf3, 0x33, 0xc3, 0x99, 0xb1, 0x82,
    0xdd, 0xc6, 0x12, 0xf4, 0x3f, 0x67, 0x77, 0x3f, 0xe0, 0xf7, 0x0b, 0x67, 0x9d, 0x4e, 0xfc, 0x4a,
    0x94, 0xad, 0xe9, 0xeb, 0xdb, 0xf2, 0xe2, 0xab, 0xb9, 0x0f, 0x41, 0x6d, 0x7a, 0xba, 0xc3, 0x86,
    0x4f, 0xb5, 0xb2, 0x64, 0x89, 0x91, 0xb9, 0xaa, 0x9b, 0xdb, 0xf4, 0x4c, 0x91, 0x6e, 0x8d, 0xab,
    0xec, 0xfd, 0x10, 0xff, 0x38, 0x5b, 0x3e, 0x9c, 0xf4, 0x33, 0x17, 0x82, 0x02, 0xf9, 0x9a, 0x62,
    0xfb, 0xcf, 0x01, 0x96, 0xd5, 0x79, 0x00, 0x6a, 0xb3, 0x47, 0x34, 0x73, 0xc1, 0xec, 0x8b, 0x14,
    0xc5, 0x3c, 0x29, 0x1a, 0x4a, 0xd3, 0xc3, 0x97, 0x3d, 0x8c, 0x69, 0x30, 0xf9, 0x0b, 0x73, 0x3a,
    0x8e, 0xc6
};
#endif

PyTypeObject *init_QPaintEngine(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX].type;

    Shiboken::AutoDecRef Sbk_QPaintEngine_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPaintEngine_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPaintEngine",
        "QPaintEngine*",
        &Sbk_QPaintEngine_spec,
        &Shiboken::callCppDestructor< QPaintEngine >,
        Sbk_QPaintEngine_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPaintEngine_TypeF(); // references _Sbk_QPaintEngine_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPaintEngine_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPaintEngine_SignatureBytes, QPaintEngine_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPaintEngine_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPaintEngine_PythonToCpp_QPaintEngine_PTR,
        is_QPaintEngine_PythonToCpp_QPaintEngine_PTR_Convertible,
        QPaintEngine_PTR_CppToPython_QPaintEngine);

    Shiboken::Conversions::registerConverterName(converter, "QPaintEngine");
    Shiboken::Conversions::registerConverterName(converter, "QPaintEngine*");
    Shiboken::Conversions::registerConverterName(converter, "QPaintEngine&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPaintEngine).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPaintEngineWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPaintEngine_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'PaintEngineFeature'.
    const char *PaintEngineFeature_Initializer[] = {
        "PrimitiveTransform",
        "PatternTransform",
        "PixmapTransform",
        "PatternBrush",
        "LinearGradientFill",
        "RadialGradientFill",
        "ConicalGradientFill",
        "AlphaBlend",
        "PorterDuff",
        "PainterPaths",
        "Antialiasing",
        "BrushStroke",
        "ConstantOpacity",
        "MaskedBrush",
        "PerspectiveTransform",
        "BlendModes",
        "ObjectBoundingModeGradients",
        "RasterOpModes",
        "PaintOutsidePaintEvent",
        "AllFeatures",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t PaintEngineFeature_InitializerValues[] = {
        uint32_t(QPaintEngine::PaintEngineFeature::PrimitiveTransform),          //  0x00000001  1
        uint32_t(QPaintEngine::PaintEngineFeature::PatternTransform),            //  0x00000002  2
        uint32_t(QPaintEngine::PaintEngineFeature::PixmapTransform),             //  0x00000004  4
        uint32_t(QPaintEngine::PaintEngineFeature::PatternBrush),                //  0x00000008  8
        uint32_t(QPaintEngine::PaintEngineFeature::LinearGradientFill),          //  0x00000010  16
        uint32_t(QPaintEngine::PaintEngineFeature::RadialGradientFill),          //  0x00000020  32
        uint32_t(QPaintEngine::PaintEngineFeature::ConicalGradientFill),         //  0x00000040  64
        uint32_t(QPaintEngine::PaintEngineFeature::AlphaBlend),                  //  0x00000080  128
        uint32_t(QPaintEngine::PaintEngineFeature::PorterDuff),                  //  0x00000100  256
        uint32_t(QPaintEngine::PaintEngineFeature::PainterPaths),                //  0x00000200  512
        uint32_t(QPaintEngine::PaintEngineFeature::Antialiasing),                //  0x00000400  1024
        uint32_t(QPaintEngine::PaintEngineFeature::BrushStroke),                 //  0x00000800  2048
        uint32_t(QPaintEngine::PaintEngineFeature::ConstantOpacity),             //  0x00001000  4096
        uint32_t(QPaintEngine::PaintEngineFeature::MaskedBrush),                 //  0x00002000  8192
        uint32_t(QPaintEngine::PaintEngineFeature::PerspectiveTransform),        //  0x00004000  16384
        uint32_t(QPaintEngine::PaintEngineFeature::BlendModes),                  //  0x00008000  32768
        uint32_t(QPaintEngine::PaintEngineFeature::ObjectBoundingModeGradients), //  0x00010000  65536
        uint32_t(QPaintEngine::PaintEngineFeature::RasterOpModes),               //  0x00020000  131072
        uint32_t(QPaintEngine::PaintEngineFeature::PaintOutsidePaintEvent),      //  0x20000000  536870912
        uint32_t(QPaintEngine::PaintEngineFeature::AllFeatures)                  //  0xffffffff  4294967295
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPaintEngine_TypeF(),
        "2:PySide6.QtGui.QPaintEngine.PaintEngineFeature",
        PaintEngineFeature_Initializer, PaintEngineFeature_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_PaintEngineFeature_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPaintEngine_PaintEngineFeature_IDX].type =
        EType;
    // Register converter for enum 'QPaintEngine::PaintEngineFeature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPaintEngine_PaintEngineFeature_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPaintEngine_PaintEngineFeature,
            is_Enum_PythonToCpp_QPaintEngine_PaintEngineFeature_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPaintEngine::PaintEngineFeature");
        Shiboken::Conversions::registerConverterAlias(converter, "PaintEngineFeature");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QPaintEngine_PaintEngineFeature_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QPaintEngine_PaintEngineFeature,
            is_Enum_PythonToCpp_QPaintEngine_PaintEngineFeature_Convertible);
        // Register converter for flag 'QFlags<QPaintEngine::PaintEngineFeature>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QPaintEngine::PaintEngineFeature>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QPaintEngine::PaintEngineFeatures");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'PaintEngineFeature' enum/flags.

    // Initialization of enum 'DirtyFlag'.
    const char *DirtyFlag_Initializer[] = {
        "DirtyPen",
        "DirtyBrush",
        "DirtyBrushOrigin",
        "DirtyFont",
        "DirtyBackground",
        "DirtyBackgroundMode",
        "DirtyTransform",
        "DirtyClipRegion",
        "DirtyClipPath",
        "DirtyHints",
        "DirtyCompositionMode",
        "DirtyClipEnabled",
        "DirtyOpacity",
        "AllDirty",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t DirtyFlag_InitializerValues[] = {
        uint16_t(QPaintEngine::DirtyFlag::DirtyPen),             //  0x0001  1
        uint16_t(QPaintEngine::DirtyFlag::DirtyBrush),           //  0x0002  2
        uint16_t(QPaintEngine::DirtyFlag::DirtyBrushOrigin),     //  0x0004  4
        uint16_t(QPaintEngine::DirtyFlag::DirtyFont),            //  0x0008  8
        uint16_t(QPaintEngine::DirtyFlag::DirtyBackground),      //  0x0010  16
        uint16_t(QPaintEngine::DirtyFlag::DirtyBackgroundMode),  //  0x0020  32
        uint16_t(QPaintEngine::DirtyFlag::DirtyTransform),       //  0x0040  64
        uint16_t(QPaintEngine::DirtyFlag::DirtyClipRegion),      //  0x0080  128
        uint16_t(QPaintEngine::DirtyFlag::DirtyClipPath),        //  0x0100  256
        uint16_t(QPaintEngine::DirtyFlag::DirtyHints),           //  0x0200  512
        uint16_t(QPaintEngine::DirtyFlag::DirtyCompositionMode), //  0x0400  1024
        uint16_t(QPaintEngine::DirtyFlag::DirtyClipEnabled),     //  0x0800  2048
        uint16_t(QPaintEngine::DirtyFlag::DirtyOpacity),         //  0x1000  4096
        uint16_t(QPaintEngine::DirtyFlag::AllDirty)              //  0xffff  65535
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPaintEngine_TypeF(),
        "2:PySide6.QtGui.QPaintEngine.DirtyFlag",
        DirtyFlag_Initializer, DirtyFlag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_DirtyFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPaintEngine_DirtyFlag_IDX].type =
        EType;
    // Register converter for enum 'QPaintEngine::DirtyFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPaintEngine_DirtyFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPaintEngine_DirtyFlag,
            is_Enum_PythonToCpp_QPaintEngine_DirtyFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPaintEngine::DirtyFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "DirtyFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QPaintEngine_DirtyFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QPaintEngine_DirtyFlag,
            is_Enum_PythonToCpp_QPaintEngine_DirtyFlag_Convertible);
        // Register converter for flag 'QFlags<QPaintEngine::DirtyFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QPaintEngine::DirtyFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QPaintEngine::DirtyFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'DirtyFlag' enum/flags.

    // Initialization of enum 'PolygonDrawMode'.
    const char *PolygonDrawMode_Initializer[] = {
        "OddEvenMode",
        "WindingMode",
        "ConvexMode",
        "PolylineMode",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PolygonDrawMode_InitializerValues[] = {
        uint8_t(QPaintEngine::PolygonDrawMode::OddEvenMode), //  0x00  0
        uint8_t(QPaintEngine::PolygonDrawMode::WindingMode), //  0x01  1
        uint8_t(QPaintEngine::PolygonDrawMode::ConvexMode),  //  0x02  2
        uint8_t(QPaintEngine::PolygonDrawMode::PolylineMode) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPaintEngine_TypeF(),
        "2:PySide6.QtGui.QPaintEngine.PolygonDrawMode",
        PolygonDrawMode_Initializer, PolygonDrawMode_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_PolygonDrawMode_IDX].type = EType;
    // Register converter for enum 'QPaintEngine::PolygonDrawMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPaintEngine_PolygonDrawMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPaintEngine_PolygonDrawMode,
            is_Enum_PythonToCpp_QPaintEngine_PolygonDrawMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPaintEngine::PolygonDrawMode");
        Shiboken::Conversions::registerConverterAlias(converter, "PolygonDrawMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PolygonDrawMode' enum.

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "X11",
        "Windows",
        "QuickDraw",
        "CoreGraphics",
        "MacPrinter",
        "QWindowSystem",
        "OpenGL",
        "Picture",
        "SVG",
        "Raster",
        "Direct3D",
        "Pdf",
        "OpenVG",
        "OpenGL2",
        "PaintBuffer",
        "Blitter",
        "Direct2D",
        "User",
        "MaxUser",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(QPaintEngine::Type::X11),           //  0x00  0
        uint8_t(QPaintEngine::Type::Windows),       //  0x01  1
        uint8_t(QPaintEngine::Type::QuickDraw),     //  0x02  2
        uint8_t(QPaintEngine::Type::CoreGraphics),  //  0x03  3
        uint8_t(QPaintEngine::Type::MacPrinter),    //  0x04  4
        uint8_t(QPaintEngine::Type::QWindowSystem), //  0x05  5
        uint8_t(QPaintEngine::Type::OpenGL),        //  0x06  6
        uint8_t(QPaintEngine::Type::Picture),       //  0x07  7
        uint8_t(QPaintEngine::Type::SVG),           //  0x08  8
        uint8_t(QPaintEngine::Type::Raster),        //  0x09  9
        uint8_t(QPaintEngine::Type::Direct3D),      //  0x0a  10
        uint8_t(QPaintEngine::Type::Pdf),           //  0x0b  11
        uint8_t(QPaintEngine::Type::OpenVG),        //  0x0c  12
        uint8_t(QPaintEngine::Type::OpenGL2),       //  0x0d  13
        uint8_t(QPaintEngine::Type::PaintBuffer),   //  0x0e  14
        uint8_t(QPaintEngine::Type::Blitter),       //  0x0f  15
        uint8_t(QPaintEngine::Type::Direct2D),      //  0x10  16
        uint8_t(QPaintEngine::Type::User),          //  0x32  50
        uint8_t(QPaintEngine::Type::MaxUser)        //  0x64  100
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPaintEngine_TypeF(),
        "2:PySide6.QtGui.QPaintEngine.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_Type_IDX].type = EType;
    // Register converter for enum 'QPaintEngine::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPaintEngine_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPaintEngine_Type,
            is_Enum_PythonToCpp_QPaintEngine_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPaintEngine::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    qRegisterMetaType< ::QPaintEngine *>();
    qRegisterMetaType< ::QPaintEngine::PaintEngineFeature >("QPaintEngine::PaintEngineFeature");
    qRegisterMetaType< ::QPaintEngine::DirtyFlag >("QPaintEngine::DirtyFlag");
    qRegisterMetaType< ::QPaintEngine::PolygonDrawMode >("QPaintEngine::PolygonDrawMode");
    qRegisterMetaType< ::QPaintEngine::Type >("QPaintEngine::Type");

    return pyType;
}
