// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qpainterpath_element_wrapper.h"

// Argument includes
#include <QPainterPath>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPainterPath_Element_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPainterPath::Element >()))
        return -1;

    ::QPainterPath::Element *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Element", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Element::Element()
    // 1: Element::Element(QPainterPath::Element)
    if (numArgs == 0) {
        overloadId = 0; // Element()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Element(QPainterPath::Element)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Element()
        {

            // Element()
            cptr = new ::QPainterPath::Element();
            break;
        }
        case 1: // Element(const QPainterPath::Element &Element)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPainterPath::Element cppArg0_local;
            ::QPainterPath::Element *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Element(QPainterPath::Element)
                cptr = new ::QPainterPath::Element(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPainterPath::Element >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPainterPath_ElementFunc_isCurveTo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPath::Element *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isCurveTo()const
        bool cppResult = const_cast<const ::QPainterPath::Element *>(cppSelf)->isCurveTo();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterPath_ElementFunc_isLineTo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPath::Element *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLineTo()const
        bool cppResult = const_cast<const ::QPainterPath::Element *>(cppSelf)->isLineTo();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterPath_ElementFunc_isMoveTo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPath::Element *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isMoveTo()const
        bool cppResult = const_cast<const ::QPainterPath::Element *>(cppSelf)->isMoveTo();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterPath_Element__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPainterPath::Element *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPainterPath_Element_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPainterPath_Element_methods[] = {
    {"isCurveTo", reinterpret_cast<PyCFunction>(Sbk_QPainterPath_ElementFunc_isCurveTo), METH_NOARGS, nullptr},
    {"isLineTo", reinterpret_cast<PyCFunction>(Sbk_QPainterPath_ElementFunc_isLineTo), METH_NOARGS, nullptr},
    {"isMoveTo", reinterpret_cast<PyCFunction>(Sbk_QPainterPath_ElementFunc_isMoveTo), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QPainterPath_Element__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QPainterPath_Element_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPainterPath::Element *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), (pyArg)))) {
                // operator!=(const QPainterPath::Element &e) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPainterPath::Element cppArg0_local;
                ::QPainterPath::Element *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), (pyArg)))) {
                // operator==(const QPainterPath::Element &e) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPainterPath::Element cppArg0_local;
                ::QPainterPath::Element *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

static PyObject *Sbk_QPainterPath_Element_get_x(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPath::Element *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppSelf->x);
    return pyOut;
}
static int Sbk_QPainterPath_Element_set_x(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QPainterPath::Element *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("x");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("x", "qreal");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->x;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QPainterPath_Element_get_y(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPath::Element *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppSelf->y);
    return pyOut;
}
static int Sbk_QPainterPath_Element_set_y(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QPainterPath::Element *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("y");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("y", "qreal");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->y;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QPainterPath_Element_get_type(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPath::Element *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QPainterPath::ElementType cppOut_local = cppSelf->type;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_ElementType_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QPainterPath_Element_set_type(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QPainterPath::Element *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("type");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_ElementType_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("type", "ElementType");
        return -1;
    }

    auto cppOut_local = cppSelf->type;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->type = cppOut_local;

    return 0;
}

// Getters and Setters for Element
static PyGetSetDef Sbk_QPainterPath_Element_getsetlist[] = {
    {const_cast<char *>("x"), Sbk_QPainterPath_Element_get_x, Sbk_QPainterPath_Element_set_x, nullptr, nullptr},
    {const_cast<char *>("y"), Sbk_QPainterPath_Element_get_y, Sbk_QPainterPath_Element_set_y, nullptr, nullptr},
    {const_cast<char *>("type"), Sbk_QPainterPath_Element_get_type, Sbk_QPainterPath_Element_set_type, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QPainterPath_Element_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPainterPath_Element_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPainterPath_Element_Type = nullptr;
static PyTypeObject *Sbk_QPainterPath_Element_TypeF(void)
{
    return _Sbk_QPainterPath_Element_Type;
}

static PyType_Slot Sbk_QPainterPath_Element_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPainterPath_Element_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPainterPath_Element_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QPainterPath_Element_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPainterPath_Element_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QPainterPath_Element_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPainterPath_Element_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPainterPath_Element_spec = {
    "2:PySide6.QtGui.QPainterPath.Element",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPainterPath_Element_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Element_PythonToCpp_Element_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPainterPath_Element_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Element_PythonToCpp_Element_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPainterPath_Element_TypeF()))
        return Element_PythonToCpp_Element_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Element_PTR_CppToPython_Element(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QPainterPath_Element_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *Element_COPY_CppToPython_Element(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QPainterPath::Element *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QPainterPath_Element_TypeF(), new ::QPainterPath::Element(*source), true, true);
}

// Python to C++ copy conversion.
static void Element_PythonToCpp_Element_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPainterPath::Element *>(cppOut) = *reinterpret_cast< ::QPainterPath::Element *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Element_PythonToCpp_Element_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QPainterPath_Element_TypeF()))
        return Element_PythonToCpp_Element_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPainterPath_Element_SignatureStrings[] = {
    "1:PySide6.QtGui.QPainterPath.Element(self)",
    "0:PySide6.QtGui.QPainterPath.Element(self,Element:PySide6.QtGui.QPainterPath.Element)",
    "PySide6.QtGui.QPainterPath.Element.isCurveTo(self)->bool",
    "PySide6.QtGui.QPainterPath.Element.isLineTo(self)->bool",
    "PySide6.QtGui.QPainterPath.Element.isMoveTo(self)->bool",
    "PySide6.QtGui.QPainterPath.Element.__copy__(self)->typing.Self",
    "PySide6.QtGui.QPainterPath.Element.__ne__(self,e:PySide6.QtGui.QPainterPath.Element)->bool",
    "PySide6.QtGui.QPainterPath.Element.__eq__(self,e:PySide6.QtGui.QPainterPath.Element)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QPainterPath_Element_SignatureByteSize = 132;
static constexpr uint8_t QPainterPath_Element_SignatureBytes[132] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x0c, 0x48, 0xcc, 0xcc, 0x2b, 0x49, 0x2d, 0x0a, 0x48, 0x2c, 0xc9, 0xd0, 0x73,
    0xcd, 0x49, 0xcd, 0x4d, 0xcd, 0x2b, 0xd1, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x20, 0x56,
    0xa9, 0x0e, 0x94, 0x43, 0x84, 0x7a, 0x4d, 0x2e, 0xc2, 0x6a, 0xf4, 0x32, 0x8b, 0x9d, 0x4b, 0x8b,
    0xca, 0x52, 0x43, 0xf2, 0x21, 0x0e, 0xd1, 0xb5, 0x4b, 0xca, 0xcf, 0xcf, 0x21, 0x4e, 0xa3, 0x4f,
    0x66, 0x1e, 0x59, 0xfa, 0x7c, 0xf3, 0xc9, 0xb1, 0x2f, 0x3e, 0x3e, 0x39, 0xbf, 0xa0, 0x32, 0x3e,
    0x1e, 0xa6, 0xaf, 0xa4, 0xb2, 0x20, 0x33, 0x2f, 0x5d, 0x2f, 0x18, 0xc8, 0x23, 0x4e, 0x7b, 0x5e,
    0x2a, 0x54, 0xb3, 0x4e, 0x2a, 0x31, 0x81, 0x47, 0x8a, 0xcb, 0x52, 0x0b, 0xc9, 0x31, 0x1a, 0x00,
    0xc1, 0x53, 0xc0, 0xd3
};
#endif

PyTypeObject *init_QPainterPath_Element(PyObject *enclosingClass)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX].type;

    Shiboken::AutoDecRef Sbk_QPainterPath_Element_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPainterPath_Element_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Element",
        "QPainterPath::Element",
        &Sbk_QPainterPath_Element_spec,
        &Shiboken::callCppDestructor< ::QPainterPath::Element >,
        Sbk_QPainterPath_Element_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QPainterPath_Element_TypeF(); // references _Sbk_QPainterPath_Element_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPainterPath_Element_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPainterPath_Element_SignatureBytes, QPainterPath_Element_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPainterPath_Element_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Element_PythonToCpp_Element_PTR,
        is_Element_PythonToCpp_Element_PTR_Convertible,
        Element_PTR_CppToPython_Element,
        Element_COPY_CppToPython_Element);

    Shiboken::Conversions::registerConverterName(converter, "QPainterPath::Element");
    Shiboken::Conversions::registerConverterName(converter, "QPainterPath::Element*");
    Shiboken::Conversions::registerConverterName(converter, "QPainterPath::Element&");
    Shiboken::Conversions::registerConverterAlias(converter, "Element");
    Shiboken::Conversions::registerConverterAlias(converter, "Element*");
    Shiboken::Conversions::registerConverterAlias(converter, "Element&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPainterPath::Element).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Element_PythonToCpp_Element_COPY,
        is_Element_PythonToCpp_Element_COPY_Convertible);

    qRegisterMetaType< ::QPainterPath::Element >("Element");
    qRegisterMetaType< ::QPainterPath::Element >("QPainterPath::Element");

    return pyType;
}
