// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qpainterpathstroker_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpen.h>
#include <qnamespace.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPainterPathStroker_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPainterPathStroker >()))
        return -1;

    ::QPainterPathStroker *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPainterPathStroker", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPainterPathStroker::QPainterPathStroker()
    // 1: QPainterPathStroker::QPainterPathStroker(QPen)
    if (numArgs == 0) {
        overloadId = 0; // QPainterPathStroker()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPainterPathStroker(QPen)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPainterPathStroker()
        {

            // QPainterPathStroker()
            cptr = new ::QPainterPathStroker();
            break;
        }
        case 1: // QPainterPathStroker(const QPen &pen)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPen cppArg0_local;
            ::QPen *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QPainterPathStroker(QPen)
                cptr = new ::QPainterPathStroker(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPainterPathStroker >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPainterPathStrokerFunc_capStyle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPathStroker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // capStyle()const
        Qt::PenCapStyle cppResult = const_cast<const ::QPainterPathStroker *>(cppSelf)->capStyle();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_PenCapStyle_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterPathStrokerFunc_createStroke(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPathStroker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainterPathStroker::createStroke(QPainterPath)const->QPainterPath
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), (pyArg)))) {
        overloadId = 0; // createStroke(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createStroke", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPainterPath cppArg0_local;
        ::QPainterPath *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // createStroke(QPainterPath)const
            QPainterPath cppResult = const_cast<const ::QPainterPathStroker *>(cppSelf)->createStroke(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterPathStrokerFunc_curveThreshold(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPathStroker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // curveThreshold()const
        qreal cppResult = const_cast<const ::QPainterPathStroker *>(cppSelf)->curveThreshold();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterPathStrokerFunc_dashOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPathStroker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dashOffset()const
        qreal cppResult = const_cast<const ::QPainterPathStroker *>(cppSelf)->dashOffset();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterPathStrokerFunc_dashPattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPathStroker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dashPattern()const
        QList<qreal> cppResult = const_cast<const ::QPainterPathStroker *>(cppSelf)->dashPattern();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_qreal_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterPathStrokerFunc_joinStyle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPathStroker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // joinStyle()const
        Qt::PenJoinStyle cppResult = const_cast<const ::QPainterPathStroker *>(cppSelf)->joinStyle();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_PenJoinStyle_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterPathStrokerFunc_miterLimit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPathStroker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // miterLimit()const
        qreal cppResult = const_cast<const ::QPainterPathStroker *>(cppSelf)->miterLimit();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterPathStrokerFunc_setCapStyle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPathStroker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainterPathStroker::setCapStyle(Qt::PenCapStyle)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_PenCapStyle_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setCapStyle(Qt::PenCapStyle)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCapStyle", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]);

    // Call function/method
    {
        ::Qt::PenCapStyle cppArg0{Qt::FlatCap};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCapStyle(Qt::PenCapStyle)
            cppSelf->setCapStyle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterPathStrokerFunc_setCurveThreshold(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPathStroker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainterPathStroker::setCurveThreshold(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setCurveThreshold(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCurveThreshold", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurveThreshold(qreal)
            cppSelf->setCurveThreshold(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterPathStrokerFunc_setDashOffset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPathStroker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainterPathStroker::setDashOffset(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setDashOffset(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDashOffset", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDashOffset(qreal)
            cppSelf->setDashOffset(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterPathStrokerFunc_setDashPattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPathStroker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainterPathStroker::setDashPattern(Qt::PenStyle)
    // 1: QPainterPathStroker::setDashPattern(QList<qreal>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_PenStyle_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDashPattern(Qt::PenStyle)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_qreal_IDX], (pyArg)))) {
        overloadId = 1; // setDashPattern(QList<qreal>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDashPattern", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setDashPattern(Qt::PenStyle arg__1)
        {
            ::Qt::PenStyle cppArg0{Qt::NoPen};
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setDashPattern(Qt::PenStyle)
                cppSelf->setDashPattern(cppArg0);
            }
            break;
        }
        case 1: // setDashPattern(const QList<qreal> &dashPattern)
        {
            ::QList<qreal> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setDashPattern(QList<qreal>)
                cppSelf->setDashPattern(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterPathStrokerFunc_setJoinStyle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPathStroker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainterPathStroker::setJoinStyle(Qt::PenJoinStyle)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_PenJoinStyle_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setJoinStyle(Qt::PenJoinStyle)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setJoinStyle", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]);

    // Call function/method
    {
        ::Qt::PenJoinStyle cppArg0{Qt::MiterJoin};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setJoinStyle(Qt::PenJoinStyle)
            cppSelf->setJoinStyle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterPathStrokerFunc_setMiterLimit(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPathStroker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainterPathStroker::setMiterLimit(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setMiterLimit(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMiterLimit", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMiterLimit(qreal)
            cppSelf->setMiterLimit(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterPathStrokerFunc_setWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPathStroker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainterPathStroker::setWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWidth", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWidth(qreal)
            cppSelf->setWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterPathStrokerFunc_width(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterPathStroker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // width()const
        qreal cppResult = const_cast<const ::QPainterPathStroker *>(cppSelf)->width();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPainterPathStroker_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPainterPathStroker_methods[] = {
    {"capStyle", reinterpret_cast<PyCFunction>(Sbk_QPainterPathStrokerFunc_capStyle), METH_NOARGS, nullptr},
    {"createStroke", reinterpret_cast<PyCFunction>(Sbk_QPainterPathStrokerFunc_createStroke), METH_O, nullptr},
    {"curveThreshold", reinterpret_cast<PyCFunction>(Sbk_QPainterPathStrokerFunc_curveThreshold), METH_NOARGS, nullptr},
    {"dashOffset", reinterpret_cast<PyCFunction>(Sbk_QPainterPathStrokerFunc_dashOffset), METH_NOARGS, nullptr},
    {"dashPattern", reinterpret_cast<PyCFunction>(Sbk_QPainterPathStrokerFunc_dashPattern), METH_NOARGS, nullptr},
    {"joinStyle", reinterpret_cast<PyCFunction>(Sbk_QPainterPathStrokerFunc_joinStyle), METH_NOARGS, nullptr},
    {"miterLimit", reinterpret_cast<PyCFunction>(Sbk_QPainterPathStrokerFunc_miterLimit), METH_NOARGS, nullptr},
    {"setCapStyle", reinterpret_cast<PyCFunction>(Sbk_QPainterPathStrokerFunc_setCapStyle), METH_O, nullptr},
    {"setCurveThreshold", reinterpret_cast<PyCFunction>(Sbk_QPainterPathStrokerFunc_setCurveThreshold), METH_O, nullptr},
    {"setDashOffset", reinterpret_cast<PyCFunction>(Sbk_QPainterPathStrokerFunc_setDashOffset), METH_O, nullptr},
    {"setDashPattern", reinterpret_cast<PyCFunction>(Sbk_QPainterPathStrokerFunc_setDashPattern), METH_O, nullptr},
    {"setJoinStyle", reinterpret_cast<PyCFunction>(Sbk_QPainterPathStrokerFunc_setJoinStyle), METH_O, nullptr},
    {"setMiterLimit", reinterpret_cast<PyCFunction>(Sbk_QPainterPathStrokerFunc_setMiterLimit), METH_O, nullptr},
    {"setWidth", reinterpret_cast<PyCFunction>(Sbk_QPainterPathStrokerFunc_setWidth), METH_O, nullptr},
    {"width", reinterpret_cast<PyCFunction>(Sbk_QPainterPathStrokerFunc_width), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QPainterPathStroker_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPainterPathStroker_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPainterPathStroker_Type = nullptr;
static PyTypeObject *Sbk_QPainterPathStroker_TypeF(void)
{
    return _Sbk_QPainterPathStroker_Type;
}

static PyType_Slot Sbk_QPainterPathStroker_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPainterPathStroker_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPainterPathStroker_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPainterPathStroker_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPainterPathStroker_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPainterPathStroker_spec = {
    "2:PySide6.QtGui.QPainterPathStroker",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPainterPathStroker_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPainterPathStroker_PythonToCpp_QPainterPathStroker_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPainterPathStroker_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPainterPathStroker_PythonToCpp_QPainterPathStroker_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPainterPathStroker_TypeF()))
        return QPainterPathStroker_PythonToCpp_QPainterPathStroker_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPainterPathStroker_PTR_CppToPython_QPainterPathStroker(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QPainterPathStroker_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPainterPathStroker_SignatureStrings[] = {
    "1:PySide6.QtGui.QPainterPathStroker(self)",
    "0:PySide6.QtGui.QPainterPathStroker(self,pen:typing.Union[PySide6.QtGui.QPen, PySide6.QtCore.Qt.PenStyle, PySide6.QtGui.QColor])",
    "PySide6.QtGui.QPainterPathStroker.capStyle(self)->PySide6.QtCore.Qt.PenCapStyle",
    "PySide6.QtGui.QPainterPathStroker.createStroke(self,path:PySide6.QtGui.QPainterPath)->PySide6.QtGui.QPainterPath",
    "PySide6.QtGui.QPainterPathStroker.curveThreshold(self)->qreal",
    "PySide6.QtGui.QPainterPathStroker.dashOffset(self)->qreal",
    "PySide6.QtGui.QPainterPathStroker.dashPattern(self)->QList[qreal]",
    "PySide6.QtGui.QPainterPathStroker.joinStyle(self)->PySide6.QtCore.Qt.PenJoinStyle",
    "PySide6.QtGui.QPainterPathStroker.miterLimit(self)->qreal",
    "PySide6.QtGui.QPainterPathStroker.setCapStyle(self,style:PySide6.QtCore.Qt.PenCapStyle)",
    "PySide6.QtGui.QPainterPathStroker.setCurveThreshold(self,threshold:qreal)",
    "PySide6.QtGui.QPainterPathStroker.setDashOffset(self,offset:qreal)",
    "1:PySide6.QtGui.QPainterPathStroker.setDashPattern(self,arg__1:PySide6.QtCore.Qt.PenStyle)",
    "0:PySide6.QtGui.QPainterPathStroker.setDashPattern(self,dashPattern:QList[qreal])",
    "PySide6.QtGui.QPainterPathStroker.setJoinStyle(self,style:PySide6.QtCore.Qt.PenJoinStyle)",
    "PySide6.QtGui.QPainterPathStroker.setMiterLimit(self,length:qreal)",
    "PySide6.QtGui.QPainterPathStroker.setWidth(self,width:qreal)",
    "PySide6.QtGui.QPainterPathStroker.width(self)->qreal",
    nullptr}; // Sentinel
#else
static constexpr size_t QPainterPathStroker_SignatureByteSize = 315;
static constexpr uint8_t QPainterPathStroker_SignatureBytes[315] = {
    0x78, 0xda, 0x9d, 0x53, 0xc1, 0x4e, 0xc3, 0x30, 0x0c, 0xbd, 0xef, 0x2b, 0x38, 0x52, 0x29, 0x54,
    0xf4, 0xc2, 0x21, 0x07, 0x2e, 0x45, 0x42, 0x9a, 0x86, 0x68, 0x55, 0x10, 0x87, 0x69, 0x9a, 0x22,
    0xea, 0xb6, 0x81, 0x90, 0x94, 0x24, 0x63, 0xea, 0xdf, 0x93, 0xb5, 0x6b, 0x49, 0xc7, 0xe8, 0x3c,
    0x4e, 0x71, 0x6c, 0xbf, 0x67, 0x3b, 0x7e, 0x89, 0x68, 0xd2, 0x64, 0x3c, 0x87, 0x9b, 0x30, 0xb5,
    0xf7, 0x1b, 0x1e, 0xa6, 0x09, 0xe3, 0xd2, 0x82, 0x4e, 0x98, 0xad, 0x32, 0xab, 0xd5, 0x3b, 0xe8,
    0x4b, 0x03, 0xa2, 0x08, 0x66, 0xd7, 0xc8, 0x4c, 0x52, 0x83, 0xa4, 0xb6, 0xa9, 0xb9, 0x2c, 0xc3,
    0x67, 0xc9, 0x95, 0x5c, 0x1e, 0xe2, 0x40, 0x92, 0x8b, 0x1f, 0x5f, 0xac, 0x34, 0xb8, 0x23, 0x74,
    0xee, 0xcc, 0x36, 0x02, 0xfc, 0x58, 0x9b, 0x1f, 0x2b, 0xa1, 0xf4, 0x2a, 0x98, 0x9d, 0x2c, 0x1f,
    0xbe, 0xb2, 0xba, 0xa5, 0xe8, 0x3a, 0xbe, 0xba, 0x3d, 0x5a, 0x24, 0xde, 0x27, 0x61, 0xf8, 0x34,
    0x30, 0x0b, 0xdd, 0x6d, 0x3f, 0x9b, 0x8b, 0x4e, 0xbc, 0xc3, 0xa8, 0xe6, 0x61, 0x10, 0x53, 0x70,
    0xa3, 0xbf, 0xe0, 0xa9, 0xd2, 0x60, 0x2a, 0x25, 0xf2, 0x7e, 0x8c, 0x4f, 0xd7, 0x86, 0x40, 0xa0,
    0x73, 0x66, 0xaa, 0xc7, 0xa2, 0x30, 0x60, 0xff, 0x83, 0x74, 0x77, 0xe7, 0x95, 0x3d, 0x34, 0x5d,
    0x70, 0x63, 0x97, 0x2d, 0xc1, 0x0a, 0xc1, 0xf0, 0xa6, 0xb8, 0x3c, 0xfd, 0xf6, 0xf3, 0x3e, 0x0b,
    0xc1, 0xf8, 0xc1, 0x9d, 0x63, 0xc1, 0xdd, 0x71, 0xee, 0x34, 0xee, 0x01, 0x62, 0x5f, 0x09, 0xc4,
    0xec, 0x4c, 0x3a, 0xa9, 0x86, 0x00, 0xc9, 0xfb, 0x7b, 0x41, 0xc4, 0xf6, 0x57, 0xda, 0x36, 0x88,
    0x64, 0xba, 0x1b, 0x2f, 0x8b, 0xa8, 0xd6, 0xee, 0x29, 0x22, 0x8a, 0x26, 0xf1, 0xf7, 0x46, 0x98,
    0x2e, 0xd7, 0xeb, 0x88, 0xfe, 0xfd, 0xbb, 0x50, 0xff, 0xf8, 0x28, 0xb5, 0xa7, 0x11, 0xea, 0x8b,
    0x03, 0x39, 0xef, 0x7c, 0x24, 0x90, 0xa9, 0x95, 0x0c, 0x99, 0x48, 0xe6, 0x87, 0xb1, 0x50, 0x88,
    0x00, 0x59, 0xba, 0x5f, 0x7a, 0xce, 0x32, 0x5e, 0x78, 0x6e, 0xab, 0x0e, 0xbd, 0xdd, 0x99, 0x78,
    0xf0, 0x76, 0x40, 0x0e, 0x02, 0xfd, 0x06, 0x73, 0x25, 0xf0, 0x27
};
#endif

PyTypeObject *init_QPainterPathStroker(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX].type;

    Shiboken::AutoDecRef Sbk_QPainterPathStroker_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPainterPathStroker_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPainterPathStroker",
        "QPainterPathStroker*",
        &Sbk_QPainterPathStroker_spec,
        &Shiboken::callCppDestructor< ::QPainterPathStroker >,
        Sbk_QPainterPathStroker_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPainterPathStroker_TypeF(); // references _Sbk_QPainterPathStroker_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPainterPathStroker_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPainterPathStroker_SignatureBytes, QPainterPathStroker_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPainterPathStroker_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QPainterPathStroker_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPainterPathStroker_PythonToCpp_QPainterPathStroker_PTR,
        is_QPainterPathStroker_PythonToCpp_QPainterPathStroker_PTR_Convertible,
        QPainterPathStroker_PTR_CppToPython_QPainterPathStroker);

    Shiboken::Conversions::registerConverterName(converter, "QPainterPathStroker");
    Shiboken::Conversions::registerConverterName(converter, "QPainterPathStroker*");
    Shiboken::Conversions::registerConverterName(converter, "QPainterPathStroker&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPainterPathStroker).name());

    qRegisterMetaType< ::QPainterPathStroker *>();

    return pyType;
}
