// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qpdfoutputintent_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qcolorspace.h>
#include <QtGui/qpdfoutputintent.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPdfOutputIntent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPdfOutputIntent >()))
        return -1;

    ::QPdfOutputIntent *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPdfOutputIntent", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPdfOutputIntent::QPdfOutputIntent()
    // 1: QPdfOutputIntent::QPdfOutputIntent(QPdfOutputIntent)
    if (numArgs == 0) {
        overloadId = 0; // QPdfOutputIntent()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPdfOutputIntent(QPdfOutputIntent)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPdfOutputIntent()
        {

            // QPdfOutputIntent()
            cptr = new ::QPdfOutputIntent();
            break;
        }
        case 1: // QPdfOutputIntent(const QPdfOutputIntent &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPdfOutputIntent cppArg0_local;
            ::QPdfOutputIntent *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QPdfOutputIntent(QPdfOutputIntent)
                cptr = new ::QPdfOutputIntent(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPdfOutputIntent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPdfOutputIntentFunc_outputCondition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfOutputIntent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // outputCondition()const
        QString cppResult = const_cast<const ::QPdfOutputIntent *>(cppSelf)->outputCondition();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfOutputIntentFunc_outputConditionIdentifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfOutputIntent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // outputConditionIdentifier()const
        QString cppResult = const_cast<const ::QPdfOutputIntent *>(cppSelf)->outputConditionIdentifier();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfOutputIntentFunc_outputProfile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfOutputIntent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // outputProfile()const
        QColorSpace cppResult = const_cast<const ::QPdfOutputIntent *>(cppSelf)->outputProfile();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfOutputIntentFunc_registryName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfOutputIntent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // registryName()const
        QUrl cppResult = const_cast<const ::QPdfOutputIntent *>(cppSelf)->registryName();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfOutputIntentFunc_setOutputCondition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfOutputIntent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfOutputIntent::setOutputCondition(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setOutputCondition(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOutputCondition", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOutputCondition(QString)
            cppSelf->setOutputCondition(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPdfOutputIntentFunc_setOutputConditionIdentifier(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfOutputIntent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfOutputIntent::setOutputConditionIdentifier(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setOutputConditionIdentifier(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOutputConditionIdentifier", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOutputConditionIdentifier(QString)
            cppSelf->setOutputConditionIdentifier(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPdfOutputIntentFunc_setOutputProfile(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfOutputIntent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfOutputIntent::setOutputProfile(QColorSpace)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), (pyArg)))) {
        overloadId = 0; // setOutputProfile(QColorSpace)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOutputProfile", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColorSpace cppArg0_local;
        ::QColorSpace *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setOutputProfile(QColorSpace)
            cppSelf->setOutputProfile(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPdfOutputIntentFunc_setRegistryName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfOutputIntent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfOutputIntent::setRegistryName(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setRegistryName(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRegistryName", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRegistryName(QUrl)
            cppSelf->setRegistryName(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPdfOutputIntentFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfOutputIntent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfOutputIntent::swap(QPdfOutputIntent&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QPdfOutputIntent&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPdfOutputIntent cppArg0_local;
        ::QPdfOutputIntent *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QPdfOutputIntent&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPdfOutputIntent__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPdfOutputIntent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPdfOutputIntent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPdfOutputIntent_methods[] = {
    {"outputCondition", reinterpret_cast<PyCFunction>(Sbk_QPdfOutputIntentFunc_outputCondition), METH_NOARGS, nullptr},
    {"outputConditionIdentifier", reinterpret_cast<PyCFunction>(Sbk_QPdfOutputIntentFunc_outputConditionIdentifier), METH_NOARGS, nullptr},
    {"outputProfile", reinterpret_cast<PyCFunction>(Sbk_QPdfOutputIntentFunc_outputProfile), METH_NOARGS, nullptr},
    {"registryName", reinterpret_cast<PyCFunction>(Sbk_QPdfOutputIntentFunc_registryName), METH_NOARGS, nullptr},
    {"setOutputCondition", reinterpret_cast<PyCFunction>(Sbk_QPdfOutputIntentFunc_setOutputCondition), METH_O, nullptr},
    {"setOutputConditionIdentifier", reinterpret_cast<PyCFunction>(Sbk_QPdfOutputIntentFunc_setOutputConditionIdentifier), METH_O, nullptr},
    {"setOutputProfile", reinterpret_cast<PyCFunction>(Sbk_QPdfOutputIntentFunc_setOutputProfile), METH_O, nullptr},
    {"setRegistryName", reinterpret_cast<PyCFunction>(Sbk_QPdfOutputIntentFunc_setRegistryName), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QPdfOutputIntentFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QPdfOutputIntent__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QPdfOutputIntent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPdfOutputIntent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPdfOutputIntent_Type = nullptr;
static PyTypeObject *Sbk_QPdfOutputIntent_TypeF(void)
{
    return _Sbk_QPdfOutputIntent_Type;
}

static PyType_Slot Sbk_QPdfOutputIntent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPdfOutputIntent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPdfOutputIntent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPdfOutputIntent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPdfOutputIntent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPdfOutputIntent_spec = {
    "2:PySide6.QtGui.QPdfOutputIntent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPdfOutputIntent_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPdfOutputIntent_PythonToCpp_QPdfOutputIntent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPdfOutputIntent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPdfOutputIntent_PythonToCpp_QPdfOutputIntent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPdfOutputIntent_TypeF()))
        return QPdfOutputIntent_PythonToCpp_QPdfOutputIntent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPdfOutputIntent_PTR_CppToPython_QPdfOutputIntent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QPdfOutputIntent_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QPdfOutputIntent_COPY_CppToPython_QPdfOutputIntent(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QPdfOutputIntent *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QPdfOutputIntent_TypeF(), new ::QPdfOutputIntent(*source), true, true);
}

// Python to C++ copy conversion.
static void QPdfOutputIntent_PythonToCpp_QPdfOutputIntent_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPdfOutputIntent *>(cppOut) = *reinterpret_cast< ::QPdfOutputIntent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QPdfOutputIntent_PythonToCpp_QPdfOutputIntent_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QPdfOutputIntent_TypeF()))
        return QPdfOutputIntent_PythonToCpp_QPdfOutputIntent_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPdfOutputIntent_SignatureStrings[] = {
    "1:PySide6.QtGui.QPdfOutputIntent(self)",
    "0:PySide6.QtGui.QPdfOutputIntent(self,other:PySide6.QtGui.QPdfOutputIntent)",
    "PySide6.QtGui.QPdfOutputIntent.outputCondition(self)->QString",
    "PySide6.QtGui.QPdfOutputIntent.outputConditionIdentifier(self)->QString",
    "PySide6.QtGui.QPdfOutputIntent.outputProfile(self)->PySide6.QtGui.QColorSpace",
    "PySide6.QtGui.QPdfOutputIntent.registryName(self)->PySide6.QtCore.QUrl",
    "PySide6.QtGui.QPdfOutputIntent.setOutputCondition(self,condition:QString)",
    "PySide6.QtGui.QPdfOutputIntent.setOutputConditionIdentifier(self,identifier:QString)",
    "PySide6.QtGui.QPdfOutputIntent.setOutputProfile(self,profile:typing.Union[PySide6.QtGui.QColorSpace, PySide6.QtGui.QColorSpace.NamedColorSpace])",
    "PySide6.QtGui.QPdfOutputIntent.setRegistryName(self,name:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtGui.QPdfOutputIntent.swap(self,other:PySide6.QtGui.QPdfOutputIntent)",
    "PySide6.QtGui.QPdfOutputIntent.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QPdfOutputIntent_SignatureByteSize = 242;
static constexpr uint8_t QPdfOutputIntent_SignatureBytes[242] = {
    0x78, 0xda, 0xad, 0x52, 0xb1, 0x6e, 0x83, 0x40, 0x0c, 0xdd, 0xf9, 0x8a, 0x8c, 0x45, 0xba, 0x9e,
    0x9a, 0xa5, 0x03, 0x43, 0x17, 0x86, 0x2a, 0x4b, 0x03, 0x41, 0x99, 0xaa, 0x0a, 0x21, 0xce, 0xa4,
    0x96, 0xe8, 0xf9, 0x64, 0x8c, 0x2a, 0xfe, 0xbe, 0xd7, 0x06, 0xd2, 0x0a, 0x85, 0x02, 0x55, 0xb7,
    0x7b, 0x67, 0xfb, 0xf9, 0xf9, 0xd9, 0xdb, 0x28, 0xe9, 0x32, 0x34, 0x70, 0xaf, 0x53, 0x79, 0x6c,
    0x51, 0xa7, 0x89, 0xa9, 0xf6, 0xad, 0xb8, 0x56, 0x76, 0x56, 0xc0, 0xca, 0x4d, 0x03, 0x75, 0x15,
    0x06, 0x77, 0x4b, 0xd2, 0x14, 0xc9, 0x2b, 0xf0, 0x4c, 0x66, 0x18, 0xfc, 0x1e, 0xd7, 0xf4, 0x05,
    0x62, 0xb2, 0x06, 0x05, 0xc9, 0x9e, 0x05, 0xdc, 0x3e, 0xa4, 0x99, 0x30, 0xda, 0xd3, 0xca, 0xea,
    0x9d, 0xf1, 0x9f, 0x58, 0x21, 0xf0, 0x9f, 0x78, 0x12, 0xa6, 0x0a, 0x6b, 0x18, 0x6a, 0x47, 0x35,
    0x31, 0xd5, 0xc4, 0x99, 0x2b, 0x4a, 0x98, 0x63, 0x63, 0x38, 0x61, 0x23, 0xdc, 0x3d, 0x15, 0x6f,
    0x57, 0xc8, 0x62, 0x62, 0xd0, 0xe9, 0x91, 0xeb, 0x39, 0x9a, 0x06, 0x64, 0x7f, 0xc5, 0x1d, 0x55,
    0x0e, 0x30, 0xea, 0xa7, 0x0b, 0xd7, 0x33, 0x8d, 0x9c, 0x52, 0x78, 0xc1, 0xeb, 0x49, 0x7f, 0xda,
    0xa6, 0xdc, 0x19, 0x44, 0xd2, 0x39, 0x4f, 0xa2, 0x8f, 0xd6, 0x37, 0x7b, 0x9e, 0x74, 0x52, 0x6d,
    0x26, 0x43, 0xfa, 0xd3, 0x3d, 0xf3, 0x8d, 0x5f, 0x96, 0x08, 0x3a, 0x8c, 0x9d, 0x57, 0xd6, 0xbf,
    0xa6, 0xc4, 0x5c, 0x36, 0xa1, 0x36, 0xfd, 0xd0, 0x0b, 0x9a, 0xbc, 0x17, 0xee, 0x1f, 0xcf, 0x3f,
    0xcf, 0x4b, 0x72, 0x5d, 0x9e, 0x0f, 0x67, 0xd2, 0x2b, 0xcd, 0x3c, 0x0a, 0x3e, 0x00, 0xa0, 0x0e,
    0x59, 0x93
};
#endif

PyTypeObject *init_QPdfOutputIntent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX].type;

    Shiboken::AutoDecRef Sbk_QPdfOutputIntent_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPdfOutputIntent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPdfOutputIntent",
        "QPdfOutputIntent",
        &Sbk_QPdfOutputIntent_spec,
        &Shiboken::callCppDestructor< ::QPdfOutputIntent >,
        Sbk_QPdfOutputIntent_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QPdfOutputIntent_TypeF(); // references _Sbk_QPdfOutputIntent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPdfOutputIntent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPdfOutputIntent_SignatureBytes, QPdfOutputIntent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPdfOutputIntent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QPdfOutputIntent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPdfOutputIntent_PythonToCpp_QPdfOutputIntent_PTR,
        is_QPdfOutputIntent_PythonToCpp_QPdfOutputIntent_PTR_Convertible,
        QPdfOutputIntent_PTR_CppToPython_QPdfOutputIntent,
        QPdfOutputIntent_COPY_CppToPython_QPdfOutputIntent);

    Shiboken::Conversions::registerConverterName(converter, "QPdfOutputIntent");
    Shiboken::Conversions::registerConverterName(converter, "QPdfOutputIntent*");
    Shiboken::Conversions::registerConverterName(converter, "QPdfOutputIntent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPdfOutputIntent).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QPdfOutputIntent_PythonToCpp_QPdfOutputIntent_COPY,
        is_QPdfOutputIntent_PythonToCpp_QPdfOutputIntent_COPY_Convertible);

    qRegisterMetaType< ::QPdfOutputIntent >("QPdfOutputIntent");

    return pyType;
}
