// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QPointerEventWrapper_H
#define SBK_QPointerEventWrapper_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qevent.h>

class QPointerEventWrapper : public QPointerEvent
{
public:
    QPointerEventWrapper(const QPointerEventWrapper &) = delete;
    QPointerEventWrapper& operator=(const QPointerEventWrapper &) = delete;
    QPointerEventWrapper(QPointerEventWrapper &&) = delete;
    QPointerEventWrapper& operator=(QPointerEventWrapper &&) = delete;

    QPointerEventWrapper(::QEvent::Type type, const ::QPointingDevice * dev, ::QFlags<Qt::KeyboardModifier> modifiers = Qt::NoModifier, const ::QList<QEventPoint> & points = {});
    QPointerEventWrapper(const QPointerEvent& self) : QPointerEvent(self)
    {
    }

    ::QPointerEvent * clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted) override;
    void setTimestamp(quint64 timestamp) override;
    ~QPointerEventWrapper() override;
    static void pysideInitQtMetaTypes();
    void resetPyMethodCache();
private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QPointerEventWrapper_H

