// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qquaternion_wrapper.h"

// Argument includes
#include <QtGui/qgenericmatrix.h>
#include <QtGui/qquaternion.h>
#include <QtGui/qvectornd.h>
#include <qdatastream.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuaternion_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuaternion >()))
        return -1;

    ::QQuaternion *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 3)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    if (PyArg_UnpackTuple(args, "QQuaternion", 0, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQuaternion::QQuaternion()
    // 1: QQuaternion::QQuaternion(QVector4D)
    // 2: QQuaternion::QQuaternion(float,QVector3D)
    // 3: QQuaternion::QQuaternion(float,float,float,float)
    if (numArgs == 0) {
        overloadId = 0; // QQuaternion()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))) {
        if (numArgs == 4
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
            overloadId = 3; // QQuaternion(float,float,float,float)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QQuaternion(float,QVector3D)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QQuaternion(QVector4D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QQuaternion()
        {

            // QQuaternion()
            cptr = new ::QQuaternion();
            break;
        }
        case 1: // QQuaternion(const QVector4D &vector)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QVector4D cppArg0_local;
            ::QVector4D *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QQuaternion(QVector4D)
                cptr = new ::QQuaternion(*cppArg0);
            }
            break;
        }
        case 2: // QQuaternion(float scalar, const QVector3D &vector)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QVector3D cppArg1_local;
            ::QVector3D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QQuaternion(float,QVector3D)
                cptr = new ::QQuaternion(cppArg0, *cppArg1);
            }
            break;
        }
        case 3: // QQuaternion(float scalar, float xpos, float ypos, float zpos)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QQuaternion(float,float,float,float)
                cptr = new ::QQuaternion(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QQuaternion >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQuaternionFunc___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __reduce__()
        // Begin code injection
        // TEMPLATE - reduce_code - START
        pyResult = Py_BuildValue("(N(dddd))", PyObject_Type(self), cppSelf->scalar(), cppSelf->x(), cppSelf->y(), cppSelf->z());
        // TEMPLATE - reduce_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - repr_code - START
        QString format = QString::asprintf("%s(%f, %f, %f, %f)",
            Py_TYPE(self)->tp_name, cppSelf->scalar(), cppSelf->x(), cppSelf->y(), cppSelf->z());
        pyResult = Shiboken::String::fromCString(qPrintable(format));
        // TEMPLATE - repr_code - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_conjugated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // conjugated()const
        QQuaternion cppResult = const_cast<const ::QQuaternion *>(cppSelf)->conjugated();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_dotProduct(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "dotProduct", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QQuaternion::dotProduct(QQuaternion,QQuaternion)->float
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArgs[1])))) {
        overloadId = 0; // dotProduct(QQuaternion,QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dotProduct", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QQuaternion cppArg0_local;
        ::QQuaternion *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QQuaternion cppArg1_local;
        ::QQuaternion *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // dotProduct(QQuaternion,QQuaternion)
            float cppResult = ::QQuaternion::dotProduct(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_fromAxes(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "fromAxes", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QQuaternion::fromAxes(QVector3D,QVector3D,QVector3D)->QQuaternion
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[2])))) {
        overloadId = 0; // fromAxes(QVector3D,QVector3D,QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromAxes", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QVector3D cppArg1_local;
        ::QVector3D *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QVector3D cppArg2_local;
        ::QVector3D *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // fromAxes(QVector3D,QVector3D,QVector3D)
            QQuaternion cppResult = ::QQuaternion::fromAxes(*cppArg0, *cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_fromAxisAndAngle(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 3)
        return Shiboken::returnWrongArguments(args, "fromAxisAndAngle", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    if (PyArg_UnpackTuple(args, "fromAxisAndAngle", 2, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QQuaternion::fromAxisAndAngle(QVector3D,float)->QQuaternion
    // 1: static QQuaternion::fromAxisAndAngle(float,float,float,float)->QQuaternion
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 1; // fromAxisAndAngle(float,float,float,float)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // fromAxisAndAngle(QVector3D,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromAxisAndAngle", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // fromAxisAndAngle(const QVector3D &axis, float angle)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QVector3D cppArg0_local;
            ::QVector3D *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromAxisAndAngle(QVector3D,float)
                QQuaternion cppResult = ::QQuaternion::fromAxisAndAngle(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
            }
            break;
        }
        case 1: // fromAxisAndAngle(float x, float y, float z, float angle)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromAxisAndAngle(float,float,float,float)
                QQuaternion cppResult = ::QQuaternion::fromAxisAndAngle(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_fromDirection(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "fromDirection", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QQuaternion::fromDirection(QVector3D,QVector3D)->QQuaternion
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))) {
        overloadId = 0; // fromDirection(QVector3D,QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromDirection", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QVector3D cppArg1_local;
        ::QVector3D *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // fromDirection(QVector3D,QVector3D)
            QQuaternion cppResult = ::QQuaternion::fromDirection(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_fromEulerAngles(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments(args, "fromEulerAngles", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    if (PyArg_UnpackTuple(args, "fromEulerAngles", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QQuaternion::fromEulerAngles(QVector3D)->QQuaternion
    // 1: static QQuaternion::fromEulerAngles(float,float,float)->QQuaternion
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 1; // fromEulerAngles(float,float,float)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))) {
        overloadId = 0; // fromEulerAngles(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromEulerAngles", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // fromEulerAngles(const QVector3D &eulerAngles)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QVector3D cppArg0_local;
            ::QVector3D *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // fromEulerAngles(QVector3D)
                QQuaternion cppResult = ::QQuaternion::fromEulerAngles(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
            }
            break;
        }
        case 1: // fromEulerAngles(float pitch, float yaw, float roll)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromEulerAngles(float,float,float)
                QQuaternion cppResult = ::QQuaternion::fromEulerAngles(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_fromRotationMatrix(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QQuaternion::fromRotationMatrix(QMatrix3x3)->QQuaternion
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x3_IDX]), (pyArg)))) {
        overloadId = 0; // fromRotationMatrix(QMatrix3x3)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromRotationMatrix", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMatrix3x3 cppArg0_local;
        ::QMatrix3x3 *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // fromRotationMatrix(QMatrix3x3)
            QQuaternion cppResult = ::QQuaternion::fromRotationMatrix(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_getAxes(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "getAxes", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuaternion::getAxes(QVector3D*,QVector3D*,QVector3D*)const
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[2])))) {
        overloadId = 0; // getAxes(QVector3D*,QVector3D*,QVector3D*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "getAxes", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVector3D *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QVector3D *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QVector3D *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // getAxes(QVector3D*,QVector3D*,QVector3D*)const
            const_cast<const ::QQuaternion *>(cppSelf)->getAxes(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuaternionFunc_getAxisAndAngle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getAxisAndAngle(QVector3D*,float*)const
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qquaternion-getaxisandangle-vector3d-float)]
            QVector3D outVec{};
            float angle{};
            cppSelf->getAxisAndAngle(&outVec, &angle);
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &outVec));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &angle));
            // END of custom code block [file: ../glue/qtgui.cpp (qquaternion-getaxisandangle-vector3d-float)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_getEulerAngles(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getEulerAngles(float*,float*,float*)const
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qquaternion-geteulerangles)]
            float pitch{}, yaw{}, roll{};
            cppSelf->getEulerAngles(&pitch, &yaw, &roll);
            pyResult = PyTuple_New(3);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &pitch));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &yaw));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &roll));
            // END of custom code block [file: ../glue/qtgui.cpp (qquaternion-geteulerangles)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_inverted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // inverted()const
        QQuaternion cppResult = const_cast<const ::QQuaternion *>(cppSelf)->inverted();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_isIdentity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isIdentity()const
        bool cppResult = const_cast<const ::QQuaternion *>(cppSelf)->isIdentity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QQuaternion *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // length()const
        float cppResult = const_cast<const ::QQuaternion *>(cppSelf)->length();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_lengthSquared(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lengthSquared()const
        float cppResult = const_cast<const ::QQuaternion *>(cppSelf)->lengthSquared();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_nlerp(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "nlerp", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QQuaternion::nlerp(QQuaternion,QQuaternion,float)->QQuaternion
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // nlerp(QQuaternion,QQuaternion,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "nlerp", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QQuaternion cppArg0_local;
        ::QQuaternion *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QQuaternion cppArg1_local;
        ::QQuaternion *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // nlerp(QQuaternion,QQuaternion,float)
            QQuaternion cppResult = ::QQuaternion::nlerp(*cppArg0, *cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_normalize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // normalize()
        cppSelf->normalize();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuaternionFunc_normalized(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // normalized()const
        QQuaternion cppResult = const_cast<const ::QQuaternion *>(cppSelf)->normalized();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_rotatedVector(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuaternion::rotatedVector(QVector3D)const->QVector3D
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // rotatedVector(QVector3D)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rotatedVector", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // rotatedVector(QVector3D)const
            QVector3D cppResult = const_cast<const ::QQuaternion *>(cppSelf)->rotatedVector(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_rotationTo(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "rotationTo", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QQuaternion::rotationTo(QVector3D,QVector3D)->QQuaternion
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))) {
        overloadId = 0; // rotationTo(QVector3D,QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rotationTo", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QVector3D cppArg1_local;
        ::QVector3D *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // rotationTo(QVector3D,QVector3D)
            QQuaternion cppResult = ::QQuaternion::rotationTo(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_scalar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scalar()const
        float cppResult = const_cast<const ::QQuaternion *>(cppSelf)->scalar();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_setScalar(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuaternion::setScalar(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setScalar(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setScalar", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setScalar(float)
            cppSelf->setScalar(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuaternionFunc_setVector(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments(args, "setVector", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    if (PyArg_UnpackTuple(args, "setVector", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuaternion::setVector(QVector3D)
    // 1: QQuaternion::setVector(float,float,float)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 1; // setVector(float,float,float)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setVector(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setVector", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setVector(const QVector3D &vector)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QVector3D cppArg0_local;
            ::QVector3D *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setVector(QVector3D)
                cppSelf->setVector(*cppArg0);
            }
            break;
        }
        case 1: // setVector(float x, float y, float z)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setVector(float,float,float)
                cppSelf->setVector(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuaternionFunc_setX(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuaternion::setX(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setX(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setX", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setX(float)
            cppSelf->setX(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuaternionFunc_setY(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuaternion::setY(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setY(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setY", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setY(float)
            cppSelf->setY(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuaternionFunc_setZ(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuaternion::setZ(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setZ(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setZ", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setZ(float)
            cppSelf->setZ(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuaternionFunc_slerp(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "slerp", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QQuaternion::slerp(QQuaternion,QQuaternion,float)->QQuaternion
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // slerp(QQuaternion,QQuaternion,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "slerp", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QQuaternion cppArg0_local;
        ::QQuaternion *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QQuaternion cppArg1_local;
        ::QQuaternion *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // slerp(QQuaternion,QQuaternion,float)
            QQuaternion cppResult = ::QQuaternion::slerp(*cppArg0, *cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_toEulerAngles(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toEulerAngles()const
        QVector3D cppResult = const_cast<const ::QQuaternion *>(cppSelf)->toEulerAngles();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_toRotationMatrix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toRotationMatrix()const
        QMatrix3x3 cppResult = const_cast<const ::QQuaternion *>(cppSelf)->toRotationMatrix();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x3_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_toVector4D(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toVector4D()const
        QVector4D cppResult = const_cast<const ::QQuaternion *>(cppSelf)->toVector4D();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_vector(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vector()const
        QVector3D cppResult = const_cast<const ::QQuaternion *>(cppSelf)->vector();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_x(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // x()const
        float cppResult = const_cast<const ::QQuaternion *>(cppSelf)->x();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_y(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // y()const
        float cppResult = const_cast<const ::QQuaternion *>(cppSelf)->y();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc_z(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // z()const
        float cppResult = const_cast<const ::QQuaternion *>(cppSelf)->z();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternion__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQuaternion_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuaternion_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc___reduce__), METH_NOARGS, nullptr},
    {"conjugated", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_conjugated), METH_NOARGS, nullptr},
    {"dotProduct", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_dotProduct), METH_VARARGS|METH_STATIC, nullptr},
    {"fromAxes", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_fromAxes), METH_VARARGS|METH_STATIC, nullptr},
    {"fromAxisAndAngle", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_fromAxisAndAngle), METH_VARARGS|METH_STATIC, nullptr},
    {"fromDirection", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_fromDirection), METH_VARARGS|METH_STATIC, nullptr},
    {"fromEulerAngles", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_fromEulerAngles), METH_VARARGS|METH_STATIC, nullptr},
    {"fromRotationMatrix", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_fromRotationMatrix), METH_O|METH_STATIC, nullptr},
    {"getAxes", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_getAxes), METH_VARARGS, nullptr},
    {"getAxisAndAngle", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_getAxisAndAngle), METH_NOARGS, nullptr},
    {"getEulerAngles", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_getEulerAngles), METH_NOARGS, nullptr},
    {"inverted", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_inverted), METH_NOARGS, nullptr},
    {"isIdentity", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_isIdentity), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_isNull), METH_NOARGS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_length), METH_NOARGS, nullptr},
    {"lengthSquared", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_lengthSquared), METH_NOARGS, nullptr},
    {"nlerp", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_nlerp), METH_VARARGS|METH_STATIC, nullptr},
    {"normalize", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_normalize), METH_NOARGS, nullptr},
    {"normalized", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_normalized), METH_NOARGS, nullptr},
    {"rotatedVector", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_rotatedVector), METH_O, nullptr},
    {"rotationTo", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_rotationTo), METH_VARARGS|METH_STATIC, nullptr},
    {"scalar", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_scalar), METH_NOARGS, nullptr},
    {"setScalar", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_setScalar), METH_O, nullptr},
    {"setVector", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_setVector), METH_VARARGS, nullptr},
    {"setX", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_setX), METH_O, nullptr},
    {"setY", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_setY), METH_O, nullptr},
    {"setZ", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_setZ), METH_O, nullptr},
    {"slerp", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_slerp), METH_VARARGS|METH_STATIC, nullptr},
    {"toEulerAngles", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_toEulerAngles), METH_NOARGS, nullptr},
    {"toRotationMatrix", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_toRotationMatrix), METH_NOARGS, nullptr},
    {"toVector4D", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_toVector4D), METH_NOARGS, nullptr},
    {"vector", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_vector), METH_NOARGS, nullptr},
    {"x", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_x), METH_NOARGS, nullptr},
    {"y", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_y), METH_NOARGS, nullptr},
    {"z", reinterpret_cast<PyCFunction>(Sbk_QQuaternionFunc_z), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QQuaternion__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQuaternion___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

static PyObject *Sbk_QQuaternionFunc___mul__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuaternion::operator*(QQuaternion)->QQuaternion
    // 1: QQuaternion::operator*(float)->QQuaternion
    // 2: QQuaternion::operator*(float)->QQuaternion
    if (isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 2; // operator*(float,QQuaternion)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 1; // operator*(QQuaternion,float)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArg)))) {
        overloadId = 0; // operator*(QQuaternion,QQuaternion)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator*", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // operator*(const QQuaternion &q2)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QQuaternion cppArg0_local;
            ::QQuaternion *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QQuaternion,QQuaternion)
                QQuaternion cppResult = (*cppSelf) * (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
            }
            break;
        }
        case 1: // operator*(float factor)
        {
            float cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QQuaternion,float)
                QQuaternion cppResult = (*cppSelf) * cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
            }
            break;
        }
        case 2: // operator*(float factor)
        {
            float cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(float,QQuaternion) [reverse operator]
                QQuaternion cppResult = cppArg0 * (*cppSelf);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc___imul__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuaternion::operator*=(QQuaternion)->QQuaternion&
    // 1: QQuaternion::operator*=(float)->QQuaternion&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 1; // operator*=(float)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArg)))) {
        overloadId = 0; // operator*=(QQuaternion)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator*=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // operator*=(const QQuaternion &quaternion)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QQuaternion cppArg0_local;
            ::QQuaternion *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*=(QQuaternion)
                (*cppSelf) *= (*cppArg0);
            }
            break;
        }
        case 1: // operator*=(float factor)
        {
            float cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*=(float)
                (*cppSelf) *= cppArg0;
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QQuaternionFunc___add__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuaternion::operator+(QQuaternion)->QQuaternion
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArg)))) {
        overloadId = 0; // operator+(QQuaternion,QQuaternion)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuaternion cppArg0_local;
        ::QQuaternion *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+(QQuaternion,QQuaternion)
            QQuaternion cppResult = (*cppSelf) + (*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuaternion::operator+=(QQuaternion)->QQuaternion&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArg)))) {
        overloadId = 0; // operator+=(QQuaternion)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuaternion cppArg0_local;
        ::QQuaternion *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+=(QQuaternion)
            (*cppSelf) += (*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QQuaternionFunc___neg__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // operator-(QQuaternion)
        QQuaternion cppResult = - (*cppSelf);
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc___sub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuaternion::operator-(QQuaternion)->QQuaternion
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArg)))) {
        overloadId = 0; // operator-(QQuaternion,QQuaternion)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuaternion cppArg0_local;
        ::QQuaternion *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator-(QQuaternion,QQuaternion)
            QQuaternion cppResult = (*cppSelf) - (*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc___isub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuaternion::operator-=(QQuaternion)->QQuaternion&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArg)))) {
        overloadId = 0; // operator-=(QQuaternion)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuaternion cppArg0_local;
        ::QQuaternion *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator-=(QQuaternion)
            (*cppSelf) -= (*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QQuaternionFunc___div__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuaternion::operator/(float)->QQuaternion
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // operator/(QQuaternion,float)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator/", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator/(QQuaternion,float)
            QQuaternion cppResult = (*cppSelf) / cppArg0;
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QQuaternion::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QQuaternion)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QQuaternion) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternionFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QQuaternion::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QQuaternion&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QQuaternion&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QQuaternion_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArg)))) {
                // operator!=(const QQuaternion &q2)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QQuaternion cppArg0_local;
                ::QQuaternion *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArg)))) {
                // operator==(const QQuaternion &q2)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QQuaternion cppArg0_local;
                ::QQuaternion *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QQuaternion_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuaternion_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuaternion_Type = nullptr;
static PyTypeObject *Sbk_QQuaternion_TypeF(void)
{
    return _Sbk_QQuaternion_Type;
}

static PyType_Slot Sbk_QQuaternion_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QQuaternionFunc___repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuaternion_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuaternion_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QQuaternion_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuaternion_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuaternion_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QQuaternionFunc___iadd__)},
    {Py_nb_subtract,    reinterpret_cast<void *>(Sbk_QQuaternionFunc___sub__)},
    {Py_nb_inplace_multiply,reinterpret_cast<void *>(Sbk_QQuaternionFunc___imul__)},
    {Py_nb_multiply,    reinterpret_cast<void *>(Sbk_QQuaternionFunc___mul__)},
    {Py_nb_negative,    reinterpret_cast<void *>(Sbk_QQuaternionFunc___neg__)},
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QQuaternion___nb_bool)},
    {Py_nb_inplace_subtract,reinterpret_cast<void *>(Sbk_QQuaternionFunc___isub__)},
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QQuaternionFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QQuaternionFunc___rshift__)},
    {Py_nb_true_divide, reinterpret_cast<void *>(Sbk_QQuaternionFunc___div__)},
    {Py_nb_add,         reinterpret_cast<void *>(Sbk_QQuaternionFunc___add__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuaternion_spec = {
    "2:PySide6.QtGui.QQuaternion",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuaternion_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQuaternion_PythonToCpp_QQuaternion_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuaternion_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQuaternion_PythonToCpp_QQuaternion_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuaternion_TypeF()))
        return QQuaternion_PythonToCpp_QQuaternion_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQuaternion_PTR_CppToPython_QQuaternion(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QQuaternion_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QQuaternion_COPY_CppToPython_QQuaternion(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QQuaternion *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QQuaternion_TypeF(), new ::QQuaternion(*source), true, true);
}

// Python to C++ copy conversion.
static void QQuaternion_PythonToCpp_QQuaternion_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QQuaternion *>(cppOut) = *reinterpret_cast< ::QQuaternion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QQuaternion_PythonToCpp_QQuaternion_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QQuaternion_TypeF()))
        return QQuaternion_PythonToCpp_QQuaternion_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQuaternion_SignatureStrings[] = {
    "3:PySide6.QtGui.QQuaternion(self)",
    "2:PySide6.QtGui.QQuaternion(self,vector:PySide6.QtGui.QVector4D)",
    "1:PySide6.QtGui.QQuaternion(self,scalar:float,vector:PySide6.QtGui.QVector3D)",
    "0:PySide6.QtGui.QQuaternion(self,scalar:float,xpos:float,ypos:float,zpos:float)",
    "PySide6.QtGui.QQuaternion.__reduce__(self)->str",
    "PySide6.QtGui.QQuaternion.__repr__(self)->str",
    "PySide6.QtGui.QQuaternion.conjugated(self)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.dotProduct(q1:PySide6.QtGui.QQuaternion,q2:PySide6.QtGui.QQuaternion)->float",
    "PySide6.QtGui.QQuaternion.fromAxes(xAxis:PySide6.QtGui.QVector3D,yAxis:PySide6.QtGui.QVector3D,zAxis:PySide6.QtGui.QVector3D)->PySide6.QtGui.QQuaternion",
    "1:PySide6.QtGui.QQuaternion.fromAxisAndAngle(axis:PySide6.QtGui.QVector3D,angle:float)->PySide6.QtGui.QQuaternion",
    "0:PySide6.QtGui.QQuaternion.fromAxisAndAngle(x:float,y:float,z:float,angle:float)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.fromDirection(direction:PySide6.QtGui.QVector3D,up:PySide6.QtGui.QVector3D)->PySide6.QtGui.QQuaternion",
    "1:PySide6.QtGui.QQuaternion.fromEulerAngles(eulerAngles:PySide6.QtGui.QVector3D)->PySide6.QtGui.QQuaternion",
    "0:PySide6.QtGui.QQuaternion.fromEulerAngles(pitch:float,yaw:float,roll:float)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.fromRotationMatrix(rot3x3:PySide6.QtGui.QMatrix3x3)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.getAxes(self,xAxis:PySide6.QtGui.QVector3D,yAxis:PySide6.QtGui.QVector3D,zAxis:PySide6.QtGui.QVector3D)",
    "PySide6.QtGui.QQuaternion.getAxisAndAngle(self)->Tuple[PySide6.QtGui.QVector3D, float]",
    "PySide6.QtGui.QQuaternion.getEulerAngles(self)->Tuple[float, float, float]",
    "PySide6.QtGui.QQuaternion.inverted(self)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.isIdentity(self)->bool",
    "PySide6.QtGui.QQuaternion.isNull(self)->bool",
    "PySide6.QtGui.QQuaternion.length(self)->float",
    "PySide6.QtGui.QQuaternion.lengthSquared(self)->float",
    "PySide6.QtGui.QQuaternion.nlerp(q1:PySide6.QtGui.QQuaternion,q2:PySide6.QtGui.QQuaternion,t:float)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.normalize(self)",
    "PySide6.QtGui.QQuaternion.normalized(self)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.rotatedVector(self,vector:PySide6.QtGui.QVector3D)->PySide6.QtGui.QVector3D",
    "PySide6.QtGui.QQuaternion.rotationTo(from:PySide6.QtGui.QVector3D,to:PySide6.QtGui.QVector3D)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.scalar(self)->float",
    "PySide6.QtGui.QQuaternion.setScalar(self,scalar:float)",
    "1:PySide6.QtGui.QQuaternion.setVector(self,vector:PySide6.QtGui.QVector3D)",
    "0:PySide6.QtGui.QQuaternion.setVector(self,x:float,y:float,z:float)",
    "PySide6.QtGui.QQuaternion.setX(self,x:float)",
    "PySide6.QtGui.QQuaternion.setY(self,y:float)",
    "PySide6.QtGui.QQuaternion.setZ(self,z:float)",
    "PySide6.QtGui.QQuaternion.slerp(q1:PySide6.QtGui.QQuaternion,q2:PySide6.QtGui.QQuaternion,t:float)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.toEulerAngles(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtGui.QQuaternion.toRotationMatrix(self)->PySide6.QtGui.QMatrix3x3",
    "PySide6.QtGui.QQuaternion.toVector4D(self)->PySide6.QtGui.QVector4D",
    "PySide6.QtGui.QQuaternion.vector(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtGui.QQuaternion.x(self)->float",
    "PySide6.QtGui.QQuaternion.y(self)->float",
    "PySide6.QtGui.QQuaternion.z(self)->float",
    "PySide6.QtGui.QQuaternion.__copy__(self)->typing.Self",
    "2:PySide6.QtGui.QQuaternion.__mul__(self,q2:PySide6.QtGui.QQuaternion)->PySide6.QtGui.QQuaternion",
    "1:PySide6.QtGui.QQuaternion.__mul__(self,factor:float)->PySide6.QtGui.QQuaternion",
    "0:PySide6.QtGui.QQuaternion.__mul__(self,factor:float)->PySide6.QtGui.QQuaternion",
    "1:PySide6.QtGui.QQuaternion.__imul__(self,quaternion:PySide6.QtGui.QQuaternion)->PySide6.QtGui.QQuaternion",
    "0:PySide6.QtGui.QQuaternion.__imul__(self,factor:float)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.__add__(self,q2:PySide6.QtGui.QQuaternion)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.__iadd__(self,quaternion:PySide6.QtGui.QQuaternion)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.__neg__(self)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.__sub__(self,q2:PySide6.QtGui.QQuaternion)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.__isub__(self,quaternion:PySide6.QtGui.QQuaternion)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.__div__(self,divisor:float)->PySide6.QtGui.QQuaternion",
    "PySide6.QtGui.QQuaternion.__lshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QQuaternion.__rshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QQuaternion.__ne__(self,q2:PySide6.QtGui.QQuaternion)->bool",
    "PySide6.QtGui.QQuaternion.__eq__(self,q2:PySide6.QtGui.QQuaternion)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QQuaternion_SignatureByteSize = 673;
static constexpr uint8_t QQuaternion_SignatureBytes[673] = {
    0x78, 0xda, 0xc5, 0x58, 0x4d, 0x8f, 0xda, 0x30, 0x10, 0xbd, 0xf3, 0x2b, 0xf6, 0x18, 0x24, 0x8a,
    0x68, 0x59, 0xf5, 0xb0, 0x87, 0x4a, 0xa8, 0x54, 0x55, 0x0f, 0xad, 0x96, 0xb2, 0xaa, 0xda, 0xad,
    0xaa, 0xc8, 0x9b, 0x98, 0xe0, 0xca, 0xd8, 0xc1, 0x9e, 0xd0, 0x84, 0x5f, 0x5f, 0xe7, 0x8b, 0x04,
    0x44, 0x26, 0x4e, 0x22, 0xda, 0x53, 0x0c, 0x7e, 0x7e, 0x6f, 0x3c, 0x5f, 0x19, 0x98, 0x3f, 0x3c,
    0x26, 0x6b, 0xe6, 0xd3, 0xb7, 0xd3, 0x15, 0x7c, 0x8c, 0xd8, 0x74, 0xb5, 0x8a, 0x08, 0x50, 0x25,
    0x98, 0x14, 0x8e, 0xa6, 0x7c, 0x33, 0x1e, 0xbd, 0x69, 0x41, 0x4c, 0x0e, 0xd4, 0x03, 0xa9, 0x2e,
    0x51, 0xdf, 0xb2, 0x6f, 0xef, 0x97, 0xe3, 0xd1, 0xeb, 0x36, 0x02, 0xed, 0x11, 0x4e, 0xd4, 0xc3,
    0x86, 0x4b, 0x02, 0x28, 0xdb, 0xdc, 0xb0, 0xcd, 0x3a, 0xb1, 0xc5, 0xa1, 0xd4, 0xc5, 0x32, 0xa9,
    0x96, 0xc7, 0xd3, 0x72, 0x3c, 0x6a, 0x64, 0x9b, 0xba, 0xae, 0xa2, 0x7e, 0xe4, 0x51, 0xd7, 0xcd,
    0x3d, 0xf1, 0xea, 0x9d, 0x06, 0xd5, 0x82, 0x0f, 0x95, 0x2d, 0xda, 0x93, 0xe2, 0x77, 0x14, 0x98,
    0x8f, 0x7e, 0x89, 0x6f, 0xc4, 0x22, 0x2c, 0xbe, 0x84, 0x47, 0x25, 0x8d, 0x95, 0xe0, 0xec, 0x11,
    0x3f, 0x4f, 0xf6, 0x48, 0x14, 0x8d, 0x74, 0xe6, 0x0b, 0x44, 0x66, 0xa3, 0xe4, 0x6e, 0x11, 0x53,
    0xed, 0xc4, 0x8b, 0x98, 0xe9, 0xa6, 0xe0, 0x4c, 0x12, 0x74, 0xf7, 0x88, 0xed, 0xa2, 0xf7, 0x47,
    0x6e, 0x56, 0x98, 0xc6, 0xf4, 0x42, 0xf8, 0x0b, 0x11, 0x70, 0xea, 0x10, 0xcc, 0x06, 0x92, 0x42,
    0x8a, 0xd0, 0x63, 0x8a, 0xb3, 0x2e, 0x8a, 0x71, 0x99, 0x61, 0x65, 0x7a, 0x15, 0x4f, 0x5b, 0x31,
    0x5c, 0x6a, 0xc9, 0x94, 0xb1, 0x3e, 0x4d, 0x6f, 0xbf, 0x5c, 0x35, 0x5e, 0x2f, 0x0a, 0x6f, 0xe2,
    0xdf, 0x0f, 0x11, 0xa7, 0x2a, 0xbb, 0xab, 0x76, 0x68, 0xb5, 0xee, 0xa5, 0x35, 0xeb, 0xa0, 0x15,
    0x32, 0xf0, 0xb6, 0xa5, 0x73, 0xc9, 0x9f, 0x62, 0xa5, 0x24, 0xe7, 0x83, 0xbd, 0xfa, 0x55, 0x02,
    0x49, 0x5d, 0xf9, 0x99, 0x80, 0x62, 0xb1, 0xa3, 0x24, 0xcc, 0xe3, 0xf9, 0xa5, 0x69, 0xf9, 0xa6,
    0xd9, 0xe8, 0x29, 0x14, 0x50, 0xc8, 0xaa, 0x26, 0xeb, 0x4b, 0xb7, 0x2b, 0x9d, 0x36, 0x0b, 0x6a,
    0xa9, 0x5a, 0xb4, 0x9a, 0xa7, 0x28, 0xe4, 0xf4, 0x67, 0x93, 0xda, 0x5d, 0xe6, 0xdc, 0x5f, 0x38,
    0x6d, 0x3d, 0x4e, 0x67, 0xac, 0x79, 0x90, 0xee, 0xea, 0x0f, 0x8c, 0x8a, 0x89, 0x03, 0x55, 0x03,
    0xbb, 0x20, 0xd3, 0x9f, 0x7c, 0x2a, 0x80, 0x41, 0x52, 0xb2, 0xbc, 0x48, 0xc9, 0xd1, 0x03, 0x5f,
    0x22, 0xce, 0x2d, 0xc1, 0x9c, 0x8a, 0x00, 0xb6, 0x25, 0xb8, 0xad, 0x55, 0xe6, 0xe8, 0xf5, 0x3e,
    0x22, 0xaa, 0xba, 0x54, 0xdb, 0x21, 0x61, 0x7c, 0x19, 0xf6, 0xef, 0xe0, 0x13, 0x18, 0x54, 0x0f,
    0x42, 0xaa, 0x1d, 0xe1, 0xec, 0x58, 0xa4, 0x87, 0x0d, 0x72, 0x50, 0xb8, 0x54, 0x5a, 0x7b, 0xd4,
    0xcf, 0xf3, 0xad, 0x7d, 0x86, 0xb8, 0xd6, 0x50, 0xca, 0x9d, 0x36, 0x15, 0xb3, 0x78, 0x92, 0x4e,
    0x5a, 0xf0, 0x8d, 0xb5, 0x05, 0xb2, 0x57, 0x1f, 0x6b, 0x16, 0xce, 0x07, 0x10, 0xdb, 0xd0, 0x6b,
    0x0a, 0xeb, 0xea, 0xc0, 0xd9, 0xf4, 0x82, 0x8e, 0x4e, 0xe9, 0xc1, 0x0e, 0x1e, 0x44, 0xfb, 0xee,
    0x05, 0x55, 0xc3, 0xfb, 0x6c, 0x8c, 0xdf, 0xe2, 0xfb, 0xd9, 0xe1, 0x16, 0xf0, 0x8f, 0x1c, 0x9c,
    0x58, 0x81, 0x9f, 0x73, 0xb0, 0x8d, 0x19, 0xff, 0xb5, 0x8e, 0x40, 0x5e, 0x69, 0x8a, 0xdd, 0x13,
    0x17, 0xe4, 0xc5, 0xcb, 0xe9, 0x3a, 0xd3, 0xe9, 0xe5, 0x84, 0x52, 0x95, 0x63, 0x38, 0x6a, 0xce,
    0x3d, 0x66, 0xce, 0xa1, 0xca, 0x8c, 0x5e, 0xd7, 0x89, 0x6d, 0x2b, 0x21, 0xb1, 0x05, 0x1e, 0x6d,
    0x81, 0xae, 0xeb, 0xc9, 0x30, 0xa9, 0x26, 0x72, 0x48, 0x42, 0x26, 0x82, 0xe9, 0xda, 0x7c, 0xc2,
    0x7e, 0xd6, 0x98, 0x73, 0xbb, 0x88, 0x17, 0xc7, 0xda, 0x46, 0xe7, 0x7e, 0x53, 0xd5, 0x99, 0xc2,
    0x86, 0x64, 0xa5, 0x3b, 0x6c, 0x2a, 0xed, 0xc7, 0x88, 0xdb, 0xc8, 0xea, 0x6e, 0x38, 0x6d, 0xf4,
    0x74, 0xc7, 0xcc, 0x5a, 0xca, 0xda, 0x7a, 0x8c, 0x90, 0xf8, 0xfe, 0xe0, 0x08, 0xa2, 0x06, 0xd7,
    0x05, 0x86, 0xfa, 0x06, 0x13, 0x12, 0x34, 0xa8, 0x32, 0xb8, 0x1f, 0x85, 0x8e, 0x5e, 0x6e, 0xeb,
    0x8b, 0xba, 0xc0, 0x2d, 0x7d, 0xe1, 0xb3, 0x43, 0xa9, 0x63, 0x96, 0x4c, 0x0f, 0xce, 0x12, 0xae,
    0xb7, 0x6c, 0x03, 0x25, 0x27, 0x51, 0xc6, 0xd5, 0xf5, 0x92, 0x78, 0x2f, 0x15, 0x9d, 0xae, 0x96,
    0x04, 0xc8, 0x1a, 0x14, 0x25, 0xbb, 0x33, 0x9d, 0xcb, 0x4d, 0xfc, 0xaf, 0x81, 0x7f, 0x25, 0x24,
    0xa8, 0x65, 0xa8, 0x5b, 0xa6, 0x5e, 0xd7, 0xa5, 0xfb, 0x2e, 0x4c, 0x7f, 0x01, 0xb5, 0x1d, 0x88,
    0x70
};
#endif

PyTypeObject *init_QQuaternion(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuaternion_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQuaternion_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQuaternion",
        "QQuaternion",
        &Sbk_QQuaternion_spec,
        &Shiboken::callCppDestructor< ::QQuaternion >,
        Sbk_QQuaternion_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QQuaternion_TypeF(); // references _Sbk_QQuaternion_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQuaternion_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQuaternion_SignatureBytes, QQuaternion_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuaternion_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQuaternion_PythonToCpp_QQuaternion_PTR,
        is_QQuaternion_PythonToCpp_QQuaternion_PTR_Convertible,
        QQuaternion_PTR_CppToPython_QQuaternion,
        QQuaternion_COPY_CppToPython_QQuaternion);

    Shiboken::Conversions::registerConverterName(converter, "QQuaternion");
    Shiboken::Conversions::registerConverterName(converter, "QQuaternion*");
    Shiboken::Conversions::registerConverterName(converter, "QQuaternion&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuaternion).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QQuaternion_PythonToCpp_QQuaternion_COPY,
        is_QQuaternion_PythonToCpp_QQuaternion_COPY_Convertible);

    qRegisterMetaType< ::QQuaternion >("QQuaternion");

    return pyType;
}
