// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrawfont_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qfont.h>
#include <QtGui/qfontdatabase.h>
#include <QtGui/qimage.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qrawfont.h>
#include <QtGui/qtransform.h>
#include <qbytearray.h>
#include <qchar.h>
#include <qpoint.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRawFont_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRawFont >()))
        return -1;

    ::QRawFont *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:QRawFont", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRawFont::QRawFont()
    // 1: QRawFont::QRawFont(QByteArray,qreal,QFont::HintingPreference=)
    // 2: QRawFont::QRawFont(QRawFont)
    // 3: QRawFont::QRawFont(QString,qreal,QFont::HintingPreference=)
    if (numArgs == 0) {
        overloadId = 0; // QRawFont()
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 3; // QRawFont(QString,qreal,QFont::HintingPreference)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_HintingPreference_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 3; // QRawFont(QString,qreal,QFont::HintingPreference)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QRawFont(QRawFont)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // QRawFont(QByteArray,qreal,QFont::HintingPreference)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_HintingPreference_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 1; // QRawFont(QByteArray,qreal,QFont::HintingPreference)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRawFont()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
            }

            // QRawFont()
            cptr = new ::QRawFont();
            break;
        }
        case 1: // QRawFont(const QByteArray &fontData, qreal pixelSize, QFont::HintingPreference hintingPreference)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_hintingPreference = Shiboken::String::createStaticString("hintingPreference");
                if (PyDict_Contains(kwds, key_hintingPreference) != 0) {
                    value = PyDict_GetItem(kwds, key_hintingPreference);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_hintingPreference);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_HintingPreference_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_hintingPreference);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFont::HintingPreference cppArg2(QFont::PreferDefaultHinting);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRawFont(QByteArray,qreal,QFont::HintingPreference)
                cptr = new ::QRawFont(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 2: // QRawFont(const QRawFont &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRawFont cppArg0_local;
            ::QRawFont *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QRawFont(QRawFont)
                cptr = new ::QRawFont(*cppArg0);
            }
            break;
        }
        case 3: // QRawFont(const QString &fileName, qreal pixelSize, QFont::HintingPreference hintingPreference)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_hintingPreference = Shiboken::String::createStaticString("hintingPreference");
                if (PyDict_Contains(kwds, key_hintingPreference) != 0) {
                    value = PyDict_GetItem(kwds, key_hintingPreference);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_hintingPreference);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_HintingPreference_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_hintingPreference);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFont::HintingPreference cppArg2(QFont::PreferDefaultHinting);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRawFont(QString,qreal,QFont::HintingPreference)
                cptr = new ::QRawFont(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRawFont >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRawFontFunc_advancesForGlyphIndexes(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "advancesForGlyphIndexes", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRawFont::advancesForGlyphIndexes(QList<quint32>)const->QList<QPointF>
    // 1: QRawFont::advancesForGlyphIndexes(QList<quint32>,QFlags<QRawFont::LayoutFlag>)const->QList<QPointF>
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_quint32_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // advancesForGlyphIndexes(QList<quint32>)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRawFont_LayoutFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 1; // advancesForGlyphIndexes(QList<quint32>,QFlags<QRawFont::LayoutFlag>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "advancesForGlyphIndexes", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // advancesForGlyphIndexes(const QList<quint32> &glyphIndexes) const
        {
            ::QList<quint32> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // advancesForGlyphIndexes(QList<quint32>)const
                QList<QPointF> cppResult = const_cast<const ::QRawFont *>(cppSelf)->advancesForGlyphIndexes(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPointF_IDX], &cppResult);
            }
            break;
        }
        case 1: // advancesForGlyphIndexes(const QList<quint32> &glyphIndexes, QFlags<QRawFont::LayoutFlag> layoutFlags) const
        {
            ::QList<quint32> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QRawFont::LayoutFlag> cppArg1 = QFlags<QRawFont::LayoutFlag>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // advancesForGlyphIndexes(QList<quint32>,QFlags<QRawFont::LayoutFlag>)const
                QList<QPointF> cppResult = const_cast<const ::QRawFont *>(cppSelf)->advancesForGlyphIndexes(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPointF_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_alphaMapForGlyph(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "alphaMapForGlyph", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:alphaMapForGlyph", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRawFont::alphaMapForGlyph(quint32,QRawFont::AntialiasingType=,const QTransform&=)const->QImage
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // alphaMapForGlyph(quint32,QRawFont::AntialiasingType,QTransform)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_AntialiasingType_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // alphaMapForGlyph(quint32,QRawFont::AntialiasingType,QTransform)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[2])))) {
                overloadId = 0; // alphaMapForGlyph(quint32,QRawFont::AntialiasingType,QTransform)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "alphaMapForGlyph", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_antialiasingType = Shiboken::String::createStaticString("antialiasingType");
            if (PyDict_Contains(kwds, key_antialiasingType) != 0) {
                value = PyDict_GetItem(kwds, key_antialiasingType);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_antialiasingType);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "alphaMapForGlyph", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_AntialiasingType_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "alphaMapForGlyph", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_antialiasingType);
            }
            static PyObject *const key_transform = Shiboken::String::createStaticString("transform");
            if (PyDict_Contains(kwds, key_transform) != 0) {
                value = PyDict_GetItem(kwds, key_transform);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_transform);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "alphaMapForGlyph", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "alphaMapForGlyph", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_transform);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "alphaMapForGlyph", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
            }
        }
        quint32 cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QRawFont::AntialiasingType cppArg1(QRawFont::AntialiasingType::SubPixelAntialiasing);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QTransform cppArg2_local = QTransform();
        ::QTransform *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // alphaMapForGlyph(quint32,QRawFont::AntialiasingType,QTransform)const
            QImage cppResult = const_cast<const ::QRawFont *>(cppSelf)->alphaMapForGlyph(cppArg0, cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_ascent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ascent()const
        qreal cppResult = const_cast<const ::QRawFont *>(cppSelf)->ascent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_averageCharWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // averageCharWidth()const
        qreal cppResult = const_cast<const ::QRawFont *>(cppSelf)->averageCharWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_boundingRect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRawFont::boundingRect(quint32)const->QRectF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 0; // boundingRect(quint32)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    // Call function/method
    {
        quint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // boundingRect(quint32)const
            QRectF cppResult = const_cast<const ::QRawFont *>(cppSelf)->boundingRect(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_capHeight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // capHeight()const
        qreal cppResult = const_cast<const ::QRawFont *>(cppSelf)->capHeight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_descent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // descent()const
        qreal cppResult = const_cast<const ::QRawFont *>(cppSelf)->descent();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_familyName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // familyName()const
        QString cppResult = const_cast<const ::QRawFont *>(cppSelf)->familyName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_fontTable(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRawFont::fontTable(QFont::Tag)const->QByteArray
    // 1: QRawFont::fontTable(const char*)const->QByteArray
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 1; // fontTable(const char*)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArg)))) {
        overloadId = 0; // fontTable(QFont::Tag)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fontTable", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // fontTable(QFont::Tag tag) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QFont::Tag cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fontTable(QFont::Tag)const
                QByteArray cppResult = const_cast<const ::QRawFont *>(cppSelf)->fontTable(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 1: // fontTable(const char *tagName) const
        {
            const char* cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fontTable(const char*)const
                QByteArray cppResult = const_cast<const ::QRawFont *>(cppSelf)->fontTable(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_fromFont(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromFont", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fromFont", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRawFont::fromFont(QFont,QFontDatabase::WritingSystem=)->QRawFont
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromFont(QFont,QFontDatabase::WritingSystem)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontDatabase_WritingSystem_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // fromFont(QFont,QFontDatabase::WritingSystem)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromFont", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_writingSystem = Shiboken::String::createStaticString("writingSystem");
            if (PyDict_Contains(kwds, key_writingSystem) != 0) {
                value = PyDict_GetItem(kwds, key_writingSystem);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_writingSystem);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromFont", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontDatabase_WritingSystem_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "fromFont", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_writingSystem);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromFont", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QFontDatabase::WritingSystem cppArg1(QFontDatabase::Any);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromFont(QFont,QFontDatabase::WritingSystem)
            QRawFont cppResult = ::QRawFont::fromFont(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_glyphIndexesForString(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRawFont::glyphIndexesForString(QString)const->QList<quint32>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // glyphIndexesForString(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glyphIndexesForString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glyphIndexesForString(QString)const
            QList<quint32> cppResult = const_cast<const ::QRawFont *>(cppSelf)->glyphIndexesForString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_quint32_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_hintingPreference(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hintingPreference()const
        QFont::HintingPreference cppResult = const_cast<const ::QRawFont *>(cppSelf)->hintingPreference();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_HintingPreference_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QRawFont *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_leading(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // leading()const
        qreal cppResult = const_cast<const ::QRawFont *>(cppSelf)->leading();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_lineThickness(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lineThickness()const
        qreal cppResult = const_cast<const ::QRawFont *>(cppSelf)->lineThickness();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_loadFromData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "loadFromData", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRawFont::loadFromData(QByteArray,qreal,QFont::HintingPreference)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_HintingPreference_IDX])))->converter, (pyArgs[2])))) {
        overloadId = 0; // loadFromData(QByteArray,qreal,QFont::HintingPreference)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "loadFromData", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QFont::HintingPreference cppArg2{QFont::PreferDefaultHinting};
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // loadFromData(QByteArray,qreal,QFont::HintingPreference)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->loadFromData(*cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRawFontFunc_loadFromFile(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "loadFromFile", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRawFont::loadFromFile(QString,qreal,QFont::HintingPreference)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_HintingPreference_IDX])))->converter, (pyArgs[2])))) {
        overloadId = 0; // loadFromFile(QString,qreal,QFont::HintingPreference)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "loadFromFile", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QFont::HintingPreference cppArg2{QFont::PreferDefaultHinting};
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // loadFromFile(QString,qreal,QFont::HintingPreference)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->loadFromFile(cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRawFontFunc_maxCharWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxCharWidth()const
        qreal cppResult = const_cast<const ::QRawFont *>(cppSelf)->maxCharWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_pathForGlyph(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRawFont::pathForGlyph(quint32)const->QPainterPath
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 0; // pathForGlyph(quint32)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "pathForGlyph", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    // Call function/method
    {
        quint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // pathForGlyph(quint32)const
            QPainterPath cppResult = const_cast<const ::QRawFont *>(cppSelf)->pathForGlyph(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_pixelSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pixelSize()const
        qreal cppResult = const_cast<const ::QRawFont *>(cppSelf)->pixelSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_setPixelSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRawFont::setPixelSize(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setPixelSize(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPixelSize", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPixelSize(qreal)
            cppSelf->setPixelSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRawFontFunc_style(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // style()const
        QFont::Style cppResult = const_cast<const ::QRawFont *>(cppSelf)->style();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Style_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_styleName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // styleName()const
        QString cppResult = const_cast<const ::QRawFont *>(cppSelf)->styleName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_supportedWritingSystems(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedWritingSystems()const
        QList<QFontDatabase::WritingSystem> cppResult = const_cast<const ::QRawFont *>(cppSelf)->supportedWritingSystems();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QFontDatabase_WritingSystem_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_supportsCharacter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRawFont::supportsCharacter(QChar)const->bool
    // 1: QRawFont::supportsCharacter(uint)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 1; // supportsCharacter(uint)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArg)))) {
        overloadId = 0; // supportsCharacter(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "supportsCharacter", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // supportsCharacter(QChar character) const
        {
            ::QChar cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // supportsCharacter(QChar)const
                bool cppResult = const_cast<const ::QRawFont *>(cppSelf)->supportsCharacter(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // supportsCharacter(uint ucs4) const
        {
            uint cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // supportsCharacter(uint)const
                bool cppResult = const_cast<const ::QRawFont *>(cppSelf)->supportsCharacter(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRawFont::swap(QRawFont&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QRawFont&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRawFont cppArg0_local;
        ::QRawFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QRawFont&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRawFontFunc_underlinePosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // underlinePosition()const
        qreal cppResult = const_cast<const ::QRawFont *>(cppSelf)->underlinePosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_unitsPerEm(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unitsPerEm()const
        qreal cppResult = const_cast<const ::QRawFont *>(cppSelf)->unitsPerEm();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_weight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // weight()const
        int cppResult = const_cast<const ::QRawFont *>(cppSelf)->weight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFontFunc_xHeight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // xHeight()const
        qreal cppResult = const_cast<const ::QRawFont *>(cppSelf)->xHeight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRawFont__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRawFont_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRawFont_EnumFlagInfo[] = {
    "AntialiasingType:Enum",
    "LayoutFlag:Flag:LayoutFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRawFont_methods[] = {
    {"advancesForGlyphIndexes", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_advancesForGlyphIndexes), METH_VARARGS, nullptr},
    {"alphaMapForGlyph", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_alphaMapForGlyph), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"ascent", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_ascent), METH_NOARGS, nullptr},
    {"averageCharWidth", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_averageCharWidth), METH_NOARGS, nullptr},
    {"boundingRect", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_boundingRect), METH_O, nullptr},
    {"capHeight", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_capHeight), METH_NOARGS, nullptr},
    {"descent", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_descent), METH_NOARGS, nullptr},
    {"familyName", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_familyName), METH_NOARGS, nullptr},
    {"fontTable", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_fontTable), METH_O, nullptr},
    {"fromFont", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_fromFont), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"glyphIndexesForString", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_glyphIndexesForString), METH_O, nullptr},
    {"hintingPreference", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_hintingPreference), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_isValid), METH_NOARGS, nullptr},
    {"leading", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_leading), METH_NOARGS, nullptr},
    {"lineThickness", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_lineThickness), METH_NOARGS, nullptr},
    {"loadFromData", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_loadFromData), METH_VARARGS, nullptr},
    {"loadFromFile", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_loadFromFile), METH_VARARGS, nullptr},
    {"maxCharWidth", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_maxCharWidth), METH_NOARGS, nullptr},
    {"pathForGlyph", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_pathForGlyph), METH_O, nullptr},
    {"pixelSize", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_pixelSize), METH_NOARGS, nullptr},
    {"setPixelSize", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_setPixelSize), METH_O, nullptr},
    {"style", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_style), METH_NOARGS, nullptr},
    {"styleName", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_styleName), METH_NOARGS, nullptr},
    {"supportedWritingSystems", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_supportedWritingSystems), METH_NOARGS, nullptr},
    {"supportsCharacter", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_supportsCharacter), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_swap), METH_O, nullptr},
    {"underlinePosition", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_underlinePosition), METH_NOARGS, nullptr},
    {"unitsPerEm", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_unitsPerEm), METH_NOARGS, nullptr},
    {"weight", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_weight), METH_NOARGS, nullptr},
    {"xHeight", reinterpret_cast<PyCFunction>(Sbk_QRawFontFunc_xHeight), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QRawFont__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QRawFont_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), (pyArg)))) {
                // operator!=(const QRawFont &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRawFont cppArg0_local;
                ::QRawFont *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), (pyArg)))) {
                // operator==(const QRawFont &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRawFont cppArg0_local;
                ::QRawFont *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QRawFont_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QRawFont_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRawFont_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRawFont_Type = nullptr;
static PyTypeObject *Sbk_QRawFont_TypeF(void)
{
    return _Sbk_QRawFont_Type;
}

static PyType_Slot Sbk_QRawFont_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QRawFont_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRawFont_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRawFont_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QRawFont_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRawFont_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRawFont_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRawFont_spec = {
    "2:PySide6.QtGui.QRawFont",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRawFont_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QRawFont_AntialiasingType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRawFont::AntialiasingType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRawFont::AntialiasingType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRawFont_AntialiasingType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_AntialiasingType_IDX])))
        return Enum_PythonToCpp_QRawFont_AntialiasingType;
    return {};
}

static PyObject *QRawFont_AntialiasingType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRawFont::AntialiasingType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRawFont::AntialiasingType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_AntialiasingType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRawFont_LayoutFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRawFont::LayoutFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRawFont::LayoutFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRawFont_LayoutFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_LayoutFlag_IDX])))
        return Enum_PythonToCpp_QRawFont_LayoutFlag;
    return {};
}

static PyObject *QRawFont_LayoutFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRawFont::LayoutFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRawFont::LayoutFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_LayoutFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QRawFont_LayoutFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QRawFont::LayoutFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QRawFont::LayoutFlag> *>(cppOut) = value;

}

static PyObject *QRawFont_LayoutFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QRawFont::LayoutFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_LayoutFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRawFont_PythonToCpp_QRawFont_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRawFont_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRawFont_PythonToCpp_QRawFont_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRawFont_TypeF()))
        return QRawFont_PythonToCpp_QRawFont_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRawFont_PTR_CppToPython_QRawFont(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QRawFont_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QRawFont_COPY_CppToPython_QRawFont(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QRawFont *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QRawFont_TypeF(), new ::QRawFont(*source), true, true);
}

// Python to C++ copy conversion.
static void QRawFont_PythonToCpp_QRawFont_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRawFont *>(cppOut) = *reinterpret_cast< ::QRawFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QRawFont_PythonToCpp_QRawFont_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QRawFont_TypeF()))
        return QRawFont_PythonToCpp_QRawFont_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRawFont_SignatureStrings[] = {
    "3:PySide6.QtGui.QRawFont(self)",
    "2:PySide6.QtGui.QRawFont(self,fontData:typing.Union[PySide6.QtCore.QByteArray, char*],pixelSize:qreal,hintingPreference:PySide6.QtGui.QFont.HintingPreference=QFont.PreferDefaultHinting)",
    "1:PySide6.QtGui.QRawFont(self,other:PySide6.QtGui.QRawFont)",
    "0:PySide6.QtGui.QRawFont(self,fileName:QString,pixelSize:qreal,hintingPreference:PySide6.QtGui.QFont.HintingPreference=QFont.PreferDefaultHinting)",
    "1:PySide6.QtGui.QRawFont.advancesForGlyphIndexes(self,glyphIndexes:QList[quint32])->QList[PySide6.QtCore.QPointF]",
    "0:PySide6.QtGui.QRawFont.advancesForGlyphIndexes(self,glyphIndexes:QList[quint32],layoutFlags:PySide6.QtGui.QRawFont.LayoutFlag)->QList[PySide6.QtCore.QPointF]",
    "PySide6.QtGui.QRawFont.alphaMapForGlyph(self,glyphIndex:quint32,antialiasingType:PySide6.QtGui.QRawFont.AntialiasingType=QRawFont.AntialiasingType.SubPixelAntialiasing,transform:PySide6.QtGui.QTransform=QTransform())->PySide6.QtGui.QImage",
    "PySide6.QtGui.QRawFont.ascent(self)->qreal",
    "PySide6.QtGui.QRawFont.averageCharWidth(self)->qreal",
    "PySide6.QtGui.QRawFont.boundingRect(self,glyphIndex:quint32)->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QRawFont.capHeight(self)->qreal",
    "PySide6.QtGui.QRawFont.descent(self)->qreal",
    "PySide6.QtGui.QRawFont.familyName(self)->QString",
    "1:PySide6.QtGui.QRawFont.fontTable(self,tag:PySide6.QtGui.QFont.Tag)->PySide6.QtCore.QByteArray",
    "0:PySide6.QtGui.QRawFont.fontTable(self,tagName:char*)->PySide6.QtCore.QByteArray",
    "PySide6.QtGui.QRawFont.fromFont(font:typing.Union[PySide6.QtGui.QFont, QString, QStringList],writingSystem:PySide6.QtGui.QFontDatabase.WritingSystem=QFontDatabase.Any)->PySide6.QtGui.QRawFont",
    "PySide6.QtGui.QRawFont.glyphIndexesForString(self,text:QString)->QList[quint32]",
    "PySide6.QtGui.QRawFont.hintingPreference(self)->PySide6.QtGui.QFont.HintingPreference",
    "PySide6.QtGui.QRawFont.isValid(self)->bool",
    "PySide6.QtGui.QRawFont.leading(self)->qreal",
    "PySide6.QtGui.QRawFont.lineThickness(self)->qreal",
    "PySide6.QtGui.QRawFont.loadFromData(self,fontData:typing.Union[PySide6.QtCore.QByteArray, char*],pixelSize:qreal,hintingPreference:PySide6.QtGui.QFont.HintingPreference)",
    "PySide6.QtGui.QRawFont.loadFromFile(self,fileName:QString,pixelSize:qreal,hintingPreference:PySide6.QtGui.QFont.HintingPreference)",
    "PySide6.QtGui.QRawFont.maxCharWidth(self)->qreal",
    "PySide6.QtGui.QRawFont.pathForGlyph(self,glyphIndex:quint32)->PySide6.QtGui.QPainterPath",
    "PySide6.QtGui.QRawFont.pixelSize(self)->qreal",
    "PySide6.QtGui.QRawFont.setPixelSize(self,pixelSize:qreal)",
    "PySide6.QtGui.QRawFont.style(self)->PySide6.QtGui.QFont.Style",
    "PySide6.QtGui.QRawFont.styleName(self)->QString",
    "PySide6.QtGui.QRawFont.supportedWritingSystems(self)->QList[PySide6.QtGui.QFontDatabase.WritingSystem]",
    "1:PySide6.QtGui.QRawFont.supportsCharacter(self,character:QChar)->bool",
    "0:PySide6.QtGui.QRawFont.supportsCharacter(self,ucs4:uint)->bool",
    "PySide6.QtGui.QRawFont.swap(self,other:PySide6.QtGui.QRawFont)",
    "PySide6.QtGui.QRawFont.underlinePosition(self)->qreal",
    "PySide6.QtGui.QRawFont.unitsPerEm(self)->qreal",
    "PySide6.QtGui.QRawFont.weight(self)->int",
    "PySide6.QtGui.QRawFont.xHeight(self)->qreal",
    "PySide6.QtGui.QRawFont.__copy__(self)->typing.Self",
    "PySide6.QtGui.QRawFont.__ne__(self,other:PySide6.QtGui.QRawFont)->bool",
    "PySide6.QtGui.QRawFont.__eq__(self,other:PySide6.QtGui.QRawFont)->bool",
    "PySide6.QtGui.QRawFont.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QRawFont_SignatureByteSize = 730;
static constexpr uint8_t QRawFont_SignatureBytes[730] = {
    0x78, 0xda, 0xcd, 0x56, 0x51, 0x4f, 0xdb, 0x30, 0x10, 0x7e, 0xe7, 0x57, 0xf0, 0x48, 0xa7, 0x10,
    0x31, 0x98, 0xf6, 0x10, 0xa9, 0x48, 0x0c, 0x56, 0x40, 0x62, 0x53, 0x4a, 0xba, 0xf1, 0x80, 0xaa,
    0xea, 0x9a, 0x5c, 0x1b, 0x6b, 0x8e, 0x1d, 0x6c, 0x87, 0x36, 0xfb, 0xf5, 0xb3, 0x9b, 0xb8, 0xb4,
    0x29, 0x4e, 0xc3, 0xb4, 0x69, 0x7b, 0x4b, 0x7d, 0xdf, 0x9d, 0xbf, 0x3b, 0xdf, 0x7d, 0xd7, 0xb3,
    0x20, 0x2c, 0x23, 0x92, 0xe0, 0x47, 0x7f, 0xa8, 0xae, 0x0b, 0xe2, 0x0f, 0xef, 0x61, 0x31, 0xe0,
    0x4c, 0x1d, 0x49, 0xa4, 0xb3, 0xde, 0xc1, 0x69, 0x9b, 0xd9, 0x9b, 0xe9, 0xaf, 0x2b, 0x50, 0x10,
    0xa8, 0x32, 0x27, 0x6c, 0xee, 0x7f, 0x63, 0x84, 0xb3, 0xc7, 0x17, 0x8f, 0x4b, 0x2e, 0xd0, 0x1f,
    0x7e, 0x2a, 0x15, 0x5e, 0x08, 0x01, 0xa5, 0x77, 0x18, 0xa7, 0x20, 0xde, 0x8d, 0xbd, 0x9c, 0x2c,
    0x91, 0x46, 0xe4, 0x27, 0x06, 0x4f, 0x02, 0x81, 0x7a, 0x29, 0x61, 0x4a, 0xfb, 0x87, 0x02, 0x67,
    0x28, 0x90, 0xc5, 0xd8, 0xbc, 0xd5, 0x5c, 0xe9, 0xdf, 0x34, 0x51, 0xfd, 0xea, 0xbc, 0x3a, 0xb8,
    0xc2, 0x19, 0x14, 0x54, 0xd5, 0xa0, 0xde, 0xc1, 0xfb, 0x56, 0xe6, 0x5c, 0xa5, 0x28, 0x1c, 0x88,
    0xde, 0xc1, 0x49, 0x7b, 0xd6, 0x84, 0xe2, 0x57, 0xc8, 0x30, 0x18, 0x46, 0x4a, 0xe8, 0xbb, 0xfe,
    0x69, 0x3a, 0x3e, 0x24, 0xcf, 0xa0, 0x9d, 0xe5, 0x80, 0x8b, 0x6b, 0x5a, 0xe6, 0xe9, 0x2d, 0x4b,
    0x70, 0x89, 0xb2, 0xa2, 0x3a, 0xdf, 0x38, 0x09, 0x86, 0x77, 0x44, 0xaa, 0xc7, 0xa7, 0x42, 0x87,
    0x3c, 0x3b, 0x1d, 0xf7, 0x8e, 0xcf, 0xab, 0x83, 0xe6, 0x73, 0x85, 0x5c, 0x03, 0x06, 0x63, 0x67,
    0x11, 0x7e, 0xfb, 0x46, 0x8f, 0x42, 0xc9, 0x0b, 0x35, 0xa0, 0x30, 0x97, 0xae, 0xd8, 0x77, 0x6b,
    0xc8, 0x5e, 0x7e, 0x2e, 0x76, 0x34, 0x4f, 0xe1, 0x0b, 0xe4, 0x96, 0x5d, 0x93, 0x56, 0x50, 0xd3,
    0xf1, 0x40, 0x57, 0x16, 0x28, 0x01, 0xa9, 0xeb, 0x3b, 0x2a, 0x73, 0x74, 0x51, 0xba, 0x68, 0xe0,
    0xfa, 0x4e, 0x8b, 0x1f, 0x15, 0xd3, 0xd0, 0xf4, 0xc2, 0xa6, 0xc1, 0x53, 0x02, 0x98, 0x9c, 0x71,
    0x91, 0x35, 0x2f, 0x18, 0x59, 0x43, 0xff, 0xe5, 0xf3, 0xa8, 0xa7, 0xf3, 0x6e, 0xe0, 0x6e, 0x33,
    0x98, 0xa3, 0x33, 0x5d, 0x19, 0xa3, 0x9d, 0xd6, 0xe3, 0xf3, 0x55, 0xff, 0x39, 0xa1, 0xcf, 0x28,
    0x74, 0xa4, 0x4b, 0x3d, 0x83, 0x0f, 0x24, 0x51, 0x69, 0x27, 0xa7, 0x29, 0x2f, 0x58, 0xa2, 0xd3,
    0xb8, 0xc7, 0x58, 0xb9, 0x4a, 0xb9, 0x45, 0xb9, 0x7a, 0x24, 0x03, 0x1f, 0xb8, 0x62, 0xc6, 0x90,
    0xdf, 0x20, 0x99, 0xa7, 0xdd, 0x68, 0x27, 0xd8, 0x3d, 0xc5, 0x19, 0x64, 0x84, 0x96, 0x66, 0x38,
    0x2d, 0xbc, 0x9e, 0x51, 0xf7, 0xfc, 0x18, 0x0d, 0x1b, 0xc1, 0x94, 0x56, 0x1e, 0x9e, 0x82, 0xf9,
    0xab, 0xd3, 0x3a, 0x5a, 0x75, 0xa4, 0x53, 0xda, 0xdc, 0xd3, 0xb2, 0x1b, 0x7f, 0xa5, 0x1d, 0x2b,
    0x25, 0x6c, 0x8d, 0xe8, 0x8a, 0x27, 0x78, 0xb6, 0xd2, 0x22, 0x13, 0xd8, 0x25, 0xbc, 0x6b, 0xde,
    0xde, 0xa1, 0x15, 0x29, 0xfb, 0x61, 0x66, 0x6a, 0xec, 0x2d, 0x04, 0x31, 0xba, 0x12, 0x95, 0x52,
    0x61, 0xf6, 0x5a, 0xc2, 0x46, 0xd6, 0xa7, 0x20, 0xd1, 0x7f, 0xd8, 0x44, 0xf6, 0xb7, 0x6d, 0x17,
    0xac, 0xdc, 0x6d, 0xd7, 0x9a, 0xa8, 0x8b, 0xff, 0xa6, 0x40, 0xe8, 0x19, 0xad, 0x48, 0xd5, 0xb5,
    0xc1, 0xa5, 0xb2, 0xa2, 0xba, 0x1e, 0x7f, 0xab, 0x1e, 0xae, 0x78, 0x3b, 0x62, 0x6b, 0x5f, 0xbe,
    0x93, 0xe6, 0xba, 0xa2, 0x12, 0xf9, 0x5d, 0x0f, 0x70, 0x62, 0x63, 0x4d, 0x39, 0x77, 0xf6, 0x1c,
    0x45, 0x48, 0x6c, 0x0a, 0xfb, 0xfa, 0x93, 0x12, 0x86, 0xa3, 0x94, 0xc4, 0x3f, 0x18, 0x4a, 0xd9,
    0xcd, 0x83, 0x43, 0x32, 0xd0, 0x4f, 0x6e, 0x6a, 0xfe, 0x5f, 0x2c, 0xdd, 0xde, 0x3e, 0xa6, 0x03,
    0x62, 0x7b, 0xfd, 0x6f, 0x2d, 0x4a, 0x27, 0x85, 0x0c, 0x96, 0x6f, 0x53, 0xb7, 0x1c, 0x54, 0xba,
    0x6f, 0x51, 0xec, 0xb6, 0x52, 0x08, 0xda, 0x80, 0x22, 0xd4, 0xce, 0xce, 0xc0, 0x36, 0xd3, 0x4e,
    0x34, 0x24, 0xaa, 0x70, 0xcb, 0xa1, 0x59, 0x29, 0x67, 0xc6, 0x52, 0x95, 0xb4, 0xb5, 0xe3, 0x23,
    0x03, 0x68, 0xf5, 0x7e, 0x4d, 0x2d, 0x5d, 0xf8, 0x22, 0xcf, 0xb9, 0x50, 0x98, 0x6c, 0x89, 0xc2,
    0xba, 0x91, 0x9b, 0xfb, 0x7a, 0x8f, 0x98, 0x8c, 0xdd, 0xa2, 0x5c, 0x5f, 0x24, 0xcd, 0x6b, 0x42,
    0xac, 0x6b, 0x5d, 0x55, 0x25, 0xb6, 0x3f, 0x83, 0xa1, 0xb1, 0xd8, 0xc1, 0x3c, 0x79, 0x63, 0x98,
    0x22, 0x96, 0x1f, 0x02, 0xf3, 0xb8, 0x7b, 0x26, 0x5b, 0x2e, 0x20, 0xef, 0xf2, 0x77, 0xd1, 0xe1,
    0xae, 0x17, 0x27, 0x0a, 0x33, 0xf1, 0x21, 0x97, 0x3a, 0x6d, 0xce, 0x3a, 0xf5, 0x42, 0xc1, 0x88,
    0x92, 0x21, 0x8a, 0xcf, 0x59, 0x27, 0xf8, 0x62, 0x6b, 0x91, 0x12, 0xb7, 0xee, 0x2e, 0xdf, 0xb0,
    0x72, 0x27, 0x93, 0x98, 0xe7, 0xe5, 0x64, 0x62, 0xc1, 0xb5, 0xd2, 0x44, 0xfa, 0x97, 0xdb, 0x85,
    0x61, 0xed, 0xd0, 0x5e, 0xad, 0xf6, 0x92, 0x4f, 0x26, 0xf8, 0xf4, 0x47, 0xc2, 0xa4, 0x20, 0xd3,
    0x97, 0x04, 0x4c, 0x5d, 0x7e, 0x01, 0x6f, 0x82, 0xa3, 0x4b
};
#endif

PyTypeObject *init_QRawFont(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX].type;

    Shiboken::AutoDecRef Sbk_QRawFont_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRawFont_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRawFont",
        "QRawFont",
        &Sbk_QRawFont_spec,
        &Shiboken::callCppDestructor< ::QRawFont >,
        Sbk_QRawFont_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QRawFont_TypeF(); // references _Sbk_QRawFont_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRawFont_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRawFont_SignatureBytes, QRawFont_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRawFont_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRawFont_PythonToCpp_QRawFont_PTR,
        is_QRawFont_PythonToCpp_QRawFont_PTR_Convertible,
        QRawFont_PTR_CppToPython_QRawFont,
        QRawFont_COPY_CppToPython_QRawFont);

    Shiboken::Conversions::registerConverterName(converter, "QRawFont");
    Shiboken::Conversions::registerConverterName(converter, "QRawFont*");
    Shiboken::Conversions::registerConverterName(converter, "QRawFont&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRawFont).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QRawFont_PythonToCpp_QRawFont_COPY,
        is_QRawFont_PythonToCpp_QRawFont_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRawFont_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'AntialiasingType'.
    const char *AntialiasingType_Initializer[] = {
        "PixelAntialiasing",
        "SubPixelAntialiasing",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AntialiasingType_InitializerValues[] = {
        uint8_t(QRawFont::AntialiasingType::PixelAntialiasing),   //  0x00  0
        uint8_t(QRawFont::AntialiasingType::SubPixelAntialiasing) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRawFont_TypeF(),
        "2:PySide6.QtGui.QRawFont.AntialiasingType",
        AntialiasingType_Initializer, AntialiasingType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_AntialiasingType_IDX].type = EType;
    // Register converter for enum 'QRawFont::AntialiasingType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRawFont_AntialiasingType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRawFont_AntialiasingType,
            is_Enum_PythonToCpp_QRawFont_AntialiasingType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRawFont::AntialiasingType");
        Shiboken::Conversions::registerConverterAlias(converter, "AntialiasingType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AntialiasingType' enum.

    // Initialization of enum 'LayoutFlag'.
    const char *LayoutFlag_Initializer[] = {
        "SeparateAdvances",
        "KernedAdvances",
        "UseDesignMetrics",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t LayoutFlag_InitializerValues[] = {
        uint8_t(QRawFont::LayoutFlag::SeparateAdvances), //  0x00  0
        uint8_t(QRawFont::LayoutFlag::KernedAdvances),   //  0x01  1
        uint8_t(QRawFont::LayoutFlag::UseDesignMetrics)  //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRawFont_TypeF(),
        "2:PySide6.QtGui.QRawFont.LayoutFlag",
        LayoutFlag_Initializer, LayoutFlag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRawFont_LayoutFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRawFont_LayoutFlag_IDX].type =
        EType;
    // Register converter for enum 'QRawFont::LayoutFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRawFont_LayoutFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRawFont_LayoutFlag,
            is_Enum_PythonToCpp_QRawFont_LayoutFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRawFont::LayoutFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "LayoutFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QRawFont_LayoutFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QRawFont_LayoutFlag,
            is_Enum_PythonToCpp_QRawFont_LayoutFlag_Convertible);
        // Register converter for flag 'QFlags<QRawFont::LayoutFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QRawFont::LayoutFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QRawFont::LayoutFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'LayoutFlag' enum/flags.

    qRegisterMetaType< ::QRawFont >("QRawFont");
    qRegisterMetaType< ::QRawFont::AntialiasingType >("QRawFont::AntialiasingType");
    qRegisterMetaType< ::QRawFont::LayoutFlag >("QRawFont::LayoutFlag");

    return pyType;
}
