// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qresizeevent_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QResizeEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QResizeEventWrapper::QResizeEventWrapper(const ::QSize & size, const ::QSize & oldSize) : QResizeEvent(size, oldSize)
{
}

::QResizeEvent * QResizeEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QResizeEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QResizeEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QResizeEvent", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QResizeEvent", funcName, Shiboken::SbkType< QResizeEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QResizeEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QResizeEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QResizeEvent", funcName);
        return;
    }
}

QResizeEventWrapper::~QResizeEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QResizeEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QResizeEvent >()))
        return -1;

    QResizeEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QResizeEvent", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QResizeEvent::QResizeEvent(QResizeEvent)
    // 1: QResizeEvent::QResizeEvent(QSize,QSize)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[1])))) {
        overloadId = 1; // QResizeEvent(QSize,QSize)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QResizeEvent(QResizeEvent)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QResizeEvent(const QResizeEvent &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QResizeEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QResizeEvent(QResizeEvent)
                cptr = new QResizeEventWrapper(*cppArg0);
            }
            break;
        }
        case 1: // QResizeEvent(const QSize &size, const QSize &oldSize)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSize cppArg0_local;
            ::QSize *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QSize cppArg1_local;
            ::QSize *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QResizeEvent(QSize,QSize)
                cptr = new QResizeEventWrapper(*cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QResizeEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QResizeEventFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResizeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - repr_qdebug_gui - START
        // TEMPLATE - repr_qdebug - START
        QString result;
        QDebug(&result).nospace() << "<PySide6.QtGui." << cppSelf << '>';
        pyResult = Shiboken::String::fromCString(qPrintable(result));
        // TEMPLATE - repr_qdebug - END
        // TEMPLATE - repr_qdebug_gui - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResizeEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResizeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clone()const
        QResizeEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QResizeEvent *>(cppSelf)->::QResizeEvent::clone()
            : const_cast<const ::QResizeEvent *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResizeEventFunc_oldSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResizeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // oldSize()const
        const QSize & cppResult = const_cast<const ::QResizeEvent *>(cppSelf)->oldSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QResizeEventFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QResizeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        const QSize & cppResult = const_cast<const ::QResizeEvent *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QResizeEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QResizeEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QResizeEventFunc_clone), METH_NOARGS, nullptr},
    {"oldSize", reinterpret_cast<PyCFunction>(Sbk_QResizeEventFunc_oldSize), METH_NOARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QResizeEventFunc_size), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QResizeEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QResizeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QResizeEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QResizeEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QResizeEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QResizeEvent_Type = nullptr;
static PyTypeObject *Sbk_QResizeEvent_TypeF(void)
{
    return _Sbk_QResizeEvent_Type;
}

static PyType_Slot Sbk_QResizeEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QResizeEventFunc___repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QResizeEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QResizeEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QResizeEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QResizeEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QResizeEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QResizeEvent_spec = {
    "2:PySide6.QtGui.QResizeEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QResizeEvent_slots
};

} //extern "C"

static void *Sbk_QResizeEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::Resize)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QResizeEvent_PythonToCpp_QResizeEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QResizeEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QResizeEvent_PythonToCpp_QResizeEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QResizeEvent_TypeF()))
        return QResizeEvent_PythonToCpp_QResizeEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QResizeEvent_PTR_CppToPython_QResizeEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QResizeEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QResizeEvent_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QResizeEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QResizeEvent(self,arg__1:PySide6.QtGui.QResizeEvent)",
    "0:PySide6.QtGui.QResizeEvent(self,size:PySide6.QtCore.QSize,oldSize:PySide6.QtCore.QSize)",
    "PySide6.QtGui.QResizeEvent.__repr__(self)->str",
    "PySide6.QtGui.QResizeEvent.clone(self)->PySide6.QtGui.QResizeEvent",
    "PySide6.QtGui.QResizeEvent.oldSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QResizeEvent.size(self)->PySide6.QtCore.QSize",
    nullptr}; // Sentinel
#else
static constexpr size_t QResizeEvent_SignatureByteSize = 123;
static constexpr uint8_t QResizeEvent_SignatureBytes[123] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x0c, 0x4a, 0x2d, 0xce, 0xac, 0x4a, 0x75, 0x2d, 0x4b, 0xcd, 0x2b, 0xd1, 0x28,
    0x4e, 0xcd, 0x49, 0xd3, 0x49, 0x2c, 0x4a, 0x8f, 0x8f, 0x37, 0xc4, 0xa3, 0x4c, 0x93, 0xcb, 0x80,
    0xa0, 0x21, 0x20, 0x2e, 0x92, 0x22, 0xe7, 0xfc, 0xa2, 0x54, 0xbd, 0xc0, 0x60, 0xa0, 0xa0, 0x4e,
    0x7e, 0x4e, 0x4a, 0x30, 0x2e, 0x49, 0x4d, 0x2e, 0xdc, 0xe6, 0xea, 0xc5, 0xc7, 0x17, 0xa5, 0x16,
    0x14, 0xc5, 0xc7, 0x83, 0x2d, 0xd0, 0xd4, 0xb5, 0x2b, 0x2e, 0x29, 0xc2, 0xa7, 0x3c, 0x39, 0x27,
    0x3f, 0x2f, 0x15, 0xa6, 0x16, 0xb7, 0x3a, 0x7c, 0x46, 0x40, 0x9d, 0x8a, 0x69, 0x08, 0xc2, 0xc5,
    0xf8, 0xb4, 0x17, 0x13, 0xd2, 0x0b, 0x00, 0x2f, 0x20, 0x8b, 0x5c
};
#endif

PyTypeObject *init_QResizeEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QResizeEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]))));

    _Sbk_QResizeEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QResizeEvent",
        "QResizeEvent*",
        &Sbk_QResizeEvent_spec,
        &Shiboken::callCppDestructor< QResizeEvent >,
        Sbk_QResizeEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QResizeEvent_TypeF(); // references _Sbk_QResizeEvent_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QResizeEvent_SignatureStrings);
#else
    InitSignatureBytes(pyType, QResizeEvent_SignatureBytes, QResizeEvent_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QResizeEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QResizeEvent_PythonToCpp_QResizeEvent_PTR,
        is_QResizeEvent_PythonToCpp_QResizeEvent_PTR_Convertible,
        QResizeEvent_PTR_CppToPython_QResizeEvent);

    Shiboken::Conversions::registerConverterName(converter, "QResizeEvent");
    Shiboken::Conversions::registerConverterName(converter, "QResizeEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QResizeEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QResizeEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QResizeEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QResizeEvent_TypeF(), &Sbk_QResizeEvent_typeDiscovery);


    return pyType;
}
