// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhibuffer_wrapper.h"

// Argument includes
#include <qbytearray.h>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRhiBufferWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

bool QRhiBufferWrapper::create()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiBuffer.create");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "create";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiBuffer.create");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiBuffer", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiBuffer", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRhiBufferWrapper::destroy()
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiBuffer.destroy");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "destroy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiBuffer.destroy");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiBuffer", funcName);
        return;
    }
}

void QRhiBufferWrapper::endFullDynamicBufferUpdateForCurrentFrame()
{
    if (m_PyMethodCache[2]) {
        return this->::QRhiBuffer::endFullDynamicBufferUpdateForCurrentFrame();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "endFullDynamicBufferUpdateForCurrentFrame";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QRhiBuffer::endFullDynamicBufferUpdateForCurrentFrame();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiBuffer", funcName);
        return;
    }
}

void QRhiBufferWrapper::fullDynamicBufferUpdateForCurrentFrame(const void * data, quint32 size)
{
    if (m_PyMethodCache[3]) {
        return this->::QRhiBuffer::fullDynamicBufferUpdateForCurrentFrame(data, size);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "fullDynamicBufferUpdateForCurrentFrame";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QRhiBuffer::fullDynamicBufferUpdateForCurrentFrame(data, size);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), data),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &size)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NI)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), data),
        size
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiBuffer", funcName);
        return;
    }
}

::QRhiResource::Type QRhiBufferWrapper::resourceType() const
{
    if (m_PyMethodCache[4])
        return this->::QRhiBuffer::resourceType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QRhiResource::Buffer;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resourceType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QRhiBuffer::resourceType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiBuffer", funcName);
        return QRhiResource::Buffer;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiBuffer", funcName, Shiboken::SbkType< QRhiResource::Type >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QRhiResource::Buffer;
    }
    ::QRhiResource::Type cppResult{QRhiResource::Buffer};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QRhiBufferWrapper::~QRhiBufferWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QRhiBufferFunc_create(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // create()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QRhiBuffer.create");
            return {};
        }
        bool cppResult = cppSelf->create();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiBufferFunc_endFullDynamicBufferUpdateForCurrentFrame(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // endFullDynamicBufferUpdateForCurrentFrame()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QRhiBuffer::endFullDynamicBufferUpdateForCurrentFrame()
            : cppSelf->endFullDynamicBufferUpdateForCurrentFrame();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiBufferFunc_fullDynamicBufferUpdateForCurrentFrame(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fullDynamicBufferUpdateForCurrentFrame", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fullDynamicBufferUpdateForCurrentFrame", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhiBuffer::fullDynamicBufferUpdateForCurrentFrame(const void*,quint32=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fullDynamicBufferUpdateForCurrentFrame(const void*,quint32)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[1])))) {
            overloadId = 0; // fullDynamicBufferUpdateForCurrentFrame(const void*,quint32)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fullDynamicBufferUpdateForCurrentFrame", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_size = Shiboken::String::createStaticString("size");
            if (PyDict_Contains(kwds, key_size) != 0) {
                value = PyDict_GetItem(kwds, key_size);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_size);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fullDynamicBufferUpdateForCurrentFrame", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "fullDynamicBufferUpdateForCurrentFrame", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_size);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fullDynamicBufferUpdateForCurrentFrame", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]);
            }
        }
        void* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        quint32 cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fullDynamicBufferUpdateForCurrentFrame(const void*,quint32)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QRhiBuffer::fullDynamicBufferUpdateForCurrentFrame(cppArg0, cppArg1)
                : cppSelf->fullDynamicBufferUpdateForCurrentFrame(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiBufferFunc_resourceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resourceType()const
        QRhiResource::Type cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QRhiBuffer *>(cppSelf)->::QRhiBuffer::resourceType()
            : const_cast<const ::QRhiBuffer *>(cppSelf)->resourceType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiBufferFunc_setSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiBuffer::setSize(quint32)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 0; // setSize(quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSize", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]);

    // Call function/method
    {
        quint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSize(quint32)
            cppSelf->setSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiBufferFunc_setType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiBuffer::setType(QRhiBuffer::Type)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_Type_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setType(QRhiBuffer::Type)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setType", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]);

    // Call function/method
    {
        ::QRhiBuffer::Type cppArg0{QRhiBuffer::Immutable};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setType(QRhiBuffer::Type)
            cppSelf->setType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiBufferFunc_setUsage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiBuffer::setUsage(QFlags<QRhiBuffer::UsageFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiBuffer_UsageFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setUsage(QFlags<QRhiBuffer::UsageFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUsage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]);

    // Call function/method
    {
        ::QFlags<QRhiBuffer::UsageFlag> cppArg0 = QFlags<QRhiBuffer::UsageFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUsage(QFlags<QRhiBuffer::UsageFlag>)
            cppSelf->setUsage(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiBufferFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        quint32 cppResult = const_cast<const ::QRhiBuffer *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiBufferFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QRhiBuffer::Type cppResult = const_cast<const ::QRhiBuffer *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiBufferFunc_usage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // usage()const
        QFlags<QRhiBuffer::UsageFlag> cppResult = const_cast<const ::QRhiBuffer *>(cppSelf)->usage();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiBuffer_UsageFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiBuffer_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRhiBuffer_EnumFlagInfo[] = {
    "Type:Enum",
    "UsageFlag:Flag:UsageFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiBuffer_methods[] = {
    {"create", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_create), METH_NOARGS, nullptr},
    {"endFullDynamicBufferUpdateForCurrentFrame", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_endFullDynamicBufferUpdateForCurrentFrame), METH_NOARGS, nullptr},
    {"fullDynamicBufferUpdateForCurrentFrame", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_fullDynamicBufferUpdateForCurrentFrame), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"resourceType", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_resourceType), METH_NOARGS, nullptr},
    {"setSize", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_setSize), METH_O, nullptr},
    {"setType", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_setType), METH_O, nullptr},
    {"setUsage", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_setUsage), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_size), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_type), METH_NOARGS, nullptr},
    {"usage", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_usage), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRhiBuffer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRhiBufferWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QRhiBuffer_get_m_type(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiBuffer::Type cppOut_local = cppSelf->m_type;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_Type_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiBuffer_set_m_type(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_type");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_Type_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_type", "Type");
        return -1;
    }

    auto cppOut_local = cppSelf->m_type;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_type = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiBuffer_get_m_usage(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiBuffer_UsageFlag_IDX])))->flagsConverter, &cppSelf->m_usage);
    return pyOut;
}
static int Sbk_QRhiBuffer_set_m_usage(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_usage");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiBuffer_UsageFlag_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_usage", "UsageFlags");
        return -1;
    }

    auto cppOut_local = cppSelf->m_usage;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_usage = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiBuffer_get_m_size(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint32 cppOut_local = cppSelf->m_size;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiBuffer_set_m_size(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_size");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_size", "quint32");
        return -1;
    }

    auto cppOut_local = cppSelf->m_size;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_size = cppOut_local;

    return 0;
}

// Getters and Setters for QRhiBuffer
static PyGetSetDef Sbk_QRhiBuffer_getsetlist[] = {
    {const_cast<char *>("m_type"), Sbk_QRhiBuffer_get_m_type, Sbk_QRhiBuffer_set_m_type, nullptr, nullptr},
    {const_cast<char *>("m_usage"), Sbk_QRhiBuffer_get_m_usage, Sbk_QRhiBuffer_set_m_usage, nullptr, nullptr},
    {const_cast<char *>("m_size"), Sbk_QRhiBuffer_get_m_size, Sbk_QRhiBuffer_set_m_size, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiBuffer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiBuffer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiBuffer_Type = nullptr;
static PyTypeObject *Sbk_QRhiBuffer_TypeF(void)
{
    return _Sbk_QRhiBuffer_Type;
}

static PyType_Slot Sbk_QRhiBuffer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRhiBuffer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiBuffer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiBuffer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiBuffer_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiBuffer_getsetlist)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiBuffer_spec = {
    "2:PySide6.QtGui.QRhiBuffer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiBuffer_slots
};

} //extern "C"

static void *Sbk_QRhiBuffer_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QRhiResource >())
        return dynamic_cast< ::QRhiBuffer *>(reinterpret_cast< ::QRhiResource *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QRhiBuffer_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiBuffer::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiBuffer::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiBuffer_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_Type_IDX])))
        return Enum_PythonToCpp_QRhiBuffer_Type;
    return {};
}

static PyObject *QRhiBuffer_Type_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiBuffer::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiBuffer::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_Type_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiBuffer_UsageFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiBuffer::UsageFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiBuffer::UsageFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiBuffer_UsageFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_UsageFlag_IDX])))
        return Enum_PythonToCpp_QRhiBuffer_UsageFlag;
    return {};
}

static PyObject *QRhiBuffer_UsageFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiBuffer::UsageFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiBuffer::UsageFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_UsageFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QRhiBuffer_UsageFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QRhiBuffer::UsageFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QRhiBuffer::UsageFlag> *>(cppOut) = value;

}

static PyObject *QRhiBuffer_UsageFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QRhiBuffer::UsageFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_UsageFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiBuffer_PythonToCpp_QRhiBuffer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiBuffer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiBuffer_PythonToCpp_QRhiBuffer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiBuffer_TypeF()))
        return QRhiBuffer_PythonToCpp_QRhiBuffer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiBuffer_PTR_CppToPython_QRhiBuffer(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QRhiBuffer *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QRhiBuffer_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiBuffer_SignatureStrings[] = {
    "PySide6.QtGui.QRhiBuffer.create(self)->bool",
    "PySide6.QtGui.QRhiBuffer.endFullDynamicBufferUpdateForCurrentFrame(self)",
    "PySide6.QtGui.QRhiBuffer.fullDynamicBufferUpdateForCurrentFrame(self,data:void,size:quint32=0)",
    "PySide6.QtGui.QRhiBuffer.resourceType(self)->PySide6.QtGui.QRhiResource.Type",
    "PySide6.QtGui.QRhiBuffer.setSize(self,sz:quint32)",
    "PySide6.QtGui.QRhiBuffer.setType(self,t:PySide6.QtGui.QRhiBuffer.Type)",
    "PySide6.QtGui.QRhiBuffer.setUsage(self,u:PySide6.QtGui.QRhiBuffer.UsageFlag)",
    "PySide6.QtGui.QRhiBuffer.size(self)->quint32",
    "PySide6.QtGui.QRhiBuffer.type(self)->PySide6.QtGui.QRhiBuffer.Type",
    "PySide6.QtGui.QRhiBuffer.usage(self)->PySide6.QtGui.QRhiBuffer.UsageFlag",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiBuffer_SignatureByteSize = 207;
static constexpr uint8_t QRhiBuffer_SignatureBytes[207] = {
    0x78, 0xda, 0x8d, 0x90, 0xcb, 0x0e, 0x82, 0x30, 0x10, 0x45, 0xf7, 0x7c, 0x89, 0x24, 0x48, 0x8c,
    0x26, 0x2e, 0x48, 0x74, 0xa1, 0xa6, 0x6e, 0x79, 0xc8, 0x07, 0x54, 0x3a, 0x60, 0x93, 0x42, 0xb1,
    0x0f, 0x13, 0xf8, 0x7a, 0x41, 0xa0, 0x31, 0x31, 0x6d, 0xdc, 0xb6, 0x67, 0xce, 0xdc, 0x3b, 0x71,
    0x97, 0x51, 0x02, 0xfb, 0x30, 0x51, 0x57, 0x4d, 0xc3, 0x24, 0x7d, 0xd0, 0x93, 0x2e, 0x4b, 0x10,
    0x61, 0x21, 0x00, 0x2b, 0x58, 0x49, 0x60, 0xa5, 0xbf, 0x3e, 0xde, 0x39, 0x67, 0x5e, 0x6c, 0x63,
    0xa1, 0x21, 0x48, 0x33, 0x76, 0xe9, 0x1a, 0x5c, 0xd3, 0x62, 0x7a, 0xcc, 0x5b, 0x32, 0xcc, 0x23,
    0x2e, 0xce, 0x5a, 0x08, 0x68, 0x14, 0x12, 0xb8, 0x9e, 0x75, 0x76, 0x51, 0xf9, 0xbf, 0x25, 0x18,
    0x3e, 0x70, 0xf4, 0xe2, 0x94, 0x04, 0x92, 0xf6, 0x10, 0x3d, 0x35, 0x6d, 0xd4, 0x6e, 0x7b, 0xd8,
    0x38, 0xf4, 0x02, 0x24, 0xd7, 0xa2, 0x80, 0x5b, 0xd7, 0x9a, 0x66, 0xbf, 0x70, 0x3a, 0x53, 0xe1,
    0x88, 0xd9, 0x65, 0x12, 0x54, 0x36, 0x2c, 0x9e, 0xc2, 0xc8, 0x7e, 0x09, 0xe0, 0x3b, 0x27, 0xcc,
    0xe6, 0x40, 0x45, 0x56, 0x6e, 0x84, 0xdc, 0x9a, 0x5c, 0xe2, 0x6a, 0xf6, 0x68, 0xbb, 0xe7, 0x43,
    0x21, 0x86, 0x2b, 0x97, 0x6c, 0xa9, 0x30, 0x9c, 0x62, 0x6e, 0x60, 0x87, 0x95, 0xf3, 0x6e, 0x5f,
    0xe9, 0xed, 0x0a, 0x6d, 0x92, 0xbb, 0x1c, 0x26, 0xb9, 0xf7, 0x06, 0x43, 0x61, 0xee, 0xdd
};
#endif

PyTypeObject *init_QRhiBuffer(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiBuffer_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_IDX]))));

    _Sbk_QRhiBuffer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiBuffer",
        "QRhiBuffer*",
        &Sbk_QRhiBuffer_spec,
        &Shiboken::callCppDestructor< QRhiBuffer >,
        Sbk_QRhiBuffer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRhiBuffer_TypeF(); // references _Sbk_QRhiBuffer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiBuffer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiBuffer_SignatureBytes, QRhiBuffer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiBuffer_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiBuffer_PythonToCpp_QRhiBuffer_PTR,
        is_QRhiBuffer_PythonToCpp_QRhiBuffer_PTR_Convertible,
        QRhiBuffer_PTR_CppToPython_QRhiBuffer);

    Shiboken::Conversions::registerConverterName(converter, "QRhiBuffer");
    Shiboken::Conversions::registerConverterName(converter, "QRhiBuffer*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiBuffer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiBuffer).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRhiBufferWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRhiBuffer_TypeF(), &Sbk_QRhiBuffer_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRhiBuffer_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "Immutable",
        "Static",
        "Dynamic",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(QRhiBuffer::Type::Immutable), //  0x00  0
        uint8_t(QRhiBuffer::Type::Static),    //  0x01  1
        uint8_t(QRhiBuffer::Type::Dynamic)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiBuffer_TypeF(),
        "2:PySide6.QtGui.QRhiBuffer.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_Type_IDX].type = EType;
    // Register converter for enum 'QRhiBuffer::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiBuffer_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiBuffer_Type,
            is_Enum_PythonToCpp_QRhiBuffer_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiBuffer::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    // Initialization of enum 'UsageFlag'.
    const char *UsageFlag_Initializer[] = {
        "VertexBuffer",
        "IndexBuffer",
        "UniformBuffer",
        "StorageBuffer",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t UsageFlag_InitializerValues[] = {
        uint8_t(QRhiBuffer::UsageFlag::VertexBuffer),  //  0x01  1
        uint8_t(QRhiBuffer::UsageFlag::IndexBuffer),   //  0x02  2
        uint8_t(QRhiBuffer::UsageFlag::UniformBuffer), //  0x04  4
        uint8_t(QRhiBuffer::UsageFlag::StorageBuffer)  //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiBuffer_TypeF(),
        "2:PySide6.QtGui.QRhiBuffer.UsageFlag",
        UsageFlag_Initializer, UsageFlag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_UsageFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiBuffer_UsageFlag_IDX].type =
        EType;
    // Register converter for enum 'QRhiBuffer::UsageFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiBuffer_UsageFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiBuffer_UsageFlag,
            is_Enum_PythonToCpp_QRhiBuffer_UsageFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiBuffer::UsageFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "UsageFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QRhiBuffer_UsageFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QRhiBuffer_UsageFlag,
            is_Enum_PythonToCpp_QRhiBuffer_UsageFlag_Convertible);
        // Register converter for flag 'QFlags<QRhiBuffer::UsageFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QRhiBuffer::UsageFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QRhiBuffer::UsageFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'UsageFlag' enum/flags.

    qRegisterMetaType< ::QRhiBuffer *>();
    qRegisterMetaType< ::QRhiBuffer::Type >("QRhiBuffer::Type");
    qRegisterMetaType< ::QRhiBuffer::UsageFlag >("QRhiBuffer::UsageFlag");

    return pyType;
}
