// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhicommandbuffer_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qcolor.h>
#include <qbytearray.h>
#include <rhi/qrhi.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRhiCommandBufferWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QRhiCommandBufferWrapper::destroy()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiCommandBuffer.destroy");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "destroy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiCommandBuffer.destroy");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiCommandBuffer", funcName);
        return;
    }
}

::QRhiResource::Type QRhiCommandBufferWrapper::resourceType() const
{
    if (m_PyMethodCache[1])
        return this->::QRhiCommandBuffer::resourceType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QRhiResource::Buffer;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resourceType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QRhiCommandBuffer::resourceType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiCommandBuffer", funcName);
        return QRhiResource::Buffer;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiCommandBuffer", funcName, Shiboken::SbkType< QRhiResource::Type >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QRhiResource::Buffer;
    }
    ::QRhiResource::Type cppResult{QRhiResource::Buffer};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QRhiCommandBufferWrapper::~QRhiCommandBufferWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QRhiCommandBufferFunc_beginComputePass(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "beginComputePass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    if (PyArg_ParseTuple(args, "|OO:beginComputePass", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhiCommandBuffer::beginComputePass(QRhiResourceUpdateBatch*=,QFlags<QRhiCommandBuffer::BeginPassFlag>=)
    if (numArgs == 0) {
        overloadId = 0; // beginComputePass(QRhiResourceUpdateBatch*,QFlags<QRhiCommandBuffer::BeginPassFlag>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResourceUpdateBatch_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // beginComputePass(QRhiResourceUpdateBatch*,QFlags<QRhiCommandBuffer::BeginPassFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiCommandBuffer_BeginPassFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // beginComputePass(QRhiResourceUpdateBatch*,QFlags<QRhiCommandBuffer::BeginPassFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "beginComputePass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_resourceUpdates = Shiboken::String::createStaticString("resourceUpdates");
            if (PyDict_Contains(kwds, key_resourceUpdates) != 0) {
                value = PyDict_GetItem(kwds, key_resourceUpdates);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_resourceUpdates);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "beginComputePass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResourceUpdateBatch_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "beginComputePass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_resourceUpdates);
            }
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "beginComputePass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiCommandBuffer_BeginPassFlag_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "beginComputePass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "beginComputePass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRhiResourceUpdateBatch *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRhiCommandBuffer::BeginPassFlag> cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // beginComputePass(QRhiResourceUpdateBatch*,QFlags<QRhiCommandBuffer::BeginPassFlag>)
            cppSelf->beginComputePass(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_beginExternal(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // beginExternal()
        cppSelf->beginExternal();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_beginPass(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "beginPass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:beginPass", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhiCommandBuffer::beginPass(QRhiRenderTarget*,QColor,QRhiDepthStencilClearValue,QRhiResourceUpdateBatch*=,QFlags<QRhiCommandBuffer::BeginPassFlag>=)
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDepthStencilClearValue_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // beginPass(QRhiRenderTarget*,QColor,QRhiDepthStencilClearValue,QRhiResourceUpdateBatch*,QFlags<QRhiCommandBuffer::BeginPassFlag>)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResourceUpdateBatch_IDX]), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 0; // beginPass(QRhiRenderTarget*,QColor,QRhiDepthStencilClearValue,QRhiResourceUpdateBatch*,QFlags<QRhiCommandBuffer::BeginPassFlag>)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiCommandBuffer_BeginPassFlag_IDX])))->flagsConverter, (pyArgs[4])))) {
                overloadId = 0; // beginPass(QRhiRenderTarget*,QColor,QRhiDepthStencilClearValue,QRhiResourceUpdateBatch*,QFlags<QRhiCommandBuffer::BeginPassFlag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "beginPass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_resourceUpdates = Shiboken::String::createStaticString("resourceUpdates");
            if (PyDict_Contains(kwds, key_resourceUpdates) != 0) {
                value = PyDict_GetItem(kwds, key_resourceUpdates);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_resourceUpdates);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "beginPass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResourceUpdateBatch_IDX]), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "beginPass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_resourceUpdates);
            }
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "beginPass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiCommandBuffer_BeginPassFlag_IDX])))->flagsConverter, (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "beginPass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "beginPass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRhiRenderTarget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QColor cppArg1_local;
        ::QColor *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRhiDepthStencilClearValue cppArg2_local;
        ::QRhiDepthStencilClearValue *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QRhiResourceUpdateBatch *cppArg3 = nullptr;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QFlags<QRhiCommandBuffer::BeginPassFlag> cppArg4{};
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // beginPass(QRhiRenderTarget*,QColor,QRhiDepthStencilClearValue,QRhiResourceUpdateBatch*,QFlags<QRhiCommandBuffer::BeginPassFlag>)
            cppSelf->beginPass(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_debugMarkBegin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiCommandBuffer::debugMarkBegin(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // debugMarkBegin(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "debugMarkBegin", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // debugMarkBegin(QByteArray)
            cppSelf->debugMarkBegin(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_debugMarkEnd(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // debugMarkEnd()
        cppSelf->debugMarkEnd();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_debugMarkMsg(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiCommandBuffer::debugMarkMsg(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // debugMarkMsg(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "debugMarkMsg", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // debugMarkMsg(QByteArray)
            cppSelf->debugMarkMsg(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_dispatch(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "dispatch", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhiCommandBuffer::dispatch(int,int,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // dispatch(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dispatch", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dispatch(int,int,int)
            cppSelf->dispatch(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_draw(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "draw", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:draw", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhiCommandBuffer::draw(quint32,quint32=,quint32=,quint32=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // draw(quint32,quint32,quint32,quint32)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // draw(quint32,quint32,quint32,quint32)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // draw(quint32,quint32,quint32,quint32)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[3])))) {
                    overloadId = 0; // draw(quint32,quint32,quint32,quint32)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "draw", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_instanceCount = Shiboken::String::createStaticString("instanceCount");
            if (PyDict_Contains(kwds, key_instanceCount) != 0) {
                value = PyDict_GetItem(kwds, key_instanceCount);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_instanceCount);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "draw", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "draw", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_instanceCount);
            }
            static PyObject *const key_firstVertex = Shiboken::String::createStaticString("firstVertex");
            if (PyDict_Contains(kwds, key_firstVertex) != 0) {
                value = PyDict_GetItem(kwds, key_firstVertex);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_firstVertex);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "draw", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "draw", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_firstVertex);
            }
            static PyObject *const key_firstInstance = Shiboken::String::createStaticString("firstInstance");
            if (PyDict_Contains(kwds, key_firstInstance) != 0) {
                value = PyDict_GetItem(kwds, key_firstInstance);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_firstInstance);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "draw", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "draw", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_firstInstance);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "draw", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
            }
        }
        quint32 cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        quint32 cppArg1 = 1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        quint32 cppArg2 = 0;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        quint32 cppArg3 = 0;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // draw(quint32,quint32,quint32,quint32)
            cppSelf->draw(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_drawIndexed(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "drawIndexed", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:drawIndexed", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhiCommandBuffer::drawIndexed(quint32,quint32=,quint32=,qint32=,quint32=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // drawIndexed(quint32,quint32,quint32,qint32,quint32)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // drawIndexed(quint32,quint32,quint32,qint32,quint32)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // drawIndexed(quint32,quint32,quint32,qint32,quint32)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint32>(), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // drawIndexed(quint32,quint32,quint32,qint32,quint32)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[4])))) {
                        overloadId = 0; // drawIndexed(quint32,quint32,quint32,qint32,quint32)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawIndexed", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_instanceCount = Shiboken::String::createStaticString("instanceCount");
            if (PyDict_Contains(kwds, key_instanceCount) != 0) {
                value = PyDict_GetItem(kwds, key_instanceCount);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_instanceCount);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "drawIndexed", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "drawIndexed", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_instanceCount);
            }
            static PyObject *const key_firstIndex = Shiboken::String::createStaticString("firstIndex");
            if (PyDict_Contains(kwds, key_firstIndex) != 0) {
                value = PyDict_GetItem(kwds, key_firstIndex);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_firstIndex);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "drawIndexed", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "drawIndexed", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_firstIndex);
            }
            static PyObject *const key_vertexOffset = Shiboken::String::createStaticString("vertexOffset");
            if (PyDict_Contains(kwds, key_vertexOffset) != 0) {
                value = PyDict_GetItem(kwds, key_vertexOffset);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_vertexOffset);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "drawIndexed", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint32>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "drawIndexed", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_vertexOffset);
            }
            static PyObject *const key_firstInstance = Shiboken::String::createStaticString("firstInstance");
            if (PyDict_Contains(kwds, key_firstInstance) != 0) {
                value = PyDict_GetItem(kwds, key_firstInstance);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_firstInstance);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "drawIndexed", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "drawIndexed", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_firstInstance);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "drawIndexed", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
            }
        }
        quint32 cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        quint32 cppArg1 = 1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        quint32 cppArg2 = 0;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        qint32 cppArg3 = 0;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        quint32 cppArg4 = 0;
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // drawIndexed(quint32,quint32,quint32,qint32,quint32)
            cppSelf->drawIndexed(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_endComputePass(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "endComputePass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    if (PyArg_ParseTuple(args, "|O:endComputePass", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhiCommandBuffer::endComputePass(QRhiResourceUpdateBatch*=)
    if (numArgs == 0) {
        overloadId = 0; // endComputePass(QRhiResourceUpdateBatch*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResourceUpdateBatch_IDX]), (pyArgs[0])))) {
        overloadId = 0; // endComputePass(QRhiResourceUpdateBatch*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "endComputePass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_resourceUpdates = Shiboken::String::createStaticString("resourceUpdates");
            if (PyDict_Contains(kwds, key_resourceUpdates) != 0) {
                value = PyDict_GetItem(kwds, key_resourceUpdates);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_resourceUpdates);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "endComputePass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResourceUpdateBatch_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "endComputePass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_resourceUpdates);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "endComputePass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRhiResourceUpdateBatch *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // endComputePass(QRhiResourceUpdateBatch*)
            cppSelf->endComputePass(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_endExternal(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // endExternal()
        cppSelf->endExternal();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_endPass(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "endPass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    if (PyArg_ParseTuple(args, "|O:endPass", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhiCommandBuffer::endPass(QRhiResourceUpdateBatch*=)
    if (numArgs == 0) {
        overloadId = 0; // endPass(QRhiResourceUpdateBatch*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResourceUpdateBatch_IDX]), (pyArgs[0])))) {
        overloadId = 0; // endPass(QRhiResourceUpdateBatch*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "endPass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_resourceUpdates = Shiboken::String::createStaticString("resourceUpdates");
            if (PyDict_Contains(kwds, key_resourceUpdates) != 0) {
                value = PyDict_GetItem(kwds, key_resourceUpdates);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_resourceUpdates);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "endPass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResourceUpdateBatch_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "endPass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_resourceUpdates);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "endPass", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRhiResourceUpdateBatch *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // endPass(QRhiResourceUpdateBatch*)
            cppSelf->endPass(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_lastCompletedGpuTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastCompletedGpuTime()
        double cppResult = cppSelf->lastCompletedGpuTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiCommandBufferFunc_nativeHandles(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nativeHandles()
        const QRhiNativeHandles * cppResult = cppSelf->nativeHandles();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiNativeHandles_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiCommandBufferFunc_resourceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resourceType()const
        QRhiResource::Type cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QRhiCommandBuffer *>(cppSelf)->::QRhiCommandBuffer::resourceType()
            : const_cast<const ::QRhiCommandBuffer *>(cppSelf)->resourceType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiCommandBufferFunc_resourceUpdate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiCommandBuffer::resourceUpdate(QRhiResourceUpdateBatch*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResourceUpdateBatch_IDX]), (pyArg)))) {
        overloadId = 0; // resourceUpdate(QRhiResourceUpdateBatch*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resourceUpdate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiResourceUpdateBatch *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resourceUpdate(QRhiResourceUpdateBatch*)
            cppSelf->resourceUpdate(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_setBlendConstants(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiCommandBuffer::setBlendConstants(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setBlendConstants(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBlendConstants", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBlendConstants(QColor)
            cppSelf->setBlendConstants(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_setComputePipeline(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiCommandBuffer::setComputePipeline(QRhiComputePipeline*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), (pyArg)))) {
        overloadId = 0; // setComputePipeline(QRhiComputePipeline*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setComputePipeline", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiComputePipeline *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setComputePipeline(QRhiComputePipeline*)
            cppSelf->setComputePipeline(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_setGraphicsPipeline(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiCommandBuffer::setGraphicsPipeline(QRhiGraphicsPipeline*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), (pyArg)))) {
        overloadId = 0; // setGraphicsPipeline(QRhiGraphicsPipeline*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGraphicsPipeline", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiGraphicsPipeline *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGraphicsPipeline(QRhiGraphicsPipeline*)
            cppSelf->setGraphicsPipeline(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_setScissor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiCommandBuffer::setScissor(QRhiScissor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]), (pyArg)))) {
        overloadId = 0; // setScissor(QRhiScissor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setScissor", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiScissor cppArg0_local;
        ::QRhiScissor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setScissor(QRhiScissor)
            cppSelf->setScissor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_setShaderResources(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setShaderResources", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setShaderResources", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhiCommandBuffer::setShaderResources(QRhiShaderResourceBindings*=,int=,const std::pair<int,uint>*=)
    if (numArgs == 0) {
        overloadId = 0; // setShaderResources(QRhiShaderResourceBindings*,int,const std::pair<int,uint>*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setShaderResources(QRhiShaderResourceBindings*,int,const std::pair<int,uint>*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setShaderResources(QRhiShaderResourceBindings*,int,const std::pair<int,uint>*)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_int_unsignedint_IDX], (pyArgs[2])))) {
                overloadId = 0; // setShaderResources(QRhiShaderResourceBindings*,int,const std::pair<int,uint>*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setShaderResources", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_srb = Shiboken::String::createStaticString("srb");
            if (PyDict_Contains(kwds, key_srb) != 0) {
                value = PyDict_GetItem(kwds, key_srb);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_srb);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setShaderResources", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "setShaderResources", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_srb);
            }
            static PyObject *const key_dynamicOffsetCount = Shiboken::String::createStaticString("dynamicOffsetCount");
            if (PyDict_Contains(kwds, key_dynamicOffsetCount) != 0) {
                value = PyDict_GetItem(kwds, key_dynamicOffsetCount);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_dynamicOffsetCount);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setShaderResources", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setShaderResources", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_dynamicOffsetCount);
            }
            static PyObject *const key_dynamicOffsets = Shiboken::String::createStaticString("dynamicOffsets");
            if (PyDict_Contains(kwds, key_dynamicOffsets) != 0) {
                value = PyDict_GetItem(kwds, key_dynamicOffsets);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_dynamicOffsets);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setShaderResources", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_int_unsignedint_IDX], (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "setShaderResources", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_dynamicOffsets);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setShaderResources", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRhiShaderResourceBindings *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        std::pair<int,unsigned int> cppArg2_local;
        std::pair<int,unsigned int> *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShaderResources(QRhiShaderResourceBindings*,int,const std::pair<int,uint>*)
            cppSelf->setShaderResources(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_setStencilRef(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiCommandBuffer::setStencilRef(quint32)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 0; // setStencilRef(quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStencilRef", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        quint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStencilRef(quint32)
            cppSelf->setStencilRef(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_setVertexInput(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setVertexInput", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:setVertexInput", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhiCommandBuffer::setVertexInput(int,QList<std::pair<QRhiBuffer*,quint32>>,QRhiBuffer*=,quint32=,QRhiCommandBuffer::IndexFormat=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_std_pair_QRhiBufferPTR_quint32_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setVertexInput(int,QList<std::pair<QRhiBuffer*,quint32>>,QRhiBuffer*,quint32,QRhiCommandBuffer::IndexFormat)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // setVertexInput(int,QList<std::pair<QRhiBuffer*,quint32>>,QRhiBuffer*,quint32,QRhiCommandBuffer::IndexFormat)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 0; // setVertexInput(int,QList<std::pair<QRhiBuffer*,quint32>>,QRhiBuffer*,quint32,QRhiCommandBuffer::IndexFormat)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IndexFormat_IDX])))->converter, (pyArgs[4])))) {
                    overloadId = 0; // setVertexInput(int,QList<std::pair<QRhiBuffer*,quint32>>,QRhiBuffer*,quint32,QRhiCommandBuffer::IndexFormat)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setVertexInput", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_indexBuf = Shiboken::String::createStaticString("indexBuf");
            if (PyDict_Contains(kwds, key_indexBuf) != 0) {
                value = PyDict_GetItem(kwds, key_indexBuf);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_indexBuf);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setVertexInput", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "setVertexInput", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_indexBuf);
            }
            static PyObject *const key_indexOffset = Shiboken::String::createStaticString("indexOffset");
            if (PyDict_Contains(kwds, key_indexOffset) != 0) {
                value = PyDict_GetItem(kwds, key_indexOffset);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_indexOffset);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setVertexInput", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "setVertexInput", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_indexOffset);
            }
            static PyObject *const key_indexFormat = Shiboken::String::createStaticString("indexFormat");
            if (PyDict_Contains(kwds, key_indexFormat) != 0) {
                value = PyDict_GetItem(kwds, key_indexFormat);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_indexFormat);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setVertexInput", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IndexFormat_IDX])))->converter, (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "setVertexInput", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_indexFormat);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setVertexInput", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        SBK_UNUSED(cppArg0)
        ::QList<std::pair<QRhiBuffer*,quint32>> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        SBK_UNUSED(cppArg1)
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRhiBuffer *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        SBK_UNUSED(cppArg2)
        quint32 cppArg3 = 0;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        SBK_UNUSED(cppArg3)
        ::QRhiCommandBuffer::IndexFormat cppArg4(QRhiCommandBuffer::IndexUInt16);
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);
        SBK_UNUSED(cppArg4)

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVertexInput(int,QList<std::pair<QRhiBuffer*,quint32>>,QRhiBuffer*,quint32,QRhiCommandBuffer::IndexFormat)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qrhi-commandbuffer-setvertexinput)]
            cppSelf->setVertexInput(cppArg0, cppArg1.size(), cppArg1.constData(), cppArg2, cppArg3, cppArg4);
            // END of custom code block [file: ../glue/qtgui.cpp (qrhi-commandbuffer-setvertexinput)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiCommandBufferFunc_setViewport(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiCommandBuffer::setViewport(QRhiViewport)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiViewport_IDX]), (pyArg)))) {
        overloadId = 0; // setViewport(QRhiViewport)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setViewport", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiViewport cppArg0_local;
        ::QRhiViewport *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setViewport(QRhiViewport)
            cppSelf->setViewport(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QRhiCommandBuffer_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRhiCommandBuffer_EnumFlagInfo[] = {
    "BeginPassFlag:Flag:BeginPassFlags",
    "IndexFormat:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiCommandBuffer_methods[] = {
    {"beginComputePass", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_beginComputePass), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"beginExternal", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_beginExternal), METH_NOARGS, nullptr},
    {"beginPass", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_beginPass), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"debugMarkBegin", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_debugMarkBegin), METH_O, nullptr},
    {"debugMarkEnd", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_debugMarkEnd), METH_NOARGS, nullptr},
    {"debugMarkMsg", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_debugMarkMsg), METH_O, nullptr},
    {"dispatch", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_dispatch), METH_VARARGS, nullptr},
    {"draw", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_draw), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"drawIndexed", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_drawIndexed), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"endComputePass", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_endComputePass), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"endExternal", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_endExternal), METH_NOARGS, nullptr},
    {"endPass", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_endPass), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"lastCompletedGpuTime", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_lastCompletedGpuTime), METH_NOARGS, nullptr},
    {"nativeHandles", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_nativeHandles), METH_NOARGS, nullptr},
    {"resourceType", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_resourceType), METH_NOARGS, nullptr},
    {"resourceUpdate", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_resourceUpdate), METH_O, nullptr},
    {"setBlendConstants", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_setBlendConstants), METH_O, nullptr},
    {"setComputePipeline", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_setComputePipeline), METH_O, nullptr},
    {"setGraphicsPipeline", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_setGraphicsPipeline), METH_O, nullptr},
    {"setScissor", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_setScissor), METH_O, nullptr},
    {"setShaderResources", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_setShaderResources), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setStencilRef", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_setStencilRef), METH_O, nullptr},
    {"setVertexInput", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_setVertexInput), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setViewport", reinterpret_cast<PyCFunction>(Sbk_QRhiCommandBufferFunc_setViewport), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRhiCommandBuffer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRhiCommandBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRhiCommandBufferWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QRhiCommandBuffer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiCommandBuffer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiCommandBuffer_Type = nullptr;
static PyTypeObject *Sbk_QRhiCommandBuffer_TypeF(void)
{
    return _Sbk_QRhiCommandBuffer_Type;
}

static PyType_Slot Sbk_QRhiCommandBuffer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRhiCommandBuffer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiCommandBuffer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiCommandBuffer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiCommandBuffer_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiCommandBuffer_spec = {
    "2:PySide6.QtGui.QRhiCommandBuffer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiCommandBuffer_slots
};

} //extern "C"

static void *Sbk_QRhiCommandBuffer_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QRhiResource >())
        return dynamic_cast< ::QRhiCommandBuffer *>(reinterpret_cast< ::QRhiResource *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QRhiCommandBuffer_IndexFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiCommandBuffer::IndexFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiCommandBuffer::IndexFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiCommandBuffer_IndexFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IndexFormat_IDX])))
        return Enum_PythonToCpp_QRhiCommandBuffer_IndexFormat;
    return {};
}

static PyObject *QRhiCommandBuffer_IndexFormat_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiCommandBuffer::IndexFormat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiCommandBuffer::IndexFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IndexFormat_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiCommandBuffer_BeginPassFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiCommandBuffer::BeginPassFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiCommandBuffer::BeginPassFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiCommandBuffer_BeginPassFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_BeginPassFlag_IDX])))
        return Enum_PythonToCpp_QRhiCommandBuffer_BeginPassFlag;
    return {};
}

static PyObject *QRhiCommandBuffer_BeginPassFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiCommandBuffer::BeginPassFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiCommandBuffer::BeginPassFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_BeginPassFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QRhiCommandBuffer_BeginPassFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QRhiCommandBuffer::BeginPassFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QRhiCommandBuffer::BeginPassFlag> *>(cppOut) = value;

}

static PyObject *QRhiCommandBuffer_BeginPassFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QRhiCommandBuffer::BeginPassFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_BeginPassFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiCommandBuffer_PythonToCpp_QRhiCommandBuffer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiCommandBuffer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiCommandBuffer_PythonToCpp_QRhiCommandBuffer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiCommandBuffer_TypeF()))
        return QRhiCommandBuffer_PythonToCpp_QRhiCommandBuffer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiCommandBuffer_PTR_CppToPython_QRhiCommandBuffer(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QRhiCommandBuffer *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QRhiCommandBuffer_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiCommandBuffer_SignatureStrings[] = {
    "PySide6.QtGui.QRhiCommandBuffer.beginComputePass(self,resourceUpdates:PySide6.QtGui.QRhiResourceUpdateBatch=nullptr,flags:PySide6.QtGui.QRhiCommandBuffer.BeginPassFlag={})",
    "PySide6.QtGui.QRhiCommandBuffer.beginExternal(self)",
    "PySide6.QtGui.QRhiCommandBuffer.beginPass(self,rt:PySide6.QtGui.QRhiRenderTarget,colorClearValue:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int],depthStencilClearValue:PySide6.QtGui.QRhiDepthStencilClearValue,resourceUpdates:PySide6.QtGui.QRhiResourceUpdateBatch=nullptr,flags:PySide6.QtGui.QRhiCommandBuffer.BeginPassFlag={})",
    "PySide6.QtGui.QRhiCommandBuffer.debugMarkBegin(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtGui.QRhiCommandBuffer.debugMarkEnd(self)",
    "PySide6.QtGui.QRhiCommandBuffer.debugMarkMsg(self,msg:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtGui.QRhiCommandBuffer.dispatch(self,x:int,y:int,z:int)",
    "PySide6.QtGui.QRhiCommandBuffer.draw(self,vertexCount:quint32,instanceCount:quint32=1,firstVertex:quint32=0,firstInstance:quint32=0)",
    "PySide6.QtGui.QRhiCommandBuffer.drawIndexed(self,indexCount:quint32,instanceCount:quint32=1,firstIndex:quint32=0,vertexOffset:qint32=0,firstInstance:quint32=0)",
    "PySide6.QtGui.QRhiCommandBuffer.endComputePass(self,resourceUpdates:PySide6.QtGui.QRhiResourceUpdateBatch=nullptr)",
    "PySide6.QtGui.QRhiCommandBuffer.endExternal(self)",
    "PySide6.QtGui.QRhiCommandBuffer.endPass(self,resourceUpdates:PySide6.QtGui.QRhiResourceUpdateBatch=nullptr)",
    "PySide6.QtGui.QRhiCommandBuffer.lastCompletedGpuTime(self)->double",
    "PySide6.QtGui.QRhiCommandBuffer.nativeHandles(self)->PySide6.QtGui.QRhiNativeHandles",
    "PySide6.QtGui.QRhiCommandBuffer.resourceType(self)->PySide6.QtGui.QRhiResource.Type",
    "PySide6.QtGui.QRhiCommandBuffer.resourceUpdate(self,resourceUpdates:PySide6.QtGui.QRhiResourceUpdateBatch)",
    "PySide6.QtGui.QRhiCommandBuffer.setBlendConstants(self,c:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGui.QRhiCommandBuffer.setComputePipeline(self,ps:PySide6.QtGui.QRhiComputePipeline)",
    "PySide6.QtGui.QRhiCommandBuffer.setGraphicsPipeline(self,ps:PySide6.QtGui.QRhiGraphicsPipeline)",
    "PySide6.QtGui.QRhiCommandBuffer.setScissor(self,scissor:PySide6.QtGui.QRhiScissor)",
    "PySide6.QtGui.QRhiCommandBuffer.setShaderResources(self,srb:PySide6.QtGui.QRhiShaderResourceBindings=nullptr,dynamicOffsetCount:int=0,dynamicOffsets:std.pair[int, unsigned int]=nullptr)",
    "PySide6.QtGui.QRhiCommandBuffer.setStencilRef(self,refValue:quint32)",
    "PySide6.QtGui.QRhiCommandBuffer.setVertexInput(self,startBinding:int,bindings:QList[std.pair[PySide6.QtGui.QRhiBuffer, quint32]],indexBuf:PySide6.QtGui.QRhiBuffer=nullptr,indexOffset:quint32=0,indexFormat:PySide6.QtGui.QRhiCommandBuffer.IndexFormat=QRhiCommandBuffer.IndexUInt16)",
    "PySide6.QtGui.QRhiCommandBuffer.setViewport(self,viewport:PySide6.QtGui.QRhiViewport)",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiCommandBuffer_SignatureByteSize = 692;
static constexpr uint8_t QRhiCommandBuffer_SignatureBytes[692] = {
    0x78, 0xda, 0xcd, 0x56, 0x4d, 0x6f, 0xdb, 0x30, 0x0c, 0xbd, 0xf7, 0x57, 0xe4, 0xb8, 0x0e, 0x9e,
    0xb1, 0x6e, 0x43, 0x0f, 0x06, 0x32, 0x60, 0xc9, 0xda, 0x2c, 0x40, 0xbb, 0xe5, 0xa3, 0xed, 0xa5,
    0xc8, 0x81, 0xb6, 0x68, 0x47, 0x98, 0x22, 0x6b, 0x12, 0xdd, 0xc6, 0x1b, 0xf6, 0xdf, 0x27, 0x5b,
    0x76, 0x9a, 0x34, 0x09, 0xa2, 0xa2, 0xc5, 0xd0, 0x8b, 0x83, 0xd0, 0x8f, 0x8f, 0x8f, 0xa4, 0x4c,
    0x6a, 0x54, 0x4e, 0x39, 0xc3, 0xd3, 0x70, 0x4c, 0x83, 0x82, 0x87, 0xe3, 0xc9, 0x9c, 0xf7, 0xf3,
    0xc5, 0x02, 0x24, 0xeb, 0x15, 0x69, 0x8a, 0x3a, 0x8c, 0x31, 0xe3, 0xd2, 0x9a, 0x54, 0x41, 0x38,
    0x02, 0x63, 0xde, 0x18, 0x14, 0x69, 0xa0, 0xd1, 0xe4, 0x85, 0x4e, 0xf0, 0x5a, 0x31, 0x20, 0x34,
    0xd1, 0x68, 0x8b, 0x65, 0xb2, 0x81, 0xe8, 0x01, 0x25, 0xf3, 0xae, 0x2c, 0x84, 0x50, 0xa4, 0x83,
    0x54, 0x40, 0xb6, 0xcb, 0x67, 0x33, 0x72, 0xaf, 0x8a, 0x5c, 0x85, 0x3c, 0xb7, 0xf0, 0xee, 0x9f,
    0xbf, 0xc7, 0x47, 0x23, 0x1f, 0xad, 0x67, 0x4b, 0x42, 0x2d, 0x41, 0xd4, 0x42, 0x3d, 0x7d, 0xd6,
    0x12, 0xa3, 0x9d, 0xb9, 0x48, 0x86, 0xfa, 0x0a, 0x74, 0x86, 0x14, 0x24, 0xb9, 0xc8, 0x75, 0x5f,
    0x20, 0xe8, 0x1b, 0x10, 0x05, 0x46, 0x54, 0x2a, 0x2e, 0xb3, 0xf0, 0x5a, 0xf2, 0x5c, 0xde, 0x3e,
    0xf2, 0xed, 0x57, 0xd8, 0xa0, 0x33, 0xbe, 0x00, 0xe2, 0xf2, 0x64, 0x4a, 0xda, 0x22, 0x83, 0xce,
    0xe3, 0x00, 0x59, 0x0c, 0xa7, 0x9f, 0x2c, 0xea, 0x06, 0x34, 0x07, 0x49, 0xeb, 0x80, 0x7e, 0xae,
    0xd1, 0xfe, 0x84, 0x03, 0x91, 0xc7, 0x20, 0x5a, 0xba, 0x96, 0xa8, 0x90, 0x86, 0x67, 0x12, 0x59,
    0x87, 0x4b, 0x9a, 0x05, 0x0c, 0x15, 0xcd, 0xa7, 0x84, 0x32, 0xe1, 0x62, 0x4d, 0xdf, 0x76, 0x3a,
    0x5f, 0x77, 0x02, 0x5f, 0x69, 0x4f, 0x19, 0xc6, 0x45, 0x76, 0x09, 0xfa, 0x67, 0xed, 0xea, 0x9a,
    0x24, 0x61, 0xb1, 0xb7, 0xee, 0xae, 0x62, 0xbd, 0x92, 0xf0, 0x8b, 0xd6, 0x50, 0x06, 0x9d, 0x64,
    0x0e, 0xfa, 0xed, 0xec, 0x09, 0x81, 0xce, 0x24, 0xf3, 0x3c, 0x3b, 0x2b, 0x97, 0x4b, 0x93, 0x39,
    0x65, 0x0b, 0x93, 0xbd, 0xbc, 0x30, 0x6e, 0x54, 0x55, 0x6a, 0x17, 0x61, 0x19, 0xd9, 0x66, 0x07,
    0x65, 0xfd, 0xfc, 0x5d, 0x3d, 0x3d, 0x08, 0x34, 0xdc, 0x3b, 0xe7, 0x3b, 0xd4, 0x84, 0xcb, 0x7e,
    0x5e, 0x48, 0x8a, 0x7e, 0x15, 0xd6, 0xf9, 0xe3, 0x87, 0x80, 0x4b, 0x43, 0x20, 0x13, 0xdc, 0xb0,
    0x76, 0x4f, 0x82, 0x94, 0x6b, 0x43, 0x37, 0xb5, 0xc3, 0xca, 0xfa, 0xde, 0x59, 0x87, 0x8d, 0xcb,
    0x83, 0xdd, 0x4f, 0xc4, 0xd0, 0x7e, 0x46, 0x4b, 0x74, 0xd5, 0xb5, 0x71, 0xd9, 0x93, 0xa4, 0xd4,
    0xce, 0x6b, 0x4a, 0x5c, 0x2e, 0x3f, 0xd2, 0xd4, 0xa0, 0xc5, 0x3e, 0x5b, 0x9f, 0xfd, 0xc4, 0x5f,
    0x76, 0xca, 0x79, 0x85, 0x7c, 0xe2, 0xb0, 0xb2, 0x1e, 0xff, 0x4d, 0x9d, 0x00, 0x43, 0x55, 0x45,
    0x04, 0x12, 0xb2, 0x81, 0x2a, 0xae, 0xf8, 0x02, 0x9d, 0xcc, 0x77, 0x9f, 0x59, 0x5e, 0xc4, 0x02,
    0x0f, 0x52, 0x48, 0x3b, 0xf6, 0xee, 0xf0, 0x9b, 0x35, 0x08, 0x34, 0xad, 0xef, 0xb6, 0xd3, 0xf7,
    0x75, 0xd8, 0x41, 0xd2, 0x36, 0xed, 0xab, 0x52, 0xe1, 0x7e, 0xce, 0x36, 0xf5, 0xb0, 0x82, 0x79,
    0x73, 0xba, 0x42, 0x3d, 0xa3, 0xbc, 0x87, 0xcb, 0x6a, 0x4f, 0x6b, 0x4f, 0xd4, 0x87, 0xad, 0x3e,
    0xa4, 0xd4, 0x34, 0x33, 0x79, 0x35, 0x7b, 0xc4, 0x2b, 0x85, 0xf6, 0x53, 0xe1, 0x0a, 0x05, 0x97,
    0x4d, 0xc5, 0xd4, 0x9e, 0xf9, 0xbf, 0x8e, 0xf4, 0x62, 0x1f, 0x68, 0x50, 0x73, 0x9e, 0x18, 0x0f,
    0xfa, 0xc7, 0x50, 0x2f, 0xfe, 0x69, 0xc2, 0x8d, 0xc9, 0xb5, 0xa3, 0x35, 0xee, 0xcf, 0x0e, 0xee,
    0x06, 0xe6, 0x47, 0x39, 0x07, 0x7b, 0x45, 0x68, 0x4f, 0x44, 0xd3, 0x54, 0xa3, 0xe3, 0x5d, 0xb4,
    0x1b, 0xd0, 0x9e, 0x9d, 0x83, 0xb6, 0x09, 0x66, 0xb5, 0x48, 0x59, 0x69, 0xd7, 0x1b, 0x4f, 0xdc,
    0x60, 0x73, 0x93, 0xd0, 0xb6, 0xc5, 0x8e, 0xb6, 0x8d, 0x17, 0x26, 0x32, 0xc4, 0x42, 0x05, 0x5c,
    0xdf, 0x56, 0x9b, 0x60, 0xb3, 0x85, 0xfe, 0x1f, 0x79, 0xa5, 0xdc, 0x5d, 0x04, 0x26, 0x98, 0xb6,
    0xe7, 0x3e, 0x75, 0x17, 0x87, 0x66, 0x78, 0x7a, 0x91, 0xb8, 0x3d, 0x31, 0x94, 0xb6, 0xd5, 0x4d,
    0xea, 0x04, 0x9a, 0x9a, 0xdc, 0xea, 0x5d, 0x15, 0x37, 0x79, 0x46, 0xe3, 0x0b, 0x6e, 0xe8, 0x76,
    0xa5, 0x7e, 0x9b, 0xdc, 0xb1, 0x06, 0x9d, 0x26, 0xfe, 0x6c, 0xe6, 0x56, 0x85, 0x35, 0x47, 0xfb,
    0xc0, 0xab, 0xe2, 0xd5, 0xc8, 0x76, 0x27, 0xac, 0x56, 0x45, 0x6d, 0x3d, 0xcf, 0xf5, 0x02, 0xe8,
    0xe0, 0x0d, 0x65, 0xf8, 0x80, 0xed, 0xee, 0x79, 0x7b, 0x3d, 0x94, 0x74, 0x72, 0xea, 0x57, 0x17,
    0x8e, 0xf7, 0x2a, 0xd7, 0x4d, 0x51, 0xee, 0x9a, 0x7f, 0x3b, 0x44, 0xb4, 0xc0, 0xe3, 0xa3, 0x7f,
    0xdf, 0xc7, 0x39, 0x51
};
#endif

PyTypeObject *init_QRhiCommandBuffer(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiCommandBuffer_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_IDX]))));

    _Sbk_QRhiCommandBuffer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiCommandBuffer",
        "QRhiCommandBuffer*",
        &Sbk_QRhiCommandBuffer_spec,
        &Shiboken::callCppDestructor< QRhiCommandBuffer >,
        Sbk_QRhiCommandBuffer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRhiCommandBuffer_TypeF(); // references _Sbk_QRhiCommandBuffer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiCommandBuffer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiCommandBuffer_SignatureBytes, QRhiCommandBuffer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiCommandBuffer_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiCommandBuffer_PythonToCpp_QRhiCommandBuffer_PTR,
        is_QRhiCommandBuffer_PythonToCpp_QRhiCommandBuffer_PTR_Convertible,
        QRhiCommandBuffer_PTR_CppToPython_QRhiCommandBuffer);

    Shiboken::Conversions::registerConverterName(converter, "QRhiCommandBuffer");
    Shiboken::Conversions::registerConverterName(converter, "QRhiCommandBuffer*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiCommandBuffer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiCommandBuffer).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRhiCommandBufferWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRhiCommandBuffer_TypeF(), &Sbk_QRhiCommandBuffer_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRhiCommandBuffer_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'IndexFormat'.
    const char *IndexFormat_Initializer[] = {
        "IndexUInt16",
        "IndexUInt32",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t IndexFormat_InitializerValues[] = {
        uint8_t(QRhiCommandBuffer::IndexFormat::IndexUInt16), //  0x00  0
        uint8_t(QRhiCommandBuffer::IndexFormat::IndexUInt32)  //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiCommandBuffer_TypeF(),
        "2:PySide6.QtGui.QRhiCommandBuffer.IndexFormat",
        IndexFormat_Initializer, IndexFormat_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IndexFormat_IDX].type = EType;
    // Register converter for enum 'QRhiCommandBuffer::IndexFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiCommandBuffer_IndexFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiCommandBuffer_IndexFormat,
            is_Enum_PythonToCpp_QRhiCommandBuffer_IndexFormat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiCommandBuffer::IndexFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "IndexFormat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'IndexFormat' enum.

    // Initialization of enum 'BeginPassFlag'.
    const char *BeginPassFlag_Initializer[] = {
        "ExternalContent",
        "DoNotTrackResourcesForCompute",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t BeginPassFlag_InitializerValues[] = {
        uint8_t(QRhiCommandBuffer::BeginPassFlag::ExternalContent),              //  0x01  1
        uint8_t(QRhiCommandBuffer::BeginPassFlag::DoNotTrackResourcesForCompute) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiCommandBuffer_TypeF(),
        "2:PySide6.QtGui.QRhiCommandBuffer.BeginPassFlag",
        BeginPassFlag_Initializer, BeginPassFlag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_BeginPassFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiCommandBuffer_BeginPassFlag_IDX].type =
        EType;
    // Register converter for enum 'QRhiCommandBuffer::BeginPassFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiCommandBuffer_BeginPassFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiCommandBuffer_BeginPassFlag,
            is_Enum_PythonToCpp_QRhiCommandBuffer_BeginPassFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiCommandBuffer::BeginPassFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "BeginPassFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QRhiCommandBuffer_BeginPassFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QRhiCommandBuffer_BeginPassFlag,
            is_Enum_PythonToCpp_QRhiCommandBuffer_BeginPassFlag_Convertible);
        // Register converter for flag 'QFlags<QRhiCommandBuffer::BeginPassFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QRhiCommandBuffer::BeginPassFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QRhiCommandBuffer::BeginPassFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'BeginPassFlag' enum/flags.

    qRegisterMetaType< ::QRhiCommandBuffer *>();
    qRegisterMetaType< ::QRhiCommandBuffer::IndexFormat >("QRhiCommandBuffer::IndexFormat");
    qRegisterMetaType< ::QRhiCommandBuffer::BeginPassFlag >("QRhiCommandBuffer::BeginPassFlag");

    return pyType;
}
