// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhicomputepipeline_wrapper.h"

// Argument includes
#include <qbytearray.h>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRhiComputePipelineWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

bool QRhiComputePipelineWrapper::create()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiComputePipeline.create");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "create";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiComputePipeline.create");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiComputePipeline", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiComputePipeline", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRhiComputePipelineWrapper::destroy()
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiComputePipeline.destroy");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "destroy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiComputePipeline.destroy");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiComputePipeline", funcName);
        return;
    }
}

::QRhiResource::Type QRhiComputePipelineWrapper::resourceType() const
{
    if (m_PyMethodCache[2])
        return this->::QRhiComputePipeline::resourceType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QRhiResource::Buffer;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resourceType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QRhiComputePipeline::resourceType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiComputePipeline", funcName);
        return QRhiResource::Buffer;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiComputePipeline", funcName, Shiboken::SbkType< QRhiResource::Type >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QRhiResource::Buffer;
    }
    ::QRhiResource::Type cppResult{QRhiResource::Buffer};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QRhiComputePipelineWrapper::~QRhiComputePipelineWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QRhiComputePipelineFunc_create(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiComputePipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // create()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QRhiComputePipeline.create");
            return {};
        }
        bool cppResult = cppSelf->create();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiComputePipelineFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiComputePipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QRhiComputePipeline::Flag> cppResult = const_cast<const ::QRhiComputePipeline *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiComputePipeline_Flag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiComputePipelineFunc_resourceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiComputePipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resourceType()const
        QRhiResource::Type cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QRhiComputePipeline *>(cppSelf)->::QRhiComputePipeline::resourceType()
            : const_cast<const ::QRhiComputePipeline *>(cppSelf)->resourceType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiComputePipelineFunc_setFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiComputePipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiComputePipeline::setFlags(QFlags<QRhiComputePipeline::Flag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiComputePipeline_Flag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setFlags(QFlags<QRhiComputePipeline::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlags", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]);

    // Call function/method
    {
        ::QFlags<QRhiComputePipeline::Flag> cppArg0 = QFlags<QRhiComputePipeline::Flag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlags(QFlags<QRhiComputePipeline::Flag>)
            cppSelf->setFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiComputePipelineFunc_setShaderResourceBindings(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiComputePipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiComputePipeline::setShaderResourceBindings(QRhiShaderResourceBindings*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), (pyArg)))) {
        overloadId = 0; // setShaderResourceBindings(QRhiShaderResourceBindings*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShaderResourceBindings", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiShaderResourceBindings *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShaderResourceBindings(QRhiShaderResourceBindings*)
            cppSelf->setShaderResourceBindings(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiComputePipelineFunc_setShaderStage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiComputePipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiComputePipeline::setShaderStage(QRhiShaderStage)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderStage_IDX]), (pyArg)))) {
        overloadId = 0; // setShaderStage(QRhiShaderStage)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShaderStage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiShaderStage cppArg0_local;
        ::QRhiShaderStage *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setShaderStage(QRhiShaderStage)
            cppSelf->setShaderStage(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiComputePipelineFunc_shaderResourceBindings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiComputePipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shaderResourceBindings()const
        QRhiShaderResourceBindings * cppResult = const_cast<const ::QRhiComputePipeline *>(cppSelf)->shaderResourceBindings();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiComputePipelineFunc_shaderStage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiComputePipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shaderStage()const
        QRhiShaderStage cppResult = const_cast<const ::QRhiComputePipeline *>(cppSelf)->shaderStage();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderStage_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiComputePipeline_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRhiComputePipeline_EnumFlagInfo[] = {
    "Flag:Flag:Flags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiComputePipeline_methods[] = {
    {"create", reinterpret_cast<PyCFunction>(Sbk_QRhiComputePipelineFunc_create), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QRhiComputePipelineFunc_flags), METH_NOARGS, nullptr},
    {"resourceType", reinterpret_cast<PyCFunction>(Sbk_QRhiComputePipelineFunc_resourceType), METH_NOARGS, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_QRhiComputePipelineFunc_setFlags), METH_O, nullptr},
    {"setShaderResourceBindings", reinterpret_cast<PyCFunction>(Sbk_QRhiComputePipelineFunc_setShaderResourceBindings), METH_O, nullptr},
    {"setShaderStage", reinterpret_cast<PyCFunction>(Sbk_QRhiComputePipelineFunc_setShaderStage), METH_O, nullptr},
    {"shaderResourceBindings", reinterpret_cast<PyCFunction>(Sbk_QRhiComputePipelineFunc_shaderResourceBindings), METH_NOARGS, nullptr},
    {"shaderStage", reinterpret_cast<PyCFunction>(Sbk_QRhiComputePipelineFunc_shaderStage), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRhiComputePipeline_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRhiComputePipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRhiComputePipelineWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QRhiComputePipeline_get_m_flags(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiComputePipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiComputePipeline_Flag_IDX])))->flagsConverter, &cppSelf->m_flags);
    return pyOut;
}
static int Sbk_QRhiComputePipeline_set_m_flags(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiComputePipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_flags");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiComputePipeline_Flag_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_flags", "Flags");
        return -1;
    }

    auto cppOut_local = cppSelf->m_flags;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_flags = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiComputePipeline_get_m_shaderStage(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiComputePipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->m_shaderStage)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderStage_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->m_shaderStage))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->m_shaderStage)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderStage_IDX]), &(cppSelf->m_shaderStage), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QRhiComputePipeline_set_m_shaderStage(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiComputePipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_shaderStage");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderStage_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_shaderStage", "QRhiShaderStage");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_shaderStage;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiComputePipeline_get_m_shaderResourceBindings(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiComputePipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), cppSelf->m_shaderResourceBindings);
    return pyOut;
}
static int Sbk_QRhiComputePipeline_set_m_shaderResourceBindings(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiComputePipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_shaderResourceBindings");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_shaderResourceBindings", "QRhiShaderResourceBindings");
        return -1;
    }

    auto *&cppOut_ptr = cppSelf->m_shaderResourceBindings;
    pythonToCpp(pyIn, &cppOut_ptr);

    Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "m_shaderResourceBindings", pyIn);
    return 0;
}

// Getters and Setters for QRhiComputePipeline
static PyGetSetDef Sbk_QRhiComputePipeline_getsetlist[] = {
    {const_cast<char *>("m_flags"), Sbk_QRhiComputePipeline_get_m_flags, Sbk_QRhiComputePipeline_set_m_flags, nullptr, nullptr},
    {const_cast<char *>("m_shaderStage"), Sbk_QRhiComputePipeline_get_m_shaderStage, Sbk_QRhiComputePipeline_set_m_shaderStage, nullptr, nullptr},
    {const_cast<char *>("m_shaderResourceBindings"), Sbk_QRhiComputePipeline_get_m_shaderResourceBindings, Sbk_QRhiComputePipeline_set_m_shaderResourceBindings, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiComputePipeline_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiComputePipeline_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiComputePipeline_Type = nullptr;
static PyTypeObject *Sbk_QRhiComputePipeline_TypeF(void)
{
    return _Sbk_QRhiComputePipeline_Type;
}

static PyType_Slot Sbk_QRhiComputePipeline_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRhiComputePipeline_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiComputePipeline_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiComputePipeline_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiComputePipeline_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiComputePipeline_getsetlist)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiComputePipeline_spec = {
    "2:PySide6.QtGui.QRhiComputePipeline",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiComputePipeline_slots
};

} //extern "C"

static void *Sbk_QRhiComputePipeline_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QRhiResource >())
        return dynamic_cast< ::QRhiComputePipeline *>(reinterpret_cast< ::QRhiResource *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QRhiComputePipeline_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiComputePipeline::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiComputePipeline::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiComputePipeline_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_Flag_IDX])))
        return Enum_PythonToCpp_QRhiComputePipeline_Flag;
    return {};
}

static PyObject *QRhiComputePipeline_Flag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiComputePipeline::Flag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiComputePipeline::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_Flag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QRhiComputePipeline_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QRhiComputePipeline::Flag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QRhiComputePipeline::Flag> *>(cppOut) = value;

}

static PyObject *QRhiComputePipeline_Flag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QRhiComputePipeline::Flag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_Flag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiComputePipeline_PythonToCpp_QRhiComputePipeline_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiComputePipeline_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiComputePipeline_PythonToCpp_QRhiComputePipeline_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiComputePipeline_TypeF()))
        return QRhiComputePipeline_PythonToCpp_QRhiComputePipeline_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiComputePipeline_PTR_CppToPython_QRhiComputePipeline(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QRhiComputePipeline *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QRhiComputePipeline_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiComputePipeline_SignatureStrings[] = {
    "PySide6.QtGui.QRhiComputePipeline.create(self)->bool",
    "PySide6.QtGui.QRhiComputePipeline.flags(self)->PySide6.QtGui.QRhiComputePipeline.Flag",
    "PySide6.QtGui.QRhiComputePipeline.resourceType(self)->PySide6.QtGui.QRhiResource.Type",
    "PySide6.QtGui.QRhiComputePipeline.setFlags(self,f:PySide6.QtGui.QRhiComputePipeline.Flag)",
    "PySide6.QtGui.QRhiComputePipeline.setShaderResourceBindings(self,srb:PySide6.QtGui.QRhiShaderResourceBindings)",
    "PySide6.QtGui.QRhiComputePipeline.setShaderStage(self,stage:PySide6.QtGui.QRhiShaderStage)",
    "PySide6.QtGui.QRhiComputePipeline.shaderResourceBindings(self)->PySide6.QtGui.QRhiShaderResourceBindings",
    "PySide6.QtGui.QRhiComputePipeline.shaderStage(self)->PySide6.QtGui.QRhiShaderStage",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiComputePipeline_SignatureByteSize = 172;
static constexpr uint8_t QRhiComputePipeline_SignatureBytes[172] = {
    0x78, 0xda, 0x95, 0x91, 0xbd, 0x0e, 0x82, 0x30, 0x14, 0x85, 0x77, 0x9e, 0x44, 0x12, 0xed, 0xe8,
    0xc0, 0xe0, 0xa0, 0x09, 0xae, 0xfc, 0xf8, 0x02, 0x85, 0x1e, 0xe0, 0x26, 0x95, 0x92, 0xb6, 0x0c,
    0xbc, 0xbd, 0x42, 0x40, 0x97, 0x56, 0xea, 0xd6, 0xe1, 0x3b, 0xdf, 0x39, 0x37, 0xcd, 0xa6, 0x92,
    0x04, 0xce, 0x2c, 0xb7, 0xf7, 0x91, 0x58, 0x5e, 0x74, 0x74, 0x53, 0xcf, 0x61, 0xb4, 0xc8, 0x68,
    0x80, 0xa4, 0x1e, 0xac, 0xd6, 0xe0, 0x16, 0x07, 0x03, 0xd9, 0xc4, 0xa7, 0x4b, 0xa5, 0x94, 0x8c,
    0xb2, 0xdd, 0x50, 0x23, 0x79, 0x6b, 0xb6, 0xcc, 0x3e, 0x9e, 0xbe, 0xf1, 0x00, 0xab, 0x86, 0x51,
    0xa3, 0xae, 0xf1, 0x98, 0x06, 0xf8, 0xe5, 0xc5, 0x4a, 0xb1, 0x19, 0x0b, 0xb0, 0x1a, 0xd8, 0xf4,
    0x33, 0xf7, 0xd8, 0x24, 0x61, 0x73, 0xe3, 0x30, 0x73, 0xd9, 0x71, 0x01, 0xbd, 0x4d, 0xba, 0x52,
    0x2f, 0xa8, 0xdf, 0xaa, 0x8c, 0xae, 0x1c, 0x65, 0xee, 0xc4, 0x5f, 0x75, 0xa5, 0xe5, 0x2d, 0xd6,
    0x8e, 0xf9, 0xe9, 0x6d, 0x59, 0xc0, 0x20, 0xb5, 0xff, 0x0c, 0xe7, 0x1f, 0xb8, 0x8f, 0x08, 0x2e,
    0xfa, 0x1e, 0xf0, 0xc3, 0xbe, 0x40, 0xd1, 0x0b, 0xee, 0xee, 0x01, 0x22
};
#endif

PyTypeObject *init_QRhiComputePipeline(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiComputePipeline_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_IDX]))));

    _Sbk_QRhiComputePipeline_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiComputePipeline",
        "QRhiComputePipeline*",
        &Sbk_QRhiComputePipeline_spec,
        &Shiboken::callCppDestructor< QRhiComputePipeline >,
        Sbk_QRhiComputePipeline_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRhiComputePipeline_TypeF(); // references _Sbk_QRhiComputePipeline_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiComputePipeline_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiComputePipeline_SignatureBytes, QRhiComputePipeline_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiComputePipeline_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiComputePipeline_PythonToCpp_QRhiComputePipeline_PTR,
        is_QRhiComputePipeline_PythonToCpp_QRhiComputePipeline_PTR_Convertible,
        QRhiComputePipeline_PTR_CppToPython_QRhiComputePipeline);

    Shiboken::Conversions::registerConverterName(converter, "QRhiComputePipeline");
    Shiboken::Conversions::registerConverterName(converter, "QRhiComputePipeline*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiComputePipeline&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiComputePipeline).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRhiComputePipelineWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRhiComputePipeline_TypeF(), &Sbk_QRhiComputePipeline_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRhiComputePipeline_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "CompileShadersWithDebugInfo",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Flag_InitializerValues[] = {
        uint8_t(QRhiComputePipeline::Flag::CompileShadersWithDebugInfo) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiComputePipeline_TypeF(),
        "2:PySide6.QtGui.QRhiComputePipeline.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiComputePipeline_Flag_IDX].type =
        EType;
    // Register converter for enum 'QRhiComputePipeline::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiComputePipeline_Flag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiComputePipeline_Flag,
            is_Enum_PythonToCpp_QRhiComputePipeline_Flag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiComputePipeline::Flag");
        Shiboken::Conversions::registerConverterAlias(converter, "Flag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QRhiComputePipeline_Flag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QRhiComputePipeline_Flag,
            is_Enum_PythonToCpp_QRhiComputePipeline_Flag_Convertible);
        // Register converter for flag 'QFlags<QRhiComputePipeline::Flag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QRhiComputePipeline::Flag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QRhiComputePipeline::Flags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Flag' enum/flags.

    qRegisterMetaType< ::QRhiComputePipeline *>();
    qRegisterMetaType< ::QRhiComputePipeline::Flag >("QRhiComputePipeline::Flag");

    return pyType;
}
