// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhinativehandles_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRhiNativeHandles_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRhiNativeHandles >()))
        return -1;

    ::QRhiNativeHandles *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QRhiNativeHandles", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRhiNativeHandles::QRhiNativeHandles()
    // 1: QRhiNativeHandles::QRhiNativeHandles(QRhiNativeHandles)
    if (numArgs == 0) {
        overloadId = 0; // QRhiNativeHandles()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiNativeHandles_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QRhiNativeHandles(QRhiNativeHandles)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiNativeHandles_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QRhiNativeHandles_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRhiNativeHandles()
        {

            // QRhiNativeHandles()
            cptr = new ::QRhiNativeHandles();
            break;
        }
        case 1: // QRhiNativeHandles(const QRhiNativeHandles &QRhiNativeHandles)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRhiNativeHandles cppArg0_local;
            ::QRhiNativeHandles *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiNativeHandles(QRhiNativeHandles)
                cptr = new ::QRhiNativeHandles(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRhiNativeHandles >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiNativeHandles_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRhiNativeHandles__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRhiNativeHandles *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiNativeHandles_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiNativeHandles_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiNativeHandles_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiNativeHandles_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QRhiNativeHandles__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiNativeHandles_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiNativeHandles_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiNativeHandles_Type = nullptr;
static PyTypeObject *Sbk_QRhiNativeHandles_TypeF(void)
{
    return _Sbk_QRhiNativeHandles_Type;
}

static PyType_Slot Sbk_QRhiNativeHandles_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiNativeHandles_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiNativeHandles_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiNativeHandles_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRhiNativeHandles_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiNativeHandles_spec = {
    "2:PySide6.QtGui.QRhiNativeHandles",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiNativeHandles_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiNativeHandles_PythonToCpp_QRhiNativeHandles_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiNativeHandles_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiNativeHandles_PythonToCpp_QRhiNativeHandles_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiNativeHandles_TypeF()))
        return QRhiNativeHandles_PythonToCpp_QRhiNativeHandles_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiNativeHandles_PTR_CppToPython_QRhiNativeHandles(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QRhiNativeHandles_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QRhiNativeHandles_COPY_CppToPython_QRhiNativeHandles(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QRhiNativeHandles *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QRhiNativeHandles_TypeF(), new ::QRhiNativeHandles(*source), true, true);
}

// Python to C++ copy conversion.
static void QRhiNativeHandles_PythonToCpp_QRhiNativeHandles_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRhiNativeHandles *>(cppOut) = *reinterpret_cast< ::QRhiNativeHandles *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiNativeHandles_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QRhiNativeHandles_PythonToCpp_QRhiNativeHandles_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiNativeHandles_TypeF()))
        return QRhiNativeHandles_PythonToCpp_QRhiNativeHandles_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiNativeHandles_SignatureStrings[] = {
    "1:PySide6.QtGui.QRhiNativeHandles(self)",
    "0:PySide6.QtGui.QRhiNativeHandles(self,QRhiNativeHandles:PySide6.QtGui.QRhiNativeHandles)",
    "PySide6.QtGui.QRhiNativeHandles.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiNativeHandles_SignatureByteSize = 85;
static constexpr uint8_t QRhiNativeHandles_SignatureBytes[85] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x0c, 0xca, 0xc8, 0xf4, 0x4b, 0x2c, 0xc9, 0x2c, 0x4b, 0xf5, 0x48, 0xcc, 0x4b,
    0xc9, 0x49, 0x2d, 0xd6, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x20, 0x4a, 0x9d, 0x0e, 0x86,
    0x30, 0x21, 0x6d, 0x9a, 0x5c, 0x04, 0x14, 0xe8, 0xc5, 0xc7, 0x27, 0xe7, 0x17, 0x54, 0xc6, 0xc7,
    0x43, 0x1c, 0xa2, 0x6b, 0x57, 0x52, 0x59, 0x90, 0x99, 0x97, 0xae, 0x17, 0x0c, 0xe4, 0x71, 0x01,
    0x00, 0x0c, 0x95, 0x43, 0x98
};
#endif

PyTypeObject *init_QRhiNativeHandles(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiNativeHandles_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiNativeHandles_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiNativeHandles_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRhiNativeHandles_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiNativeHandles",
        "QRhiNativeHandles",
        &Sbk_QRhiNativeHandles_spec,
        &Shiboken::callCppDestructor< ::QRhiNativeHandles >,
        Sbk_QRhiNativeHandles_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QRhiNativeHandles_TypeF(); // references _Sbk_QRhiNativeHandles_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiNativeHandles_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiNativeHandles_SignatureBytes, QRhiNativeHandles_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiNativeHandles_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiNativeHandles_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiNativeHandles_PythonToCpp_QRhiNativeHandles_PTR,
        is_QRhiNativeHandles_PythonToCpp_QRhiNativeHandles_PTR_Convertible,
        QRhiNativeHandles_PTR_CppToPython_QRhiNativeHandles,
        QRhiNativeHandles_COPY_CppToPython_QRhiNativeHandles);

    Shiboken::Conversions::registerConverterName(converter, "QRhiNativeHandles");
    Shiboken::Conversions::registerConverterName(converter, "QRhiNativeHandles*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiNativeHandles&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiNativeHandles).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QRhiNativeHandles_PythonToCpp_QRhiNativeHandles_COPY,
        is_QRhiNativeHandles_PythonToCpp_QRhiNativeHandles_COPY_Convertible);

    qRegisterMetaType< ::QRhiNativeHandles >("QRhiNativeHandles");

    return pyType;
}
