// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhireadbackdescription_wrapper.h"

// Argument includes
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRhiReadbackDescription_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRhiReadbackDescription >()))
        return -1;

    ::QRhiReadbackDescription *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QRhiReadbackDescription", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRhiReadbackDescription::QRhiReadbackDescription()
    // 1: QRhiReadbackDescription::QRhiReadbackDescription(QRhiTexture*)
    // 2: QRhiReadbackDescription::QRhiReadbackDescription(QRhiReadbackDescription)
    if (numArgs == 0) {
        overloadId = 0; // QRhiReadbackDescription()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QRhiReadbackDescription(QRhiTexture*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QRhiReadbackDescription(QRhiReadbackDescription)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRhiReadbackDescription()
        {

            // QRhiReadbackDescription()
            cptr = new ::QRhiReadbackDescription();
            break;
        }
        case 1: // QRhiReadbackDescription(QRhiTexture *texture)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRhiTexture *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiReadbackDescription(QRhiTexture*)
                cptr = new ::QRhiReadbackDescription(cppArg0);
            }
            break;
        }
        case 2: // QRhiReadbackDescription(const QRhiReadbackDescription &QRhiReadbackDescription)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRhiReadbackDescription cppArg0_local;
            ::QRhiReadbackDescription *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiReadbackDescription(QRhiReadbackDescription)
                cptr = new ::QRhiReadbackDescription(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRhiReadbackDescription >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRhiReadbackDescriptionFunc_layer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiReadbackDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // layer()const
        int cppResult = const_cast<const ::QRhiReadbackDescription *>(cppSelf)->layer();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiReadbackDescriptionFunc_level(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiReadbackDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // level()const
        int cppResult = const_cast<const ::QRhiReadbackDescription *>(cppSelf)->level();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiReadbackDescriptionFunc_setLayer(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiReadbackDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiReadbackDescription::setLayer(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLayer(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLayer", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLayer(int)
            cppSelf->setLayer(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiReadbackDescriptionFunc_setLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiReadbackDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiReadbackDescription::setLevel(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLevel(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLevel", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLevel(int)
            cppSelf->setLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiReadbackDescriptionFunc_setTexture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiReadbackDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiReadbackDescription::setTexture(QRhiTexture*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), (pyArg)))) {
        overloadId = 0; // setTexture(QRhiTexture*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTexture", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiTexture *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTexture(QRhiTexture*)
            cppSelf->setTexture(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiReadbackDescriptionFunc_texture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiReadbackDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // texture()const
        QRhiTexture * cppResult = const_cast<const ::QRhiReadbackDescription *>(cppSelf)->texture();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiReadbackDescription__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRhiReadbackDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiReadbackDescription_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiReadbackDescription_methods[] = {
    {"layer", reinterpret_cast<PyCFunction>(Sbk_QRhiReadbackDescriptionFunc_layer), METH_NOARGS, nullptr},
    {"level", reinterpret_cast<PyCFunction>(Sbk_QRhiReadbackDescriptionFunc_level), METH_NOARGS, nullptr},
    {"setLayer", reinterpret_cast<PyCFunction>(Sbk_QRhiReadbackDescriptionFunc_setLayer), METH_O, nullptr},
    {"setLevel", reinterpret_cast<PyCFunction>(Sbk_QRhiReadbackDescriptionFunc_setLevel), METH_O, nullptr},
    {"setTexture", reinterpret_cast<PyCFunction>(Sbk_QRhiReadbackDescriptionFunc_setTexture), METH_O, nullptr},
    {"texture", reinterpret_cast<PyCFunction>(Sbk_QRhiReadbackDescriptionFunc_texture), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QRhiReadbackDescription__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiReadbackDescription_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiReadbackDescription_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiReadbackDescription_Type = nullptr;
static PyTypeObject *Sbk_QRhiReadbackDescription_TypeF(void)
{
    return _Sbk_QRhiReadbackDescription_Type;
}

static PyType_Slot Sbk_QRhiReadbackDescription_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiReadbackDescription_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiReadbackDescription_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiReadbackDescription_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRhiReadbackDescription_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiReadbackDescription_spec = {
    "2:PySide6.QtGui.QRhiReadbackDescription",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiReadbackDescription_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiReadbackDescription_PythonToCpp_QRhiReadbackDescription_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiReadbackDescription_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiReadbackDescription_PythonToCpp_QRhiReadbackDescription_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiReadbackDescription_TypeF()))
        return QRhiReadbackDescription_PythonToCpp_QRhiReadbackDescription_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiReadbackDescription_PTR_CppToPython_QRhiReadbackDescription(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QRhiReadbackDescription_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QRhiReadbackDescription_COPY_CppToPython_QRhiReadbackDescription(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QRhiReadbackDescription *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QRhiReadbackDescription_TypeF(), new ::QRhiReadbackDescription(*source), true, true);
}

// Python to C++ copy conversion.
static void QRhiReadbackDescription_PythonToCpp_QRhiReadbackDescription_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRhiReadbackDescription *>(cppOut) = *reinterpret_cast< ::QRhiReadbackDescription *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QRhiReadbackDescription_PythonToCpp_QRhiReadbackDescription_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiReadbackDescription_TypeF()))
        return QRhiReadbackDescription_PythonToCpp_QRhiReadbackDescription_COPY;
    return {};
}

// Implicit conversions.
static void QRhiTexturePTR_PythonToCpp_QRhiReadbackDescription(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRhiReadbackDescription *>(cppOut) = ::QRhiReadbackDescription(reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_QRhiTexturePTR_PythonToCpp_QRhiReadbackDescription_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), pyIn))
        return QRhiTexturePTR_PythonToCpp_QRhiReadbackDescription;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiReadbackDescription_SignatureStrings[] = {
    "2:PySide6.QtGui.QRhiReadbackDescription(self)",
    "1:PySide6.QtGui.QRhiReadbackDescription(self,texture:PySide6.QtGui.QRhiTexture)",
    "0:PySide6.QtGui.QRhiReadbackDescription(self,QRhiReadbackDescription:PySide6.QtGui.QRhiReadbackDescription)",
    "PySide6.QtGui.QRhiReadbackDescription.layer(self)->int",
    "PySide6.QtGui.QRhiReadbackDescription.level(self)->int",
    "PySide6.QtGui.QRhiReadbackDescription.setLayer(self,layer:int)",
    "PySide6.QtGui.QRhiReadbackDescription.setLevel(self,level:int)",
    "PySide6.QtGui.QRhiReadbackDescription.setTexture(self,tex:PySide6.QtGui.QRhiTexture)",
    "PySide6.QtGui.QRhiReadbackDescription.texture(self)->PySide6.QtGui.QRhiTexture",
    "PySide6.QtGui.QRhiReadbackDescription.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiReadbackDescription_SignatureByteSize = 171;
static constexpr uint8_t QRhiReadbackDescription_SignatureBytes[171] = {
    0x78, 0xda, 0x33, 0xb2, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x0c, 0xca, 0xc8, 0x0c, 0x4a, 0x4d, 0x4c, 0x49, 0x4a, 0x4c, 0xce, 0x76, 0x49,
    0x2d, 0x4e, 0x2e, 0xca, 0x2c, 0x28, 0xc9, 0xcc, 0xcf, 0xd3, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4,
    0x32, 0x24, 0x41, 0xb5, 0x4e, 0x49, 0x6a, 0x45, 0x49, 0x69, 0x51, 0x2a, 0x16, 0x2d, 0x21, 0x10,
    0x19, 0x4d, 0x2e, 0x03, 0x52, 0xcc, 0xc3, 0x21, 0x49, 0x9c, 0x11, 0x9a, 0x5c, 0x44, 0x29, 0xd3,
    0xcb, 0x49, 0xac, 0x4c, 0x2d, 0x82, 0xf8, 0x56, 0xd7, 0x2e, 0x33, 0xaf, 0x84, 0x58, 0x6d, 0xa9,
    0x65, 0xa9, 0x39, 0xa4, 0x6b, 0x2b, 0x4e, 0x2d, 0xf1, 0x81, 0x5b, 0xa8, 0x03, 0xb6, 0xdb, 0x0a,
    0xa8, 0x5b, 0x93, 0x04, 0xed, 0x70, 0x8b, 0x75, 0xc0, 0x6e, 0x20, 0x51, 0x3b, 0x34, 0x26, 0xe0,
    0x11, 0x86, 0x2f, 0xb2, 0x88, 0x33, 0xb4, 0x04, 0xc9, 0x44, 0x60, 0x58, 0xe0, 0x34, 0x8f, 0x48,
    0xe3, 0xe2, 0xe3, 0x93, 0xf3, 0x0b, 0x2a, 0xe3, 0xe3, 0x61, 0xe6, 0x95, 0x54, 0x16, 0x64, 0xe6,
    0xa5, 0xeb, 0x05, 0x03, 0x79, 0x5c, 0x00, 0x42, 0x5e, 0xfe, 0x34
};
#endif

PyTypeObject *init_QRhiReadbackDescription(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiReadbackDescription_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRhiReadbackDescription_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiReadbackDescription",
        "QRhiReadbackDescription",
        &Sbk_QRhiReadbackDescription_spec,
        &Shiboken::callCppDestructor< ::QRhiReadbackDescription >,
        Sbk_QRhiReadbackDescription_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QRhiReadbackDescription_TypeF(); // references _Sbk_QRhiReadbackDescription_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiReadbackDescription_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiReadbackDescription_SignatureBytes, QRhiReadbackDescription_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiReadbackDescription_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiReadbackDescription_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiReadbackDescription_PythonToCpp_QRhiReadbackDescription_PTR,
        is_QRhiReadbackDescription_PythonToCpp_QRhiReadbackDescription_PTR_Convertible,
        QRhiReadbackDescription_PTR_CppToPython_QRhiReadbackDescription,
        QRhiReadbackDescription_COPY_CppToPython_QRhiReadbackDescription);

    Shiboken::Conversions::registerConverterName(converter, "QRhiReadbackDescription");
    Shiboken::Conversions::registerConverterName(converter, "QRhiReadbackDescription*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiReadbackDescription&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiReadbackDescription).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QRhiReadbackDescription_PythonToCpp_QRhiReadbackDescription_COPY,
        is_QRhiReadbackDescription_PythonToCpp_QRhiReadbackDescription_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QRhiTexturePTR_PythonToCpp_QRhiReadbackDescription,
        is_QRhiTexturePTR_PythonToCpp_QRhiReadbackDescription_Convertible);

    qRegisterMetaType< ::QRhiReadbackDescription >("QRhiReadbackDescription");

    return pyType;
}
