// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhirenderbuffer_wrapper.h"

// Argument includes
#include <qbytearray.h>
#include <qsize.h>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRhiRenderBufferWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

::QRhiTexture::Format QRhiRenderBufferWrapper::backingFormat() const
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderBuffer.backingFormat");
        return QRhiTexture::UnknownFormat;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QRhiTexture::UnknownFormat;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "backingFormat";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderBuffer.backingFormat");
        return QRhiTexture::UnknownFormat;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiRenderBuffer", funcName);
        return QRhiTexture::UnknownFormat;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiRenderBuffer", funcName, Shiboken::SbkType< QRhiTexture::Format >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QRhiTexture::UnknownFormat;
    }
    ::QRhiTexture::Format cppResult{QRhiTexture::UnknownFormat};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QRhiRenderBufferWrapper::create()
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderBuffer.create");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "create";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderBuffer.create");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiRenderBuffer", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiRenderBuffer", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRhiRenderBufferWrapper::destroy()
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderBuffer.destroy");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "destroy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderBuffer.destroy");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiRenderBuffer", funcName);
        return;
    }
}

::QRhiResource::Type QRhiRenderBufferWrapper::resourceType() const
{
    if (m_PyMethodCache[3])
        return this->::QRhiRenderBuffer::resourceType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QRhiResource::Buffer;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resourceType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QRhiRenderBuffer::resourceType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiRenderBuffer", funcName);
        return QRhiResource::Buffer;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiRenderBuffer", funcName, Shiboken::SbkType< QRhiResource::Type >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QRhiResource::Buffer;
    }
    ::QRhiResource::Type cppResult{QRhiResource::Buffer};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QRhiRenderBufferWrapper::~QRhiRenderBufferWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QRhiRenderBufferFunc_backingFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // backingFormat()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QRhiRenderBuffer.backingFormat");
            return {};
        }
        QRhiTexture::Format cppResult = const_cast<const ::QRhiRenderBuffer *>(cppSelf)->backingFormat();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiRenderBufferFunc_create(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // create()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QRhiRenderBuffer.create");
            return {};
        }
        bool cppResult = cppSelf->create();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiRenderBufferFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QRhiRenderBuffer::Flag> cppResult = const_cast<const ::QRhiRenderBuffer *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiRenderBuffer_Flag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiRenderBufferFunc_pixelSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pixelSize()const
        QSize cppResult = const_cast<const ::QRhiRenderBuffer *>(cppSelf)->pixelSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiRenderBufferFunc_resourceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resourceType()const
        QRhiResource::Type cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QRhiRenderBuffer *>(cppSelf)->::QRhiRenderBuffer::resourceType()
            : const_cast<const ::QRhiRenderBuffer *>(cppSelf)->resourceType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiRenderBufferFunc_sampleCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sampleCount()const
        int cppResult = const_cast<const ::QRhiRenderBuffer *>(cppSelf)->sampleCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiRenderBufferFunc_setFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiRenderBuffer::setFlags(QFlags<QRhiRenderBuffer::Flag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiRenderBuffer_Flag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setFlags(QFlags<QRhiRenderBuffer::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlags", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]);

    // Call function/method
    {
        ::QFlags<QRhiRenderBuffer::Flag> cppArg0 = QFlags<QRhiRenderBuffer::Flag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlags(QFlags<QRhiRenderBuffer::Flag>)
            cppSelf->setFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiRenderBufferFunc_setPixelSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiRenderBuffer::setPixelSize(QSize)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
        overloadId = 0; // setPixelSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPixelSize", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSize cppArg0_local;
        ::QSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPixelSize(QSize)
            cppSelf->setPixelSize(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiRenderBufferFunc_setSampleCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiRenderBuffer::setSampleCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSampleCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSampleCount", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSampleCount(int)
            cppSelf->setSampleCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiRenderBufferFunc_setType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiRenderBuffer::setType(QRhiRenderBuffer::Type)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_Type_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setType(QRhiRenderBuffer::Type)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setType", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]);

    // Call function/method
    {
        ::QRhiRenderBuffer::Type cppArg0{QRhiRenderBuffer::DepthStencil};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setType(QRhiRenderBuffer::Type)
            cppSelf->setType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiRenderBufferFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QRhiRenderBuffer::Type cppResult = const_cast<const ::QRhiRenderBuffer *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiRenderBuffer_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRhiRenderBuffer_EnumFlagInfo[] = {
    "Flag:Flag:Flags",
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiRenderBuffer_methods[] = {
    {"backingFormat", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderBufferFunc_backingFormat), METH_NOARGS, nullptr},
    {"create", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderBufferFunc_create), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderBufferFunc_flags), METH_NOARGS, nullptr},
    {"pixelSize", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderBufferFunc_pixelSize), METH_NOARGS, nullptr},
    {"resourceType", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderBufferFunc_resourceType), METH_NOARGS, nullptr},
    {"sampleCount", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderBufferFunc_sampleCount), METH_NOARGS, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderBufferFunc_setFlags), METH_O, nullptr},
    {"setPixelSize", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderBufferFunc_setPixelSize), METH_O, nullptr},
    {"setSampleCount", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderBufferFunc_setSampleCount), METH_O, nullptr},
    {"setType", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderBufferFunc_setType), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderBufferFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRhiRenderBuffer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRhiRenderBufferWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QRhiRenderBuffer_get_m_type(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiRenderBuffer::Type cppOut_local = cppSelf->m_type;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_Type_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiRenderBuffer_set_m_type(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_type");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_Type_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_type", "Type");
        return -1;
    }

    auto cppOut_local = cppSelf->m_type;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_type = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiRenderBuffer_get_m_pixelSize(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->m_pixelSize)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->m_pixelSize))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->m_pixelSize)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &(cppSelf->m_pixelSize), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QRhiRenderBuffer_set_m_pixelSize(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_pixelSize");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_pixelSize", "QSize");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_pixelSize;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiRenderBuffer_get_m_sampleCount(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->m_sampleCount;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiRenderBuffer_set_m_sampleCount(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_sampleCount");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_sampleCount", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->m_sampleCount;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_sampleCount = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiRenderBuffer_get_m_flags(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiRenderBuffer_Flag_IDX])))->flagsConverter, &cppSelf->m_flags);
    return pyOut;
}
static int Sbk_QRhiRenderBuffer_set_m_flags(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_flags");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiRenderBuffer_Flag_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_flags", "Flags");
        return -1;
    }

    auto cppOut_local = cppSelf->m_flags;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_flags = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiRenderBuffer_get_m_backingFormatHint(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiTexture::Format cppOut_local = cppSelf->m_backingFormatHint;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiRenderBuffer_set_m_backingFormatHint(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiRenderBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_backingFormatHint");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_backingFormatHint", "Format");
        return -1;
    }

    auto cppOut_local = cppSelf->m_backingFormatHint;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_backingFormatHint = cppOut_local;

    return 0;
}

// Getters and Setters for QRhiRenderBuffer
static PyGetSetDef Sbk_QRhiRenderBuffer_getsetlist[] = {
    {const_cast<char *>("m_type"), Sbk_QRhiRenderBuffer_get_m_type, Sbk_QRhiRenderBuffer_set_m_type, nullptr, nullptr},
    {const_cast<char *>("m_pixelSize"), Sbk_QRhiRenderBuffer_get_m_pixelSize, Sbk_QRhiRenderBuffer_set_m_pixelSize, nullptr, nullptr},
    {const_cast<char *>("m_sampleCount"), Sbk_QRhiRenderBuffer_get_m_sampleCount, Sbk_QRhiRenderBuffer_set_m_sampleCount, nullptr, nullptr},
    {const_cast<char *>("m_flags"), Sbk_QRhiRenderBuffer_get_m_flags, Sbk_QRhiRenderBuffer_set_m_flags, nullptr, nullptr},
    {const_cast<char *>("m_backingFormatHint"), Sbk_QRhiRenderBuffer_get_m_backingFormatHint, Sbk_QRhiRenderBuffer_set_m_backingFormatHint, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiRenderBuffer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiRenderBuffer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiRenderBuffer_Type = nullptr;
static PyTypeObject *Sbk_QRhiRenderBuffer_TypeF(void)
{
    return _Sbk_QRhiRenderBuffer_Type;
}

static PyType_Slot Sbk_QRhiRenderBuffer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRhiRenderBuffer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiRenderBuffer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiRenderBuffer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiRenderBuffer_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiRenderBuffer_getsetlist)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiRenderBuffer_spec = {
    "2:PySide6.QtGui.QRhiRenderBuffer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiRenderBuffer_slots
};

} //extern "C"

static void *Sbk_QRhiRenderBuffer_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QRhiResource >())
        return dynamic_cast< ::QRhiRenderBuffer *>(reinterpret_cast< ::QRhiResource *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QRhiRenderBuffer_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiRenderBuffer::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiRenderBuffer::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiRenderBuffer_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_Type_IDX])))
        return Enum_PythonToCpp_QRhiRenderBuffer_Type;
    return {};
}

static PyObject *QRhiRenderBuffer_Type_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiRenderBuffer::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiRenderBuffer::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_Type_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiRenderBuffer_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiRenderBuffer::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiRenderBuffer::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiRenderBuffer_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_Flag_IDX])))
        return Enum_PythonToCpp_QRhiRenderBuffer_Flag;
    return {};
}

static PyObject *QRhiRenderBuffer_Flag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiRenderBuffer::Flag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiRenderBuffer::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_Flag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QRhiRenderBuffer_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QRhiRenderBuffer::Flag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QRhiRenderBuffer::Flag> *>(cppOut) = value;

}

static PyObject *QRhiRenderBuffer_Flag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QRhiRenderBuffer::Flag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_Flag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiRenderBuffer_PythonToCpp_QRhiRenderBuffer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiRenderBuffer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiRenderBuffer_PythonToCpp_QRhiRenderBuffer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiRenderBuffer_TypeF()))
        return QRhiRenderBuffer_PythonToCpp_QRhiRenderBuffer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiRenderBuffer_PTR_CppToPython_QRhiRenderBuffer(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QRhiRenderBuffer *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QRhiRenderBuffer_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiRenderBuffer_SignatureStrings[] = {
    "PySide6.QtGui.QRhiRenderBuffer.backingFormat(self)->PySide6.QtGui.QRhiTexture.Format",
    "PySide6.QtGui.QRhiRenderBuffer.create(self)->bool",
    "PySide6.QtGui.QRhiRenderBuffer.flags(self)->PySide6.QtGui.QRhiRenderBuffer.Flag",
    "PySide6.QtGui.QRhiRenderBuffer.pixelSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QRhiRenderBuffer.resourceType(self)->PySide6.QtGui.QRhiResource.Type",
    "PySide6.QtGui.QRhiRenderBuffer.sampleCount(self)->int",
    "PySide6.QtGui.QRhiRenderBuffer.setFlags(self,f:PySide6.QtGui.QRhiRenderBuffer.Flag)",
    "PySide6.QtGui.QRhiRenderBuffer.setPixelSize(self,sz:PySide6.QtCore.QSize)",
    "PySide6.QtGui.QRhiRenderBuffer.setSampleCount(self,s:int)",
    "PySide6.QtGui.QRhiRenderBuffer.setType(self,t:PySide6.QtGui.QRhiRenderBuffer.Type)",
    "PySide6.QtGui.QRhiRenderBuffer.type(self)->PySide6.QtGui.QRhiRenderBuffer.Type",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiRenderBuffer_SignatureByteSize = 205;
static constexpr uint8_t QRhiRenderBuffer_SignatureBytes[205] = {
    0x78, 0xda, 0x8d, 0x91, 0xbb, 0x0e, 0x83, 0x20, 0x18, 0x85, 0x77, 0x9f, 0xa4, 0x26, 0x96, 0xb1,
    0x83, 0x43, 0x87, 0x9a, 0xd8, 0x15, 0x2f, 0x2f, 0x80, 0xfa, 0x63, 0x49, 0x11, 0x0c, 0x97, 0x44,
    0x7d, 0xfa, 0x6a, 0x4c, 0x4d, 0xd4, 0x56, 0x9c, 0x39, 0xe7, 0x83, 0xf3, 0x81, 0xfb, 0x8c, 0x55,
    0x70, 0x43, 0x89, 0x79, 0x5a, 0x86, 0x92, 0xf4, 0xc5, 0x52, 0x10, 0x15, 0xa8, 0x87, 0xa5, 0x14,
    0x14, 0x2a, 0x48, 0xf9, 0x66, 0xa2, 0x8e, 0xa5, 0x6a, 0x88, 0xb9, 0x68, 0xe0, 0xd4, 0xbf, 0xde,
    0xf1, 0xae, 0x93, 0x43, 0x67, 0xac, 0x02, 0x34, 0xe7, 0x3c, 0x7c, 0x0c, 0x2d, 0x15, 0x10, 0x03,
    0x5f, 0x5a, 0x21, 0x25, 0x77, 0x35, 0x28, 0x27, 0xb5, 0xfe, 0x7f, 0xfd, 0x2a, 0x1b, 0x8f, 0x59,
    0x17, 0xaf, 0x65, 0x1d, 0xf0, 0x8c, 0x0d, 0xb0, 0x67, 0x46, 0x72, 0xdc, 0x91, 0x4c, 0x67, 0x2e,
    0x88, 0x02, 0x2d, 0xad, 0x2a, 0x21, 0xef, 0x5b, 0x38, 0x7a, 0xdb, 0x9c, 0x42, 0x53, 0xcc, 0x85,
    0xd4, 0xa4, 0x69, 0x39, 0x44, 0xd2, 0x8a, 0x45, 0x36, 0x13, 0x4e, 0x9f, 0x1a, 0x4c, 0xbc, 0x08,
    0x0a, 0x68, 0x78, 0x42, 0x90, 0x7f, 0x82, 0x89, 0x57, 0x92, 0x02, 0x3d, 0x84, 0xbf, 0x2c, 0x9d,
    0x21, 0x65, 0x9b, 0x59, 0x81, 0x0e, 0xc7, 0x59, 0x67, 0x9a, 0x8b, 0xdb, 0xc0, 0xb8, 0x66, 0x4d,
    0x51, 0x27, 0xd2, 0x38, 0xfe, 0x6a, 0xc3, 0xf3, 0x3e, 0x4d, 0xb8, 0x1d, 0x9e
};
#endif

PyTypeObject *init_QRhiRenderBuffer(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiRenderBuffer_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_IDX]))));

    _Sbk_QRhiRenderBuffer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiRenderBuffer",
        "QRhiRenderBuffer*",
        &Sbk_QRhiRenderBuffer_spec,
        &Shiboken::callCppDestructor< QRhiRenderBuffer >,
        Sbk_QRhiRenderBuffer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRhiRenderBuffer_TypeF(); // references _Sbk_QRhiRenderBuffer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiRenderBuffer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiRenderBuffer_SignatureBytes, QRhiRenderBuffer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiRenderBuffer_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiRenderBuffer_PythonToCpp_QRhiRenderBuffer_PTR,
        is_QRhiRenderBuffer_PythonToCpp_QRhiRenderBuffer_PTR_Convertible,
        QRhiRenderBuffer_PTR_CppToPython_QRhiRenderBuffer);

    Shiboken::Conversions::registerConverterName(converter, "QRhiRenderBuffer");
    Shiboken::Conversions::registerConverterName(converter, "QRhiRenderBuffer*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiRenderBuffer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiRenderBuffer).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRhiRenderBufferWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRhiRenderBuffer_TypeF(), &Sbk_QRhiRenderBuffer_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRhiRenderBuffer_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "DepthStencil",
        "Color",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(QRhiRenderBuffer::Type::DepthStencil), //  0x00  0
        uint8_t(QRhiRenderBuffer::Type::Color)         //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiRenderBuffer_TypeF(),
        "2:PySide6.QtGui.QRhiRenderBuffer.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_Type_IDX].type = EType;
    // Register converter for enum 'QRhiRenderBuffer::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiRenderBuffer_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiRenderBuffer_Type,
            is_Enum_PythonToCpp_QRhiRenderBuffer_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiRenderBuffer::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "UsedWithSwapChainOnly",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Flag_InitializerValues[] = {
        uint8_t(QRhiRenderBuffer::Flag::UsedWithSwapChainOnly) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiRenderBuffer_TypeF(),
        "2:PySide6.QtGui.QRhiRenderBuffer.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiRenderBuffer_Flag_IDX].type =
        EType;
    // Register converter for enum 'QRhiRenderBuffer::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiRenderBuffer_Flag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiRenderBuffer_Flag,
            is_Enum_PythonToCpp_QRhiRenderBuffer_Flag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiRenderBuffer::Flag");
        Shiboken::Conversions::registerConverterAlias(converter, "Flag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QRhiRenderBuffer_Flag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QRhiRenderBuffer_Flag,
            is_Enum_PythonToCpp_QRhiRenderBuffer_Flag_Convertible);
        // Register converter for flag 'QFlags<QRhiRenderBuffer::Flag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QRhiRenderBuffer::Flag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QRhiRenderBuffer::Flags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Flag' enum/flags.

    qRegisterMetaType< ::QRhiRenderBuffer *>();
    qRegisterMetaType< ::QRhiRenderBuffer::Type >("QRhiRenderBuffer::Type");
    qRegisterMetaType< ::QRhiRenderBuffer::Flag >("QRhiRenderBuffer::Flag");

    return pyType;
}
