// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhiscissor_wrapper.h"

// Argument includes
#include <array>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRhiScissor_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRhiScissor >()))
        return -1;

    ::QRhiScissor *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]);

    if (PyArg_UnpackTuple(args, "QRhiScissor", 0, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRhiScissor::QRhiScissor()
    // 1: QRhiScissor::QRhiScissor(QRhiScissor)
    // 2: QRhiScissor::QRhiScissor(int,int,int,int)
    if (numArgs == 0) {
        overloadId = 0; // QRhiScissor()
    } else if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 2; // QRhiScissor(int,int,int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QRhiScissor(QRhiScissor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRhiScissor()
        {

            // QRhiScissor()
            cptr = new ::QRhiScissor();
            break;
        }
        case 1: // QRhiScissor(const QRhiScissor &QRhiScissor)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRhiScissor cppArg0_local;
            ::QRhiScissor *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiScissor(QRhiScissor)
                cptr = new ::QRhiScissor(*cppArg0);
            }
            break;
        }
        case 2: // QRhiScissor(int x, int y, int w, int h)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiScissor(int,int,int,int)
                cptr = new ::QRhiScissor(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRhiScissor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRhiScissorFunc_scissor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiScissor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scissor()const
        std::array<int,4> cppResult = const_cast<const ::QRhiScissor *>(cppSelf)->scissor();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_array_int_4_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiScissorFunc_setScissor(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiScissor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setScissor", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhiScissor::setScissor(int,int,int,int)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // setScissor(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setScissor", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setScissor(int,int,int,int)
            cppSelf->setScissor(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiScissor__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRhiScissor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiScissor_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiScissor_methods[] = {
    {"scissor", reinterpret_cast<PyCFunction>(Sbk_QRhiScissorFunc_scissor), METH_NOARGS, nullptr},
    {"setScissor", reinterpret_cast<PyCFunction>(Sbk_QRhiScissorFunc_setScissor), METH_VARARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QRhiScissor__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QRhiScissor_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRhiScissor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]), (pyArg)))) {
                // operator!=(const QRhiScissor &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRhiScissor cppArg0_local;
                ::QRhiScissor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]), (pyArg)))) {
                // operator==(const QRhiScissor &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRhiScissor cppArg0_local;
                ::QRhiScissor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QRhiScissor_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiScissor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QRhiScissor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiScissor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QRhiScissor__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiScissor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiScissor_Type = nullptr;
static PyTypeObject *Sbk_QRhiScissor_TypeF(void)
{
    return _Sbk_QRhiScissor_Type;
}

static PyType_Slot Sbk_QRhiScissor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QRhiScissor__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QRhiScissor_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiScissor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiScissor_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QRhiScissor_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiScissor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRhiScissor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiScissor_spec = {
    "2:PySide6.QtGui.QRhiScissor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiScissor_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiScissor_PythonToCpp_QRhiScissor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiScissor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiScissor_PythonToCpp_QRhiScissor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiScissor_TypeF()))
        return QRhiScissor_PythonToCpp_QRhiScissor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiScissor_PTR_CppToPython_QRhiScissor(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QRhiScissor_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QRhiScissor_COPY_CppToPython_QRhiScissor(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QRhiScissor *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QRhiScissor_TypeF(), new ::QRhiScissor(*source), true, true);
}

// Python to C++ copy conversion.
static void QRhiScissor_PythonToCpp_QRhiScissor_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRhiScissor *>(cppOut) = *reinterpret_cast< ::QRhiScissor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QRhiScissor_PythonToCpp_QRhiScissor_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiScissor_TypeF()))
        return QRhiScissor_PythonToCpp_QRhiScissor_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiScissor_SignatureStrings[] = {
    "2:PySide6.QtGui.QRhiScissor(self)",
    "1:PySide6.QtGui.QRhiScissor(self,QRhiScissor:PySide6.QtGui.QRhiScissor)",
    "0:PySide6.QtGui.QRhiScissor(self,x:int,y:int,w:int,h:int)",
    "PySide6.QtGui.QRhiScissor.scissor(self)->std.array[int, 4]",
    "PySide6.QtGui.QRhiScissor.setScissor(self,x:int,y:int,w:int,h:int)",
    "PySide6.QtGui.QRhiScissor.__copy__(self)->typing.Self",
    "PySide6.QtGui.QRhiScissor.__ne__(self,b:PySide6.QtGui.QRhiScissor)->bool",
    "PySide6.QtGui.QRhiScissor.__eq__(self,b:PySide6.QtGui.QRhiScissor)->bool",
    "PySide6.QtGui.QRhiScissor.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiScissor_SignatureByteSize = 155;
static constexpr uint8_t QRhiScissor_SignatureBytes[155] = {
    0x78, 0xda, 0x33, 0xb2, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x0c, 0xca, 0xc8, 0x0c, 0x4e, 0xce, 0x2c, 0x2e, 0xce, 0x2f, 0xd2, 0x28, 0x4e,
    0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x24, 0xa0, 0x42, 0x07, 0x49, 0x00, 0xb7, 0x52, 0x4d, 0x2e, 0x03,
    0x42, 0xe6, 0x54, 0x58, 0x65, 0xe6, 0x95, 0xe8, 0x54, 0x82, 0xc9, 0x72, 0x30, 0x99, 0x01, 0x22,
    0x35, 0xb9, 0x70, 0xea, 0xd3, 0x2b, 0x46, 0x76, 0xa9, 0xae, 0x5d, 0x71, 0x49, 0x8a, 0x5e, 0x62,
    0x51, 0x51, 0x62, 0x65, 0x34, 0x48, 0xb7, 0x82, 0x49, 0x2c, 0x3e, 0xad, 0xa9, 0x25, 0x94, 0xda,
    0x1e, 0x1f, 0x9f, 0x9c, 0x5f, 0x50, 0x19, 0x1f, 0x0f, 0xb3, 0xbe, 0xa4, 0xb2, 0x20, 0x33, 0x2f,
    0x5d, 0x2f, 0x18, 0xc8, 0xc3, 0xab, 0x2b, 0x2f, 0x15, 0xaa, 0x47, 0x27, 0x09, 0x4f, 0x80, 0xe9,
    0xda, 0x25, 0xe5, 0xe7, 0xe7, 0xe0, 0x35, 0x28, 0xb5, 0x90, 0x4a, 0x06, 0x65, 0x24, 0x16, 0x67,
    0x20, 0xfc, 0x01, 0xf4, 0x36, 0x17, 0x00, 0x24, 0xd9, 0xbd, 0x03
};
#endif

PyTypeObject *init_QRhiScissor(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiScissor_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRhiScissor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiScissor",
        "QRhiScissor",
        &Sbk_QRhiScissor_spec,
        &Shiboken::callCppDestructor< ::QRhiScissor >,
        Sbk_QRhiScissor_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QRhiScissor_TypeF(); // references _Sbk_QRhiScissor_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiScissor_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiScissor_SignatureBytes, QRhiScissor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiScissor_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiScissor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiScissor_PythonToCpp_QRhiScissor_PTR,
        is_QRhiScissor_PythonToCpp_QRhiScissor_PTR_Convertible,
        QRhiScissor_PTR_CppToPython_QRhiScissor,
        QRhiScissor_COPY_CppToPython_QRhiScissor);

    Shiboken::Conversions::registerConverterName(converter, "QRhiScissor");
    Shiboken::Conversions::registerConverterName(converter, "QRhiScissor*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiScissor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiScissor).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QRhiScissor_PythonToCpp_QRhiScissor_COPY,
        is_QRhiScissor_PythonToCpp_QRhiScissor_COPY_Convertible);

    qRegisterMetaType< ::QRhiScissor >("QRhiScissor");

    return pyType;
}
