// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhishaderresourcebinding_data_wrapper.h"

// inner classes
#include "qrhishaderresourcebinding_data_storagebufferdata_wrapper.h"
#include "qrhishaderresourcebinding_data_storageimagedata_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRhiShaderResourceBinding_Data_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRhiShaderResourceBinding::Data >()))
        return -1;

    ::QRhiShaderResourceBinding::Data *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Data", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Data::Data()
    // 1: Data::Data(QRhiShaderResourceBinding::Data)
    if (numArgs == 0) {
        overloadId = 0; // Data()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Data(QRhiShaderResourceBinding::Data)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Data()
        {

            // Data()
            cptr = new ::QRhiShaderResourceBinding::Data();
            break;
        }
        case 1: // Data(const QRhiShaderResourceBinding::Data &Data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRhiShaderResourceBinding::Data cppArg0_local;
            ::QRhiShaderResourceBinding::Data *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Data(QRhiShaderResourceBinding::Data)
                cptr = new ::QRhiShaderResourceBinding::Data(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRhiShaderResourceBinding::Data >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRhiShaderResourceBinding_DataFunc_arraySize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBinding::Data *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // arraySize()const
        int cppResult = const_cast<const ::QRhiShaderResourceBinding::Data *>(cppSelf)->arraySize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBinding_Data__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRhiShaderResourceBinding::Data *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiShaderResourceBinding_Data_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiShaderResourceBinding_Data_methods[] = {
    {"arraySize", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBinding_DataFunc_arraySize), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBinding_Data__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QRhiShaderResourceBinding_Data_get_binding(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBinding::Data *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->binding;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiShaderResourceBinding_Data_set_binding(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBinding::Data *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("binding");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("binding", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->binding;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->binding = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiShaderResourceBinding_Data_get_stage(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBinding::Data *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX])))->flagsConverter, &cppSelf->stage);
    return pyOut;
}
static int Sbk_QRhiShaderResourceBinding_Data_set_stage(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBinding::Data *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("stage");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("stage", "StageFlags");
        return -1;
    }

    auto cppOut_local = cppSelf->stage;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->stage = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiShaderResourceBinding_Data_get_type(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBinding::Data *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiShaderResourceBinding::Type cppOut_local = cppSelf->type;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Type_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiShaderResourceBinding_Data_set_type(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBinding::Data *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("type");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Type_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("type", "Type");
        return -1;
    }

    auto cppOut_local = cppSelf->type;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->type = cppOut_local;

    return 0;
}


// Getters and Setters for Data
static PyGetSetDef Sbk_QRhiShaderResourceBinding_Data_getsetlist[] = {
    {const_cast<char *>("binding"), Sbk_QRhiShaderResourceBinding_Data_get_binding, Sbk_QRhiShaderResourceBinding_Data_set_binding, nullptr, nullptr},
    {const_cast<char *>("stage"), Sbk_QRhiShaderResourceBinding_Data_get_stage, Sbk_QRhiShaderResourceBinding_Data_set_stage, nullptr, nullptr},
    {const_cast<char *>("type"), Sbk_QRhiShaderResourceBinding_Data_get_type, Sbk_QRhiShaderResourceBinding_Data_set_type, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiShaderResourceBinding_Data_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiShaderResourceBinding_Data_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiShaderResourceBinding_Data_Type = nullptr;
static PyTypeObject *Sbk_QRhiShaderResourceBinding_Data_TypeF(void)
{
    return _Sbk_QRhiShaderResourceBinding_Data_Type;
}

static PyType_Slot Sbk_QRhiShaderResourceBinding_Data_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiShaderResourceBinding_Data_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiShaderResourceBinding_Data_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiShaderResourceBinding_Data_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiShaderResourceBinding_Data_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRhiShaderResourceBinding_Data_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiShaderResourceBinding_Data_spec = {
    "2:PySide6.QtGui.QRhiShaderResourceBinding.Data",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiShaderResourceBinding_Data_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Data_PythonToCpp_Data_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiShaderResourceBinding_Data_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Data_PythonToCpp_Data_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiShaderResourceBinding_Data_TypeF()))
        return Data_PythonToCpp_Data_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Data_PTR_CppToPython_Data(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QRhiShaderResourceBinding_Data_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *Data_COPY_CppToPython_Data(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QRhiShaderResourceBinding::Data *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QRhiShaderResourceBinding_Data_TypeF(), new ::QRhiShaderResourceBinding::Data(*source), true, true);
}

// Python to C++ copy conversion.
static void Data_PythonToCpp_Data_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRhiShaderResourceBinding::Data *>(cppOut) = *reinterpret_cast< ::QRhiShaderResourceBinding::Data *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Data_PythonToCpp_Data_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiShaderResourceBinding_Data_TypeF()))
        return Data_PythonToCpp_Data_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiShaderResourceBinding_Data_SignatureStrings[] = {
    "1:PySide6.QtGui.QRhiShaderResourceBinding.Data(self)",
    "0:PySide6.QtGui.QRhiShaderResourceBinding.Data(self,Data:PySide6.QtGui.QRhiShaderResourceBinding.Data)",
    "PySide6.QtGui.QRhiShaderResourceBinding.Data.arraySize(self)->int",
    "PySide6.QtGui.QRhiShaderResourceBinding.Data.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiShaderResourceBinding_Data_SignatureByteSize = 111;
static constexpr uint8_t QRhiShaderResourceBinding_Data_SignatureBytes[111] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x0c, 0xca, 0xc8, 0x0c, 0xce, 0x48, 0x4c, 0x49, 0x2d, 0x0a, 0x4a, 0x2d, 0xce,
    0x2f, 0x2d, 0x4a, 0x4e, 0x75, 0xca, 0xcc, 0x4b, 0xc9, 0xcc, 0x4b, 0xd7, 0x73, 0x49, 0x2c, 0x49,
    0xd4, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x20, 0x5d, 0x93, 0x0e, 0x88, 0x45, 0x92, 0x36,
    0x4d, 0x2e, 0x52, 0x54, 0xeb, 0x25, 0x16, 0x15, 0x25, 0x02, 0xd5, 0x57, 0xa5, 0x42, 0xdc, 0xa8,
    0x6b, 0x97, 0x99, 0x57, 0x42, 0x9a, 0x09, 0xf1, 0xf1, 0xc9, 0xf9, 0x05, 0x95, 0xf1, 0xf1, 0x30,
    0x03, 0x4a, 0x2a, 0x0b, 0x40, 0x72, 0xc1, 0x40, 0x1e, 0x17, 0x00, 0xec, 0xdd, 0x69, 0xcb
};
#endif

PyTypeObject *init_QRhiShaderResourceBinding_Data(PyObject *enclosingClass)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiShaderResourceBinding_Data_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRhiShaderResourceBinding_Data_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Data",
        "QRhiShaderResourceBinding::Data",
        &Sbk_QRhiShaderResourceBinding_Data_spec,
        &Shiboken::callCppDestructor< ::QRhiShaderResourceBinding::Data >,
        Sbk_QRhiShaderResourceBinding_Data_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QRhiShaderResourceBinding_Data_TypeF(); // references _Sbk_QRhiShaderResourceBinding_Data_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiShaderResourceBinding_Data_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiShaderResourceBinding_Data_SignatureBytes, QRhiShaderResourceBinding_Data_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiShaderResourceBinding_Data_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Data_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Data_PythonToCpp_Data_PTR,
        is_Data_PythonToCpp_Data_PTR_Convertible,
        Data_PTR_CppToPython_Data,
        Data_COPY_CppToPython_Data);

    Shiboken::Conversions::registerConverterName(converter, "QRhiShaderResourceBinding::Data");
    Shiboken::Conversions::registerConverterName(converter, "QRhiShaderResourceBinding::Data*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiShaderResourceBinding::Data&");
    Shiboken::Conversions::registerConverterAlias(converter, "Data");
    Shiboken::Conversions::registerConverterAlias(converter, "Data*");
    Shiboken::Conversions::registerConverterAlias(converter, "Data&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiShaderResourceBinding::Data).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Data_PythonToCpp_Data_COPY,
        is_Data_PythonToCpp_Data_COPY_Convertible);

    qRegisterMetaType< ::QRhiShaderResourceBinding::Data >("Data");
    qRegisterMetaType< ::QRhiShaderResourceBinding::Data >("QRhiShaderResourceBinding::Data");

    return pyType;
}

PyTypeObject *init_QRhiShaderResourceBinding_DataStaticFields(PyObject *module)
{
    auto *obContainerType = PyObject_GetAttrString(module, "QRhiShaderResourceBinding");
    auto *obType = PyObject_GetAttrString(obContainerType, "Data");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "MAX_TEX_SAMPLER_ARRAY_SIZE",
                         Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &QRhiShaderResourceBinding::Data::MAX_TEX_SAMPLER_ARRAY_SIZE));
    return type;
}
