// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhistats_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRhiStats_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRhiStats >()))
        return -1;

    ::QRhiStats *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QRhiStats", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRhiStats::QRhiStats()
    // 1: QRhiStats::QRhiStats(QRhiStats)
    if (numArgs == 0) {
        overloadId = 0; // QRhiStats()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QRhiStats(QRhiStats)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRhiStats()
        {

            // QRhiStats()
            cptr = new ::QRhiStats();
            break;
        }
        case 1: // QRhiStats(const QRhiStats &QRhiStats)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRhiStats cppArg0_local;
            ::QRhiStats *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiStats(QRhiStats)
                cptr = new ::QRhiStats(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRhiStats >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRhiStats__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRhiStats *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiStats_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiStats_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QRhiStats__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QRhiStats_get_totalPipelineCreationTime(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiStats *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    qint64 cppOut_local = cppSelf->totalPipelineCreationTime;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiStats_set_totalPipelineCreationTime(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiStats *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("totalPipelineCreationTime");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("totalPipelineCreationTime", "qint64");
        return -1;
    }

    auto cppOut_local = cppSelf->totalPipelineCreationTime;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->totalPipelineCreationTime = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiStats_get_blockCount(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiStats *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint32 cppOut_local = cppSelf->blockCount;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiStats_set_blockCount(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiStats *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("blockCount");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("blockCount", "quint32");
        return -1;
    }

    auto cppOut_local = cppSelf->blockCount;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->blockCount = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiStats_get_allocCount(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiStats *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint32 cppOut_local = cppSelf->allocCount;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiStats_set_allocCount(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiStats *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("allocCount");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("allocCount", "quint32");
        return -1;
    }

    auto cppOut_local = cppSelf->allocCount;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->allocCount = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiStats_get_usedBytes(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiStats *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->usedBytes;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiStats_set_usedBytes(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiStats *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("usedBytes");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("usedBytes", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->usedBytes;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->usedBytes = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiStats_get_unusedBytes(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiStats *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->unusedBytes;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiStats_set_unusedBytes(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiStats *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("unusedBytes");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("unusedBytes", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->unusedBytes;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->unusedBytes = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiStats_get_totalUsageBytes(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiStats *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->totalUsageBytes;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiStats_set_totalUsageBytes(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiStats *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("totalUsageBytes");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("totalUsageBytes", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->totalUsageBytes;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->totalUsageBytes = cppOut_local;

    return 0;
}

// Getters and Setters for QRhiStats
static PyGetSetDef Sbk_QRhiStats_getsetlist[] = {
    {const_cast<char *>("totalPipelineCreationTime"), Sbk_QRhiStats_get_totalPipelineCreationTime, Sbk_QRhiStats_set_totalPipelineCreationTime, nullptr, nullptr},
    {const_cast<char *>("blockCount"), Sbk_QRhiStats_get_blockCount, Sbk_QRhiStats_set_blockCount, nullptr, nullptr},
    {const_cast<char *>("allocCount"), Sbk_QRhiStats_get_allocCount, Sbk_QRhiStats_set_allocCount, nullptr, nullptr},
    {const_cast<char *>("usedBytes"), Sbk_QRhiStats_get_usedBytes, Sbk_QRhiStats_set_usedBytes, nullptr, nullptr},
    {const_cast<char *>("unusedBytes"), Sbk_QRhiStats_get_unusedBytes, Sbk_QRhiStats_set_unusedBytes, nullptr, nullptr},
    {const_cast<char *>("totalUsageBytes"), Sbk_QRhiStats_get_totalUsageBytes, Sbk_QRhiStats_set_totalUsageBytes, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiStats_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiStats_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QRhiStats__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiStats *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiStats_Type = nullptr;
static PyTypeObject *Sbk_QRhiStats_TypeF(void)
{
    return _Sbk_QRhiStats_Type;
}

static PyType_Slot Sbk_QRhiStats_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QRhiStats__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiStats_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiStats_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiStats_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiStats_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRhiStats_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiStats_spec = {
    "2:PySide6.QtGui.QRhiStats",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiStats_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiStats_PythonToCpp_QRhiStats_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiStats_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiStats_PythonToCpp_QRhiStats_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiStats_TypeF()))
        return QRhiStats_PythonToCpp_QRhiStats_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiStats_PTR_CppToPython_QRhiStats(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QRhiStats_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QRhiStats_COPY_CppToPython_QRhiStats(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QRhiStats *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QRhiStats_TypeF(), new ::QRhiStats(*source), true, true);
}

// Python to C++ copy conversion.
static void QRhiStats_PythonToCpp_QRhiStats_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRhiStats *>(cppOut) = *reinterpret_cast< ::QRhiStats *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QRhiStats_PythonToCpp_QRhiStats_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiStats_TypeF()))
        return QRhiStats_PythonToCpp_QRhiStats_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiStats_SignatureStrings[] = {
    "1:PySide6.QtGui.QRhiStats(self)",
    "0:PySide6.QtGui.QRhiStats(self,QRhiStats:PySide6.QtGui.QRhiStats)",
    "PySide6.QtGui.QRhiStats.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiStats_SignatureByteSize = 76;
static constexpr uint8_t QRhiStats_SignatureBytes[76] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x0c, 0xca, 0xc8, 0x0c, 0x2e, 0x49, 0x2c, 0x29, 0xd6, 0x28, 0x4e, 0xcd, 0x49,
    0xd3, 0xe4, 0x32, 0xc0, 0x2b, 0xaf, 0x03, 0xe7, 0xe2, 0x52, 0xa6, 0xc9, 0x85, 0x43, 0x42, 0x2f,
    0x3e, 0x3e, 0x39, 0xbf, 0xa0, 0x32, 0x3e, 0x1e, 0x62, 0x91, 0xae, 0x5d, 0x49, 0x65, 0x41, 0x66,
    0x5e, 0xba, 0x5e, 0x30, 0x90, 0xc7, 0x05, 0x00, 0x3c, 0x04, 0x34, 0x25
};
#endif

PyTypeObject *init_QRhiStats(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiStats_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRhiStats_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiStats",
        "QRhiStats",
        &Sbk_QRhiStats_spec,
        &Shiboken::callCppDestructor< ::QRhiStats >,
        Sbk_QRhiStats_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QRhiStats_TypeF(); // references _Sbk_QRhiStats_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiStats_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiStats_SignatureBytes, QRhiStats_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiStats_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiStats_PythonToCpp_QRhiStats_PTR,
        is_QRhiStats_PythonToCpp_QRhiStats_PTR_Convertible,
        QRhiStats_PTR_CppToPython_QRhiStats,
        QRhiStats_COPY_CppToPython_QRhiStats);

    Shiboken::Conversions::registerConverterName(converter, "QRhiStats");
    Shiboken::Conversions::registerConverterName(converter, "QRhiStats*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiStats&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiStats).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QRhiStats_PythonToCpp_QRhiStats_COPY,
        is_QRhiStats_PythonToCpp_QRhiStats_COPY_Convertible);

    qRegisterMetaType< ::QRhiStats >("QRhiStats");

    return pyType;
}
