// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhiswapchain_wrapper.h"

// Argument includes
#include <QtGui/qwindow.h>
#include <qbytearray.h>
#include <qsize.h>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRhiSwapChainWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

bool QRhiSwapChainWrapper::createOrResize()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.createOrResize");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createOrResize";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.createOrResize");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiSwapChain", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiSwapChain", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QRhiCommandBuffer * QRhiSwapChainWrapper::currentFrameCommandBuffer()
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.currentFrameCommandBuffer");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "currentFrameCommandBuffer";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.currentFrameCommandBuffer");
        return nullptr;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiSwapChain", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiSwapChain", funcName, Shiboken::SbkType< QRhiCommandBuffer >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QRhiCommandBuffer *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QRhiRenderTarget * QRhiSwapChainWrapper::currentFrameRenderTarget()
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.currentFrameRenderTarget");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "currentFrameRenderTarget";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.currentFrameRenderTarget");
        return nullptr;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiSwapChain", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiSwapChain", funcName, Shiboken::SbkType< QRhiRenderTarget >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QRhiRenderTarget *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QRhiRenderTarget * QRhiSwapChainWrapper::currentFrameRenderTarget(::QRhiSwapChain::StereoTargetBuffer targetBuffer)
{
    if (m_PyMethodCache[3])
        return this->::QRhiSwapChain::currentFrameRenderTarget(targetBuffer);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "currentFrameRenderTarget";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QRhiSwapChain::currentFrameRenderTarget(targetBuffer);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_StereoTargetBuffer_IDX])))->converter, &targetBuffer)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_StereoTargetBuffer_IDX])))->converter, &targetBuffer)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiSwapChain", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiSwapChain", funcName, Shiboken::SbkType< QRhiRenderTarget >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QRhiRenderTarget *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRhiSwapChainWrapper::destroy()
{
    if (m_PyMethodCache[4]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.destroy");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "destroy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.destroy");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiSwapChain", funcName);
        return;
    }
}

bool QRhiSwapChainWrapper::isFormatSupported(::QRhiSwapChain::Format f)
{
    if (m_PyMethodCache[5]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.isFormatSupported");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isFormatSupported";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.isFormatSupported");
        return false;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_Format_IDX])))->converter, &f)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_Format_IDX])))->converter, &f)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiSwapChain", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiSwapChain", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QRhiRenderPassDescriptor * QRhiSwapChainWrapper::newCompatibleRenderPassDescriptor()
{
    if (m_PyMethodCache[6]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.newCompatibleRenderPassDescriptor");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "newCompatibleRenderPassDescriptor";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.newCompatibleRenderPassDescriptor");
        return nullptr;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiSwapChain", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiSwapChain", funcName, Shiboken::SbkType< QRhiRenderPassDescriptor >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QRhiRenderPassDescriptor *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QRhiResource::Type QRhiSwapChainWrapper::resourceType() const
{
    if (m_PyMethodCache[7])
        return this->::QRhiSwapChain::resourceType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QRhiResource::Buffer;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resourceType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QRhiSwapChain::resourceType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiSwapChain", funcName);
        return QRhiResource::Buffer;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiSwapChain", funcName, Shiboken::SbkType< QRhiResource::Type >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QRhiResource::Buffer;
    }
    ::QRhiResource::Type cppResult{QRhiResource::Buffer};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSize QRhiSwapChainWrapper::surfacePixelSize()
{
    if (m_PyMethodCache[8]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.surfacePixelSize");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "surfacePixelSize";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.surfacePixelSize");
        return {};
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiSwapChain", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiSwapChain", funcName, Shiboken::SbkType< QSize >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSize cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QRhiSwapChainWrapper::~QRhiSwapChainWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QRhiSwapChainFunc_createOrResize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createOrResize()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.createOrResize");
            return {};
        }
        bool cppResult = cppSelf->createOrResize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSwapChainFunc_currentFrameCommandBuffer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentFrameCommandBuffer()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.currentFrameCommandBuffer");
            return {};
        }
        QRhiCommandBuffer * cppResult = cppSelf->currentFrameCommandBuffer();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSwapChainFunc_currentFrameRenderTarget(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "currentFrameRenderTarget", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhiSwapChain::currentFrameRenderTarget(QRhiSwapChain::StereoTargetBuffer)->QRhiRenderTarget*
    // 1: QRhiSwapChain::currentFrameRenderTarget()->QRhiRenderTarget*
    if (numArgs == 0) {
        overloadId = 1; // currentFrameRenderTarget()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_StereoTargetBuffer_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // currentFrameRenderTarget(QRhiSwapChain::StereoTargetBuffer)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "currentFrameRenderTarget", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // currentFrameRenderTarget(QRhiSwapChain::StereoTargetBuffer targetBuffer)
        {
            ::QRhiSwapChain::StereoTargetBuffer cppArg0{QRhiSwapChain::LeftBuffer};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // currentFrameRenderTarget(QRhiSwapChain::StereoTargetBuffer)
                QRhiRenderTarget * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QRhiSwapChain::currentFrameRenderTarget(cppArg0)
                    : cppSelf->currentFrameRenderTarget(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), cppResult);
            }
            break;
        }
        case 1: // currentFrameRenderTarget()
        {

            // currentFrameRenderTarget()
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.currentFrameRenderTarget");
                return {};
            }
            QRhiRenderTarget * cppResult = cppSelf->currentFrameRenderTarget();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), cppResult);
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSwapChainFunc_currentPixelSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentPixelSize()const
        QSize cppResult = const_cast<const ::QRhiSwapChain *>(cppSelf)->currentPixelSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSwapChainFunc_depthStencil(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // depthStencil()const
        QRhiRenderBuffer * cppResult = const_cast<const ::QRhiSwapChain *>(cppSelf)->depthStencil();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSwapChainFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QRhiSwapChain::Flag> cppResult = const_cast<const ::QRhiSwapChain *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiSwapChain_Flag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSwapChainFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // format()const
        QRhiSwapChain::Format cppResult = const_cast<const ::QRhiSwapChain *>(cppSelf)->format();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_Format_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSwapChainFunc_isFormatSupported(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiSwapChain::isFormatSupported(QRhiSwapChain::Format)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_Format_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isFormatSupported(QRhiSwapChain::Format)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isFormatSupported", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]);

    // Call function/method
    {
        ::QRhiSwapChain::Format cppArg0{QRhiSwapChain::SDR};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isFormatSupported(QRhiSwapChain::Format)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.isFormatSupported");
                return {};
            }
            bool cppResult = cppSelf->isFormatSupported(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSwapChainFunc_newCompatibleRenderPassDescriptor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // newCompatibleRenderPassDescriptor()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.newCompatibleRenderPassDescriptor");
            return {};
        }
        QRhiRenderPassDescriptor * cppResult = cppSelf->newCompatibleRenderPassDescriptor();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSwapChainFunc_renderPassDescriptor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // renderPassDescriptor()const
        QRhiRenderPassDescriptor * cppResult = const_cast<const ::QRhiSwapChain *>(cppSelf)->renderPassDescriptor();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSwapChainFunc_resourceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resourceType()const
        QRhiResource::Type cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QRhiSwapChain *>(cppSelf)->::QRhiSwapChain::resourceType()
            : const_cast<const ::QRhiSwapChain *>(cppSelf)->resourceType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSwapChainFunc_sampleCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sampleCount()const
        int cppResult = const_cast<const ::QRhiSwapChain *>(cppSelf)->sampleCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSwapChainFunc_setDepthStencil(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiSwapChain::setDepthStencil(QRhiRenderBuffer*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), (pyArg)))) {
        overloadId = 0; // setDepthStencil(QRhiRenderBuffer*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDepthStencil", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiRenderBuffer *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthStencil(QRhiRenderBuffer*)
            cppSelf->setDepthStencil(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiSwapChainFunc_setFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiSwapChain::setFlags(QFlags<QRhiSwapChain::Flag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiSwapChain_Flag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setFlags(QFlags<QRhiSwapChain::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlags", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]);

    // Call function/method
    {
        ::QFlags<QRhiSwapChain::Flag> cppArg0 = QFlags<QRhiSwapChain::Flag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlags(QFlags<QRhiSwapChain::Flag>)
            cppSelf->setFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiSwapChainFunc_setFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiSwapChain::setFormat(QRhiSwapChain::Format)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_Format_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFormat(QRhiSwapChain::Format)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]);

    // Call function/method
    {
        ::QRhiSwapChain::Format cppArg0{QRhiSwapChain::SDR};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFormat(QRhiSwapChain::Format)
            cppSelf->setFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiSwapChainFunc_setRenderPassDescriptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiSwapChain::setRenderPassDescriptor(QRhiRenderPassDescriptor*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), (pyArg)))) {
        overloadId = 0; // setRenderPassDescriptor(QRhiRenderPassDescriptor*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRenderPassDescriptor", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiRenderPassDescriptor *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRenderPassDescriptor(QRhiRenderPassDescriptor*)
            cppSelf->setRenderPassDescriptor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiSwapChainFunc_setSampleCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiSwapChain::setSampleCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSampleCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSampleCount", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSampleCount(int)
            cppSelf->setSampleCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiSwapChainFunc_setWindow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiSwapChain::setWindow(QWindow*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArg)))) {
        overloadId = 0; // setWindow(QWindow*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWindow *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWindow(QWindow*)
            cppSelf->setWindow(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiSwapChainFunc_surfacePixelSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // surfacePixelSize()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QRhiSwapChain.surfacePixelSize");
            return {};
        }
        QSize cppResult = cppSelf->surfacePixelSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSwapChainFunc_window(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // window()const
        QWindow * cppResult = const_cast<const ::QRhiSwapChain *>(cppSelf)->window();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiSwapChain_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRhiSwapChain_EnumFlagInfo[] = {
    "Flag:Flag:Flags",
    "Format:Enum",
    "StereoTargetBuffer:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiSwapChain_methods[] = {
    {"createOrResize", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_createOrResize), METH_NOARGS, nullptr},
    {"currentFrameCommandBuffer", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_currentFrameCommandBuffer), METH_NOARGS, nullptr},
    {"currentFrameRenderTarget", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_currentFrameRenderTarget), METH_VARARGS, nullptr},
    {"currentPixelSize", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_currentPixelSize), METH_NOARGS, nullptr},
    {"depthStencil", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_depthStencil), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_flags), METH_NOARGS, nullptr},
    {"format", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_format), METH_NOARGS, nullptr},
    {"isFormatSupported", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_isFormatSupported), METH_O, nullptr},
    {"newCompatibleRenderPassDescriptor", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_newCompatibleRenderPassDescriptor), METH_NOARGS, nullptr},
    {"renderPassDescriptor", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_renderPassDescriptor), METH_NOARGS, nullptr},
    {"resourceType", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_resourceType), METH_NOARGS, nullptr},
    {"sampleCount", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_sampleCount), METH_NOARGS, nullptr},
    {"setDepthStencil", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_setDepthStencil), METH_O, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_setFlags), METH_O, nullptr},
    {"setFormat", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_setFormat), METH_O, nullptr},
    {"setRenderPassDescriptor", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_setRenderPassDescriptor), METH_O, nullptr},
    {"setSampleCount", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_setSampleCount), METH_O, nullptr},
    {"setWindow", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_setWindow), METH_O, nullptr},
    {"surfacePixelSize", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_surfacePixelSize), METH_NOARGS, nullptr},
    {"window", reinterpret_cast<PyCFunction>(Sbk_QRhiSwapChainFunc_window), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRhiSwapChain_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRhiSwapChainWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QRhiSwapChain_get_m_window(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), cppSelf->m_window);
    return pyOut;
}
static int Sbk_QRhiSwapChain_set_m_window(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_window");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_window", "QWindow");
        return -1;
    }

    auto *&cppOut_ptr = cppSelf->m_window;
    pythonToCpp(pyIn, &cppOut_ptr);

    Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "m_window", pyIn);
    return 0;
}

static PyObject *Sbk_QRhiSwapChain_get_m_flags(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiSwapChain_Flag_IDX])))->flagsConverter, &cppSelf->m_flags);
    return pyOut;
}
static int Sbk_QRhiSwapChain_set_m_flags(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_flags");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiSwapChain_Flag_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_flags", "Flags");
        return -1;
    }

    auto cppOut_local = cppSelf->m_flags;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_flags = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiSwapChain_get_m_format(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiSwapChain::Format cppOut_local = cppSelf->m_format;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_Format_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiSwapChain_set_m_format(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_format");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_Format_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_format", "Format");
        return -1;
    }

    auto cppOut_local = cppSelf->m_format;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_format = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiSwapChain_get_m_depthStencil(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), cppSelf->m_depthStencil);
    return pyOut;
}
static int Sbk_QRhiSwapChain_set_m_depthStencil(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_depthStencil");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_depthStencil", "QRhiRenderBuffer");
        return -1;
    }

    auto *&cppOut_ptr = cppSelf->m_depthStencil;
    pythonToCpp(pyIn, &cppOut_ptr);

    Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "m_depthStencil", pyIn);
    return 0;
}

static PyObject *Sbk_QRhiSwapChain_get_m_sampleCount(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->m_sampleCount;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiSwapChain_set_m_sampleCount(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_sampleCount");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_sampleCount", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->m_sampleCount;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_sampleCount = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiSwapChain_get_m_renderPassDesc(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), cppSelf->m_renderPassDesc);
    return pyOut;
}
static int Sbk_QRhiSwapChain_set_m_renderPassDesc(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_renderPassDesc");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_renderPassDesc", "QRhiRenderPassDescriptor");
        return -1;
    }

    auto *&cppOut_ptr = cppSelf->m_renderPassDesc;
    pythonToCpp(pyIn, &cppOut_ptr);

    Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "m_renderPassDesc", pyIn);
    return 0;
}

static PyObject *Sbk_QRhiSwapChain_get_m_currentPixelSize(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->m_currentPixelSize)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->m_currentPixelSize))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->m_currentPixelSize)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &(cppSelf->m_currentPixelSize), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QRhiSwapChain_set_m_currentPixelSize(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiSwapChain *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_currentPixelSize");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_currentPixelSize", "QSize");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_currentPixelSize;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

// Getters and Setters for QRhiSwapChain
static PyGetSetDef Sbk_QRhiSwapChain_getsetlist[] = {
    {const_cast<char *>("m_window"), Sbk_QRhiSwapChain_get_m_window, Sbk_QRhiSwapChain_set_m_window, nullptr, nullptr},
    {const_cast<char *>("m_flags"), Sbk_QRhiSwapChain_get_m_flags, Sbk_QRhiSwapChain_set_m_flags, nullptr, nullptr},
    {const_cast<char *>("m_format"), Sbk_QRhiSwapChain_get_m_format, Sbk_QRhiSwapChain_set_m_format, nullptr, nullptr},
    {const_cast<char *>("m_depthStencil"), Sbk_QRhiSwapChain_get_m_depthStencil, Sbk_QRhiSwapChain_set_m_depthStencil, nullptr, nullptr},
    {const_cast<char *>("m_sampleCount"), Sbk_QRhiSwapChain_get_m_sampleCount, Sbk_QRhiSwapChain_set_m_sampleCount, nullptr, nullptr},
    {const_cast<char *>("m_renderPassDesc"), Sbk_QRhiSwapChain_get_m_renderPassDesc, Sbk_QRhiSwapChain_set_m_renderPassDesc, nullptr, nullptr},
    {const_cast<char *>("m_currentPixelSize"), Sbk_QRhiSwapChain_get_m_currentPixelSize, Sbk_QRhiSwapChain_set_m_currentPixelSize, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiSwapChain_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiSwapChain_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiSwapChain_Type = nullptr;
static PyTypeObject *Sbk_QRhiSwapChain_TypeF(void)
{
    return _Sbk_QRhiSwapChain_Type;
}

static PyType_Slot Sbk_QRhiSwapChain_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRhiSwapChain_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiSwapChain_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiSwapChain_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiSwapChain_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiSwapChain_getsetlist)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiSwapChain_spec = {
    "2:PySide6.QtGui.QRhiSwapChain",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiSwapChain_slots
};

} //extern "C"

static void *Sbk_QRhiSwapChain_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QRhiResource >())
        return dynamic_cast< ::QRhiSwapChain *>(reinterpret_cast< ::QRhiResource *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QRhiSwapChain_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiSwapChain::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiSwapChain::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiSwapChain_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_Flag_IDX])))
        return Enum_PythonToCpp_QRhiSwapChain_Flag;
    return {};
}

static PyObject *QRhiSwapChain_Flag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiSwapChain::Flag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiSwapChain::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_Flag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QRhiSwapChain_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QRhiSwapChain::Flag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QRhiSwapChain::Flag> *>(cppOut) = value;

}

static PyObject *QRhiSwapChain_Flag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QRhiSwapChain::Flag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_Flag_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QRhiSwapChain_Format(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiSwapChain::Format>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiSwapChain::Format *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiSwapChain_Format_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_Format_IDX])))
        return Enum_PythonToCpp_QRhiSwapChain_Format;
    return {};
}

static PyObject *QRhiSwapChain_Format_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiSwapChain::Format>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiSwapChain::Format *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_Format_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiSwapChain_StereoTargetBuffer(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiSwapChain::StereoTargetBuffer>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiSwapChain::StereoTargetBuffer *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiSwapChain_StereoTargetBuffer_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_StereoTargetBuffer_IDX])))
        return Enum_PythonToCpp_QRhiSwapChain_StereoTargetBuffer;
    return {};
}

static PyObject *QRhiSwapChain_StereoTargetBuffer_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiSwapChain::StereoTargetBuffer>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiSwapChain::StereoTargetBuffer *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_StereoTargetBuffer_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiSwapChain_PythonToCpp_QRhiSwapChain_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiSwapChain_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiSwapChain_PythonToCpp_QRhiSwapChain_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiSwapChain_TypeF()))
        return QRhiSwapChain_PythonToCpp_QRhiSwapChain_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiSwapChain_PTR_CppToPython_QRhiSwapChain(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QRhiSwapChain *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QRhiSwapChain_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiSwapChain_SignatureStrings[] = {
    "PySide6.QtGui.QRhiSwapChain.createOrResize(self)->bool",
    "PySide6.QtGui.QRhiSwapChain.currentFrameCommandBuffer(self)->PySide6.QtGui.QRhiCommandBuffer",
    "1:PySide6.QtGui.QRhiSwapChain.currentFrameRenderTarget(self,targetBuffer:PySide6.QtGui.QRhiSwapChain.StereoTargetBuffer)->PySide6.QtGui.QRhiRenderTarget",
    "0:PySide6.QtGui.QRhiSwapChain.currentFrameRenderTarget(self)->PySide6.QtGui.QRhiRenderTarget",
    "PySide6.QtGui.QRhiSwapChain.currentPixelSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QRhiSwapChain.depthStencil(self)->PySide6.QtGui.QRhiRenderBuffer",
    "PySide6.QtGui.QRhiSwapChain.flags(self)->PySide6.QtGui.QRhiSwapChain.Flag",
    "PySide6.QtGui.QRhiSwapChain.format(self)->PySide6.QtGui.QRhiSwapChain.Format",
    "PySide6.QtGui.QRhiSwapChain.isFormatSupported(self,f:PySide6.QtGui.QRhiSwapChain.Format)->bool",
    "PySide6.QtGui.QRhiSwapChain.newCompatibleRenderPassDescriptor(self)->PySide6.QtGui.QRhiRenderPassDescriptor",
    "PySide6.QtGui.QRhiSwapChain.renderPassDescriptor(self)->PySide6.QtGui.QRhiRenderPassDescriptor",
    "PySide6.QtGui.QRhiSwapChain.resourceType(self)->PySide6.QtGui.QRhiResource.Type",
    "PySide6.QtGui.QRhiSwapChain.sampleCount(self)->int",
    "PySide6.QtGui.QRhiSwapChain.setDepthStencil(self,ds:PySide6.QtGui.QRhiRenderBuffer)",
    "PySide6.QtGui.QRhiSwapChain.setFlags(self,f:PySide6.QtGui.QRhiSwapChain.Flag)",
    "PySide6.QtGui.QRhiSwapChain.setFormat(self,f:PySide6.QtGui.QRhiSwapChain.Format)",
    "PySide6.QtGui.QRhiSwapChain.setRenderPassDescriptor(self,desc:PySide6.QtGui.QRhiRenderPassDescriptor)",
    "PySide6.QtGui.QRhiSwapChain.setSampleCount(self,samples:int)",
    "PySide6.QtGui.QRhiSwapChain.setWindow(self,window:PySide6.QtGui.QWindow)",
    "PySide6.QtGui.QRhiSwapChain.surfacePixelSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QRhiSwapChain.window(self)->PySide6.QtGui.QWindow",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiSwapChain_SignatureByteSize = 358;
static constexpr uint8_t QRhiSwapChain_SignatureBytes[358] = {
    0x78, 0xda, 0xb5, 0x94, 0xcd, 0x6e, 0x83, 0x30, 0x10, 0x84, 0xef, 0x3c, 0x49, 0x23, 0x51, 0xd4,
    0x5e, 0x7a, 0xe0, 0xd0, 0x43, 0x89, 0xd2, 0x63, 0x49, 0x40, 0xea, 0xd9, 0xc1, 0x4b, 0x62, 0xc9,
    0xd8, 0xd6, 0xda, 0x16, 0x4d, 0x9f, 0xbe, 0x0e, 0x4e, 0x43, 0x7e, 0x1a, 0x1b, 0xb5, 0xea, 0xcd,
    0x88, 0xd9, 0x6f, 0x07, 0x66, 0xa0, 0xdc, 0x55, 0x8c, 0xc2, 0x53, 0xb6, 0x34, 0xaf, 0x96, 0x65,
    0xcb, 0xd5, 0x96, 0x55, 0x3d, 0x51, 0xc5, 0x96, 0x30, 0x91, 0x35, 0x08, 0xc4, 0xc0, 0x1b, 0xae,
    0x40, 0xb3, 0x4f, 0xb8, 0xd3, 0xc0, 0xdb, 0xd9, 0xfd, 0xf3, 0x5a, 0x4a, 0x9e, 0x94, 0xa1, 0x31,
    0x8b, 0x08, 0xc2, 0x2c, 0x90, 0x74, 0x50, 0xc8, 0xae, 0x23, 0x82, 0xbe, 0xd8, 0xb6, 0x05, 0xfc,
    0x26, 0x5c, 0x0f, 0x9f, 0xc9, 0x92, 0xc7, 0x7c, 0x2a, 0x7e, 0x05, 0x82, 0x02, 0xd6, 0x04, 0x37,
    0x60, 0x06, 0x7a, 0x6a, 0x86, 0xb3, 0x07, 0x05, 0x31, 0x95, 0x01, 0x04, 0x59, 0x9f, 0xc8, 0x7f,
    0x74, 0x76, 0xba, 0x21, 0x79, 0xf8, 0xbd, 0xb1, 0x38, 0x7c, 0x02, 0xba, 0x64, 0x1f, 0xc0, 0xab,
    0x93, 0x2c, 0xc6, 0x99, 0x42, 0x22, 0x64, 0xcb, 0xfd, 0xbd, 0x20, 0x88, 0x82, 0x32, 0x5b, 0xf7,
    0xe8, 0xa2, 0x61, 0x3c, 0xe6, 0xeb, 0x90, 0x46, 0x08, 0xd7, 0x72, 0xb2, 0xd1, 0xb7, 0x39, 0xa3,
    0x70, 0xe1, 0x84, 0x61, 0x92, 0xc4, 0x8e, 0x98, 0x49, 0xa8, 0x41, 0x19, 0x84, 0x31, 0xed, 0x45,
    0x95, 0x55, 0x4a, 0xa2, 0x01, 0xea, 0xbb, 0xd1, 0xe6, 0x71, 0xee, 0x94, 0x82, 0x0b, 0xe8, 0x5d,
    0x61, 0x15, 0x31, 0x6c, 0xcd, 0x0f, 0x49, 0x97, 0x44, 0xeb, 0x39, 0xe8, 0x06, 0x99, 0x32, 0x12,
    0x63, 0x6f, 0xf6, 0x5c, 0x1d, 0xdc, 0x85, 0xff, 0x8d, 0xd7, 0xd2, 0x62, 0x03, 0xf5, 0x4e, 0x41,
    0x08, 0xeb, 0x55, 0xd9, 0x5e, 0x16, 0xe4, 0x69, 0xd2, 0x29, 0xee, 0xbe, 0x7a, 0x2b, 0x8e, 0x59,
    0x32, 0x11, 0x0e, 0x4b, 0x83, 0x99, 0x5f, 0xb6, 0x32, 0xa5, 0x3a, 0x0f, 0xd7, 0x72, 0x16, 0x63,
    0x2e, 0x8e, 0xd5, 0x8c, 0xe5, 0xee, 0x84, 0x71, 0xda, 0x58, 0xcf, 0x69, 0x35, 0x8a, 0x01, 0x6f,
    0xd6, 0x26, 0xa5, 0xee, 0x3a, 0x9f, 0x16, 0x6d, 0x74, 0x4b, 0x75, 0x11, 0x47, 0xea, 0xf3, 0xd1,
    0xb9, 0x0b, 0x25, 0x3a, 0xfc, 0xce, 0x04, 0x95, 0xbd, 0x9f, 0xeb, 0x87, 0xf3, 0xa5, 0x2d, 0xaf,
    0x88, 0x80, 0x2c, 0xb6, 0xa4, 0x81, 0xbf, 0xff, 0xba, 0xfa, 0xd1, 0xce, 0x75, 0x49, 0xbd, 0x93,
    0xe4, 0x0b, 0x37, 0x94, 0x73, 0x4a
};
#endif

PyTypeObject *init_QRhiSwapChain(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiSwapChain_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_IDX]))));

    _Sbk_QRhiSwapChain_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiSwapChain",
        "QRhiSwapChain*",
        &Sbk_QRhiSwapChain_spec,
        &Shiboken::callCppDestructor< QRhiSwapChain >,
        Sbk_QRhiSwapChain_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRhiSwapChain_TypeF(); // references _Sbk_QRhiSwapChain_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiSwapChain_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiSwapChain_SignatureBytes, QRhiSwapChain_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiSwapChain_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiSwapChain_PythonToCpp_QRhiSwapChain_PTR,
        is_QRhiSwapChain_PythonToCpp_QRhiSwapChain_PTR_Convertible,
        QRhiSwapChain_PTR_CppToPython_QRhiSwapChain);

    Shiboken::Conversions::registerConverterName(converter, "QRhiSwapChain");
    Shiboken::Conversions::registerConverterName(converter, "QRhiSwapChain*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiSwapChain&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiSwapChain).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRhiSwapChainWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRhiSwapChain_TypeF(), &Sbk_QRhiSwapChain_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRhiSwapChain_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "SurfaceHasPreMulAlpha",
        "SurfaceHasNonPreMulAlpha",
        "sRGB",
        "UsedAsTransferSource",
        "NoVSync",
        "MinimalBufferCount",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Flag_InitializerValues[] = {
        uint8_t(QRhiSwapChain::Flag::SurfaceHasPreMulAlpha),    //  0x01  1
        uint8_t(QRhiSwapChain::Flag::SurfaceHasNonPreMulAlpha), //  0x02  2
        uint8_t(QRhiSwapChain::Flag::sRGB),                     //  0x04  4
        uint8_t(QRhiSwapChain::Flag::UsedAsTransferSource),     //  0x08  8
        uint8_t(QRhiSwapChain::Flag::NoVSync),                  //  0x10  16
        uint8_t(QRhiSwapChain::Flag::MinimalBufferCount)        //  0x20  32
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiSwapChain_TypeF(),
        "2:PySide6.QtGui.QRhiSwapChain.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiSwapChain_Flag_IDX].type =
        EType;
    // Register converter for enum 'QRhiSwapChain::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiSwapChain_Flag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiSwapChain_Flag,
            is_Enum_PythonToCpp_QRhiSwapChain_Flag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiSwapChain::Flag");
        Shiboken::Conversions::registerConverterAlias(converter, "Flag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QRhiSwapChain_Flag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QRhiSwapChain_Flag,
            is_Enum_PythonToCpp_QRhiSwapChain_Flag_Convertible);
        // Register converter for flag 'QFlags<QRhiSwapChain::Flag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QRhiSwapChain::Flag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QRhiSwapChain::Flags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Flag' enum/flags.

    // Initialization of enum 'Format'.
    const char *Format_Initializer[] = {
        "SDR",
        "HDRExtendedSrgbLinear",
        "HDR10",
        "HDRExtendedDisplayP3Linear",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Format_InitializerValues[] = {
        uint8_t(QRhiSwapChain::Format::SDR),                       //  0x00  0
        uint8_t(QRhiSwapChain::Format::HDRExtendedSrgbLinear),     //  0x01  1
        uint8_t(QRhiSwapChain::Format::HDR10),                     //  0x02  2
        uint8_t(QRhiSwapChain::Format::HDRExtendedDisplayP3Linear) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiSwapChain_TypeF(),
        "2:PySide6.QtGui.QRhiSwapChain.Format",
        Format_Initializer, Format_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_Format_IDX].type = EType;
    // Register converter for enum 'QRhiSwapChain::Format'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiSwapChain_Format_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiSwapChain_Format,
            is_Enum_PythonToCpp_QRhiSwapChain_Format_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiSwapChain::Format");
        Shiboken::Conversions::registerConverterAlias(converter, "Format");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Format' enum.

    // Initialization of enum 'StereoTargetBuffer'.
    const char *StereoTargetBuffer_Initializer[] = {
        "LeftBuffer",
        "RightBuffer",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StereoTargetBuffer_InitializerValues[] = {
        uint8_t(QRhiSwapChain::StereoTargetBuffer::LeftBuffer), //  0x00  0
        uint8_t(QRhiSwapChain::StereoTargetBuffer::RightBuffer) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiSwapChain_TypeF(),
        "2:PySide6.QtGui.QRhiSwapChain.StereoTargetBuffer",
        StereoTargetBuffer_Initializer, StereoTargetBuffer_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_StereoTargetBuffer_IDX].type = EType;
    // Register converter for enum 'QRhiSwapChain::StereoTargetBuffer'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiSwapChain_StereoTargetBuffer_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiSwapChain_StereoTargetBuffer,
            is_Enum_PythonToCpp_QRhiSwapChain_StereoTargetBuffer_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiSwapChain::StereoTargetBuffer");
        Shiboken::Conversions::registerConverterAlias(converter, "StereoTargetBuffer");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StereoTargetBuffer' enum.

    qRegisterMetaType< ::QRhiSwapChain *>();
    qRegisterMetaType< ::QRhiSwapChain::Flag >("QRhiSwapChain::Flag");
    qRegisterMetaType< ::QRhiSwapChain::Format >("QRhiSwapChain::Format");
    qRegisterMetaType< ::QRhiSwapChain::StereoTargetBuffer >("QRhiSwapChain::StereoTargetBuffer");

    return pyType;
}
