// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhitexture_viewformat_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRhiTexture_ViewFormat_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRhiTexture::ViewFormat >()))
        return -1;

    ::QRhiTexture::ViewFormat *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "ViewFormat", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: ViewFormat::ViewFormat()
    // 1: ViewFormat::ViewFormat(QRhiTexture::ViewFormat)
    if (numArgs == 0) {
        overloadId = 0; // ViewFormat()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), (pyArgs[0])))) {
        overloadId = 1; // ViewFormat(QRhiTexture::ViewFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // ViewFormat()
        {

            // ViewFormat()
            cptr = new ::QRhiTexture::ViewFormat();
            break;
        }
        case 1: // ViewFormat(const QRhiTexture::ViewFormat &ViewFormat)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRhiTexture::ViewFormat cppArg0_local;
            ::QRhiTexture::ViewFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // ViewFormat(QRhiTexture::ViewFormat)
                cptr = new ::QRhiTexture::ViewFormat(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRhiTexture::ViewFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRhiTexture_ViewFormat__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRhiTexture::ViewFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiTexture_ViewFormat_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiTexture_ViewFormat_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QRhiTexture_ViewFormat__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QRhiTexture_ViewFormat_get_format(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture::ViewFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiTexture::Format cppOut_local = cppSelf->format;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiTexture_ViewFormat_set_format(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiTexture::ViewFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("format");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("format", "Format");
        return -1;
    }

    auto cppOut_local = cppSelf->format;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->format = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiTexture_ViewFormat_get_srgb(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture::ViewFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    bool cppOut_local = cppSelf->srgb;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiTexture_ViewFormat_set_srgb(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiTexture::ViewFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("srgb");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("srgb", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->srgb;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->srgb = cppOut_local;

    return 0;
}

// Getters and Setters for ViewFormat
static PyGetSetDef Sbk_QRhiTexture_ViewFormat_getsetlist[] = {
    {const_cast<char *>("format"), Sbk_QRhiTexture_ViewFormat_get_format, Sbk_QRhiTexture_ViewFormat_set_format, nullptr, nullptr},
    {const_cast<char *>("srgb"), Sbk_QRhiTexture_ViewFormat_get_srgb, Sbk_QRhiTexture_ViewFormat_set_srgb, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiTexture_ViewFormat_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiTexture_ViewFormat_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiTexture_ViewFormat_Type = nullptr;
static PyTypeObject *Sbk_QRhiTexture_ViewFormat_TypeF(void)
{
    return _Sbk_QRhiTexture_ViewFormat_Type;
}

static PyType_Slot Sbk_QRhiTexture_ViewFormat_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiTexture_ViewFormat_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiTexture_ViewFormat_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiTexture_ViewFormat_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiTexture_ViewFormat_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRhiTexture_ViewFormat_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiTexture_ViewFormat_spec = {
    "2:PySide6.QtGui.QRhiTexture.ViewFormat",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiTexture_ViewFormat_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void ViewFormat_PythonToCpp_ViewFormat_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiTexture_ViewFormat_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_ViewFormat_PythonToCpp_ViewFormat_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiTexture_ViewFormat_TypeF()))
        return ViewFormat_PythonToCpp_ViewFormat_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *ViewFormat_PTR_CppToPython_ViewFormat(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QRhiTexture_ViewFormat_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *ViewFormat_COPY_CppToPython_ViewFormat(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QRhiTexture::ViewFormat *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QRhiTexture_ViewFormat_TypeF(), new ::QRhiTexture::ViewFormat(*source), true, true);
}

// Python to C++ copy conversion.
static void ViewFormat_PythonToCpp_ViewFormat_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRhiTexture::ViewFormat *>(cppOut) = *reinterpret_cast< ::QRhiTexture::ViewFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_ViewFormat_PythonToCpp_ViewFormat_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiTexture_ViewFormat_TypeF()))
        return ViewFormat_PythonToCpp_ViewFormat_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiTexture_ViewFormat_SignatureStrings[] = {
    "1:PySide6.QtGui.QRhiTexture.ViewFormat(self)",
    "0:PySide6.QtGui.QRhiTexture.ViewFormat(self,ViewFormat:PySide6.QtGui.QRhiTexture.ViewFormat)",
    "PySide6.QtGui.QRhiTexture.ViewFormat.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiTexture_ViewFormat_SignatureByteSize = 90;
static constexpr uint8_t QRhiTexture_ViewFormat_SignatureBytes[90] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f,
    0xcd, 0xd4, 0x0b, 0x0c, 0xca, 0xc8, 0x0c, 0x49, 0xad, 0x28, 0x29, 0x2d, 0x4a, 0xd5, 0x0b, 0xcb,
    0x4c, 0x2d, 0x77, 0xcb, 0x2f, 0xca, 0x4d, 0x2c, 0xd1, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32,
    0x20, 0x5e, 0xb1, 0x0e, 0x82, 0x4f, 0x94, 0x26, 0x4d, 0x2e, 0x62, 0x54, 0xe9, 0xc5, 0xc7, 0x27,
    0xe7, 0x17, 0x54, 0xc6, 0xc7, 0x43, 0x1c, 0xa4, 0x6b, 0x57, 0x52, 0x59, 0x90, 0x99, 0x97, 0xae,
    0x17, 0x0c, 0xe4, 0x71, 0x01, 0x00, 0xe8, 0x78, 0x48, 0xf6
};
#endif

PyTypeObject *init_QRhiTexture_ViewFormat(PyObject *enclosingClass)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiTexture_ViewFormat_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRhiTexture_ViewFormat_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "ViewFormat",
        "QRhiTexture::ViewFormat",
        &Sbk_QRhiTexture_ViewFormat_spec,
        &Shiboken::callCppDestructor< ::QRhiTexture::ViewFormat >,
        Sbk_QRhiTexture_ViewFormat_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QRhiTexture_ViewFormat_TypeF(); // references _Sbk_QRhiTexture_ViewFormat_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiTexture_ViewFormat_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiTexture_ViewFormat_SignatureBytes, QRhiTexture_ViewFormat_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiTexture_ViewFormat_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        ViewFormat_PythonToCpp_ViewFormat_PTR,
        is_ViewFormat_PythonToCpp_ViewFormat_PTR_Convertible,
        ViewFormat_PTR_CppToPython_ViewFormat,
        ViewFormat_COPY_CppToPython_ViewFormat);

    Shiboken::Conversions::registerConverterName(converter, "QRhiTexture::ViewFormat");
    Shiboken::Conversions::registerConverterName(converter, "QRhiTexture::ViewFormat*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiTexture::ViewFormat&");
    Shiboken::Conversions::registerConverterAlias(converter, "ViewFormat");
    Shiboken::Conversions::registerConverterAlias(converter, "ViewFormat*");
    Shiboken::Conversions::registerConverterAlias(converter, "ViewFormat&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiTexture::ViewFormat).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        ViewFormat_PythonToCpp_ViewFormat_COPY,
        is_ViewFormat_PythonToCpp_ViewFormat_COPY_Convertible);

    qRegisterMetaType< ::QRhiTexture::ViewFormat >("ViewFormat");
    qRegisterMetaType< ::QRhiTexture::ViewFormat >("QRhiTexture::ViewFormat");

    return pyType;
}
