// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhitexture_wrapper.h"

// inner classes
#include "qrhitexture_viewformat_wrapper.h"

// Argument includes
#include <qbytearray.h>
#include <qsize.h>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRhiTextureWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

bool QRhiTextureWrapper::create()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTexture.create");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "create";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTexture.create");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiTexture", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiTexture", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRhiTextureWrapper::destroy()
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTexture.destroy");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "destroy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiTexture.destroy");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiTexture", funcName);
        return;
    }
}

::QRhiResource::Type QRhiTextureWrapper::resourceType() const
{
    if (m_PyMethodCache[2])
        return this->::QRhiTexture::resourceType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QRhiResource::Buffer;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resourceType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QRhiTexture::resourceType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiTexture", funcName);
        return QRhiResource::Buffer;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiTexture", funcName, Shiboken::SbkType< QRhiResource::Type >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QRhiResource::Buffer;
    }
    ::QRhiResource::Type cppResult{QRhiResource::Buffer};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRhiTextureWrapper::setNativeLayout(int layout)
{
    if (m_PyMethodCache[3]) {
        return this->::QRhiTexture::setNativeLayout(layout);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setNativeLayout";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QRhiTexture::setNativeLayout(layout);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &layout)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        layout
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiTexture", funcName);
        return;
    }
}

QRhiTextureWrapper::~QRhiTextureWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QRhiTextureFunc_arrayRangeLength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // arrayRangeLength()const
        int cppResult = const_cast<const ::QRhiTexture *>(cppSelf)->arrayRangeLength();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureFunc_arrayRangeStart(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // arrayRangeStart()const
        int cppResult = const_cast<const ::QRhiTexture *>(cppSelf)->arrayRangeStart();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureFunc_arraySize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // arraySize()const
        int cppResult = const_cast<const ::QRhiTexture *>(cppSelf)->arraySize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureFunc_create(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // create()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QRhiTexture.create");
            return {};
        }
        bool cppResult = cppSelf->create();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureFunc_depth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // depth()const
        int cppResult = const_cast<const ::QRhiTexture *>(cppSelf)->depth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QRhiTexture::Flag> cppResult = const_cast<const ::QRhiTexture *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTexture_Flag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // format()const
        QRhiTexture::Format cppResult = const_cast<const ::QRhiTexture *>(cppSelf)->format();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureFunc_pixelSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pixelSize()const
        QSize cppResult = const_cast<const ::QRhiTexture *>(cppSelf)->pixelSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureFunc_readViewFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readViewFormat()const
        QRhiTexture::ViewFormat cppResult = const_cast<const ::QRhiTexture *>(cppSelf)->readViewFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureFunc_resourceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resourceType()const
        QRhiResource::Type cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QRhiTexture *>(cppSelf)->::QRhiTexture::resourceType()
            : const_cast<const ::QRhiTexture *>(cppSelf)->resourceType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureFunc_sampleCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sampleCount()const
        int cppResult = const_cast<const ::QRhiTexture *>(cppSelf)->sampleCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiTextureFunc_setArrayRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setArrayRange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhiTexture::setArrayRange(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setArrayRange(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setArrayRange", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setArrayRange(int,int)
            cppSelf->setArrayRange(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiTextureFunc_setArraySize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTexture::setArraySize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setArraySize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setArraySize", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setArraySize(int)
            cppSelf->setArraySize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiTextureFunc_setDepth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTexture::setDepth(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setDepth(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDepth", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepth(int)
            cppSelf->setDepth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiTextureFunc_setFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTexture::setFlags(QFlags<QRhiTexture::Flag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTexture_Flag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setFlags(QFlags<QRhiTexture::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlags", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]);

    // Call function/method
    {
        ::QFlags<QRhiTexture::Flag> cppArg0 = QFlags<QRhiTexture::Flag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlags(QFlags<QRhiTexture::Flag>)
            cppSelf->setFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiTextureFunc_setFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTexture::setFormat(QRhiTexture::Format)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFormat(QRhiTexture::Format)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]);

    // Call function/method
    {
        ::QRhiTexture::Format cppArg0{QRhiTexture::UnknownFormat};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFormat(QRhiTexture::Format)
            cppSelf->setFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiTextureFunc_setNativeLayout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTexture::setNativeLayout(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setNativeLayout(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNativeLayout", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNativeLayout(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QRhiTexture::setNativeLayout(cppArg0)
                : cppSelf->setNativeLayout(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiTextureFunc_setPixelSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTexture::setPixelSize(QSize)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
        overloadId = 0; // setPixelSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPixelSize", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSize cppArg0_local;
        ::QSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPixelSize(QSize)
            cppSelf->setPixelSize(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiTextureFunc_setReadViewFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTexture::setReadViewFormat(QRhiTexture::ViewFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), (pyArg)))) {
        overloadId = 0; // setReadViewFormat(QRhiTexture::ViewFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReadViewFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiTexture::ViewFormat cppArg0_local;
        ::QRhiTexture::ViewFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setReadViewFormat(QRhiTexture::ViewFormat)
            cppSelf->setReadViewFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiTextureFunc_setSampleCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTexture::setSampleCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSampleCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSampleCount", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSampleCount(int)
            cppSelf->setSampleCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiTextureFunc_setWriteViewFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiTexture::setWriteViewFormat(QRhiTexture::ViewFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), (pyArg)))) {
        overloadId = 0; // setWriteViewFormat(QRhiTexture::ViewFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWriteViewFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiTexture::ViewFormat cppArg0_local;
        ::QRhiTexture::ViewFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setWriteViewFormat(QRhiTexture::ViewFormat)
            cppSelf->setWriteViewFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiTextureFunc_writeViewFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // writeViewFormat()const
        QRhiTexture::ViewFormat cppResult = const_cast<const ::QRhiTexture *>(cppSelf)->writeViewFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiTexture_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRhiTexture_EnumFlagInfo[] = {
    "Flag:Flag:Flags",
    "Format:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiTexture_methods[] = {
    {"arrayRangeLength", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_arrayRangeLength), METH_NOARGS, nullptr},
    {"arrayRangeStart", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_arrayRangeStart), METH_NOARGS, nullptr},
    {"arraySize", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_arraySize), METH_NOARGS, nullptr},
    {"create", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_create), METH_NOARGS, nullptr},
    {"depth", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_depth), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_flags), METH_NOARGS, nullptr},
    {"format", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_format), METH_NOARGS, nullptr},
    {"pixelSize", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_pixelSize), METH_NOARGS, nullptr},
    {"readViewFormat", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_readViewFormat), METH_NOARGS, nullptr},
    {"resourceType", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_resourceType), METH_NOARGS, nullptr},
    {"sampleCount", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_sampleCount), METH_NOARGS, nullptr},
    {"setArrayRange", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_setArrayRange), METH_VARARGS, nullptr},
    {"setArraySize", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_setArraySize), METH_O, nullptr},
    {"setDepth", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_setDepth), METH_O, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_setFlags), METH_O, nullptr},
    {"setFormat", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_setFormat), METH_O, nullptr},
    {"setNativeLayout", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_setNativeLayout), METH_O, nullptr},
    {"setPixelSize", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_setPixelSize), METH_O, nullptr},
    {"setReadViewFormat", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_setReadViewFormat), METH_O, nullptr},
    {"setSampleCount", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_setSampleCount), METH_O, nullptr},
    {"setWriteViewFormat", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_setWriteViewFormat), METH_O, nullptr},
    {"writeViewFormat", reinterpret_cast<PyCFunction>(Sbk_QRhiTextureFunc_writeViewFormat), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRhiTexture_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRhiTextureWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QRhiTexture_get_m_format(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiTexture::Format cppOut_local = cppSelf->m_format;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiTexture_set_m_format(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_format");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_format", "Format");
        return -1;
    }

    auto cppOut_local = cppSelf->m_format;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_format = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiTexture_get_m_pixelSize(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->m_pixelSize)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->m_pixelSize))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->m_pixelSize)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &(cppSelf->m_pixelSize), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QRhiTexture_set_m_pixelSize(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_pixelSize");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_pixelSize", "QSize");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_pixelSize;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiTexture_get_m_depth(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->m_depth;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiTexture_set_m_depth(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_depth");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_depth", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->m_depth;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_depth = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiTexture_get_m_arraySize(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->m_arraySize;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiTexture_set_m_arraySize(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_arraySize");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_arraySize", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->m_arraySize;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_arraySize = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiTexture_get_m_sampleCount(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->m_sampleCount;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiTexture_set_m_sampleCount(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_sampleCount");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_sampleCount", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->m_sampleCount;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_sampleCount = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiTexture_get_m_flags(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTexture_Flag_IDX])))->flagsConverter, &cppSelf->m_flags);
    return pyOut;
}
static int Sbk_QRhiTexture_set_m_flags(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_flags");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTexture_Flag_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_flags", "Flags");
        return -1;
    }

    auto cppOut_local = cppSelf->m_flags;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_flags = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiTexture_get_m_arrayRangeStart(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->m_arrayRangeStart;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiTexture_set_m_arrayRangeStart(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_arrayRangeStart");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_arrayRangeStart", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->m_arrayRangeStart;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_arrayRangeStart = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiTexture_get_m_arrayRangeLength(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->m_arrayRangeLength;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiTexture_set_m_arrayRangeLength(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_arrayRangeLength");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_arrayRangeLength", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->m_arrayRangeLength;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_arrayRangeLength = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiTexture_get_m_readViewFormat(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->m_readViewFormat)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->m_readViewFormat))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->m_readViewFormat)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), &(cppSelf->m_readViewFormat), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QRhiTexture_set_m_readViewFormat(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_readViewFormat");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_readViewFormat", "ViewFormat");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_readViewFormat;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiTexture_get_m_writeViewFormat(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->m_writeViewFormat)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->m_writeViewFormat))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->m_writeViewFormat)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), &(cppSelf->m_writeViewFormat), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QRhiTexture_set_m_writeViewFormat(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_writeViewFormat");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_ViewFormat_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_writeViewFormat", "ViewFormat");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_writeViewFormat;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

// Getters and Setters for QRhiTexture
static PyGetSetDef Sbk_QRhiTexture_getsetlist[] = {
    {const_cast<char *>("m_format"), Sbk_QRhiTexture_get_m_format, Sbk_QRhiTexture_set_m_format, nullptr, nullptr},
    {const_cast<char *>("m_pixelSize"), Sbk_QRhiTexture_get_m_pixelSize, Sbk_QRhiTexture_set_m_pixelSize, nullptr, nullptr},
    {const_cast<char *>("m_depth"), Sbk_QRhiTexture_get_m_depth, Sbk_QRhiTexture_set_m_depth, nullptr, nullptr},
    {const_cast<char *>("m_arraySize"), Sbk_QRhiTexture_get_m_arraySize, Sbk_QRhiTexture_set_m_arraySize, nullptr, nullptr},
    {const_cast<char *>("m_sampleCount"), Sbk_QRhiTexture_get_m_sampleCount, Sbk_QRhiTexture_set_m_sampleCount, nullptr, nullptr},
    {const_cast<char *>("m_flags"), Sbk_QRhiTexture_get_m_flags, Sbk_QRhiTexture_set_m_flags, nullptr, nullptr},
    {const_cast<char *>("m_arrayRangeStart"), Sbk_QRhiTexture_get_m_arrayRangeStart, Sbk_QRhiTexture_set_m_arrayRangeStart, nullptr, nullptr},
    {const_cast<char *>("m_arrayRangeLength"), Sbk_QRhiTexture_get_m_arrayRangeLength, Sbk_QRhiTexture_set_m_arrayRangeLength, nullptr, nullptr},
    {const_cast<char *>("m_readViewFormat"), Sbk_QRhiTexture_get_m_readViewFormat, Sbk_QRhiTexture_set_m_readViewFormat, nullptr, nullptr},
    {const_cast<char *>("m_writeViewFormat"), Sbk_QRhiTexture_get_m_writeViewFormat, Sbk_QRhiTexture_set_m_writeViewFormat, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiTexture_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiTexture_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiTexture_Type = nullptr;
static PyTypeObject *Sbk_QRhiTexture_TypeF(void)
{
    return _Sbk_QRhiTexture_Type;
}

static PyType_Slot Sbk_QRhiTexture_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRhiTexture_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiTexture_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiTexture_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiTexture_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiTexture_getsetlist)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiTexture_spec = {
    "2:PySide6.QtGui.QRhiTexture",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiTexture_slots
};

} //extern "C"

static void *Sbk_QRhiTexture_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QRhiResource >())
        return dynamic_cast< ::QRhiTexture *>(reinterpret_cast< ::QRhiResource *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QRhiTexture_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiTexture::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiTexture::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiTexture_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Flag_IDX])))
        return Enum_PythonToCpp_QRhiTexture_Flag;
    return {};
}

static PyObject *QRhiTexture_Flag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiTexture::Flag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiTexture::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Flag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QRhiTexture_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QRhiTexture::Flag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QRhiTexture::Flag> *>(cppOut) = value;

}

static PyObject *QRhiTexture_Flag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QRhiTexture::Flag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Flag_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QRhiTexture_Format(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiTexture::Format>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiTexture::Format *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiTexture_Format_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))
        return Enum_PythonToCpp_QRhiTexture_Format;
    return {};
}

static PyObject *QRhiTexture_Format_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiTexture::Format>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiTexture::Format *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiTexture_PythonToCpp_QRhiTexture_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiTexture_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiTexture_PythonToCpp_QRhiTexture_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiTexture_TypeF()))
        return QRhiTexture_PythonToCpp_QRhiTexture_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiTexture_PTR_CppToPython_QRhiTexture(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QRhiTexture *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QRhiTexture_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiTexture_SignatureStrings[] = {
    "PySide6.QtGui.QRhiTexture.arrayRangeLength(self)->int",
    "PySide6.QtGui.QRhiTexture.arrayRangeStart(self)->int",
    "PySide6.QtGui.QRhiTexture.arraySize(self)->int",
    "PySide6.QtGui.QRhiTexture.create(self)->bool",
    "PySide6.QtGui.QRhiTexture.depth(self)->int",
    "PySide6.QtGui.QRhiTexture.flags(self)->PySide6.QtGui.QRhiTexture.Flag",
    "PySide6.QtGui.QRhiTexture.format(self)->PySide6.QtGui.QRhiTexture.Format",
    "PySide6.QtGui.QRhiTexture.pixelSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QRhiTexture.readViewFormat(self)->PySide6.QtGui.QRhiTexture.ViewFormat",
    "PySide6.QtGui.QRhiTexture.resourceType(self)->PySide6.QtGui.QRhiResource.Type",
    "PySide6.QtGui.QRhiTexture.sampleCount(self)->int",
    "PySide6.QtGui.QRhiTexture.setArrayRange(self,startIndex:int,count:int)",
    "PySide6.QtGui.QRhiTexture.setArraySize(self,arraySize:int)",
    "PySide6.QtGui.QRhiTexture.setDepth(self,depth:int)",
    "PySide6.QtGui.QRhiTexture.setFlags(self,f:PySide6.QtGui.QRhiTexture.Flag)",
    "PySide6.QtGui.QRhiTexture.setFormat(self,fmt:PySide6.QtGui.QRhiTexture.Format)",
    "PySide6.QtGui.QRhiTexture.setNativeLayout(self,layout:int)",
    "PySide6.QtGui.QRhiTexture.setPixelSize(self,sz:PySide6.QtCore.QSize)",
    "PySide6.QtGui.QRhiTexture.setReadViewFormat(self,fmt:PySide6.QtGui.QRhiTexture.ViewFormat)",
    "PySide6.QtGui.QRhiTexture.setSampleCount(self,s:int)",
    "PySide6.QtGui.QRhiTexture.setWriteViewFormat(self,fmt:PySide6.QtGui.QRhiTexture.ViewFormat)",
    "PySide6.QtGui.QRhiTexture.writeViewFormat(self)->PySide6.QtGui.QRhiTexture.ViewFormat",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiTexture_SignatureByteSize = 300;
static constexpr uint8_t QRhiTexture_SignatureBytes[300] = {
    0x78, 0xda, 0xb5, 0x93, 0xcb, 0x6e, 0x83, 0x30, 0x10, 0x45, 0xf7, 0xfd, 0x92, 0x46, 0x72, 0x59,
    0x76, 0xc1, 0xa2, 0x52, 0x94, 0x8a, 0xaa, 0x52, 0x54, 0xf1, 0x88, 0xda, 0xb5, 0x0b, 0x03, 0xb1,
    0x64, 0x30, 0xb2, 0x87, 0x04, 0xf2, 0xf5, 0x05, 0x94, 0x9a, 0x3e, 0x12, 0x7b, 0xba, 0xe8, 0xce,
    0x92, 0xef, 0x3d, 0x1a, 0x0f, 0x87, 0x78, 0xc8, 0x44, 0x01, 0xf7, 0x41, 0x82, 0x4f, 0x9d, 0x08,
    0x92, 0x74, 0x2f, 0x76, 0xd0, 0x63, 0xa7, 0x21, 0xe0, 0x5a, 0xf3, 0x21, 0xe5, 0x4d, 0x05, 0x5b,
    0x68, 0x2a, 0xdc, 0xdf, 0x1a, 0x90, 0xe5, 0xea, 0xee, 0x41, 0x34, 0x78, 0x13, 0x13, 0x5a, 0x19,
    0x72, 0x8d, 0x7f, 0x28, 0x65, 0xe2, 0x04, 0xb4, 0x78, 0xae, 0x81, 0xa3, 0xcd, 0xbe, 0x2b, 0x25,
    0x1d, 0xe1, 0x02, 0x5a, 0xea, 0xec, 0xa5, 0xe4, 0x95, 0xf9, 0x8c, 0x5e, 0x8f, 0x45, 0x63, 0xcc,
    0x45, 0x51, 0xba, 0xe6, 0x48, 0xc0, 0xcc, 0x39, 0x07, 0xa8, 0x15, 0x3d, 0xc8, 0xaf, 0x5b, 0x59,
    0xa2, 0x1b, 0x35, 0xde, 0x27, 0xd3, 0x9d, 0xa3, 0x3f, 0x6e, 0xa9, 0x78, 0x15, 0x70, 0x8c, 0x88,
    0x03, 0x2d, 0x59, 0x27, 0xd4, 0xa8, 0x4e, 0xe7, 0xb0, 0x1b, 0x5a, 0xb8, 0x8e, 0x4c, 0xcf, 0xa9,
    0x60, 0x8a, 0x39, 0x68, 0x86, 0xd7, 0xad, 0x84, 0x8d, 0xea, 0x1a, 0xa2, 0x29, 0x06, 0x70, 0x6d,
    0x0d, 0x9b, 0x2b, 0xcc, 0x4c, 0x9e, 0x3d, 0x37, 0x05, 0xf4, 0xe1, 0xd8, 0x65, 0xf9, 0x04, 0x9b,
    0x4e, 0x2b, 0x02, 0xc6, 0x6e, 0x97, 0x59, 0x05, 0x09, 0xd5, 0x47, 0xab, 0x14, 0x9b, 0xed, 0x22,
    0x54, 0x22, 0xab, 0x16, 0x2b, 0x43, 0xb7, 0x5a, 0x3e, 0xd2, 0xf2, 0x35, 0x59, 0x59, 0x63, 0xe8,
    0x13, 0xcc, 0x83, 0x7b, 0xe1, 0x28, 0x0e, 0xb0, 0xe5, 0x83, 0xea, 0xce, 0x50, 0x39, 0x9f, 0x09,
    0x6f, 0x8a, 0xbf, 0xf9, 0xc9, 0xcc, 0x29, 0xbc, 0x24, 0xa8, 0x07, 0x92, 0xfe, 0x96, 0xd4, 0xf3,
    0xac, 0x25, 0xed, 0x41, 0x67, 0x3f, 0xe4, 0x62, 0x86, 0xf0, 0xa8, 0x37, 0x2d, 0x10, 0xfe, 0x63,
    0xa0, 0xe3, 0x05, 0x30, 0xf5, 0x77, 0xfc, 0x00, 0x00, 0xf9, 0x0a, 0x3c
};
#endif

PyTypeObject *init_QRhiTexture(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiTexture_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_IDX]))));

    _Sbk_QRhiTexture_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiTexture",
        "QRhiTexture*",
        &Sbk_QRhiTexture_spec,
        &Shiboken::callCppDestructor< QRhiTexture >,
        Sbk_QRhiTexture_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRhiTexture_TypeF(); // references _Sbk_QRhiTexture_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiTexture_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiTexture_SignatureBytes, QRhiTexture_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiTexture_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiTexture_PythonToCpp_QRhiTexture_PTR,
        is_QRhiTexture_PythonToCpp_QRhiTexture_PTR_Convertible,
        QRhiTexture_PTR_CppToPython_QRhiTexture);

    Shiboken::Conversions::registerConverterName(converter, "QRhiTexture");
    Shiboken::Conversions::registerConverterName(converter, "QRhiTexture*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiTexture&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiTexture).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRhiTextureWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRhiTexture_TypeF(), &Sbk_QRhiTexture_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRhiTexture_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "RenderTarget",
        "CubeMap",
        "MipMapped",
        "sRGB",
        "UsedAsTransferSource",
        "UsedWithGenerateMips",
        "UsedWithLoadStore",
        "UsedAsCompressedAtlas",
        "ExternalOES",
        "ThreeDimensional",
        "TextureRectangleGL",
        "TextureArray",
        "OneDimensional",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Flag_InitializerValues[] = {
        uint16_t(QRhiTexture::Flag::RenderTarget),          //  0x0001  1
        uint16_t(QRhiTexture::Flag::CubeMap),               //  0x0004  4
        uint16_t(QRhiTexture::Flag::MipMapped),             //  0x0008  8
        uint16_t(QRhiTexture::Flag::sRGB),                  //  0x0010  16
        uint16_t(QRhiTexture::Flag::UsedAsTransferSource),  //  0x0020  32
        uint16_t(QRhiTexture::Flag::UsedWithGenerateMips),  //  0x0040  64
        uint16_t(QRhiTexture::Flag::UsedWithLoadStore),     //  0x0080  128
        uint16_t(QRhiTexture::Flag::UsedAsCompressedAtlas), //  0x0100  256
        uint16_t(QRhiTexture::Flag::ExternalOES),           //  0x0200  512
        uint16_t(QRhiTexture::Flag::ThreeDimensional),      //  0x0400  1024
        uint16_t(QRhiTexture::Flag::TextureRectangleGL),    //  0x0800  2048
        uint16_t(QRhiTexture::Flag::TextureArray),          //  0x1000  4096
        uint16_t(QRhiTexture::Flag::OneDimensional)         //  0x2000  8192
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiTexture_TypeF(),
        "2:PySide6.QtGui.QRhiTexture.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTexture_Flag_IDX].type =
        EType;
    // Register converter for enum 'QRhiTexture::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiTexture_Flag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiTexture_Flag,
            is_Enum_PythonToCpp_QRhiTexture_Flag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiTexture::Flag");
        Shiboken::Conversions::registerConverterAlias(converter, "Flag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QRhiTexture_Flag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QRhiTexture_Flag,
            is_Enum_PythonToCpp_QRhiTexture_Flag_Convertible);
        // Register converter for flag 'QFlags<QRhiTexture::Flag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QRhiTexture::Flag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QRhiTexture::Flags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Flag' enum/flags.

    // Initialization of enum 'Format'.
    const char *Format_Initializer[] = {
        "UnknownFormat",
        "RGBA8",
        "BGRA8",
        "R8",
        "RG8",
        "R16",
        "RG16",
        "RED_OR_ALPHA8",
        "RGBA16F",
        "RGBA32F",
        "R16F",
        "R32F",
        "RGB10A2",
        "D16",
        "D24",
        "D24S8",
        "D32F",
        "BC1",
        "BC2",
        "BC3",
        "BC4",
        "BC5",
        "BC6H",
        "BC7",
        "ETC2_RGB8",
        "ETC2_RGB8A1",
        "ETC2_RGBA8",
        "ASTC_4x4",
        "ASTC_5x4",
        "ASTC_5x5",
        "ASTC_6x5",
        "ASTC_6x6",
        "ASTC_8x5",
        "ASTC_8x6",
        "ASTC_8x8",
        "ASTC_10x5",
        "ASTC_10x6",
        "ASTC_10x8",
        "ASTC_10x10",
        "ASTC_12x10",
        "ASTC_12x12",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Format_InitializerValues[] = {
        uint8_t(QRhiTexture::Format::UnknownFormat), //  0x00  0
        uint8_t(QRhiTexture::Format::RGBA8),         //  0x01  1
        uint8_t(QRhiTexture::Format::BGRA8),         //  0x02  2
        uint8_t(QRhiTexture::Format::R8),            //  0x03  3
        uint8_t(QRhiTexture::Format::RG8),           //  0x04  4
        uint8_t(QRhiTexture::Format::R16),           //  0x05  5
        uint8_t(QRhiTexture::Format::RG16),          //  0x06  6
        uint8_t(QRhiTexture::Format::RED_OR_ALPHA8), //  0x07  7
        uint8_t(QRhiTexture::Format::RGBA16F),       //  0x08  8
        uint8_t(QRhiTexture::Format::RGBA32F),       //  0x09  9
        uint8_t(QRhiTexture::Format::R16F),          //  0x0a  10
        uint8_t(QRhiTexture::Format::R32F),          //  0x0b  11
        uint8_t(QRhiTexture::Format::RGB10A2),       //  0x0c  12
        uint8_t(QRhiTexture::Format::D16),           //  0x0d  13
        uint8_t(QRhiTexture::Format::D24),           //  0x0e  14
        uint8_t(QRhiTexture::Format::D24S8),         //  0x0f  15
        uint8_t(QRhiTexture::Format::D32F),          //  0x10  16
        uint8_t(QRhiTexture::Format::BC1),           //  0x11  17
        uint8_t(QRhiTexture::Format::BC2),           //  0x12  18
        uint8_t(QRhiTexture::Format::BC3),           //  0x13  19
        uint8_t(QRhiTexture::Format::BC4),           //  0x14  20
        uint8_t(QRhiTexture::Format::BC5),           //  0x15  21
        uint8_t(QRhiTexture::Format::BC6H),          //  0x16  22
        uint8_t(QRhiTexture::Format::BC7),           //  0x17  23
        uint8_t(QRhiTexture::Format::ETC2_RGB8),     //  0x18  24
        uint8_t(QRhiTexture::Format::ETC2_RGB8A1),   //  0x19  25
        uint8_t(QRhiTexture::Format::ETC2_RGBA8),    //  0x1a  26
        uint8_t(QRhiTexture::Format::ASTC_4x4),      //  0x1b  27
        uint8_t(QRhiTexture::Format::ASTC_5x4),      //  0x1c  28
        uint8_t(QRhiTexture::Format::ASTC_5x5),      //  0x1d  29
        uint8_t(QRhiTexture::Format::ASTC_6x5),      //  0x1e  30
        uint8_t(QRhiTexture::Format::ASTC_6x6),      //  0x1f  31
        uint8_t(QRhiTexture::Format::ASTC_8x5),      //  0x20  32
        uint8_t(QRhiTexture::Format::ASTC_8x6),      //  0x21  33
        uint8_t(QRhiTexture::Format::ASTC_8x8),      //  0x22  34
        uint8_t(QRhiTexture::Format::ASTC_10x5),     //  0x23  35
        uint8_t(QRhiTexture::Format::ASTC_10x6),     //  0x24  36
        uint8_t(QRhiTexture::Format::ASTC_10x8),     //  0x25  37
        uint8_t(QRhiTexture::Format::ASTC_10x10),    //  0x26  38
        uint8_t(QRhiTexture::Format::ASTC_12x10),    //  0x27  39
        uint8_t(QRhiTexture::Format::ASTC_12x12)     //  0x28  40
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiTexture_TypeF(),
        "2:PySide6.QtGui.QRhiTexture.Format",
        Format_Initializer, Format_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX].type = EType;
    // Register converter for enum 'QRhiTexture::Format'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiTexture_Format_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiTexture_Format,
            is_Enum_PythonToCpp_QRhiTexture_Format_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiTexture::Format");
        Shiboken::Conversions::registerConverterAlias(converter, "Format");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Format' enum.

    qRegisterMetaType< ::QRhiTexture *>();
    qRegisterMetaType< ::QRhiTexture::Flag >("QRhiTexture::Flag");
    qRegisterMetaType< ::QRhiTexture::Format >("QRhiTexture::Format");

    return pyType;
}
